# Names in __all__ with no definition:
#   Qt3DAnimation
#   Qt3DCore
#   Qt3DExtras
#   Qt3DInput
#   Qt3DLogic
#   Qt3DRender
#   QtCharts
#   QtConcurrent
#   QtCore
#   QtDataVisualization
#   QtGui
#   QtHelp
#   QtLocation
#   QtMacExtras
#   QtMultimedia
#   QtMultimediaWidgets
#   QtNetwork
#   QtOpenGL
#   QtOpenGLFunctions
#   QtPositioning
#   QtPrintSupport
#   QtQml
#   QtQuick
#   QtQuickControls2
#   QtQuickWidgets
#   QtRemoteObjects
#   QtScript
#   QtScriptTools
#   QtScxml
#   QtSensors
#   QtSerialPort
#   QtSql
#   QtSvg
#   QtTest
#   QtTextToSpeech
#   QtUiTools
#   QtWebChannel
#   QtWebEngine
#   QtWebEngineCore
#   QtWebEngineWidgets
#   QtWebSockets
#   QtWidgets
#   QtX11Extras
#   QtXml
#   QtXmlPatterns
__version__: str
__version_info__: tuple[int, int, float, str, str]
