from _typeshed import Incomplete

built_modules: Incomplete
shiboken_library_soversion: Incomplete
pyside_library_soversion: Incomplete
version: str
version_info: Incomplete
__build_date__: str
__setup_py_package_version__: str
