import PySide2.QtCore
import PySide2.QtGui
import _typeshed
import collections.abc
import datetime
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class QAbstractButton(QWidget):
    clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    released: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    toggled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def animateClick(self, msec: int = ...) -> None: ...
    def autoExclusive(self) -> bool: ...
    def autoRepeat(self) -> bool: ...
    def autoRepeatDelay(self) -> int: ...
    def autoRepeatInterval(self) -> int: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def checkStateSet(self) -> None: ...
    def click(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def group(self) -> QButtonGroup: ...
    def hitButton(self, pos: PySide2.QtCore.QPoint) -> bool: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def isCheckable(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isDown(self) -> bool: ...
    def keyPressEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def mouseMoveEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def nextCheckState(self) -> None: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def setAutoExclusive(self, arg__1: bool) -> None: ...
    def setAutoRepeat(self, arg__1: bool) -> None: ...
    def setAutoRepeatDelay(self, arg__1: int) -> None: ...
    def setAutoRepeatInterval(self, arg__1: int) -> None: ...
    def setCheckable(self, arg__1: bool) -> None: ...
    def setChecked(self, arg__1: bool) -> None: ...
    def setDown(self, arg__1: bool) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setIconSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setShortcut(self, key: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    def setText(self, text: str) -> None: ...
    def shortcut(self) -> PySide2.QtGui.QKeySequence: ...
    def text(self) -> str: ...
    def timerEvent(self, e: PySide2.QtCore.QTimerEvent) -> None: ...
    def toggle(self) -> None: ...

class QAbstractGraphicsShapeItem(QGraphicsItem):
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def brush(self) -> PySide2.QtGui.QBrush: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def pen(self) -> PySide2.QtGui.QPen: ...
    def setBrush(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setPen(self, pen: PySide2.QtGui.QPen) -> None: ...

class QAbstractItemDelegate(PySide2.QtCore.QObject):
    class EndEditHint:
        EditNextItem: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
        EditPreviousItem: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
        NoHint: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
        RevertModelCache: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
        SubmitModelCache: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemDelegate.EndEditHint: ...
    EditNextItem: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
    EditPreviousItem: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
    NoHint: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
    RevertModelCache: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
    SubmitModelCache: typing.ClassVar[QAbstractItemDelegate.EndEditHint] = ...
    closeEditor: typing.ClassVar[PySide2.QtCore.Signal] = ...
    commitData: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sizeHintChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def createEditor(self, parent: typing.Union[QWidget, None], option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> QWidget: ...
    def destroyEditor(self, editor: QWidget, index: PySide2.QtCore.QModelIndex) -> None: ...
    def editorEvent(self, event: PySide2.QtCore.QEvent, model: PySide2.QtCore.QAbstractItemModel, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> bool: ...
    @classmethod
    def elidedText(cls, fontMetrics: PySide2.QtGui.QFontMetrics, width: int, mode: PySide2.QtCore.Qt.TextElideMode, text: str) -> str: ...
    def helpEvent(self, event: PySide2.QtGui.QHelpEvent, view: QAbstractItemView, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def paintingRoles(self) -> typing.List[int]: ...
    def setEditorData(self, editor: QWidget, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setModelData(self, editor: QWidget, model: PySide2.QtCore.QAbstractItemModel, index: PySide2.QtCore.QModelIndex) -> None: ...
    def sizeHint(self, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QSize: ...
    def updateEditorGeometry(self, editor: QWidget, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...

class QAbstractItemView(QAbstractScrollArea):
    class CursorAction:
        MoveDown: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveEnd: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveHome: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveLeft: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveNext: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MovePageDown: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MovePageUp: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MovePrevious: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveRight: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        MoveUp: typing.ClassVar[QAbstractItemView.CursorAction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.CursorAction: ...

    class DragDropMode:
        DragDrop: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
        DragOnly: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
        DropOnly: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
        InternalMove: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
        NoDragDrop: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.DragDropMode: ...

    class DropIndicatorPosition:
        AboveItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
        BelowItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
        OnItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
        OnViewport: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.DropIndicatorPosition: ...

    class EditTrigger:
        AllEditTriggers: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        AnyKeyPressed: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        CurrentChanged: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        DoubleClicked: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        EditKeyPressed: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        NoEditTriggers: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        SelectedClicked: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QAbstractItemView.EditTriggers: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...

    class EditTriggers:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QAbstractItemView.EditTriggers: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.EditTriggers: ...

    class ScrollHint:
        EnsureVisible: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
        PositionAtBottom: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
        PositionAtCenter: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
        PositionAtTop: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollHint: ...

    class ScrollMode:
        ScrollPerItem: typing.ClassVar[QAbstractItemView.ScrollMode] = ...
        ScrollPerPixel: typing.ClassVar[QAbstractItemView.ScrollMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.ScrollMode: ...

    class SelectionBehavior:
        SelectColumns: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
        SelectItems: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
        SelectRows: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionBehavior: ...

    class SelectionMode:
        ContiguousSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
        ExtendedSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
        MultiSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
        NoSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
        SingleSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.SelectionMode: ...

    class State:
        AnimatingState: typing.ClassVar[QAbstractItemView.State] = ...
        CollapsingState: typing.ClassVar[QAbstractItemView.State] = ...
        DragSelectingState: typing.ClassVar[QAbstractItemView.State] = ...
        DraggingState: typing.ClassVar[QAbstractItemView.State] = ...
        EditingState: typing.ClassVar[QAbstractItemView.State] = ...
        ExpandingState: typing.ClassVar[QAbstractItemView.State] = ...
        NoState: typing.ClassVar[QAbstractItemView.State] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractItemView.State: ...
    AboveItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
    AllEditTriggers: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    AnimatingState: typing.ClassVar[QAbstractItemView.State] = ...
    AnyKeyPressed: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    BelowItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
    CollapsingState: typing.ClassVar[QAbstractItemView.State] = ...
    ContiguousSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
    CurrentChanged: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    DoubleClicked: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    DragDrop: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
    DragOnly: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
    DragSelectingState: typing.ClassVar[QAbstractItemView.State] = ...
    DraggingState: typing.ClassVar[QAbstractItemView.State] = ...
    DropOnly: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
    EditKeyPressed: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    EditingState: typing.ClassVar[QAbstractItemView.State] = ...
    EnsureVisible: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
    ExpandingState: typing.ClassVar[QAbstractItemView.State] = ...
    ExtendedSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
    InternalMove: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
    MoveDown: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveEnd: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveHome: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveLeft: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveNext: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MovePageDown: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MovePageUp: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MovePrevious: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveRight: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MoveUp: typing.ClassVar[QAbstractItemView.CursorAction] = ...
    MultiSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
    NoDragDrop: typing.ClassVar[QAbstractItemView.DragDropMode] = ...
    NoEditTriggers: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    NoSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
    NoState: typing.ClassVar[QAbstractItemView.State] = ...
    OnItem: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
    OnViewport: typing.ClassVar[QAbstractItemView.DropIndicatorPosition] = ...
    PositionAtBottom: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
    PositionAtCenter: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
    PositionAtTop: typing.ClassVar[QAbstractItemView.ScrollHint] = ...
    ScrollPerItem: typing.ClassVar[QAbstractItemView.ScrollMode] = ...
    ScrollPerPixel: typing.ClassVar[QAbstractItemView.ScrollMode] = ...
    SelectColumns: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
    SelectItems: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
    SelectRows: typing.ClassVar[QAbstractItemView.SelectionBehavior] = ...
    SelectedClicked: typing.ClassVar[QAbstractItemView.EditTrigger] = ...
    SingleSelection: typing.ClassVar[QAbstractItemView.SelectionMode] = ...
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    doubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    entered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    iconSizeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    viewportEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QAbstractScrollArea.Shadow = ..., frameShape: QAbstractScrollArea.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QAbstractScrollArea.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def alternatingRowColors(self) -> bool: ...
    def autoScrollMargin(self) -> int: ...
    def clearSelection(self) -> None: ...
    def closeEditor(self, editor: QWidget, hint: QAbstractItemDelegate.EndEditHint) -> None: ...
    def closePersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def commitData(self, editor: QWidget) -> None: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, previous: PySide2.QtCore.QModelIndex) -> None: ...
    def currentIndex(self) -> PySide2.QtCore.QModelIndex: ...
    def dataChanged(self, topLeft: PySide2.QtCore.QModelIndex, bottomRight: PySide2.QtCore.QModelIndex, roles: typing.List[int] = ...) -> None: ...
    def defaultDropAction(self) -> PySide2.QtCore.Qt.DropAction: ...
    def dirtyRegionOffset(self) -> PySide2.QtCore.QPoint: ...
    def doAutoScroll(self) -> None: ...
    def doItemsLayout(self) -> None: ...
    def dragDropMode(self) -> QAbstractItemView.DragDropMode: ...
    def dragDropOverwriteMode(self) -> bool: ...
    def dragEnabled(self) -> bool: ...
    def dragEnterEvent(self, event: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, event: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, event: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    def dropIndicatorPosition(self) -> QAbstractItemView.DropIndicatorPosition: ...
    @typing.overload
    def edit(self, index: PySide2.QtCore.QModelIndex, trigger: QAbstractItemView.EditTrigger, event: PySide2.QtCore.QEvent) -> bool: ...
    @typing.overload
    def edit(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def editTriggers(self) -> typing.Union[QAbstractItemView.EditTriggers, QAbstractItemView.EditTrigger]: ...
    def editorDestroyed(self, editor: PySide2.QtCore.QObject) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def executeDelayedItemsLayout(self) -> None: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def hasAutoScroll(self) -> bool: ...
    def horizontalOffset(self) -> int: ...
    def horizontalScrollMode(self) -> QAbstractItemView.ScrollMode: ...
    def horizontalScrollbarAction(self, action: int) -> None: ...
    def horizontalScrollbarValueChanged(self, value: int) -> None: ...
    def horizontalStepsPerItem(self) -> int: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def indexAt(self, point: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    def indexWidget(self, index: PySide2.QtCore.QModelIndex) -> QWidget: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isPersistentEditorOpen(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    @typing.overload
    def itemDelegate(self, index: PySide2.QtCore.QModelIndex) -> QAbstractItemDelegate: ...
    @typing.overload
    def itemDelegate(self) -> QAbstractItemDelegate: ...
    def itemDelegateForColumn(self, column: int) -> QAbstractItemDelegate: ...
    def itemDelegateForRow(self, row: int) -> QAbstractItemDelegate: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyboardSearch(self, search: str) -> None: ...
    def model(self) -> PySide2.QtCore.QAbstractItemModel: ...
    def mouseDoubleClickEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def openPersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def reset(self) -> None: ...
    def resetHorizontalScrollMode(self) -> None: ...
    def resetVerticalScrollMode(self) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def rootIndex(self) -> PySide2.QtCore.QModelIndex: ...
    def rowsAboutToBeRemoved(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def rowsInserted(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def scheduleDelayedItemsLayout(self) -> None: ...
    def scrollDirtyRegion(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def scrollToBottom(self) -> None: ...
    def scrollToTop(self) -> None: ...
    def selectAll(self) -> None: ...
    def selectedIndexes(self) -> typing.List[PySide2.QtCore.QModelIndex]: ...
    def selectionBehavior(self) -> QAbstractItemView.SelectionBehavior: ...
    def selectionChanged(self, selected: PySide2.QtCore.QItemSelection, deselected: PySide2.QtCore.QItemSelection) -> None: ...
    def selectionCommand(self, index: PySide2.QtCore.QModelIndex, event: typing.Union[PySide2.QtCore.QEvent, None] = ...) -> typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]: ...
    def selectionMode(self) -> QAbstractItemView.SelectionMode: ...
    def selectionModel(self) -> PySide2.QtCore.QItemSelectionModel: ...
    def setAlternatingRowColors(self, enable: bool) -> None: ...
    def setAutoScroll(self, enable: bool) -> None: ...
    def setAutoScrollMargin(self, margin: int) -> None: ...
    def setCurrentIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setDefaultDropAction(self, dropAction: PySide2.QtCore.Qt.DropAction) -> None: ...
    def setDirtyRegion(self, region: PySide2.QtGui.QRegion) -> None: ...
    def setDragDropMode(self, behavior: QAbstractItemView.DragDropMode) -> None: ...
    def setDragDropOverwriteMode(self, overwrite: bool) -> None: ...
    def setDragEnabled(self, enable: bool) -> None: ...
    def setDropIndicatorShown(self, enable: bool) -> None: ...
    def setEditTriggers(self, triggers: typing.Union[QAbstractItemView.EditTriggers, QAbstractItemView.EditTrigger]) -> None: ...
    def setHorizontalScrollMode(self, mode: QAbstractItemView.ScrollMode) -> None: ...
    def setHorizontalStepsPerItem(self, steps: int) -> None: ...
    def setIconSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setIndexWidget(self, index: PySide2.QtCore.QModelIndex, widget: QWidget) -> None: ...
    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None: ...
    def setItemDelegateForColumn(self, column: int, delegate: QAbstractItemDelegate) -> None: ...
    def setItemDelegateForRow(self, row: int, delegate: QAbstractItemDelegate) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSelectionBehavior(self, behavior: QAbstractItemView.SelectionBehavior) -> None: ...
    def setSelectionMode(self, mode: QAbstractItemView.SelectionMode) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def setState(self, state: QAbstractItemView.State) -> None: ...
    def setTabKeyNavigation(self, enable: bool) -> None: ...
    def setTextElideMode(self, mode: PySide2.QtCore.Qt.TextElideMode) -> None: ...
    def setVerticalScrollMode(self, mode: QAbstractItemView.ScrollMode) -> None: ...
    def setVerticalStepsPerItem(self, steps: int) -> None: ...
    def showDropIndicator(self) -> bool: ...
    def sizeHintForColumn(self, column: int) -> int: ...
    def sizeHintForIndex(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QSize: ...
    def sizeHintForRow(self, row: int) -> int: ...
    def startAutoScroll(self) -> None: ...
    def startDrag(self, supportedActions: typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]) -> None: ...
    def state(self) -> QAbstractItemView.State: ...
    def stopAutoScroll(self) -> None: ...
    def tabKeyNavigation(self) -> bool: ...
    def textElideMode(self) -> PySide2.QtCore.Qt.TextElideMode: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    @typing.overload
    def update(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    @typing.overload
    def update(self) -> None: ...
    def updateEditorData(self) -> None: ...
    def updateEditorGeometries(self) -> None: ...
    def updateGeometries(self) -> None: ...
    def verticalOffset(self) -> int: ...
    def verticalScrollMode(self) -> QAbstractItemView.ScrollMode: ...
    def verticalScrollbarAction(self, action: int) -> None: ...
    def verticalScrollbarValueChanged(self, value: int) -> None: ...
    def verticalStepsPerItem(self) -> int: ...
    def viewOptions(self) -> QStyleOptionViewItem: ...
    def viewportEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...

class QAbstractScrollArea(QFrame):
    class SizeAdjustPolicy:
        AdjustIgnored: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
        AdjustToContents: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
        AdjustToContentsOnFirstShow: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractScrollArea.SizeAdjustPolicy: ...
    AdjustIgnored: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
    AdjustToContents: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
    AdjustToContentsOnFirstShow: typing.ClassVar[QAbstractScrollArea.SizeAdjustPolicy] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QAbstractScrollArea.Shadow = ..., frameShape: QAbstractScrollArea.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QAbstractScrollArea.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def addScrollBarWidget(self, widget: QWidget, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def contextMenuEvent(self, arg__1: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def cornerWidget(self) -> QWidget: ...
    def dragEnterEvent(self, arg__1: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, arg__1: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, arg__1: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, arg__1: PySide2.QtGui.QDropEvent) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def horizontalScrollBar(self) -> QScrollBar: ...
    def horizontalScrollBarPolicy(self) -> PySide2.QtCore.Qt.ScrollBarPolicy: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def maximumViewportSize(self) -> PySide2.QtCore.QSize: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseDoubleClickEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def scrollBarWidgets(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> typing.List[QWidget]: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def setCornerWidget(self, widget: QWidget) -> None: ...
    def setHorizontalScrollBar(self, scrollbar: QScrollBar) -> None: ...
    def setHorizontalScrollBarPolicy(self, arg__1: PySide2.QtCore.Qt.ScrollBarPolicy) -> None: ...
    def setSizeAdjustPolicy(self, policy: QAbstractScrollArea.SizeAdjustPolicy) -> None: ...
    def setVerticalScrollBar(self, scrollbar: QScrollBar) -> None: ...
    def setVerticalScrollBarPolicy(self, arg__1: PySide2.QtCore.Qt.ScrollBarPolicy) -> None: ...
    def setViewport(self, widget: QWidget) -> None: ...
    @typing.overload
    def setViewportMargins(self, left: int, top: int, right: int, bottom: int) -> None: ...
    @typing.overload
    def setViewportMargins(self, margins: PySide2.QtCore.QMargins) -> None: ...
    def setupViewport(self, viewport: QWidget) -> None: ...
    def sizeAdjustPolicy(self) -> QAbstractScrollArea.SizeAdjustPolicy: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def verticalScrollBar(self) -> QScrollBar: ...
    def verticalScrollBarPolicy(self) -> PySide2.QtCore.Qt.ScrollBarPolicy: ...
    def viewport(self) -> QWidget: ...
    def viewportEvent(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def viewportMargins(self) -> PySide2.QtCore.QMargins: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def wheelEvent(self, arg__1: PySide2.QtGui.QWheelEvent) -> None: ...

class QAbstractSlider(QWidget):
    class SliderAction:
        SliderMove: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderNoAction: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderPageStepAdd: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderPageStepSub: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderSingleStepAdd: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderSingleStepSub: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderToMaximum: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        SliderToMinimum: typing.ClassVar[QAbstractSlider.SliderAction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderAction: ...

    class SliderChange:
        SliderOrientationChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
        SliderRangeChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
        SliderStepsChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
        SliderValueChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSlider.SliderChange: ...
    SliderMove: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderNoAction: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderOrientationChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
    SliderPageStepAdd: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderPageStepSub: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderRangeChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
    SliderSingleStepAdd: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderSingleStepSub: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderStepsChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
    SliderToMaximum: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderToMinimum: typing.ClassVar[QAbstractSlider.SliderAction] = ...
    SliderValueChange: typing.ClassVar[QAbstractSlider.SliderChange] = ...
    actionTriggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    rangeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sliderMoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sliderPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sliderReleased: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def hasTracking(self) -> bool: ...
    def invertedAppearance(self) -> bool: ...
    def invertedControls(self) -> bool: ...
    def isSliderDown(self) -> bool: ...
    def keyPressEvent(self, ev: PySide2.QtGui.QKeyEvent) -> None: ...
    def maximum(self) -> int: ...
    def minimum(self) -> int: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def pageStep(self) -> int: ...
    def repeatAction(self) -> QAbstractSlider.SliderAction: ...
    def setInvertedAppearance(self, arg__1: bool) -> None: ...
    def setInvertedControls(self, arg__1: bool) -> None: ...
    def setMaximum(self, arg__1: int) -> None: ...
    def setMinimum(self, arg__1: int) -> None: ...
    def setOrientation(self, arg__1: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setPageStep(self, arg__1: int) -> None: ...
    def setRange(self, min: int, max: int) -> None: ...
    def setRepeatAction(self, action: QAbstractSlider.SliderAction, thresholdTime: int = ..., repeatTime: int = ...) -> None: ...
    def setSingleStep(self, arg__1: int) -> None: ...
    def setSliderDown(self, arg__1: bool) -> None: ...
    def setSliderPosition(self, arg__1: int) -> None: ...
    def setTracking(self, enable: bool) -> None: ...
    def setValue(self, arg__1: int) -> None: ...
    def singleStep(self) -> int: ...
    def sliderChange(self, change: QAbstractSlider.SliderChange) -> None: ...
    def sliderPosition(self) -> int: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...
    def triggerAction(self, action: QAbstractSlider.SliderAction) -> None: ...
    def value(self) -> int: ...
    def wheelEvent(self, e: PySide2.QtGui.QWheelEvent) -> None: ...

class QAbstractSpinBox(QWidget):
    class ButtonSymbols:
        NoButtons: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
        PlusMinus: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
        UpDownArrows: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.ButtonSymbols: ...

    class CorrectionMode:
        CorrectToNearestValue: typing.ClassVar[QAbstractSpinBox.CorrectionMode] = ...
        CorrectToPreviousValue: typing.ClassVar[QAbstractSpinBox.CorrectionMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.CorrectionMode: ...

    class StepEnabled:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QAbstractSpinBox.StepEnabled: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...

    class StepEnabledFlag:
        StepDownEnabled: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
        StepNone: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
        StepUpEnabled: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QAbstractSpinBox.StepEnabled: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepEnabled: ...

    class StepType:
        AdaptiveDecimalStepType: typing.ClassVar[QAbstractSpinBox.StepType] = ...
        DefaultStepType: typing.ClassVar[QAbstractSpinBox.StepType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __and__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __rand__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __ror__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __sub__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
        def __xor__(self, other: typing.SupportsInt) -> QAbstractSpinBox.StepType: ...
    AdaptiveDecimalStepType: typing.ClassVar[QAbstractSpinBox.StepType] = ...
    CorrectToNearestValue: typing.ClassVar[QAbstractSpinBox.CorrectionMode] = ...
    CorrectToPreviousValue: typing.ClassVar[QAbstractSpinBox.CorrectionMode] = ...
    DefaultStepType: typing.ClassVar[QAbstractSpinBox.StepType] = ...
    NoButtons: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
    PlusMinus: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
    StepDownEnabled: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
    StepNone: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
    StepUpEnabled: typing.ClassVar[QAbstractSpinBox.StepEnabledFlag] = ...
    UpDownArrows: typing.ClassVar[QAbstractSpinBox.ButtonSymbols] = ...
    editingFinished: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QAbstractSpinBox.ButtonSymbols = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QAbstractSpinBox.CorrectionMode = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def buttonSymbols(self) -> QAbstractSpinBox.ButtonSymbols: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    def contextMenuEvent(self, event: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def correctionMode(self) -> QAbstractSpinBox.CorrectionMode: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def fixup(self, input: str) -> None: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def hasAcceptableInput(self) -> bool: ...
    def hasFrame(self) -> bool: ...
    def hideEvent(self, event: PySide2.QtGui.QHideEvent) -> None: ...
    def initStyleOption(self, option: QStyleOptionSpinBox) -> None: ...
    def inputMethodQuery(self, arg__1: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def interpretText(self) -> None: ...
    def isAccelerated(self) -> bool: ...
    def isGroupSeparatorShown(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyboardTracking(self) -> bool: ...
    def lineEdit(self) -> QLineEdit: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def selectAll(self) -> None: ...
    def setAccelerated(self, on: bool) -> None: ...
    def setAlignment(self, flag: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setButtonSymbols(self, bs: QAbstractSpinBox.ButtonSymbols) -> None: ...
    def setCorrectionMode(self, cm: QAbstractSpinBox.CorrectionMode) -> None: ...
    def setFrame(self, arg__1: bool) -> None: ...
    def setGroupSeparatorShown(self, shown: bool) -> None: ...
    def setKeyboardTracking(self, kt: bool) -> None: ...
    def setLineEdit(self, edit: QLineEdit) -> None: ...
    def setReadOnly(self, r: bool) -> None: ...
    def setSpecialValueText(self, txt: str) -> None: ...
    def setWrapping(self, w: bool) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def specialValueText(self) -> str: ...
    def stepBy(self, steps: int) -> None: ...
    def stepDown(self) -> None: ...
    def stepEnabled(self) -> typing.Union[QAbstractSpinBox.StepEnabled, QAbstractSpinBox.StepEnabledFlag]: ...
    def stepUp(self) -> None: ...
    def text(self) -> str: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    def validate(self, input: str, pos: int) -> PySide2.QtGui.QValidator.State: ...
    def wheelEvent(self, event: PySide2.QtGui.QWheelEvent) -> None: ...
    def wrapping(self) -> bool: ...

class QAccessibleWidget(PySide2.QtGui.QAccessibleObject):
    def __init__(self, o: QWidget, r: PySide2.QtGui.QAccessible.Role = ..., name: str = ...) -> None: ...
    def actionNames(self) -> typing.List[str]: ...
    def addControllingSignal(self, signal: str) -> None: ...
    def backgroundColor(self) -> PySide2.QtGui.QColor: ...
    def child(self, index: int) -> PySide2.QtGui.QAccessibleInterface: ...
    def childCount(self) -> int: ...
    def doAction(self, actionName: str) -> None: ...
    def focusChild(self) -> PySide2.QtGui.QAccessibleInterface: ...
    def foregroundColor(self) -> PySide2.QtGui.QColor: ...
    def indexOfChild(self, child: PySide2.QtGui.QAccessibleInterface) -> int: ...
    def interface_cast(self, t: PySide2.QtGui.QAccessible.InterfaceType) -> int: ...
    def isValid(self) -> bool: ...
    def keyBindingsForAction(self, actionName: str) -> typing.List[str]: ...
    def parent(self) -> PySide2.QtGui.QAccessibleInterface: ...
    def parentObject(self) -> PySide2.QtCore.QObject: ...
    def rect(self) -> PySide2.QtCore.QRect: ...
    def relations(self, match: typing.Union[PySide2.QtGui.QAccessible.Relation, PySide2.QtGui.QAccessible.RelationFlag] = ...) -> typing.List[typing.Tuple[PySide2.QtGui.QAccessibleInterface, PySide2.QtGui.QAccessible.Relation]]: ...
    def role(self) -> PySide2.QtGui.QAccessible.Role: ...
    def state(self) -> PySide2.QtGui.QAccessible.State: ...
    def text(self, t: PySide2.QtGui.QAccessible.Text) -> str: ...
    def widget(self) -> QWidget: ...
    def window(self) -> PySide2.QtGui.QWindow: ...

class QAction(PySide2.QtCore.QObject):
    class ActionEvent:
        Hover: typing.ClassVar[QAction.ActionEvent] = ...
        Trigger: typing.ClassVar[QAction.ActionEvent] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __and__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __rand__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __ror__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __sub__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...
        def __xor__(self, other: typing.SupportsInt) -> QAction.ActionEvent: ...

    class MenuRole:
        AboutQtRole: typing.ClassVar[QAction.MenuRole] = ...
        AboutRole: typing.ClassVar[QAction.MenuRole] = ...
        ApplicationSpecificRole: typing.ClassVar[QAction.MenuRole] = ...
        NoRole: typing.ClassVar[QAction.MenuRole] = ...
        PreferencesRole: typing.ClassVar[QAction.MenuRole] = ...
        QuitRole: typing.ClassVar[QAction.MenuRole] = ...
        TextHeuristicRole: typing.ClassVar[QAction.MenuRole] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __and__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __rand__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __ror__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __sub__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...
        def __xor__(self, other: typing.SupportsInt) -> QAction.MenuRole: ...

    class Priority:
        HighPriority: typing.ClassVar[QAction.Priority] = ...
        LowPriority: typing.ClassVar[QAction.Priority] = ...
        NormalPriority: typing.ClassVar[QAction.Priority] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __and__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __rand__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __rmul__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __ror__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __rsub__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __rxor__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __sub__(self, other: typing.SupportsInt) -> QAction.Priority: ...
        def __xor__(self, other: typing.SupportsInt) -> QAction.Priority: ...
    AboutQtRole: typing.ClassVar[QAction.MenuRole] = ...
    AboutRole: typing.ClassVar[QAction.MenuRole] = ...
    ApplicationSpecificRole: typing.ClassVar[QAction.MenuRole] = ...
    HighPriority: typing.ClassVar[QAction.Priority] = ...
    Hover: typing.ClassVar[QAction.ActionEvent] = ...
    LowPriority: typing.ClassVar[QAction.Priority] = ...
    NoRole: typing.ClassVar[QAction.MenuRole] = ...
    NormalPriority: typing.ClassVar[QAction.Priority] = ...
    PreferencesRole: typing.ClassVar[QAction.MenuRole] = ...
    QuitRole: typing.ClassVar[QAction.MenuRole] = ...
    TextHeuristicRole: typing.ClassVar[QAction.MenuRole] = ...
    Trigger: typing.ClassVar[QAction.ActionEvent] = ...
    changed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    hovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    toggled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    triggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, icon: PySide2.QtGui.QIcon, text: str, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., autoRepeat: bool = ..., changed: typing.Callable = ..., checkable: bool = ..., checked: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., font: PySide2.QtGui.QFont = ..., hovered: typing.Callable = ..., iconText: str = ..., iconVisibleInMenu: bool = ..., menuRole: QAction.MenuRole = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., priority: QAction.Priority = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., shortcutContext: PySide2.QtCore.Qt.ShortcutContext = ..., shortcutVisibleInContextMenu: bool = ..., statusTip: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., triggered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ...) -> None: ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., autoRepeat: bool = ..., changed: typing.Callable = ..., checkable: bool = ..., checked: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., font: PySide2.QtGui.QFont = ..., hovered: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., iconText: str = ..., iconVisibleInMenu: bool = ..., menuRole: QAction.MenuRole = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., priority: QAction.Priority = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., shortcutContext: PySide2.QtCore.Qt.ShortcutContext = ..., shortcutVisibleInContextMenu: bool = ..., statusTip: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., triggered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., autoRepeat: bool = ..., changed: typing.Callable = ..., checkable: bool = ..., checked: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., font: PySide2.QtGui.QFont = ..., hovered: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., iconText: str = ..., iconVisibleInMenu: bool = ..., menuRole: QAction.MenuRole = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., priority: QAction.Priority = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., shortcutContext: PySide2.QtCore.Qt.ShortcutContext = ..., shortcutVisibleInContextMenu: bool = ..., statusTip: str = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., triggered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ...) -> None: ...
    def actionGroup(self) -> QActionGroup: ...
    def activate(self, event: QAction.ActionEvent) -> None: ...
    def associatedGraphicsWidgets(self) -> typing.List[QGraphicsWidget]: ...
    def associatedWidgets(self) -> typing.List[QWidget]: ...
    def autoRepeat(self) -> bool: ...
    def data(self) -> typing.Any: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def hover(self) -> None: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    def iconText(self) -> str: ...
    def isCheckable(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isIconVisibleInMenu(self) -> bool: ...
    def isSeparator(self) -> bool: ...
    def isShortcutVisibleInContextMenu(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def menu(self) -> QMenu: ...
    def menuRole(self) -> QAction.MenuRole: ...
    def parentWidget(self) -> QWidget: ...
    def priority(self) -> QAction.Priority: ...
    def setActionGroup(self, group: QActionGroup) -> None: ...
    def setAutoRepeat(self, arg__1: bool) -> None: ...
    def setCheckable(self, arg__1: bool) -> None: ...
    def setChecked(self, arg__1: bool) -> None: ...
    def setData(self, var: typing.Any) -> None: ...
    def setDisabled(self, b: bool) -> None: ...
    def setEnabled(self, arg__1: bool) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setIconText(self, text: str) -> None: ...
    def setIconVisibleInMenu(self, visible: bool) -> None: ...
    def setMenu(self, menu: QMenu) -> None: ...
    def setMenuRole(self, menuRole: QAction.MenuRole) -> None: ...
    def setPriority(self, priority: QAction.Priority) -> None: ...
    def setSeparator(self, b: bool) -> None: ...
    def setShortcut(self, shortcut: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    def setShortcutContext(self, context: PySide2.QtCore.Qt.ShortcutContext) -> None: ...
    def setShortcutVisibleInContextMenu(self, show: bool) -> None: ...
    @typing.overload
    def setShortcuts(self, shortcuts: typing.Iterable[PySide2.QtGui.QKeySequence]) -> None: ...
    @typing.overload
    def setShortcuts(self, arg__1: PySide2.QtGui.QKeySequence.StandardKey) -> None: ...
    def setStatusTip(self, statusTip: str) -> None: ...
    def setText(self, text: str) -> None: ...
    def setToolTip(self, tip: str) -> None: ...
    def setVisible(self, arg__1: bool) -> None: ...
    def setWhatsThis(self, what: str) -> None: ...
    def shortcut(self) -> PySide2.QtGui.QKeySequence: ...
    def shortcutContext(self) -> PySide2.QtCore.Qt.ShortcutContext: ...
    def shortcuts(self) -> typing.List[PySide2.QtGui.QKeySequence]: ...
    def showStatusText(self, widget: typing.Union[QWidget, None] = ...) -> bool: ...
    def statusTip(self) -> str: ...
    def text(self) -> str: ...
    def toggle(self) -> None: ...
    def toolTip(self) -> str: ...
    def trigger(self) -> None: ...
    def whatsThis(self) -> str: ...

class QActionGroup(PySide2.QtCore.QObject):
    class ExclusionPolicy:
        Exclusive: typing.ClassVar[QActionGroup.ExclusionPolicy] = ...
        ExclusiveOptional: typing.ClassVar[QActionGroup.ExclusionPolicy] = ...
        None_: typing.ClassVar[QActionGroup.ExclusionPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QActionGroup.ExclusionPolicy: ...
    hovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    triggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None], destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def actions(self) -> typing.List[QAction]: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, a: QAction) -> QAction: ...
    def checkedAction(self) -> QAction: ...
    def exclusionPolicy(self) -> QActionGroup.ExclusionPolicy: ...
    def isEnabled(self) -> bool: ...
    def isExclusive(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def removeAction(self, a: QAction) -> None: ...
    def setDisabled(self, b: bool) -> None: ...
    def setEnabled(self, arg__1: bool) -> None: ...
    def setExclusionPolicy(self, policy: QActionGroup.ExclusionPolicy) -> None: ...
    def setExclusive(self, arg__1: bool) -> None: ...
    def setVisible(self, arg__1: bool) -> None: ...

class QApplication(PySide2.QtGui.QGuiApplication):
    class ColorSpec:
        CustomColor: typing.ClassVar[QApplication.ColorSpec] = ...
        ManyColor: typing.ClassVar[QApplication.ColorSpec] = ...
        NormalColor: typing.ClassVar[QApplication.ColorSpec] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __and__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __rand__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __rmul__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __ror__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __rsub__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __rxor__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __sub__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
        def __xor__(self, other: typing.SupportsInt) -> QApplication.ColorSpec: ...
    CustomColor: typing.ClassVar[QApplication.ColorSpec] = ...
    ManyColor: typing.ClassVar[QApplication.ColorSpec] = ...
    NormalColor: typing.ClassVar[QApplication.ColorSpec] = ...
    focusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, arg__1: typing.Iterable[str], destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @classmethod
    def aboutQt(cls) -> None: ...
    @classmethod
    def activeModalWidget(cls) -> QWidget: ...
    @classmethod
    def activePopupWidget(cls) -> QWidget: ...
    @classmethod
    def activeWindow(cls) -> QWidget: ...
    @classmethod
    def alert(cls, widget: QWidget, duration: int = ...) -> None: ...
    @classmethod
    def allWidgets(cls) -> typing.List[QWidget]: ...
    def autoSipEnabled(self) -> bool: ...
    @classmethod
    def beep(cls) -> None: ...
    @classmethod
    def closeAllWindows(cls) -> None: ...
    @classmethod
    def colorSpec(cls) -> int: ...
    @classmethod
    def cursorFlashTime(cls) -> int: ...
    @classmethod
    def desktop(cls) -> QDesktopWidget: ...
    @classmethod
    def doubleClickInterval(cls) -> int: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    @classmethod
    def exec_(cls) -> int: ...
    @classmethod
    def focusWidget(cls) -> QWidget: ...
    @typing.overload
    @classmethod
    def font(cls, className: bytes) -> PySide2.QtGui.QFont: ...
    @typing.overload
    @classmethod
    def font(cls, arg__1: QWidget) -> PySide2.QtGui.QFont: ...
    @typing.overload
    @classmethod
    def font(cls) -> PySide2.QtGui.QFont: ...
    @classmethod
    def fontMetrics(cls) -> PySide2.QtGui.QFontMetrics: ...
    @classmethod
    def globalStrut(cls) -> PySide2.QtCore.QSize: ...
    @classmethod
    def isEffectEnabled(cls, arg__1: PySide2.QtCore.Qt.UIEffect) -> bool: ...
    @classmethod
    def keyboardInputInterval(cls) -> int: ...
    def notify(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    @typing.overload
    @classmethod
    def palette(cls, className: bytes) -> PySide2.QtGui.QPalette: ...
    @typing.overload
    @classmethod
    def palette(cls, arg__1: QWidget) -> PySide2.QtGui.QPalette: ...
    @typing.overload
    @classmethod
    def palette(cls) -> PySide2.QtGui.QPalette: ...
    @classmethod
    def setActiveWindow(cls, act: QWidget) -> None: ...
    def setAutoSipEnabled(self, enabled: bool) -> None: ...
    @classmethod
    def setColorSpec(cls, arg__1: int) -> None: ...
    @classmethod
    def setCursorFlashTime(cls, arg__1: int) -> None: ...
    @classmethod
    def setDoubleClickInterval(cls, arg__1: int) -> None: ...
    @classmethod
    def setEffectEnabled(cls, arg__1: PySide2.QtCore.Qt.UIEffect, enable: bool = ...) -> None: ...
    @classmethod
    def setFont(cls, arg__1: PySide2.QtGui.QFont, className: typing.Union[bytes, None] = ...) -> None: ...
    @classmethod
    def setGlobalStrut(cls, arg__1: PySide2.QtCore.QSize) -> None: ...
    @classmethod
    def setKeyboardInputInterval(cls, arg__1: int) -> None: ...
    @typing.overload
    @classmethod
    def setPalette(cls, arg__1: PySide2.QtGui.QPalette, className: typing.Union[bytes, None] = ...) -> None: ...
    @typing.overload
    @classmethod
    def setPalette(cls, pal: PySide2.QtGui.QPalette) -> None: ...
    @classmethod
    def setStartDragDistance(cls, l: int) -> None: ...
    @classmethod
    def setStartDragTime(cls, ms: int) -> None: ...
    @typing.overload
    @classmethod
    def setStyle(cls, arg__1: QStyle) -> None: ...
    @typing.overload
    @classmethod
    def setStyle(cls, arg__1: str) -> QStyle: ...
    def setStyleSheet(self, sheet: str) -> None: ...
    @classmethod
    def setWheelScrollLines(cls, arg__1: int) -> None: ...
    @classmethod
    def setWindowIcon(cls, icon: PySide2.QtGui.QIcon) -> None: ...
    @classmethod
    def startDragDistance(cls) -> int: ...
    @classmethod
    def startDragTime(cls) -> int: ...
    @classmethod
    def style(cls) -> QStyle: ...
    def styleSheet(self) -> str: ...
    @typing.overload
    @classmethod
    def topLevelAt(cls, x: int, y: int) -> QWidget: ...
    @typing.overload
    @classmethod
    def topLevelAt(cls, p: PySide2.QtCore.QPoint) -> QWidget: ...
    @classmethod
    def topLevelWidgets(cls) -> typing.List[QWidget]: ...
    @classmethod
    def wheelScrollLines(cls) -> int: ...
    @typing.overload
    @classmethod
    def widgetAt(cls, x: int, y: int) -> QWidget: ...
    @typing.overload
    @classmethod
    def widgetAt(cls, p: PySide2.QtCore.QPoint) -> QWidget: ...
    @classmethod
    def windowIcon(cls) -> PySide2.QtGui.QIcon: ...

class QBoxLayout(QLayout):
    class Direction:
        BottomToTop: typing.ClassVar[QBoxLayout.Direction] = ...
        Down: typing.ClassVar[QBoxLayout.Direction] = ...
        LeftToRight: typing.ClassVar[QBoxLayout.Direction] = ...
        RightToLeft: typing.ClassVar[QBoxLayout.Direction] = ...
        TopToBottom: typing.ClassVar[QBoxLayout.Direction] = ...
        Up: typing.ClassVar[QBoxLayout.Direction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __and__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __rand__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __ror__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __sub__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
        def __xor__(self, other: typing.SupportsInt) -> QBoxLayout.Direction: ...
    BottomToTop: typing.ClassVar[QBoxLayout.Direction] = ...
    Down: typing.ClassVar[QBoxLayout.Direction] = ...
    LeftToRight: typing.ClassVar[QBoxLayout.Direction] = ...
    RightToLeft: typing.ClassVar[QBoxLayout.Direction] = ...
    TopToBottom: typing.ClassVar[QBoxLayout.Direction] = ...
    Up: typing.ClassVar[QBoxLayout.Direction] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, arg__1: QBoxLayout.Direction, parent: typing.Union[QWidget, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def addItem(self, arg__1: QLayoutItem) -> None: ...
    def addLayout(self, layout: QLayout, stretch: int = ...) -> None: ...
    def addSpacerItem(self, spacerItem: QSpacerItem) -> None: ...
    def addSpacing(self, size: int) -> None: ...
    def addStretch(self, stretch: int = ...) -> None: ...
    def addStrut(self, arg__1: int) -> None: ...
    @typing.overload
    def addWidget(self, arg__1: QWidget, stretch: int = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addWidget(self, w: QWidget) -> None: ...
    def count(self) -> int: ...
    def direction(self) -> QBoxLayout.Direction: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def insertItem(self, index: int, arg__2: QLayoutItem) -> None: ...
    def insertLayout(self, index: int, layout: QLayout, stretch: int = ...) -> None: ...
    def insertSpacerItem(self, index: int, spacerItem: QSpacerItem) -> None: ...
    def insertSpacing(self, index: int, size: int) -> None: ...
    def insertStretch(self, index: int, stretch: int = ...) -> None: ...
    def insertWidget(self, index: int, widget: QWidget, stretch: int = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    def invalidate(self) -> None: ...
    def itemAt(self, arg__1: int) -> QLayoutItem: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumHeightForWidth(self, arg__1: int) -> int: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def setDirection(self, arg__1: QBoxLayout.Direction) -> None: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def setSpacing(self, spacing: int) -> None: ...
    def setStretch(self, index: int, stretch: int) -> None: ...
    @typing.overload
    def setStretchFactor(self, w: QWidget, stretch: int) -> bool: ...
    @typing.overload
    def setStretchFactor(self, l: QLayout, stretch: int) -> bool: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def spacing(self) -> int: ...
    def stretch(self, index: int) -> int: ...
    def takeAt(self, arg__1: int) -> QLayoutItem: ...

class QButtonGroup(PySide2.QtCore.QObject):
    buttonClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    buttonPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    buttonReleased: typing.ClassVar[PySide2.QtCore.Signal] = ...
    buttonToggled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    idClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    idPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    idReleased: typing.ClassVar[PySide2.QtCore.Signal] = ...
    idToggled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., buttonClicked: typing.Callable = ..., buttonPressed: typing.Callable = ..., buttonReleased: typing.Callable = ..., buttonToggled: typing.Callable = ..., destroyed: typing.Callable = ..., exclusive: bool = ..., idClicked: typing.Callable = ..., idPressed: typing.Callable = ..., idReleased: typing.Callable = ..., idToggled: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def addButton(self, arg__1: QAbstractButton, id: int = ...) -> None: ...
    def button(self, id: int) -> QAbstractButton: ...
    def buttons(self) -> typing.List[QAbstractButton]: ...
    def checkedButton(self) -> QAbstractButton: ...
    def checkedId(self) -> int: ...
    def exclusive(self) -> bool: ...
    def id(self, button: QAbstractButton) -> int: ...
    def removeButton(self, arg__1: QAbstractButton) -> None: ...
    def setExclusive(self, arg__1: bool) -> None: ...
    def setId(self, button: QAbstractButton, id: int) -> None: ...

class QCalendarWidget(QWidget):
    class HorizontalHeaderFormat:
        LongDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
        NoHorizontalHeader: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
        ShortDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
        SingleLetterDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __and__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __rand__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __rmul__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __ror__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __rsub__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __rxor__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __sub__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...
        def __xor__(self, other: typing.SupportsInt) -> QCalendarWidget.HorizontalHeaderFormat: ...

    class SelectionMode:
        NoSelection: typing.ClassVar[QCalendarWidget.SelectionMode] = ...
        SingleSelection: typing.ClassVar[QCalendarWidget.SelectionMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __and__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QCalendarWidget.SelectionMode: ...

    class VerticalHeaderFormat:
        ISOWeekNumbers: typing.ClassVar[QCalendarWidget.VerticalHeaderFormat] = ...
        NoVerticalHeader: typing.ClassVar[QCalendarWidget.VerticalHeaderFormat] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __and__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __rand__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __rmul__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __ror__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __rsub__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __rxor__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __sub__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
        def __xor__(self, other: typing.SupportsInt) -> QCalendarWidget.VerticalHeaderFormat: ...
    ISOWeekNumbers: typing.ClassVar[QCalendarWidget.VerticalHeaderFormat] = ...
    LongDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
    NoHorizontalHeader: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
    NoSelection: typing.ClassVar[QCalendarWidget.SelectionMode] = ...
    NoVerticalHeader: typing.ClassVar[QCalendarWidget.VerticalHeaderFormat] = ...
    ShortDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
    SingleLetterDayNames: typing.ClassVar[QCalendarWidget.HorizontalHeaderFormat] = ...
    SingleSelection: typing.ClassVar[QCalendarWidget.SelectionMode] = ...
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentPageChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    selectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentPageChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., dateEditAcceptDelay: int = ..., dateEditEnabled: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., firstDayOfWeek: PySide2.QtCore.Qt.DayOfWeek = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridVisible: bool = ..., height: int = ..., horizontalHeaderFormat: QCalendarWidget.HorizontalHeaderFormat = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., navigationBarVisible: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., selectedDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., selectionChanged: typing.Callable = ..., selectionMode: QCalendarWidget.SelectionMode = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalHeaderFormat: QCalendarWidget.VerticalHeaderFormat = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def calendar(self) -> PySide2.QtCore.QCalendar: ...
    def dateEditAcceptDelay(self) -> int: ...
    @typing.overload
    def dateTextFormat(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> PySide2.QtGui.QTextCharFormat: ...
    @typing.overload
    def dateTextFormat(self) -> typing.Dict[PySide2.QtCore.QDate, PySide2.QtGui.QTextCharFormat]: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, watched: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def firstDayOfWeek(self) -> PySide2.QtCore.Qt.DayOfWeek: ...
    def headerTextFormat(self) -> PySide2.QtGui.QTextCharFormat: ...
    def horizontalHeaderFormat(self) -> QCalendarWidget.HorizontalHeaderFormat: ...
    def isDateEditEnabled(self) -> bool: ...
    def isGridVisible(self) -> bool: ...
    def isNavigationBarVisible(self) -> bool: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def maximumDate(self) -> PySide2.QtCore.QDate: ...
    def minimumDate(self) -> PySide2.QtCore.QDate: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def monthShown(self) -> int: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintCell(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def selectedDate(self) -> PySide2.QtCore.QDate: ...
    def selectionMode(self) -> QCalendarWidget.SelectionMode: ...
    def setCalendar(self, calendar: PySide2.QtCore.QCalendar) -> None: ...
    def setCurrentPage(self, year: int, month: int) -> None: ...
    def setDateEditAcceptDelay(self, delay: int) -> None: ...
    def setDateEditEnabled(self, enable: bool) -> None: ...
    def setDateRange(self, min: typing.Union[PySide2.QtCore.QDate, datetime.date], max: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setDateTextFormat(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date], format: PySide2.QtGui.QTextCharFormat) -> None: ...
    def setFirstDayOfWeek(self, dayOfWeek: PySide2.QtCore.Qt.DayOfWeek) -> None: ...
    def setGridVisible(self, show: bool) -> None: ...
    def setHeaderTextFormat(self, format: PySide2.QtGui.QTextCharFormat) -> None: ...
    def setHorizontalHeaderFormat(self, format: QCalendarWidget.HorizontalHeaderFormat) -> None: ...
    def setMaximumDate(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setMinimumDate(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setNavigationBarVisible(self, visible: bool) -> None: ...
    def setSelectedDate(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setSelectionMode(self, mode: QCalendarWidget.SelectionMode) -> None: ...
    def setVerticalHeaderFormat(self, format: QCalendarWidget.VerticalHeaderFormat) -> None: ...
    def setWeekdayTextFormat(self, dayOfWeek: PySide2.QtCore.Qt.DayOfWeek, format: PySide2.QtGui.QTextCharFormat) -> None: ...
    def showNextMonth(self) -> None: ...
    def showNextYear(self) -> None: ...
    def showPreviousMonth(self) -> None: ...
    def showPreviousYear(self) -> None: ...
    def showSelectedDate(self) -> None: ...
    def showToday(self) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def updateCell(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def updateCells(self) -> None: ...
    def verticalHeaderFormat(self) -> QCalendarWidget.VerticalHeaderFormat: ...
    def weekdayTextFormat(self, dayOfWeek: PySide2.QtCore.Qt.DayOfWeek) -> PySide2.QtGui.QTextCharFormat: ...
    def yearShown(self) -> int: ...

class QCheckBox(QAbstractButton):
    stateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., stateChanged: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., tristate: bool = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., stateChanged: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., tristate: bool = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def checkState(self) -> PySide2.QtCore.Qt.CheckState: ...
    def checkStateSet(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def hitButton(self, pos: PySide2.QtCore.QPoint) -> bool: ...
    def initStyleOption(self, option: QStyleOptionButton) -> None: ...
    def isTristate(self) -> bool: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def nextCheckState(self) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setCheckState(self, state: PySide2.QtCore.Qt.CheckState) -> None: ...
    def setTristate(self, y: bool = ...) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QColorDialog(QDialog):
    class ColorDialogOption:
        DontUseNativeDialog: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
        NoButtons: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
        ShowAlphaChannel: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QColorDialog.ColorDialogOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...

    class ColorDialogOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QColorDialog.ColorDialogOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QColorDialog.ColorDialogOptions: ...
    DontUseNativeDialog: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
    NoButtons: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
    ShowAlphaChannel: typing.ClassVar[QColorDialog.ColorDialogOption] = ...
    colorSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentColorChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, initial: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int], parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., colorSelected: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentColor: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ..., currentColorChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QColorDialog.ColorDialogOptions, QColorDialog.ColorDialogOption] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., colorSelected: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentColor: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ..., currentColorChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QColorDialog.ColorDialogOptions, QColorDialog.ColorDialogOption] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def currentColor(self) -> PySide2.QtGui.QColor: ...
    @classmethod
    def customColor(cls, index: int) -> PySide2.QtGui.QColor: ...
    @classmethod
    def customCount(cls) -> int: ...
    def done(self, result: int) -> None: ...
    @classmethod
    def getColor(cls, initial: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ..., parent: typing.Union[QWidget, None] = ..., title: str = ..., options: typing.Union[QColorDialog.ColorDialogOptions, QColorDialog.ColorDialogOption] = ...) -> PySide2.QtGui.QColor: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    def options(self) -> typing.Union[QColorDialog.ColorDialogOptions, QColorDialog.ColorDialogOption]: ...
    def selectedColor(self) -> PySide2.QtGui.QColor: ...
    def setCurrentColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    @classmethod
    def setCustomColor(cls, index: int, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setOption(self, option: QColorDialog.ColorDialogOption, on: bool = ...) -> None: ...
    def setOptions(self, options: typing.Union[QColorDialog.ColorDialogOptions, QColorDialog.ColorDialogOption]) -> None: ...
    @classmethod
    def setStandardColor(cls, index: int, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    @classmethod
    def standardColor(cls, index: int) -> PySide2.QtGui.QColor: ...
    def testOption(self, option: QColorDialog.ColorDialogOption) -> bool: ...

class QColormap(shiboken2.Object):
    class Mode:
        Direct: typing.ClassVar[QColormap.Mode] = ...
        Gray: typing.ClassVar[QColormap.Mode] = ...
        Indexed: typing.ClassVar[QColormap.Mode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __and__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __rand__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __ror__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __sub__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
        def __xor__(self, other: typing.SupportsInt) -> QColormap.Mode: ...
    Direct: typing.ClassVar[QColormap.Mode] = ...
    Gray: typing.ClassVar[QColormap.Mode] = ...
    Indexed: typing.ClassVar[QColormap.Mode] = ...
    def __init__(self, colormap: QColormap) -> None: ...
    @classmethod
    def cleanup(cls) -> None: ...
    def colorAt(self, pixel: int) -> PySide2.QtGui.QColor: ...
    def colormap(self) -> typing.List[PySide2.QtGui.QColor]: ...
    def depth(self) -> int: ...
    @classmethod
    def initialize(cls) -> None: ...
    @classmethod
    def instance(cls, screen: int = ...) -> QColormap: ...
    def mode(self) -> QColormap.Mode: ...
    def pixel(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> int: ...
    def size(self) -> int: ...
    def __copy__(self) -> None: ...

class QColumnView(QAbstractItemView):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    updatePreviewWidget: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QColumnView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QColumnView.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QColumnView.Shadow = ..., frameShape: QColumnView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QColumnView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeGripsVisible: bool = ..., selectionBehavior: QColumnView.SelectionBehavior = ..., selectionMode: QColumnView.SelectionMode = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QColumnView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., updatePreviewWidget: typing.Callable = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QColumnView.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def columnWidths(self) -> typing.List[int]: ...
    def createColumn(self, rootIndex: PySide2.QtCore.QModelIndex) -> QAbstractItemView: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, previous: PySide2.QtCore.QModelIndex) -> None: ...
    def horizontalOffset(self) -> int: ...
    def indexAt(self, point: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    def initializeColumn(self, column: QAbstractItemView) -> None: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def previewWidget(self) -> QWidget: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def resizeGripsVisible(self) -> bool: ...
    def rowsInserted(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectAll(self) -> None: ...
    def setColumnWidths(self, list: typing.Iterable[int]) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setPreviewWidget(self, widget: QWidget) -> None: ...
    def setResizeGripsVisible(self, visible: bool) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def verticalOffset(self) -> int: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...

class QComboBox(QWidget):
    class InsertPolicy:
        InsertAfterCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
        InsertAlphabetically: typing.ClassVar[QComboBox.InsertPolicy] = ...
        InsertAtBottom: typing.ClassVar[QComboBox.InsertPolicy] = ...
        InsertAtCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
        InsertAtTop: typing.ClassVar[QComboBox.InsertPolicy] = ...
        InsertBeforeCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
        NoInsert: typing.ClassVar[QComboBox.InsertPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QComboBox.InsertPolicy: ...

    class SizeAdjustPolicy:
        AdjustToContents: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
        AdjustToContentsOnFirstShow: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
        AdjustToMinimumContentsLength: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
        AdjustToMinimumContentsLengthWithIcon: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QComboBox.SizeAdjustPolicy: ...
    AdjustToContents: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
    AdjustToContentsOnFirstShow: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
    AdjustToMinimumContentsLength: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
    AdjustToMinimumContentsLengthWithIcon: typing.ClassVar[QComboBox.SizeAdjustPolicy] = ...
    InsertAfterCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
    InsertAlphabetically: typing.ClassVar[QComboBox.InsertPolicy] = ...
    InsertAtBottom: typing.ClassVar[QComboBox.InsertPolicy] = ...
    InsertAtCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
    InsertAtTop: typing.ClassVar[QComboBox.InsertPolicy] = ...
    InsertBeforeCurrent: typing.ClassVar[QComboBox.InsertPolicy] = ...
    NoInsert: typing.ClassVar[QComboBox.InsertPolicy] = ...
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentIndexChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    editTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    highlighted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    textHighlighted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., autoCompletion: bool = ..., autoCompletionCaseSensitivity: PySide2.QtCore.Qt.CaseSensitivity = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentData: object = ..., currentIndex: int = ..., currentIndexChanged: typing.Callable = ..., currentText: str = ..., currentTextChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., duplicatesEnabled: bool = ..., editTextChanged: typing.Callable = ..., editable: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., highlighted: typing.Callable = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., insertPolicy: QComboBox.InsertPolicy = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maxCount: int = ..., maxVisibleItems: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumContentsLength: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QComboBox.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., textActivated: typing.Callable = ..., textHighlighted: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addItem(self, icon: PySide2.QtGui.QIcon, text: str, userData: typing.Any = ...) -> None: ...
    @typing.overload
    def addItem(self, text: str, userData: typing.Any = ...) -> None: ...
    def addItems(self, texts: typing.Iterable[str]) -> None: ...
    def autoCompletion(self) -> bool: ...
    def autoCompletionCaseSensitivity(self) -> PySide2.QtCore.Qt.CaseSensitivity: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def clearEditText(self) -> None: ...
    def completer(self) -> QCompleter: ...
    def contextMenuEvent(self, e: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def count(self) -> int: ...
    def currentData(self, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def currentIndex(self) -> int: ...
    def currentText(self) -> str: ...
    def duplicatesEnabled(self) -> bool: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def findData(self, data: typing.Any, role: PySide2.QtCore.Qt.ItemDataRole = ..., flags: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag] = ...) -> int: ...
    def findText(self, text: str, flags: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag] = ...) -> int: ...
    def focusInEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def hasFrame(self) -> bool: ...
    def hideEvent(self, e: PySide2.QtGui.QHideEvent) -> None: ...
    def hidePopup(self) -> None: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def initStyleOption(self, option: QStyleOptionComboBox) -> None: ...
    def inputMethodEvent(self, arg__1: PySide2.QtGui.QInputMethodEvent) -> None: ...
    @typing.overload
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery, argument: typing.Any) -> typing.Any: ...
    @typing.overload
    def inputMethodQuery(self, arg__1: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    @typing.overload
    def insertItem(self, index: int, icon: PySide2.QtGui.QIcon, text: str, userData: typing.Any = ...) -> None: ...
    @typing.overload
    def insertItem(self, index: int, text: str, userData: typing.Any = ...) -> None: ...
    def insertItems(self, index: int, texts: typing.Iterable[str]) -> None: ...
    def insertPolicy(self) -> QComboBox.InsertPolicy: ...
    def insertSeparator(self, index: int) -> None: ...
    def isEditable(self) -> bool: ...
    def itemData(self, index: int, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def itemDelegate(self) -> QAbstractItemDelegate: ...
    def itemIcon(self, index: int) -> PySide2.QtGui.QIcon: ...
    def itemText(self, index: int) -> str: ...
    def keyPressEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def lineEdit(self) -> QLineEdit: ...
    def maxCount(self) -> int: ...
    def maxVisibleItems(self) -> int: ...
    def minimumContentsLength(self) -> int: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def model(self) -> PySide2.QtCore.QAbstractItemModel: ...
    def modelColumn(self) -> int: ...
    def mousePressEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def placeholderText(self) -> str: ...
    def removeItem(self, index: int) -> None: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    def rootModelIndex(self) -> PySide2.QtCore.QModelIndex: ...
    def setAutoCompletion(self, enable: bool) -> None: ...
    def setAutoCompletionCaseSensitivity(self, sensitivity: PySide2.QtCore.Qt.CaseSensitivity) -> None: ...
    def setCompleter(self, c: QCompleter) -> None: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentText(self, text: str) -> None: ...
    def setDuplicatesEnabled(self, enable: bool) -> None: ...
    def setEditText(self, text: str) -> None: ...
    def setEditable(self, editable: bool) -> None: ...
    def setFrame(self, arg__1: bool) -> None: ...
    def setIconSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setInsertPolicy(self, policy: QComboBox.InsertPolicy) -> None: ...
    def setItemData(self, index: int, value: typing.Any, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> None: ...
    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None: ...
    def setItemIcon(self, index: int, icon: PySide2.QtGui.QIcon) -> None: ...
    def setItemText(self, index: int, text: str) -> None: ...
    def setLineEdit(self, edit: QLineEdit) -> None: ...
    def setMaxCount(self, max: int) -> None: ...
    def setMaxVisibleItems(self, maxItems: int) -> None: ...
    def setMinimumContentsLength(self, characters: int) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setModelColumn(self, visibleColumn: int) -> None: ...
    def setPlaceholderText(self, placeholderText: str) -> None: ...
    def setRootModelIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setSizeAdjustPolicy(self, policy: QComboBox.SizeAdjustPolicy) -> None: ...
    def setValidator(self, v: PySide2.QtGui.QValidator) -> None: ...
    def setView(self, itemView: QAbstractItemView) -> None: ...
    def showEvent(self, e: PySide2.QtGui.QShowEvent) -> None: ...
    def showPopup(self) -> None: ...
    def sizeAdjustPolicy(self) -> QComboBox.SizeAdjustPolicy: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def validator(self) -> PySide2.QtGui.QValidator: ...
    def view(self) -> QAbstractItemView: ...
    def wheelEvent(self, e: PySide2.QtGui.QWheelEvent) -> None: ...

class QCommandLinkButton(QPushButton):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, text: str, description: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., description: str = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., description: str = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def description(self) -> str: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setDescription(self, description: str) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QCommonStyle(QStyle):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def drawComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, p: PySide2.QtGui.QPainter, w: typing.Union[QWidget, None] = ...) -> None: ...
    def drawControl(self, element: QStyle.ControlElement, opt: QStyleOption, p: PySide2.QtGui.QPainter, w: typing.Union[QWidget, None] = ...) -> None: ...
    def drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption, p: PySide2.QtGui.QPainter, w: typing.Union[QWidget, None] = ...) -> None: ...
    def generatedIconPixmap(self, iconMode: PySide2.QtGui.QIcon.Mode, pixmap: PySide2.QtGui.QPixmap, opt: QStyleOption) -> PySide2.QtGui.QPixmap: ...
    def hitTestComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, pt: PySide2.QtCore.QPoint, w: typing.Union[QWidget, None] = ...) -> QStyle.SubControl: ...
    def layoutSpacing(self, control1: QSizePolicy.ControlType, control2: QSizePolicy.ControlType, orientation: PySide2.QtCore.Qt.Orientation, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    def pixelMetric(self, m: QStyle.PixelMetric, opt: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    @typing.overload
    def polish(self, widget: QWidget) -> None: ...
    @typing.overload
    def polish(self, arg__1: PySide2.QtGui.QPalette) -> None: ...
    @typing.overload
    def polish(self, application: QApplication) -> None: ...
    @typing.overload
    def polish(self, app: QApplication) -> None: ...
    def sizeFromContents(self, ct: QStyle.ContentsType, opt: QStyleOption, contentsSize: PySide2.QtCore.QSize, widget: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QSize: ...
    def standardIcon(self, standardIcon: QStyle.StandardPixmap, opt: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QIcon: ...
    def standardPixmap(self, sp: QStyle.StandardPixmap, opt: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QPixmap: ...
    def styleHint(self, sh: QStyle.StyleHint, opt: typing.Union[QStyleOption, None] = ..., w: typing.Union[QWidget, None] = ..., shret: typing.Union[QStyleHintReturn, None] = ...) -> int: ...
    def subControlRect(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, sc: QStyle.SubControl, w: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QRect: ...
    def subElementRect(self, r: QStyle.SubElement, opt: QStyleOption, widget: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def unpolish(self, widget: QWidget) -> None: ...
    @typing.overload
    def unpolish(self, application: QApplication) -> None: ...

class QCompleter(PySide2.QtCore.QObject):
    class CompletionMode:
        InlineCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
        PopupCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
        UnfilteredPopupCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __and__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QCompleter.CompletionMode: ...

    class ModelSorting:
        CaseInsensitivelySortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
        CaseSensitivelySortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
        UnsortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __and__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __rand__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __rmul__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __ror__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __rsub__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __rxor__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __sub__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
        def __xor__(self, other: typing.SupportsInt) -> QCompleter.ModelSorting: ...
    CaseInsensitivelySortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
    CaseSensitivelySortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
    InlineCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
    PopupCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
    UnfilteredPopupCompletion: typing.ClassVar[QCompleter.CompletionMode] = ...
    UnsortedModel: typing.ClassVar[QCompleter.ModelSorting] = ...
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    highlighted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, model: PySide2.QtCore.QAbstractItemModel, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activated: typing.Callable = ..., caseSensitivity: PySide2.QtCore.Qt.CaseSensitivity = ..., completionColumn: int = ..., completionMode: QCompleter.CompletionMode = ..., completionPrefix: str = ..., completionRole: int = ..., destroyed: typing.Callable = ..., filterMode: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag] = ..., highlighted: typing.Callable = ..., maxVisibleItems: int = ..., modelSorting: QCompleter.ModelSorting = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., wrapAround: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, completions: typing.Iterable[str], parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activated: typing.Callable = ..., caseSensitivity: PySide2.QtCore.Qt.CaseSensitivity = ..., completionColumn: int = ..., completionMode: QCompleter.CompletionMode = ..., completionPrefix: str = ..., completionRole: int = ..., destroyed: typing.Callable = ..., filterMode: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag] = ..., highlighted: typing.Callable = ..., maxVisibleItems: int = ..., modelSorting: QCompleter.ModelSorting = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., wrapAround: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activated: typing.Callable = ..., caseSensitivity: PySide2.QtCore.Qt.CaseSensitivity = ..., completionColumn: int = ..., completionMode: QCompleter.CompletionMode = ..., completionPrefix: str = ..., completionRole: int = ..., destroyed: typing.Callable = ..., filterMode: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag] = ..., highlighted: typing.Callable = ..., maxVisibleItems: int = ..., modelSorting: QCompleter.ModelSorting = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., wrapAround: bool = ...) -> None: ...
    def caseSensitivity(self) -> PySide2.QtCore.Qt.CaseSensitivity: ...
    def complete(self, rect: PySide2.QtCore.QRect = ...) -> None: ...
    def completionColumn(self) -> int: ...
    def completionCount(self) -> int: ...
    def completionMode(self) -> QCompleter.CompletionMode: ...
    def completionModel(self) -> PySide2.QtCore.QAbstractItemModel: ...
    def completionPrefix(self) -> str: ...
    def completionRole(self) -> int: ...
    def currentCompletion(self) -> str: ...
    def currentIndex(self) -> PySide2.QtCore.QModelIndex: ...
    def currentRow(self) -> int: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, o: PySide2.QtCore.QObject, e: PySide2.QtCore.QEvent) -> bool: ...
    def filterMode(self) -> typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag]: ...
    def maxVisibleItems(self) -> int: ...
    def model(self) -> PySide2.QtCore.QAbstractItemModel: ...
    def modelSorting(self) -> QCompleter.ModelSorting: ...
    def pathFromIndex(self, index: PySide2.QtCore.QModelIndex) -> str: ...
    def popup(self) -> QAbstractItemView: ...
    def setCaseSensitivity(self, caseSensitivity: PySide2.QtCore.Qt.CaseSensitivity) -> None: ...
    def setCompletionColumn(self, column: int) -> None: ...
    def setCompletionMode(self, mode: QCompleter.CompletionMode) -> None: ...
    def setCompletionPrefix(self, prefix: str) -> None: ...
    def setCompletionRole(self, role: PySide2.QtCore.Qt.ItemDataRole) -> None: ...
    def setCurrentRow(self, row: int) -> bool: ...
    def setFilterMode(self, filterMode: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag]) -> None: ...
    def setMaxVisibleItems(self, maxItems: int) -> None: ...
    def setModel(self, c: PySide2.QtCore.QAbstractItemModel) -> None: ...
    def setModelSorting(self, sorting: QCompleter.ModelSorting) -> None: ...
    def setPopup(self, popup: QAbstractItemView) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def setWrapAround(self, wrap: bool) -> None: ...
    def splitPath(self, path: str) -> typing.List[str]: ...
    def widget(self) -> QWidget: ...
    def wrapAround(self) -> bool: ...

class QDataWidgetMapper(PySide2.QtCore.QObject):
    class SubmitPolicy:
        AutoSubmit: typing.ClassVar[QDataWidgetMapper.SubmitPolicy] = ...
        ManualSubmit: typing.ClassVar[QDataWidgetMapper.SubmitPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QDataWidgetMapper.SubmitPolicy: ...
    AutoSubmit: typing.ClassVar[QDataWidgetMapper.SubmitPolicy] = ...
    ManualSubmit: typing.ClassVar[QDataWidgetMapper.SubmitPolicy] = ...
    currentIndexChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., currentIndex: int = ..., currentIndexChanged: typing.Callable = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., submitPolicy: QDataWidgetMapper.SubmitPolicy = ...) -> None: ...
    @typing.overload
    def addMapping(self, widget: QWidget, section: int, propertyName: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> None: ...
    @typing.overload
    def addMapping(self, widget: QWidget, section: int) -> None: ...
    def clearMapping(self) -> None: ...
    def currentIndex(self) -> int: ...
    def itemDelegate(self) -> QAbstractItemDelegate: ...
    def mappedPropertyName(self, widget: QWidget) -> PySide2.QtCore.QByteArray: ...
    def mappedSection(self, widget: QWidget) -> int: ...
    def mappedWidgetAt(self, section: int) -> QWidget: ...
    def model(self) -> PySide2.QtCore.QAbstractItemModel: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def removeMapping(self, widget: QWidget) -> None: ...
    def revert(self) -> None: ...
    def rootIndex(self) -> PySide2.QtCore.QModelIndex: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentModelIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setOrientation(self, aOrientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setSubmitPolicy(self, policy: QDataWidgetMapper.SubmitPolicy) -> None: ...
    def submit(self) -> bool: ...
    def submitPolicy(self) -> QDataWidgetMapper.SubmitPolicy: ...
    def toFirst(self) -> None: ...
    def toLast(self) -> None: ...
    def toNext(self) -> None: ...
    def toPrevious(self) -> None: ...

class QDateEdit(QDateTimeEdit):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    userDateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date], parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateEdit.CorrectionMode = ..., currentSection: QDateEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: QDateEdit.Sections = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., userDateChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateEdit.CorrectionMode = ..., currentSection: QDateEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: QDateEdit.Sections = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., userDateChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...

class QDateTimeEdit(QAbstractSpinBox):
    class Section:
        AmPmSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        DateSections_Mask: typing.ClassVar[QDateTimeEdit.Section] = ...
        DaySection: typing.ClassVar[QDateTimeEdit.Section] = ...
        HourSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        MSecSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        MinuteSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        MonthSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        NoSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        SecondSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        TimeSections_Mask: typing.ClassVar[QDateTimeEdit.Section] = ...
        YearSection: typing.ClassVar[QDateTimeEdit.Section] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDateTimeEdit.Sections: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __rand__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __ror__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __xor__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...

    class Sections:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDateTimeEdit.Sections: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __rand__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __ror__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
        def __xor__(self, other: typing.SupportsInt) -> QDateTimeEdit.Sections: ...
    AmPmSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    DateSections_Mask: typing.ClassVar[QDateTimeEdit.Section] = ...
    DaySection: typing.ClassVar[QDateTimeEdit.Section] = ...
    HourSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    MSecSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    MinuteSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    MonthSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    NoSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    SecondSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    TimeSections_Mask: typing.ClassVar[QDateTimeEdit.Section] = ...
    YearSection: typing.ClassVar[QDateTimeEdit.Section] = ...
    dateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    dateTimeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    timeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, val: typing.Any, parserType: type, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateTimeEdit.CorrectionMode = ..., currentSection: QDateTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section] = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, t: PySide2.QtCore.QTime, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateTimeEdit.CorrectionMode = ..., currentSection: QDateTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section] = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, dt: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime], parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateTimeEdit.CorrectionMode = ..., currentSection: QDateTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section] = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, d: typing.Union[PySide2.QtCore.QDate, datetime.date], parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateTimeEdit.CorrectionMode = ..., currentSection: QDateTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section] = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDateTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDateTimeEdit.CorrectionMode = ..., currentSection: QDateTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section] = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def calendar(self) -> PySide2.QtCore.QCalendar: ...
    def calendarPopup(self) -> bool: ...
    def calendarWidget(self) -> QCalendarWidget: ...
    def clear(self) -> None: ...
    def clearMaximumDate(self) -> None: ...
    def clearMaximumDateTime(self) -> None: ...
    def clearMaximumTime(self) -> None: ...
    def clearMinimumDate(self) -> None: ...
    def clearMinimumDateTime(self) -> None: ...
    def clearMinimumTime(self) -> None: ...
    def currentSection(self) -> QDateTimeEdit.Section: ...
    def currentSectionIndex(self) -> int: ...
    def date(self) -> PySide2.QtCore.QDate: ...
    def dateTime(self) -> PySide2.QtCore.QDateTime: ...
    def dateTimeFromText(self, text: str) -> PySide2.QtCore.QDateTime: ...
    def displayFormat(self) -> str: ...
    def displayedSections(self) -> typing.Union[QDateTimeEdit.Sections, QDateTimeEdit.Section]: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def fixup(self, input: str) -> None: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def initStyleOption(self, option: QStyleOptionSpinBox) -> None: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def maximumDate(self) -> PySide2.QtCore.QDate: ...
    def maximumDateTime(self) -> PySide2.QtCore.QDateTime: ...
    def maximumTime(self) -> PySide2.QtCore.QTime: ...
    def minimumDate(self) -> PySide2.QtCore.QDate: ...
    def minimumDateTime(self) -> PySide2.QtCore.QDateTime: ...
    def minimumTime(self) -> PySide2.QtCore.QTime: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def sectionAt(self, index: int) -> QDateTimeEdit.Section: ...
    def sectionCount(self) -> int: ...
    def sectionText(self, section: QDateTimeEdit.Section) -> str: ...
    def setCalendar(self, calendar: PySide2.QtCore.QCalendar) -> None: ...
    def setCalendarPopup(self, enable: bool) -> None: ...
    def setCalendarWidget(self, calendarWidget: QCalendarWidget) -> None: ...
    def setCurrentSection(self, section: QDateTimeEdit.Section) -> None: ...
    def setCurrentSectionIndex(self, index: int) -> None: ...
    def setDate(self, date: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setDateRange(self, min: typing.Union[PySide2.QtCore.QDate, datetime.date], max: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setDateTime(self, dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> None: ...
    def setDateTimeRange(self, min: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime], max: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> None: ...
    def setDisplayFormat(self, format: str) -> None: ...
    def setMaximumDate(self, max: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setMaximumDateTime(self, dt: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> None: ...
    def setMaximumTime(self, max: PySide2.QtCore.QTime) -> None: ...
    def setMinimumDate(self, min: typing.Union[PySide2.QtCore.QDate, datetime.date]) -> None: ...
    def setMinimumDateTime(self, dt: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> None: ...
    def setMinimumTime(self, min: PySide2.QtCore.QTime) -> None: ...
    def setSelectedSection(self, section: QDateTimeEdit.Section) -> None: ...
    def setTime(self, time: PySide2.QtCore.QTime) -> None: ...
    def setTimeRange(self, min: PySide2.QtCore.QTime, max: PySide2.QtCore.QTime) -> None: ...
    def setTimeSpec(self, spec: PySide2.QtCore.Qt.TimeSpec) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def stepBy(self, steps: int) -> None: ...
    def stepEnabled(self) -> typing.Union[QAbstractSpinBox.StepEnabled, QAbstractSpinBox.StepEnabledFlag]: ...
    def textFromDateTime(self, dt: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> str: ...
    def time(self) -> PySide2.QtCore.QTime: ...
    def timeSpec(self) -> PySide2.QtCore.Qt.TimeSpec: ...
    def validate(self, input: str, pos: int) -> PySide2.QtGui.QValidator.State: ...
    def wheelEvent(self, event: PySide2.QtGui.QWheelEvent) -> None: ...

class QDesktopWidget(QWidget):
    primaryScreenChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    resized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    screenCountChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    workAreaResized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., primaryScreen: int = ..., primaryScreenChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resized: typing.Callable = ..., screenCount: int = ..., screenCountChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., virtualDesktop: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., workAreaResized: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def availableGeometry(self, widget: QWidget) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def availableGeometry(self, screen: int = ...) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def availableGeometry(self, point: PySide2.QtCore.QPoint) -> PySide2.QtCore.QRect: ...
    def isVirtualDesktop(self) -> bool: ...
    def numScreens(self) -> int: ...
    def primaryScreen(self) -> int: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    @typing.overload
    def screen(self, screen: int = ...) -> QWidget: ...
    @typing.overload
    def screen(self) -> PySide2.QtGui.QScreen: ...
    def screenCount(self) -> int: ...
    @typing.overload
    def screenGeometry(self, widget: QWidget) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def screenGeometry(self, screen: int = ...) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def screenGeometry(self, point: PySide2.QtCore.QPoint) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def screenNumber(self, widget: typing.Union[QWidget, None] = ...) -> int: ...
    @typing.overload
    def screenNumber(self, arg__1: PySide2.QtCore.QPoint) -> int: ...

class QDial(QAbstractSlider):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., notchSize: int = ..., notchTarget: float = ..., notchesVisible: bool = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def initStyleOption(self, option: QStyleOptionSlider) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, me: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, me: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, me: PySide2.QtGui.QMouseEvent) -> None: ...
    def notchSize(self) -> int: ...
    def notchTarget(self) -> float: ...
    def notchesVisible(self) -> bool: ...
    def paintEvent(self, pe: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, re: PySide2.QtGui.QResizeEvent) -> None: ...
    def setNotchTarget(self, target: float) -> None: ...
    def setNotchesVisible(self, visible: bool) -> None: ...
    def setWrapping(self, on: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sliderChange(self, change: QAbstractSlider.SliderChange) -> None: ...
    def wrapping(self) -> bool: ...

class QDialog(QWidget):
    class DialogCode:
        Accepted: typing.ClassVar[QDialog.DialogCode] = ...
        Rejected: typing.ClassVar[QDialog.DialogCode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __and__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __rand__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __ror__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __sub__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
        def __xor__(self, other: typing.SupportsInt) -> QDialog.DialogCode: ...
    Accepted: typing.ClassVar[QDialog.DialogCode] = ...
    Rejected: typing.ClassVar[QDialog.DialogCode] = ...
    accepted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    finished: typing.ClassVar[PySide2.QtCore.Signal] = ...
    rejected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def accept(self) -> None: ...
    def adjustPosition(self, arg__1: QWidget) -> None: ...
    def closeEvent(self, arg__1: PySide2.QtGui.QCloseEvent) -> None: ...
    def contextMenuEvent(self, arg__1: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def done(self, arg__1: int) -> None: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def exec(self, *args, **kwargs): ...
    def exec_(self) -> int: ...
    def extension(self) -> QWidget: ...
    def isSizeGripEnabled(self) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def open(self) -> None: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def reject(self) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def result(self) -> int: ...
    def setExtension(self, extension: QWidget) -> None: ...
    def setModal(self, modal: bool) -> None: ...
    def setOrientation(self, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setResult(self, r: int) -> None: ...
    def setSizeGripEnabled(self, arg__1: bool) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def showExtension(self, arg__1: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QDialogButtonBox(QWidget):
    class ButtonLayout:
        AndroidLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
        GnomeLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
        KdeLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
        MacLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
        WinLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __and__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __rand__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __rmul__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __ror__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __rsub__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __sub__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...
        def __xor__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonLayout: ...

    class ButtonRole:
        AcceptRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        ActionRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        ApplyRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        DestructiveRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        HelpRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        InvalidRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        NRoles: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        NoRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        RejectRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        ResetRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        YesRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __and__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __rand__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __rmul__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __ror__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __rsub__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __sub__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...
        def __xor__(self, other: typing.SupportsInt) -> QDialogButtonBox.ButtonRole: ...

    class StandardButton:
        Abort: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Apply: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Cancel: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Close: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Discard: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        FirstButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Help: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Ignore: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        LastButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        No: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        NoButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        NoToAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Ok: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Open: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Reset: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        RestoreDefaults: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Retry: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Save: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        SaveAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        Yes: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        YesToAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDialogButtonBox.StandardButtons: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __rand__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __ror__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __xor__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...

    class StandardButtons:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDialogButtonBox.StandardButtons: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __rand__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __ror__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
        def __xor__(self, other: typing.SupportsInt) -> QDialogButtonBox.StandardButtons: ...
    Abort: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    AcceptRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    ActionRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    AndroidLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
    Apply: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    ApplyRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    Cancel: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    Close: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    DestructiveRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    Discard: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    FirstButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    GnomeLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
    Help: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    HelpRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    Ignore: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    InvalidRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    KdeLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
    LastButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    MacLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
    NRoles: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    No: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    NoButton: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    NoRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    NoToAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    Ok: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    Open: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    RejectRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    Reset: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    ResetRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    RestoreDefaults: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    Retry: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    Save: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    SaveAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    WinLayout: typing.ClassVar[QDialogButtonBox.ButtonLayout] = ...
    Yes: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    YesRole: typing.ClassVar[QDialogButtonBox.ButtonRole] = ...
    YesToAll: typing.ClassVar[QDialogButtonBox.StandardButton] = ...
    accepted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    helpRequested: typing.ClassVar[PySide2.QtCore.Signal] = ...
    rejected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, buttons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton], orientation: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., centerButtons: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., helpRequested: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, orientation: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., centerButtons: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., helpRequested: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, buttons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton], parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., centerButtons: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., helpRequested: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., centerButtons: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., helpRequested: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addButton(self, text: str, role: QDialogButtonBox.ButtonRole) -> QPushButton: ...
    @typing.overload
    def addButton(self, button: QAbstractButton, role: QDialogButtonBox.ButtonRole) -> None: ...
    @typing.overload
    def addButton(self, button: QDialogButtonBox.StandardButton) -> QPushButton: ...
    def button(self, which: QDialogButtonBox.StandardButton) -> QPushButton: ...
    def buttonRole(self, button: QAbstractButton) -> QDialogButtonBox.ButtonRole: ...
    def buttons(self) -> typing.List[QAbstractButton]: ...
    def centerButtons(self) -> bool: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def removeButton(self, button: QAbstractButton) -> None: ...
    def setCenterButtons(self, center: bool) -> None: ...
    def setOrientation(self, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setStandardButtons(self, buttons: typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton]) -> None: ...
    def standardButton(self, button: QAbstractButton) -> QDialogButtonBox.StandardButton: ...
    def standardButtons(self) -> typing.Union[QDialogButtonBox.StandardButtons, QDialogButtonBox.StandardButton]: ...

class QDirModel(PySide2.QtCore.QAbstractItemModel):
    class Roles:
        FileIconRole: typing.ClassVar[QDirModel.Roles] = ...
        FileNameRole: typing.ClassVar[QDirModel.Roles] = ...
        FilePathRole: typing.ClassVar[QDirModel.Roles] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __and__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __rand__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __rmul__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __ror__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __rsub__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __sub__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
        def __xor__(self, other: typing.SupportsInt) -> QDirModel.Roles: ...
    FileIconRole: typing.ClassVar[QDirModel.Roles] = ...
    FileNameRole: typing.ClassVar[QDirModel.Roles] = ...
    FilePathRole: typing.ClassVar[QDirModel.Roles] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, nameFilters: typing.Iterable[str], filters: typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter], sort: typing.Union[PySide2.QtCore.QDir.SortFlags, PySide2.QtCore.QDir.SortFlag], parent: typing.Union[PySide2.QtCore.QObject, None] = ..., columnsAboutToBeInserted: typing.Callable = ..., columnsAboutToBeMoved: typing.Callable = ..., columnsAboutToBeRemoved: typing.Callable = ..., columnsInserted: typing.Callable = ..., columnsMoved: typing.Callable = ..., columnsRemoved: typing.Callable = ..., dataChanged: typing.Callable = ..., destroyed: typing.Callable = ..., headerDataChanged: typing.Callable = ..., layoutAboutToBeChanged: typing.Callable = ..., layoutChanged: typing.Callable = ..., lazyChildCount: bool = ..., modelAboutToBeReset: typing.Callable = ..., modelReset: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., readOnly: bool = ..., resolveSymlinks: bool = ..., rowsAboutToBeInserted: typing.Callable = ..., rowsAboutToBeMoved: typing.Callable = ..., rowsAboutToBeRemoved: typing.Callable = ..., rowsInserted: typing.Callable = ..., rowsMoved: typing.Callable = ..., rowsRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., columnsAboutToBeInserted: typing.Callable = ..., columnsAboutToBeMoved: typing.Callable = ..., columnsAboutToBeRemoved: typing.Callable = ..., columnsInserted: typing.Callable = ..., columnsMoved: typing.Callable = ..., columnsRemoved: typing.Callable = ..., dataChanged: typing.Callable = ..., destroyed: typing.Callable = ..., headerDataChanged: typing.Callable = ..., layoutAboutToBeChanged: typing.Callable = ..., layoutChanged: typing.Callable = ..., lazyChildCount: bool = ..., modelAboutToBeReset: typing.Callable = ..., modelReset: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., readOnly: bool = ..., resolveSymlinks: bool = ..., rowsAboutToBeInserted: typing.Callable = ..., rowsAboutToBeMoved: typing.Callable = ..., rowsAboutToBeRemoved: typing.Callable = ..., rowsInserted: typing.Callable = ..., rowsMoved: typing.Callable = ..., rowsRemoved: typing.Callable = ...) -> None: ...
    def columnCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def data(self, index: PySide2.QtCore.QModelIndex, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def dropMimeData(self, data: PySide2.QtCore.QMimeData, action: PySide2.QtCore.Qt.DropAction, row: int, column: int, parent: PySide2.QtCore.QModelIndex) -> bool: ...
    def fileIcon(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtGui.QIcon: ...
    def fileInfo(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QFileInfo: ...
    def fileName(self, index: PySide2.QtCore.QModelIndex) -> str: ...
    def filePath(self, index: PySide2.QtCore.QModelIndex) -> str: ...
    def filter(self) -> typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]: ...
    def flags(self, index: PySide2.QtCore.QModelIndex) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def hasChildren(self, index: PySide2.QtCore.QModelIndex = ...) -> bool: ...
    def headerData(self, section: int, orientation: PySide2.QtCore.Qt.Orientation, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def iconProvider(self) -> QFileIconProvider: ...
    @typing.overload
    def index(self, row: int, column: int, parent: PySide2.QtCore.QModelIndex = ...) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def index(self, path: str, column: int = ...) -> PySide2.QtCore.QModelIndex: ...
    def isDir(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def lazyChildCount(self) -> bool: ...
    def mimeData(self, indexes: typing.List[int]) -> PySide2.QtCore.QMimeData: ...
    def mimeTypes(self) -> typing.List[str]: ...
    def mkdir(self, parent: PySide2.QtCore.QModelIndex, name: str) -> PySide2.QtCore.QModelIndex: ...
    def nameFilters(self) -> typing.List[str]: ...
    @typing.overload
    def parent(self, child: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def parent(self) -> PySide2.QtCore.QObject: ...
    def refresh(self, parent: PySide2.QtCore.QModelIndex = ...) -> None: ...
    def remove(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def resolveSymlinks(self) -> bool: ...
    def rmdir(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def rowCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def setData(self, index: PySide2.QtCore.QModelIndex, value: typing.Any, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> bool: ...
    def setFilter(self, filters: typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]) -> None: ...
    def setIconProvider(self, provider: QFileIconProvider) -> None: ...
    def setLazyChildCount(self, enable: bool) -> None: ...
    def setNameFilters(self, filters: typing.Iterable[str]) -> None: ...
    def setReadOnly(self, enable: bool) -> None: ...
    def setResolveSymlinks(self, enable: bool) -> None: ...
    def setSorting(self, sort: typing.Union[PySide2.QtCore.QDir.SortFlags, PySide2.QtCore.QDir.SortFlag]) -> None: ...
    def sort(self, column: int, order: PySide2.QtCore.Qt.SortOrder = ...) -> None: ...
    def sorting(self) -> typing.Union[PySide2.QtCore.QDir.SortFlags, PySide2.QtCore.QDir.SortFlag]: ...
    def supportedDropActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...

class QDockWidget(QWidget):
    class DockWidgetFeature:
        AllDockWidgetFeatures: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        DockWidgetClosable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        DockWidgetFeatureMask: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        DockWidgetFloatable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        DockWidgetMovable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        DockWidgetVerticalTitleBar: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        NoDockWidgetFeatures: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        Reserved: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDockWidget.DockWidgetFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...

    class DockWidgetFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QDockWidget.DockWidgetFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QDockWidget.DockWidgetFeatures: ...
    AllDockWidgetFeatures: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    DockWidgetClosable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    DockWidgetFeatureMask: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    DockWidgetFloatable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    DockWidgetMovable: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    DockWidgetVerticalTitleBar: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    NoDockWidgetFeatures: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    Reserved: typing.ClassVar[QDockWidget.DockWidgetFeature] = ...
    allowedAreasChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    dockLocationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    featuresChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    topLevelChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    visibilityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, title: str, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., allowedAreas: typing.Union[PySide2.QtCore.Qt.DockWidgetAreas, PySide2.QtCore.Qt.DockWidgetArea] = ..., allowedAreasChanged: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., dockLocationChanged: typing.Callable = ..., enabled: bool = ..., features: typing.Union[QDockWidget.DockWidgetFeatures, QDockWidget.DockWidgetFeature] = ..., featuresChanged: typing.Callable = ..., floating: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., topLevelChanged: typing.Callable = ..., updatesEnabled: bool = ..., visibilityChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., allowedAreas: typing.Union[PySide2.QtCore.Qt.DockWidgetAreas, PySide2.QtCore.Qt.DockWidgetArea] = ..., allowedAreasChanged: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., dockLocationChanged: typing.Callable = ..., enabled: bool = ..., features: typing.Union[QDockWidget.DockWidgetFeatures, QDockWidget.DockWidgetFeature] = ..., featuresChanged: typing.Callable = ..., floating: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., topLevelChanged: typing.Callable = ..., updatesEnabled: bool = ..., visibilityChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def allowedAreas(self) -> typing.Union[PySide2.QtCore.Qt.DockWidgetAreas, PySide2.QtCore.Qt.DockWidgetArea]: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def features(self) -> typing.Union[QDockWidget.DockWidgetFeatures, QDockWidget.DockWidgetFeature]: ...
    def initStyleOption(self, option: QStyleOptionDockWidget) -> None: ...
    def isAreaAllowed(self, area: PySide2.QtCore.Qt.DockWidgetArea) -> bool: ...
    def isFloating(self) -> bool: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def setAllowedAreas(self, areas: typing.Union[PySide2.QtCore.Qt.DockWidgetAreas, PySide2.QtCore.Qt.DockWidgetArea]) -> None: ...
    def setFeatures(self, features: typing.Union[QDockWidget.DockWidgetFeatures, QDockWidget.DockWidgetFeature]) -> None: ...
    def setFloating(self, floating: bool) -> None: ...
    def setTitleBarWidget(self, widget: QWidget) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def titleBarWidget(self) -> QWidget: ...
    def toggleViewAction(self) -> QAction: ...
    def widget(self) -> QWidget: ...

class QDoubleSpinBox(QAbstractSpinBox):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QDoubleSpinBox.ButtonSymbols = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., cleanText: str = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QDoubleSpinBox.CorrectionMode = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., decimals: int = ..., destroyed: typing.Callable = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: float = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: float = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., prefix: str = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., showGroupSeparator: bool = ..., singleStep: float = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., stepType: QDoubleSpinBox.StepType = ..., styleSheet: str = ..., suffix: str = ..., tabletTracking: bool = ..., text: str = ..., textChanged: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: float = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def cleanText(self) -> str: ...
    def decimals(self) -> int: ...
    def fixup(self, str: str) -> None: ...
    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def prefix(self) -> str: ...
    def setDecimals(self, prec: int) -> None: ...
    def setMaximum(self, max: float) -> None: ...
    def setMinimum(self, min: float) -> None: ...
    def setPrefix(self, prefix: str) -> None: ...
    def setRange(self, min: float, max: float) -> None: ...
    def setSingleStep(self, val: float) -> None: ...
    def setStepType(self, stepType: QAbstractSpinBox.StepType) -> None: ...
    def setSuffix(self, suffix: str) -> None: ...
    def setValue(self, val: float) -> None: ...
    def singleStep(self) -> float: ...
    def stepType(self) -> QAbstractSpinBox.StepType: ...
    def suffix(self) -> str: ...
    def textFromValue(self, val: float) -> str: ...
    def validate(self, input: str, pos: int) -> PySide2.QtGui.QValidator.State: ...
    def value(self) -> float: ...
    def valueFromText(self, text: str) -> float: ...

class QErrorMessage(QDialog):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def done(self, arg__1: int) -> None: ...
    @classmethod
    def qtHandler(cls) -> QErrorMessage: ...
    @typing.overload
    def showMessage(self, message: str, type: str) -> None: ...
    @typing.overload
    def showMessage(self, message: str) -> None: ...

class QFileDialog(QDialog):
    class AcceptMode:
        AcceptOpen: typing.ClassVar[QFileDialog.AcceptMode] = ...
        AcceptSave: typing.ClassVar[QFileDialog.AcceptMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.AcceptMode: ...

    class DialogLabel:
        Accept: typing.ClassVar[QFileDialog.DialogLabel] = ...
        FileName: typing.ClassVar[QFileDialog.DialogLabel] = ...
        FileType: typing.ClassVar[QFileDialog.DialogLabel] = ...
        LookIn: typing.ClassVar[QFileDialog.DialogLabel] = ...
        Reject: typing.ClassVar[QFileDialog.DialogLabel] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.DialogLabel: ...

    class FileMode:
        AnyFile: typing.ClassVar[QFileDialog.FileMode] = ...
        Directory: typing.ClassVar[QFileDialog.FileMode] = ...
        DirectoryOnly: typing.ClassVar[QFileDialog.FileMode] = ...
        ExistingFile: typing.ClassVar[QFileDialog.FileMode] = ...
        ExistingFiles: typing.ClassVar[QFileDialog.FileMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.FileMode: ...

    class Option:
        DontConfirmOverwrite: typing.ClassVar[QFileDialog.Option] = ...
        DontResolveSymlinks: typing.ClassVar[QFileDialog.Option] = ...
        DontUseCustomDirectoryIcons: typing.ClassVar[QFileDialog.Option] = ...
        DontUseNativeDialog: typing.ClassVar[QFileDialog.Option] = ...
        DontUseSheet: typing.ClassVar[QFileDialog.Option] = ...
        HideNameFilterDetails: typing.ClassVar[QFileDialog.Option] = ...
        ReadOnly: typing.ClassVar[QFileDialog.Option] = ...
        ShowDirsOnly: typing.ClassVar[QFileDialog.Option] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileDialog.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...

    class Options:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileDialog.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.Options: ...

    class ViewMode:
        Detail: typing.ClassVar[QFileDialog.ViewMode] = ...
        List: typing.ClassVar[QFileDialog.ViewMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __and__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileDialog.ViewMode: ...
    Accept: typing.ClassVar[QFileDialog.DialogLabel] = ...
    AcceptOpen: typing.ClassVar[QFileDialog.AcceptMode] = ...
    AcceptSave: typing.ClassVar[QFileDialog.AcceptMode] = ...
    AnyFile: typing.ClassVar[QFileDialog.FileMode] = ...
    Detail: typing.ClassVar[QFileDialog.ViewMode] = ...
    Directory: typing.ClassVar[QFileDialog.FileMode] = ...
    DirectoryOnly: typing.ClassVar[QFileDialog.FileMode] = ...
    DontConfirmOverwrite: typing.ClassVar[QFileDialog.Option] = ...
    DontResolveSymlinks: typing.ClassVar[QFileDialog.Option] = ...
    DontUseCustomDirectoryIcons: typing.ClassVar[QFileDialog.Option] = ...
    DontUseNativeDialog: typing.ClassVar[QFileDialog.Option] = ...
    DontUseSheet: typing.ClassVar[QFileDialog.Option] = ...
    ExistingFile: typing.ClassVar[QFileDialog.FileMode] = ...
    ExistingFiles: typing.ClassVar[QFileDialog.FileMode] = ...
    FileName: typing.ClassVar[QFileDialog.DialogLabel] = ...
    FileType: typing.ClassVar[QFileDialog.DialogLabel] = ...
    HideNameFilterDetails: typing.ClassVar[QFileDialog.Option] = ...
    List: typing.ClassVar[QFileDialog.ViewMode] = ...
    LookIn: typing.ClassVar[QFileDialog.DialogLabel] = ...
    ReadOnly: typing.ClassVar[QFileDialog.Option] = ...
    Reject: typing.ClassVar[QFileDialog.DialogLabel] = ...
    ShowDirsOnly: typing.ClassVar[QFileDialog.Option] = ...
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentUrlChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    directoryEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    directoryUrlEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    fileSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    filesSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    filterSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    urlSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    urlsSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., caption: str = ..., directory: str = ..., filter: str = ..., acceptDrops: bool = ..., acceptMode: QFileDialog.AcceptMode = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., confirmOverwrite: bool = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentChanged: typing.Callable = ..., currentUrlChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultSuffix: str = ..., destroyed: typing.Callable = ..., directoryEntered: typing.Callable = ..., directoryUrlEntered: typing.Callable = ..., enabled: bool = ..., fileMode: QFileDialog.FileMode = ..., fileSelected: typing.Callable = ..., filesSelected: typing.Callable = ..., filterSelected: typing.Callable = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., nameFilterDetailsVisible: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., resolveSymlinks: bool = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., supportedSchemes: None = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., urlSelected: typing.Callable = ..., urlsSelected: typing.Callable = ..., viewMode: QFileDialog.ViewMode = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType], acceptDrops: bool = ..., acceptMode: QFileDialog.AcceptMode = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., confirmOverwrite: bool = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentChanged: typing.Callable = ..., currentUrlChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultSuffix: str = ..., destroyed: typing.Callable = ..., directoryEntered: typing.Callable = ..., directoryUrlEntered: typing.Callable = ..., enabled: bool = ..., fileMode: QFileDialog.FileMode = ..., fileSelected: typing.Callable = ..., filesSelected: typing.Callable = ..., filterSelected: typing.Callable = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., nameFilterDetailsVisible: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., resolveSymlinks: bool = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., supportedSchemes: None = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., urlSelected: typing.Callable = ..., urlsSelected: typing.Callable = ..., viewMode: QFileDialog.ViewMode = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def accept(self) -> None: ...
    def acceptMode(self) -> QFileDialog.AcceptMode: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def confirmOverwrite(self) -> bool: ...
    def defaultSuffix(self) -> str: ...
    def directory(self) -> PySide2.QtCore.QDir: ...
    def directoryUrl(self) -> PySide2.QtCore.QUrl: ...
    def done(self, result: int) -> None: ...
    def fileMode(self) -> QFileDialog.FileMode: ...
    def filter(self) -> typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]: ...
    @classmethod
    def getExistingDirectory(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ...) -> str: ...
    @classmethod
    def getExistingDirectoryUrl(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: PySide2.QtCore.QUrl = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., supportedSchemes: typing.Iterable[str] = ...) -> PySide2.QtCore.QUrl: ...
    @classmethod
    def getOpenFileName(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: str = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ...) -> typing.Tuple[str, str]: ...
    @classmethod
    def getOpenFileNames(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: str = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ...) -> typing.Tuple[typing.List[str], str]: ...
    @classmethod
    def getOpenFileUrl(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: PySide2.QtCore.QUrl = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., supportedSchemes: typing.Iterable[str] = ...) -> typing.Tuple[PySide2.QtCore.QUrl, str]: ...
    @classmethod
    def getOpenFileUrls(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: PySide2.QtCore.QUrl = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., supportedSchemes: typing.Iterable[str] = ...) -> typing.Tuple[typing.List[PySide2.QtCore.QUrl], str]: ...
    @classmethod
    def getSaveFileName(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: str = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ...) -> typing.Tuple[str, str]: ...
    @classmethod
    def getSaveFileUrl(cls, parent: typing.Union[QWidget, None] = ..., caption: str = ..., dir: PySide2.QtCore.QUrl = ..., filter: str = ..., options: typing.Union[QFileDialog.Options, QFileDialog.Option] = ..., supportedSchemes: typing.Iterable[str] = ...) -> typing.Tuple[PySide2.QtCore.QUrl, str]: ...
    def history(self) -> typing.List[str]: ...
    def iconProvider(self) -> QFileIconProvider: ...
    def isNameFilterDetailsVisible(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def itemDelegate(self) -> QAbstractItemDelegate: ...
    def labelText(self, label: QFileDialog.DialogLabel) -> str: ...
    def mimeTypeFilters(self) -> typing.List[str]: ...
    def nameFilters(self) -> typing.List[str]: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    def options(self) -> typing.Union[QFileDialog.Options, QFileDialog.Option]: ...
    def proxyModel(self) -> PySide2.QtCore.QAbstractProxyModel: ...
    def resolveSymlinks(self) -> bool: ...
    def restoreState(self, state: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> bool: ...
    @classmethod
    def saveFileContent(cls, fileContent: typing.Union[PySide2.QtCore.QByteArray, bytes], fileNameHint: str = ...) -> None: ...
    def saveState(self) -> PySide2.QtCore.QByteArray: ...
    def selectFile(self, filename: str) -> None: ...
    def selectMimeTypeFilter(self, filter: str) -> None: ...
    def selectNameFilter(self, filter: str) -> None: ...
    def selectUrl(self, url: PySide2.QtCore.QUrl) -> None: ...
    def selectedFiles(self) -> typing.List[str]: ...
    def selectedMimeTypeFilter(self) -> str: ...
    def selectedNameFilter(self) -> str: ...
    def selectedUrls(self) -> typing.List[PySide2.QtCore.QUrl]: ...
    def setAcceptMode(self, mode: QFileDialog.AcceptMode) -> None: ...
    def setConfirmOverwrite(self, enabled: bool) -> None: ...
    def setDefaultSuffix(self, suffix: str) -> None: ...
    @typing.overload
    def setDirectory(self, directory: PySide2.QtCore.QDir) -> None: ...
    @typing.overload
    def setDirectory(self, directory: str) -> None: ...
    def setDirectoryUrl(self, directory: PySide2.QtCore.QUrl) -> None: ...
    def setFileMode(self, mode: QFileDialog.FileMode) -> None: ...
    def setFilter(self, filters: typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]) -> None: ...
    def setHistory(self, paths: typing.Iterable[str]) -> None: ...
    def setIconProvider(self, provider: QFileIconProvider) -> None: ...
    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None: ...
    def setLabelText(self, label: QFileDialog.DialogLabel, text: str) -> None: ...
    def setMimeTypeFilters(self, filters: typing.Iterable[str]) -> None: ...
    def setNameFilter(self, filter: str) -> None: ...
    def setNameFilterDetailsVisible(self, enabled: bool) -> None: ...
    def setNameFilters(self, filters: typing.Iterable[str]) -> None: ...
    def setOption(self, option: QFileDialog.Option, on: bool = ...) -> None: ...
    def setOptions(self, options: typing.Union[QFileDialog.Options, QFileDialog.Option]) -> None: ...
    def setProxyModel(self, model: PySide2.QtCore.QAbstractProxyModel) -> None: ...
    def setReadOnly(self, enabled: bool) -> None: ...
    def setResolveSymlinks(self, enabled: bool) -> None: ...
    def setSidebarUrls(self, urls: typing.Iterable[PySide2.QtCore.QUrl]) -> None: ...
    def setSupportedSchemes(self, schemes: typing.Iterable[str]) -> None: ...
    def setViewMode(self, mode: QFileDialog.ViewMode) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def sidebarUrls(self) -> typing.List[PySide2.QtCore.QUrl]: ...
    def supportedSchemes(self) -> typing.List[str]: ...
    def testOption(self, option: QFileDialog.Option) -> bool: ...
    def viewMode(self) -> QFileDialog.ViewMode: ...

class QFileIconProvider(shiboken2.Object):
    class IconType:
        Computer: typing.ClassVar[QFileIconProvider.IconType] = ...
        Desktop: typing.ClassVar[QFileIconProvider.IconType] = ...
        Drive: typing.ClassVar[QFileIconProvider.IconType] = ...
        File: typing.ClassVar[QFileIconProvider.IconType] = ...
        Folder: typing.ClassVar[QFileIconProvider.IconType] = ...
        Network: typing.ClassVar[QFileIconProvider.IconType] = ...
        Trashcan: typing.ClassVar[QFileIconProvider.IconType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __and__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileIconProvider.IconType: ...

    class Option:
        DontUseCustomDirectoryIcons: typing.ClassVar[QFileIconProvider.Option] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileIconProvider.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...

    class Options:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileIconProvider.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileIconProvider.Options: ...
    Computer: typing.ClassVar[QFileIconProvider.IconType] = ...
    Desktop: typing.ClassVar[QFileIconProvider.IconType] = ...
    DontUseCustomDirectoryIcons: typing.ClassVar[QFileIconProvider.Option] = ...
    Drive: typing.ClassVar[QFileIconProvider.IconType] = ...
    File: typing.ClassVar[QFileIconProvider.IconType] = ...
    Folder: typing.ClassVar[QFileIconProvider.IconType] = ...
    Network: typing.ClassVar[QFileIconProvider.IconType] = ...
    Trashcan: typing.ClassVar[QFileIconProvider.IconType] = ...
    def __init__(self) -> None: ...
    @typing.overload
    def icon(self, type: QFileIconProvider.IconType) -> PySide2.QtGui.QIcon: ...
    @typing.overload
    def icon(self, info: PySide2.QtCore.QFileInfo) -> PySide2.QtGui.QIcon: ...
    def options(self) -> typing.Union[QFileIconProvider.Options, QFileIconProvider.Option]: ...
    def setOptions(self, options: typing.Union[QFileIconProvider.Options, QFileIconProvider.Option]) -> None: ...
    def type(self, info: PySide2.QtCore.QFileInfo) -> str: ...

class QFileSystemModel(PySide2.QtCore.QAbstractItemModel):
    class Option:
        DontResolveSymlinks: typing.ClassVar[QFileSystemModel.Option] = ...
        DontUseCustomDirectoryIcons: typing.ClassVar[QFileSystemModel.Option] = ...
        DontWatchForChanges: typing.ClassVar[QFileSystemModel.Option] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileSystemModel.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...

    class Options:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFileSystemModel.Options: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileSystemModel.Options: ...

    class Roles:
        FileIconRole: typing.ClassVar[QFileSystemModel.Roles] = ...
        FileNameRole: typing.ClassVar[QFileSystemModel.Roles] = ...
        FilePathRole: typing.ClassVar[QFileSystemModel.Roles] = ...
        FilePermissions: typing.ClassVar[QFileSystemModel.Roles] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __and__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __rand__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __ror__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __sub__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
        def __xor__(self, other: typing.SupportsInt) -> QFileSystemModel.Roles: ...
    DontResolveSymlinks: typing.ClassVar[QFileSystemModel.Option] = ...
    DontUseCustomDirectoryIcons: typing.ClassVar[QFileSystemModel.Option] = ...
    DontWatchForChanges: typing.ClassVar[QFileSystemModel.Option] = ...
    FileIconRole: typing.ClassVar[QFileSystemModel.Roles] = ...
    FileNameRole: typing.ClassVar[QFileSystemModel.Roles] = ...
    FilePathRole: typing.ClassVar[QFileSystemModel.Roles] = ...
    FilePermissions: typing.ClassVar[QFileSystemModel.Roles] = ...
    directoryLoaded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    fileRenamed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    rootPathChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., columnsAboutToBeInserted: typing.Callable = ..., columnsAboutToBeMoved: typing.Callable = ..., columnsAboutToBeRemoved: typing.Callable = ..., columnsInserted: typing.Callable = ..., columnsMoved: typing.Callable = ..., columnsRemoved: typing.Callable = ..., dataChanged: typing.Callable = ..., destroyed: typing.Callable = ..., directoryLoaded: typing.Callable = ..., fileRenamed: typing.Callable = ..., headerDataChanged: typing.Callable = ..., layoutAboutToBeChanged: typing.Callable = ..., layoutChanged: typing.Callable = ..., modelAboutToBeReset: typing.Callable = ..., modelReset: typing.Callable = ..., nameFilterDisables: bool = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QFileSystemModel.Options, QFileSystemModel.Option] = ..., readOnly: bool = ..., resolveSymlinks: bool = ..., rootPathChanged: typing.Callable = ..., rowsAboutToBeInserted: typing.Callable = ..., rowsAboutToBeMoved: typing.Callable = ..., rowsAboutToBeRemoved: typing.Callable = ..., rowsInserted: typing.Callable = ..., rowsMoved: typing.Callable = ..., rowsRemoved: typing.Callable = ...) -> None: ...
    def canFetchMore(self, parent: PySide2.QtCore.QModelIndex) -> bool: ...
    def columnCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def data(self, index: PySide2.QtCore.QModelIndex, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def dropMimeData(self, data: PySide2.QtCore.QMimeData, action: PySide2.QtCore.Qt.DropAction, row: int, column: int, parent: PySide2.QtCore.QModelIndex) -> bool: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def fetchMore(self, parent: PySide2.QtCore.QModelIndex) -> None: ...
    def fileIcon(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtGui.QIcon: ...
    def fileInfo(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QFileInfo: ...
    def fileName(self, index: PySide2.QtCore.QModelIndex) -> str: ...
    def filePath(self, index: PySide2.QtCore.QModelIndex) -> str: ...
    def filter(self) -> typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]: ...
    def flags(self, index: PySide2.QtCore.QModelIndex) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def hasChildren(self, parent: PySide2.QtCore.QModelIndex = ...) -> bool: ...
    def headerData(self, section: int, orientation: PySide2.QtCore.Qt.Orientation, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def iconProvider(self) -> QFileIconProvider: ...
    @typing.overload
    def index(self, row: int, column: int, parent: PySide2.QtCore.QModelIndex = ...) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def index(self, path: str, column: int = ...) -> PySide2.QtCore.QModelIndex: ...
    def isDir(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def lastModified(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QDateTime: ...
    def mimeData(self, indexes: typing.List[int]) -> PySide2.QtCore.QMimeData: ...
    def mimeTypes(self) -> typing.List[str]: ...
    def mkdir(self, parent: PySide2.QtCore.QModelIndex, name: str) -> PySide2.QtCore.QModelIndex: ...
    def myComputer(self, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def nameFilterDisables(self) -> bool: ...
    def nameFilters(self) -> typing.List[str]: ...
    def options(self) -> typing.Union[QFileSystemModel.Options, QFileSystemModel.Option]: ...
    @typing.overload
    def parent(self, child: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def parent(self) -> PySide2.QtCore.QObject: ...
    def remove(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def resolveSymlinks(self) -> bool: ...
    def rmdir(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def rootDirectory(self) -> PySide2.QtCore.QDir: ...
    def rootPath(self) -> str: ...
    def rowCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def setData(self, index: PySide2.QtCore.QModelIndex, value: typing.Any, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> bool: ...
    def setFilter(self, filters: typing.Union[PySide2.QtCore.QDir.Filters, PySide2.QtCore.QDir.Filter]) -> None: ...
    def setIconProvider(self, provider: QFileIconProvider) -> None: ...
    def setNameFilterDisables(self, enable: bool) -> None: ...
    def setNameFilters(self, filters: typing.Iterable[str]) -> None: ...
    def setOption(self, option: QFileSystemModel.Option, on: bool = ...) -> None: ...
    def setOptions(self, options: typing.Union[QFileSystemModel.Options, QFileSystemModel.Option]) -> None: ...
    def setReadOnly(self, enable: bool) -> None: ...
    def setResolveSymlinks(self, enable: bool) -> None: ...
    def setRootPath(self, path: str) -> PySide2.QtCore.QModelIndex: ...
    def sibling(self, row: int, column: int, idx: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    def size(self, index: PySide2.QtCore.QModelIndex) -> int: ...
    def sort(self, column: int, order: PySide2.QtCore.Qt.SortOrder = ...) -> None: ...
    def supportedDropActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...
    def testOption(self, option: QFileSystemModel.Option) -> bool: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    def type(self, index: PySide2.QtCore.QModelIndex) -> str: ...

class QFocusFrame(QWidget):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def initStyleOption(self, option: QStyleOption) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def widget(self) -> QWidget: ...

class QFontComboBox(QComboBox):
    class FontFilter:
        AllFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
        MonospacedFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
        NonScalableFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
        ProportionalFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
        ScalableFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFontComboBox.FontFilters: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __rand__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __ror__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __xor__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...

    class FontFilters:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFontComboBox.FontFilters: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __rand__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __ror__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
        def __xor__(self, other: typing.SupportsInt) -> QFontComboBox.FontFilters: ...
    AllFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
    MonospacedFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
    NonScalableFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
    ProportionalFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
    ScalableFonts: typing.ClassVar[QFontComboBox.FontFilter] = ...
    currentFontChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., autoCompletion: bool = ..., autoCompletionCaseSensitivity: PySide2.QtCore.Qt.CaseSensitivity = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentData: object = ..., currentFont: PySide2.QtGui.QFont = ..., currentFontChanged: typing.Callable = ..., currentIndex: int = ..., currentIndexChanged: typing.Callable = ..., currentText: str = ..., currentTextChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., duplicatesEnabled: bool = ..., editTextChanged: typing.Callable = ..., editable: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., fontFilters: typing.Union[QFontComboBox.FontFilters, QFontComboBox.FontFilter] = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., highlighted: typing.Callable = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., insertPolicy: QFontComboBox.InsertPolicy = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maxCount: int = ..., maxVisibleItems: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumContentsLength: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QFontComboBox.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., textActivated: typing.Callable = ..., textHighlighted: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., writingSystem: typing.Any = ..., x: int = ..., y: int = ...) -> None: ...
    def currentFont(self) -> PySide2.QtGui.QFont: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def fontFilters(self) -> typing.Union[QFontComboBox.FontFilters, QFontComboBox.FontFilter]: ...
    def setCurrentFont(self, f: PySide2.QtGui.QFont) -> None: ...
    def setFontFilters(self, filters: typing.Union[QFontComboBox.FontFilters, QFontComboBox.FontFilter]) -> None: ...
    def setWritingSystem(self, arg__1: PySide2.QtGui.QFontDatabase.WritingSystem) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def writingSystem(self) -> PySide2.QtGui.QFontDatabase.WritingSystem: ...

class QFontDialog(QDialog):
    class FontDialogOption:
        DontUseNativeDialog: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        MonospacedFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        NoButtons: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        NonScalableFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        ProportionalFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        ScalableFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFontDialog.FontDialogOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...

    class FontDialogOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QFontDialog.FontDialogOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QFontDialog.FontDialogOptions: ...
    DontUseNativeDialog: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    MonospacedFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    NoButtons: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    NonScalableFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    ProportionalFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    ScalableFonts: typing.ClassVar[QFontDialog.FontDialogOption] = ...
    currentFontChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    fontSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, initial: PySide2.QtGui.QFont, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentFont: PySide2.QtGui.QFont = ..., currentFontChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., fontSelected: typing.Callable = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QFontDialog.FontDialogOptions, QFontDialog.FontDialogOption] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentFont: PySide2.QtGui.QFont = ..., currentFontChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., fontSelected: typing.Callable = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QFontDialog.FontDialogOptions, QFontDialog.FontDialogOption] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def currentFont(self) -> PySide2.QtGui.QFont: ...
    def done(self, result: int) -> None: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    @typing.overload
    @classmethod
    def getFont(cls, initial: PySide2.QtGui.QFont, parent: typing.Union[QWidget, None] = ..., title: str = ..., options: typing.Union[QFontDialog.FontDialogOptions, QFontDialog.FontDialogOption] = ...) -> typing.Tuple[PySide2.QtGui.QFont, bool]: ...
    @typing.overload
    @classmethod
    def getFont(cls, parent: typing.Union[QWidget, None] = ...) -> typing.Tuple[PySide2.QtGui.QFont, bool]: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    def options(self) -> typing.Union[QFontDialog.FontDialogOptions, QFontDialog.FontDialogOption]: ...
    def selectedFont(self) -> PySide2.QtGui.QFont: ...
    def setCurrentFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setOption(self, option: QFontDialog.FontDialogOption, on: bool = ...) -> None: ...
    def setOptions(self, options: typing.Union[QFontDialog.FontDialogOptions, QFontDialog.FontDialogOption]) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def testOption(self, option: QFontDialog.FontDialogOption) -> bool: ...

class QFormLayout(QLayout):
    class FieldGrowthPolicy:
        AllNonFixedFieldsGrow: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
        ExpandingFieldsGrow: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
        FieldsStayAtSizeHint: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QFormLayout.FieldGrowthPolicy: ...

    class ItemRole:
        FieldRole: typing.ClassVar[QFormLayout.ItemRole] = ...
        LabelRole: typing.ClassVar[QFormLayout.ItemRole] = ...
        SpanningRole: typing.ClassVar[QFormLayout.ItemRole] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __and__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __rand__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __ror__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __sub__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...
        def __xor__(self, other: typing.SupportsInt) -> QFormLayout.ItemRole: ...

    class RowWrapPolicy:
        DontWrapRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
        WrapAllRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
        WrapLongRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QFormLayout.RowWrapPolicy: ...
    AllNonFixedFieldsGrow: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
    DontWrapRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
    ExpandingFieldsGrow: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
    FieldRole: typing.ClassVar[QFormLayout.ItemRole] = ...
    FieldsStayAtSizeHint: typing.ClassVar[QFormLayout.FieldGrowthPolicy] = ...
    LabelRole: typing.ClassVar[QFormLayout.ItemRole] = ...
    SpanningRole: typing.ClassVar[QFormLayout.ItemRole] = ...
    WrapAllRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
    WrapLongRows: typing.ClassVar[QFormLayout.RowWrapPolicy] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., destroyed: typing.Callable = ..., fieldGrowthPolicy: QFormLayout.FieldGrowthPolicy = ..., formAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., horizontalSpacing: int = ..., labelAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., rowWrapPolicy: QFormLayout.RowWrapPolicy = ..., sizeConstraint: QFormLayout.SizeConstraint = ..., spacing: int = ..., verticalSpacing: int = ...) -> None: ...
    def addItem(self, item: QLayoutItem) -> None: ...
    @typing.overload
    def addRow(self, labelText: str, field: QLayout) -> None: ...
    @typing.overload
    def addRow(self, labelText: str, field: QWidget) -> None: ...
    @typing.overload
    def addRow(self, label: QWidget, field: QLayout) -> None: ...
    @typing.overload
    def addRow(self, label: QWidget, field: QWidget) -> None: ...
    @typing.overload
    def addRow(self, widget: QWidget) -> None: ...
    @typing.overload
    def addRow(self, layout: QLayout) -> None: ...
    def count(self) -> int: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def fieldGrowthPolicy(self) -> QFormLayout.FieldGrowthPolicy: ...
    def formAlignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def getItemPosition(self, index: int, rolePtr: QFormLayout.ItemRole) -> int: ...
    def getLayoutPosition(self, layout: QLayout, rolePtr: QFormLayout.ItemRole) -> int: ...
    def getWidgetPosition(self, widget: QWidget, rolePtr: QFormLayout.ItemRole) -> int: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, width: int) -> int: ...
    def horizontalSpacing(self) -> int: ...
    @typing.overload
    def insertRow(self, row: int, labelText: str, field: QLayout) -> None: ...
    @typing.overload
    def insertRow(self, row: int, labelText: str, field: QWidget) -> None: ...
    @typing.overload
    def insertRow(self, row: int, label: QWidget, field: QLayout) -> None: ...
    @typing.overload
    def insertRow(self, row: int, label: QWidget, field: QWidget) -> None: ...
    @typing.overload
    def insertRow(self, row: int, widget: QWidget) -> None: ...
    @typing.overload
    def insertRow(self, row: int, layout: QLayout) -> None: ...
    def invalidate(self) -> None: ...
    @typing.overload
    def itemAt(self, row: int, role: QFormLayout.ItemRole) -> QLayoutItem: ...
    @typing.overload
    def itemAt(self, index: int) -> QLayoutItem: ...
    def labelAlignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    @typing.overload
    def labelForField(self, field: QLayout) -> QWidget: ...
    @typing.overload
    def labelForField(self, field: QWidget) -> QWidget: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    @typing.overload
    def removeRow(self, widget: QWidget) -> None: ...
    @typing.overload
    def removeRow(self, row: int) -> None: ...
    @typing.overload
    def removeRow(self, layout: QLayout) -> None: ...
    def rowCount(self) -> int: ...
    def rowWrapPolicy(self) -> QFormLayout.RowWrapPolicy: ...
    def setFieldGrowthPolicy(self, policy: QFormLayout.FieldGrowthPolicy) -> None: ...
    def setFormAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRect) -> None: ...
    def setHorizontalSpacing(self, spacing: int) -> None: ...
    def setItem(self, row: int, role: QFormLayout.ItemRole, item: QLayoutItem) -> None: ...
    def setLabelAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setLayout(self, row: int, role: QFormLayout.ItemRole, layout: QLayout) -> None: ...
    def setRowWrapPolicy(self, policy: QFormLayout.RowWrapPolicy) -> None: ...
    def setSpacing(self, arg__1: int) -> None: ...
    def setVerticalSpacing(self, spacing: int) -> None: ...
    def setWidget(self, row: int, role: QFormLayout.ItemRole, widget: QWidget) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def spacing(self) -> int: ...
    def takeAt(self, index: int) -> QLayoutItem: ...
    def verticalSpacing(self) -> int: ...

class QFrame(QWidget):
    class Shadow:
        Plain: typing.ClassVar[QFrame.Shadow] = ...
        Raised: typing.ClassVar[QFrame.Shadow] = ...
        Sunken: typing.ClassVar[QFrame.Shadow] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __and__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __rand__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __ror__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __sub__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...
        def __xor__(self, other: typing.SupportsInt) -> QFrame.Shadow: ...

    class Shape:
        Box: typing.ClassVar[QFrame.Shape] = ...
        HLine: typing.ClassVar[QFrame.Shape] = ...
        NoFrame: typing.ClassVar[QFrame.Shape] = ...
        Panel: typing.ClassVar[QFrame.Shape] = ...
        StyledPanel: typing.ClassVar[QFrame.Shape] = ...
        VLine: typing.ClassVar[QFrame.Shape] = ...
        WinPanel: typing.ClassVar[QFrame.Shape] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __and__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __rand__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __ror__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __sub__(self, other: typing.SupportsInt) -> QFrame.Shape: ...
        def __xor__(self, other: typing.SupportsInt) -> QFrame.Shape: ...

    class StyleMask:
        Shadow_Mask: typing.ClassVar[QFrame.StyleMask] = ...
        Shape_Mask: typing.ClassVar[QFrame.StyleMask] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __and__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __rand__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __rmul__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __ror__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __rsub__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __rxor__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __sub__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
        def __xor__(self, other: typing.SupportsInt) -> QFrame.StyleMask: ...
    Box: typing.ClassVar[QFrame.Shape] = ...
    HLine: typing.ClassVar[QFrame.Shape] = ...
    NoFrame: typing.ClassVar[QFrame.Shape] = ...
    Panel: typing.ClassVar[QFrame.Shape] = ...
    Plain: typing.ClassVar[QFrame.Shadow] = ...
    Raised: typing.ClassVar[QFrame.Shadow] = ...
    Shadow_Mask: typing.ClassVar[QFrame.StyleMask] = ...
    Shape_Mask: typing.ClassVar[QFrame.StyleMask] = ...
    StyledPanel: typing.ClassVar[QFrame.Shape] = ...
    Sunken: typing.ClassVar[QFrame.Shadow] = ...
    VLine: typing.ClassVar[QFrame.Shape] = ...
    WinPanel: typing.ClassVar[QFrame.Shape] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QFrame.Shadow = ..., frameShape: QFrame.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def drawFrame(self, arg__1: PySide2.QtGui.QPainter) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def frameRect(self) -> PySide2.QtCore.QRect: ...
    def frameShadow(self) -> QFrame.Shadow: ...
    def frameShape(self) -> QFrame.Shape: ...
    def frameStyle(self) -> int: ...
    def frameWidth(self) -> int: ...
    def initStyleOption(self, option: QStyleOptionFrame) -> None: ...
    def lineWidth(self) -> int: ...
    def midLineWidth(self) -> int: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setFrameRect(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def setFrameShadow(self, arg__1: QFrame.Shadow) -> None: ...
    def setFrameShape(self, arg__1: QFrame.Shape) -> None: ...
    def setFrameStyle(self, arg__1: typing.Union[QFrame.Shape, QFrame.Shadow, typing.SupportsInt]) -> None: ...
    def setLineWidth(self, arg__1: int) -> None: ...
    def setMidLineWidth(self, arg__1: int) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QGesture(PySide2.QtCore.QObject):
    class GestureCancelPolicy:
        CancelAllInContext: typing.ClassVar[QGesture.GestureCancelPolicy] = ...
        CancelNone: typing.ClassVar[QGesture.GestureCancelPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QGesture.GestureCancelPolicy: ...
    CancelAllInContext: typing.ClassVar[QGesture.GestureCancelPolicy] = ...
    CancelNone: typing.ClassVar[QGesture.GestureCancelPolicy] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., hotSpot: PySide2.QtCore.QPointF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., state: PySide2.QtCore.Qt.GestureState = ...) -> None: ...
    def gestureCancelPolicy(self) -> QGesture.GestureCancelPolicy: ...
    def gestureType(self) -> PySide2.QtCore.Qt.GestureType: ...
    def hasHotSpot(self) -> bool: ...
    def hotSpot(self) -> PySide2.QtCore.QPointF: ...
    def setGestureCancelPolicy(self, policy: QGesture.GestureCancelPolicy) -> None: ...
    def setHotSpot(self, value: PySide2.QtCore.QPointF) -> None: ...
    def state(self) -> PySide2.QtCore.Qt.GestureState: ...
    def unsetHotSpot(self) -> None: ...

class QGestureEvent(PySide2.QtCore.QEvent):
    def __init__(self, gestures: typing.Iterable[QGesture]) -> None: ...
    @typing.overload
    def accept(self, arg__1: PySide2.QtCore.Qt.GestureType) -> None: ...
    @typing.overload
    def accept(self, arg__1: QGesture) -> None: ...
    @typing.overload
    def accept(self) -> None: ...
    def activeGestures(self) -> typing.List[QGesture]: ...
    def canceledGestures(self) -> typing.List[QGesture]: ...
    def gesture(self, type: PySide2.QtCore.Qt.GestureType) -> QGesture: ...
    def gestures(self) -> typing.List[QGesture]: ...
    @typing.overload
    def ignore(self, arg__1: PySide2.QtCore.Qt.GestureType) -> None: ...
    @typing.overload
    def ignore(self, arg__1: QGesture) -> None: ...
    @typing.overload
    def ignore(self) -> None: ...
    @typing.overload
    def isAccepted(self, arg__1: PySide2.QtCore.Qt.GestureType) -> bool: ...
    @typing.overload
    def isAccepted(self, arg__1: QGesture) -> bool: ...
    @typing.overload
    def isAccepted(self) -> bool: ...
    def mapToGraphicsScene(self, gesturePoint: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def setAccepted(self, arg__1: PySide2.QtCore.Qt.GestureType, arg__2: bool) -> None: ...
    @typing.overload
    def setAccepted(self, arg__1: QGesture, arg__2: bool) -> None: ...
    @typing.overload
    def setAccepted(self, accepted: bool) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def widget(self) -> QWidget: ...

class QGestureRecognizer(shiboken2.Object):
    class Result:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGestureRecognizer.Result: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __rand__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __ror__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __xor__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...

    class ResultFlag:
        CancelGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        ConsumeEventHint: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        FinishGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        Ignore: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        MayBeGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        ResultHint_Mask: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        ResultState_Mask: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        TriggerGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGestureRecognizer.Result: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __rand__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __ror__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
        def __xor__(self, other: typing.SupportsInt) -> QGestureRecognizer.Result: ...
    CancelGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    ConsumeEventHint: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    FinishGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    Ignore: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    MayBeGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    ResultHint_Mask: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    ResultState_Mask: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    TriggerGesture: typing.ClassVar[QGestureRecognizer.ResultFlag] = ...
    def __init__(self) -> None: ...
    def create(self, target: PySide2.QtCore.QObject) -> QGesture: ...
    def recognize(self, state: QGesture, watched: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> typing.Union[QGestureRecognizer.Result, QGestureRecognizer.ResultFlag]: ...
    @classmethod
    def registerRecognizer(cls, recognizer: QGestureRecognizer) -> PySide2.QtCore.Qt.GestureType: ...
    def reset(self, state: QGesture) -> None: ...
    @classmethod
    def unregisterRecognizer(cls, type: PySide2.QtCore.Qt.GestureType) -> None: ...

class QGraphicsAnchor(PySide2.QtCore.QObject):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def setSizePolicy(self, policy: QSizePolicy.Policy) -> None: ...
    def setSpacing(self, spacing: float) -> None: ...
    def sizePolicy(self) -> QSizePolicy.Policy: ...
    def spacing(self) -> float: ...
    def unsetSpacing(self) -> None: ...

class QGraphicsAnchorLayout(QGraphicsLayout):
    def __init__(self, parent: typing.Union[QGraphicsLayoutItem, None] = ...) -> None: ...
    def addAnchor(self, firstItem: QGraphicsLayoutItem, firstEdge: PySide2.QtCore.Qt.AnchorPoint, secondItem: QGraphicsLayoutItem, secondEdge: PySide2.QtCore.Qt.AnchorPoint) -> QGraphicsAnchor: ...
    def addAnchors(self, firstItem: QGraphicsLayoutItem, secondItem: QGraphicsLayoutItem, orientations: typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation] = ...) -> None: ...
    def addCornerAnchors(self, firstItem: QGraphicsLayoutItem, firstCorner: PySide2.QtCore.Qt.Corner, secondItem: QGraphicsLayoutItem, secondCorner: PySide2.QtCore.Qt.Corner) -> None: ...
    def anchor(self, firstItem: QGraphicsLayoutItem, firstEdge: PySide2.QtCore.Qt.AnchorPoint, secondItem: QGraphicsLayoutItem, secondEdge: PySide2.QtCore.Qt.AnchorPoint) -> QGraphicsAnchor: ...
    def count(self) -> int: ...
    def horizontalSpacing(self) -> float: ...
    def invalidate(self) -> None: ...
    def itemAt(self, index: int) -> QGraphicsLayoutItem: ...
    def removeAt(self, index: int) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setHorizontalSpacing(self, spacing: float) -> None: ...
    def setSpacing(self, spacing: float) -> None: ...
    def setVerticalSpacing(self, spacing: float) -> None: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def verticalSpacing(self) -> float: ...

class QGraphicsBlurEffect(QGraphicsEffect):
    class BlurHint:
        AnimationHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
        PerformanceHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
        QualityHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsBlurEffect.BlurHints: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...

    class BlurHints:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsBlurEffect.BlurHints: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsBlurEffect.BlurHints: ...
    AnimationHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
    PerformanceHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
    QualityHint: typing.ClassVar[QGraphicsBlurEffect.BlurHint] = ...
    blurHintsChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    blurRadiusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., blurHints: typing.Union[QGraphicsBlurEffect.BlurHints, QGraphicsBlurEffect.BlurHint] = ..., blurHintsChanged: typing.Callable = ..., blurRadius: float = ..., blurRadiusChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def blurHints(self) -> typing.Union[QGraphicsBlurEffect.BlurHints, QGraphicsBlurEffect.BlurHint]: ...
    def blurRadius(self) -> float: ...
    def boundingRectFor(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    def draw(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def setBlurHints(self, hints: typing.Union[QGraphicsBlurEffect.BlurHints, QGraphicsBlurEffect.BlurHint]) -> None: ...
    def setBlurRadius(self, blurRadius: float) -> None: ...

class QGraphicsColorizeEffect(QGraphicsEffect):
    colorChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    strengthChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ..., colorChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., strength: float = ..., strengthChanged: typing.Callable = ...) -> None: ...
    def color(self) -> PySide2.QtGui.QColor: ...
    def draw(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def setColor(self, c: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setStrength(self, strength: float) -> None: ...
    def strength(self) -> float: ...

class QGraphicsDropShadowEffect(QGraphicsEffect):
    blurRadiusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    colorChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    offsetChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., blurRadius: float = ..., blurRadiusChanged: typing.Callable = ..., color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ..., colorChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., offset: PySide2.QtCore.QPointF = ..., offsetChanged: typing.Callable = ..., xOffset: float = ..., yOffset: float = ...) -> None: ...
    def blurRadius(self) -> float: ...
    def boundingRectFor(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    def color(self) -> PySide2.QtGui.QColor: ...
    def draw(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def offset(self) -> PySide2.QtCore.QPointF: ...
    def setBlurRadius(self, blurRadius: float) -> None: ...
    def setColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    @typing.overload
    def setOffset(self, dx: float, dy: float) -> None: ...
    @typing.overload
    def setOffset(self, ofs: PySide2.QtCore.QPointF) -> None: ...
    @typing.overload
    def setOffset(self, d: float) -> None: ...
    def setXOffset(self, dx: float) -> None: ...
    def setYOffset(self, dy: float) -> None: ...
    def xOffset(self) -> float: ...
    def yOffset(self) -> float: ...

class QGraphicsEffect(PySide2.QtCore.QObject):
    class ChangeFlag:
        SourceAttached: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
        SourceBoundingRectChanged: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
        SourceDetached: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
        SourceInvalidated: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsEffect.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...

    class ChangeFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsEffect.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsEffect.ChangeFlags: ...

    class PixmapPadMode:
        NoPad: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
        PadToEffectiveBoundingRect: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
        PadToTransparentBorder: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsEffect.PixmapPadMode: ...
    NoPad: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
    PadToEffectiveBoundingRect: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
    PadToTransparentBorder: typing.ClassVar[QGraphicsEffect.PixmapPadMode] = ...
    SourceAttached: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
    SourceBoundingRectChanged: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
    SourceDetached: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
    SourceInvalidated: typing.ClassVar[QGraphicsEffect.ChangeFlag] = ...
    enabledChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def boundingRectFor(self, sourceRect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    def draw(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def drawSource(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enable: bool) -> None: ...
    def sourceBoundingRect(self, system: PySide2.QtCore.Qt.CoordinateSystem = ...) -> PySide2.QtCore.QRectF: ...
    def sourceChanged(self, flags: typing.Union[QGraphicsEffect.ChangeFlags, QGraphicsEffect.ChangeFlag]) -> None: ...
    def sourceIsPixmap(self) -> bool: ...
    def sourcePixmap(self, system: PySide2.QtCore.Qt.CoordinateSystem = ..., offset: typing.Union[PySide2.QtCore.QPoint, None] = ..., mode: QGraphicsEffect.PixmapPadMode = ...) -> PySide2.QtGui.QPixmap: ...
    def update(self) -> None: ...
    def updateBoundingRect(self) -> None: ...

class QGraphicsEllipseItem(QAbstractGraphicsShapeItem):
    @typing.overload
    def __init__(self, x: float, y: float, w: float, h: float, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, rect: PySide2.QtCore.QRectF, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def rect(self) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def setRect(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setSpanAngle(self, angle: int) -> None: ...
    def setStartAngle(self, angle: int) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def spanAngle(self) -> int: ...
    def startAngle(self) -> int: ...
    def type(self) -> int: ...

class QGraphicsGridLayout(QGraphicsLayout):
    def __init__(self, parent: typing.Union[QGraphicsLayoutItem, None] = ...) -> None: ...
    @typing.overload
    def addItem(self, item: QGraphicsLayoutItem, row: int, column: int, rowSpan: int, columnSpan: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addItem(self, item: QGraphicsLayoutItem, row: int, column: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    def alignment(self, item: QGraphicsLayoutItem) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def columnAlignment(self, column: int) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def columnCount(self) -> int: ...
    def columnMaximumWidth(self, column: int) -> float: ...
    def columnMinimumWidth(self, column: int) -> float: ...
    def columnPreferredWidth(self, column: int) -> float: ...
    def columnSpacing(self, column: int) -> float: ...
    def columnStretchFactor(self, column: int) -> int: ...
    def count(self) -> int: ...
    def horizontalSpacing(self) -> float: ...
    def invalidate(self) -> None: ...
    @typing.overload
    def itemAt(self, row: int, column: int) -> QGraphicsLayoutItem: ...
    @typing.overload
    def itemAt(self, index: int) -> QGraphicsLayoutItem: ...
    def removeAt(self, index: int) -> None: ...
    def removeItem(self, item: QGraphicsLayoutItem) -> None: ...
    def rowAlignment(self, row: int) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def rowCount(self) -> int: ...
    def rowMaximumHeight(self, row: int) -> float: ...
    def rowMinimumHeight(self, row: int) -> float: ...
    def rowPreferredHeight(self, row: int) -> float: ...
    def rowSpacing(self, row: int) -> float: ...
    def rowStretchFactor(self, row: int) -> int: ...
    def setAlignment(self, item: QGraphicsLayoutItem, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setColumnAlignment(self, column: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setColumnFixedWidth(self, column: int, width: float) -> None: ...
    def setColumnMaximumWidth(self, column: int, width: float) -> None: ...
    def setColumnMinimumWidth(self, column: int, width: float) -> None: ...
    def setColumnPreferredWidth(self, column: int, width: float) -> None: ...
    def setColumnSpacing(self, column: int, spacing: float) -> None: ...
    def setColumnStretchFactor(self, column: int, stretch: int) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setHorizontalSpacing(self, spacing: float) -> None: ...
    def setRowAlignment(self, row: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setRowFixedHeight(self, row: int, height: float) -> None: ...
    def setRowMaximumHeight(self, row: int, height: float) -> None: ...
    def setRowMinimumHeight(self, row: int, height: float) -> None: ...
    def setRowPreferredHeight(self, row: int, height: float) -> None: ...
    def setRowSpacing(self, row: int, spacing: float) -> None: ...
    def setRowStretchFactor(self, row: int, stretch: int) -> None: ...
    def setSpacing(self, spacing: float) -> None: ...
    def setVerticalSpacing(self, spacing: float) -> None: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def verticalSpacing(self) -> float: ...

class QGraphicsItem(shiboken2.Object):
    class CacheMode:
        DeviceCoordinateCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
        ItemCoordinateCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
        NoCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.CacheMode: ...

    class Extension:
        UserExtension: typing.ClassVar[QGraphicsItem.Extension] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.Extension: ...

    class GraphicsItemChange:
        ItemChildAddedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemChildRemovedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemCursorChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemCursorHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemEnabledChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemEnabledHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemFlagsChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemFlagsHaveChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemMatrixChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemOpacityChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemOpacityHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemParentChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemParentHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemPositionChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemPositionHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemRotationChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemRotationHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemScaleChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemScaleHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemSceneChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemSceneHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemScenePositionHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemSelectedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemSelectedHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemToolTipChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemToolTipHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemTransformChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemTransformHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemTransformOriginPointChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemTransformOriginPointHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemVisibleChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemVisibleHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemZValueChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        ItemZValueHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemChange: ...

    class GraphicsItemFlag:
        ItemAcceptsInputMethod: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemClipsChildrenToShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemClipsToShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemContainsChildrenInShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemDoesntPropagateOpacityToChildren: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemHasNoContents: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIgnoresParentOpacity: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIgnoresTransformations: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIsFocusScope: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIsFocusable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIsMovable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIsPanel: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemIsSelectable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemNegativeZStacksBehindParent: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemSendsGeometryChanges: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemSendsScenePositionChanges: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemStacksBehindParent: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemStopsClickFocusPropagation: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemStopsFocusHandling: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        ItemUsesExtendedStyleOption: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsItem.GraphicsItemFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...

    class GraphicsItemFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsItem.GraphicsItemFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.GraphicsItemFlags: ...

    class PanelModality:
        NonModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
        PanelModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
        SceneModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsItem.PanelModality: ...
    DeviceCoordinateCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
    ItemAcceptsInputMethod: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemChildAddedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemChildRemovedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemClipsChildrenToShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemClipsToShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemContainsChildrenInShape: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemCoordinateCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
    ItemCursorChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemCursorHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemDoesntPropagateOpacityToChildren: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemEnabledChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemEnabledHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemFlagsChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemFlagsHaveChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemHasNoContents: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIgnoresParentOpacity: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIgnoresTransformations: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIsFocusScope: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIsFocusable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIsMovable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIsPanel: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemIsSelectable: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemMatrixChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemNegativeZStacksBehindParent: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemOpacityChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemOpacityHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemParentChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemParentHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemPositionChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemPositionHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemRotationChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemRotationHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemScaleChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemScaleHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemSceneChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemSceneHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemScenePositionHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemSelectedChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemSelectedHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemSendsGeometryChanges: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemSendsScenePositionChanges: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemStacksBehindParent: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemStopsClickFocusPropagation: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemStopsFocusHandling: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemToolTipChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemToolTipHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemTransformChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemTransformHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemTransformOriginPointChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemTransformOriginPointHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemUsesExtendedStyleOption: typing.ClassVar[QGraphicsItem.GraphicsItemFlag] = ...
    ItemVisibleChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemVisibleHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemZValueChange: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    ItemZValueHasChanged: typing.ClassVar[QGraphicsItem.GraphicsItemChange] = ...
    NoCache: typing.ClassVar[QGraphicsItem.CacheMode] = ...
    NonModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
    PanelModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
    SceneModal: typing.ClassVar[QGraphicsItem.PanelModality] = ...
    UserExtension: typing.ClassVar[QGraphicsItem.Extension] = ...
    UserType: typing.ClassVar[int] = ...
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def acceptDrops(self) -> bool: ...
    def acceptHoverEvents(self) -> bool: ...
    def acceptTouchEvents(self) -> bool: ...
    def acceptedMouseButtons(self) -> typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]: ...
    def addToIndex(self) -> None: ...
    def advance(self, phase: int) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def boundingRegion(self, itemToDeviceTransform: PySide2.QtGui.QTransform) -> PySide2.QtGui.QRegion: ...
    def boundingRegionGranularity(self) -> float: ...
    def cacheMode(self) -> QGraphicsItem.CacheMode: ...
    def childItems(self) -> typing.List[QGraphicsItem]: ...
    def childrenBoundingRect(self) -> PySide2.QtCore.QRectF: ...
    def clearFocus(self) -> None: ...
    def clipPath(self) -> PySide2.QtGui.QPainterPath: ...
    def collidesWithItem(self, other: QGraphicsItem, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> bool: ...
    def collidesWithPath(self, path: PySide2.QtGui.QPainterPath, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> bool: ...
    def collidingItems(self, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    def commonAncestorItem(self, other: QGraphicsItem) -> QGraphicsItem: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def contextMenuEvent(self, event: QGraphicsSceneContextMenuEvent) -> None: ...
    def cursor(self) -> PySide2.QtGui.QCursor: ...
    def data(self, key: int) -> typing.Any: ...
    def deviceTransform(self, viewportTransform: PySide2.QtGui.QTransform) -> PySide2.QtGui.QTransform: ...
    def dragEnterEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragLeaveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragMoveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dropEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def effectiveOpacity(self) -> float: ...
    @typing.overload
    def ensureVisible(self, x: float, y: float, w: float, h: float, xmargin: int = ..., ymargin: int = ...) -> None: ...
    @typing.overload
    def ensureVisible(self, rect: PySide2.QtCore.QRectF = ..., xmargin: int = ..., ymargin: int = ...) -> None: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def filtersChildEvents(self) -> bool: ...
    def flags(self) -> typing.Union[QGraphicsItem.GraphicsItemFlags, QGraphicsItem.GraphicsItemFlag]: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusItem(self) -> QGraphicsItem: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusProxy(self) -> QGraphicsItem: ...
    def focusScopeItem(self) -> QGraphicsItem: ...
    def grabKeyboard(self) -> None: ...
    def grabMouse(self) -> None: ...
    def graphicsEffect(self) -> QGraphicsEffect: ...
    def group(self) -> QGraphicsItemGroup: ...
    def handlesChildEvents(self) -> bool: ...
    def hasCursor(self) -> bool: ...
    def hasFocus(self) -> bool: ...
    def hide(self) -> None: ...
    def hoverEnterEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverLeaveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverMoveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodHints(self) -> typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint]: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def installSceneEventFilter(self, filterItem: QGraphicsItem) -> None: ...
    def isActive(self) -> bool: ...
    def isAncestorOf(self, child: QGraphicsItem) -> bool: ...
    def isBlockedByModalPanel(self, blockingPanel: typing.Union[QGraphicsItem, None] = ...) -> bool: ...
    def isClipped(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    @typing.overload
    def isObscured(self, x: float, y: float, w: float, h: float) -> bool: ...
    @typing.overload
    def isObscured(self, rect: PySide2.QtCore.QRectF = ...) -> bool: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def isPanel(self) -> bool: ...
    def isSelected(self) -> bool: ...
    def isUnderMouse(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def isVisibleTo(self, parent: QGraphicsItem) -> bool: ...
    def isWidget(self) -> bool: ...
    def isWindow(self) -> bool: ...
    def itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: typing.Any) -> typing.Any: ...
    def itemTransform(self, other: QGraphicsItem) -> typing.Tuple[PySide2.QtGui.QTransform, bool]: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromItem(self, item: QGraphicsItem, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapFromParent(self, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromParent(self, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromParent(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromParent(self, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromParent(self, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromParent(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapFromScene(self, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromScene(self, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromScene(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromScene(self, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapFromScene(self, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapFromScene(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapRectFromItem(self, item: QGraphicsItem, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectFromItem(self, item: QGraphicsItem, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectFromParent(self, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectFromParent(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectFromScene(self, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectFromScene(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToItem(self, item: QGraphicsItem, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToItem(self, item: QGraphicsItem, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToParent(self, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToParent(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToScene(self, x: float, y: float, w: float, h: float) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapRectToScene(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToItem(self, item: QGraphicsItem, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapToParent(self, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToParent(self, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToParent(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToParent(self, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToParent(self, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToParent(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapToScene(self, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, x: float, y: float) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToScene(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToScene(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    def matrix(self) -> PySide2.QtGui.QMatrix: ...
    def mouseDoubleClickEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mousePressEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def moveBy(self, dx: float, dy: float) -> None: ...
    def opacity(self) -> float: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def panel(self) -> QGraphicsItem: ...
    def panelModality(self) -> QGraphicsItem.PanelModality: ...
    def parentItem(self) -> QGraphicsItem: ...
    def parentObject(self) -> QGraphicsObject: ...
    def parentWidget(self) -> QGraphicsWidget: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def prepareGeometryChange(self) -> None: ...
    def removeFromIndex(self) -> None: ...
    def removeSceneEventFilter(self, filterItem: QGraphicsItem) -> None: ...
    def resetMatrix(self) -> None: ...
    def resetTransform(self) -> None: ...
    def rotation(self) -> float: ...
    def scale(self) -> float: ...
    def scene(self) -> QGraphicsScene: ...
    def sceneBoundingRect(self) -> PySide2.QtCore.QRectF: ...
    def sceneEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def sceneEventFilter(self, watched: QGraphicsItem, event: PySide2.QtCore.QEvent) -> bool: ...
    def sceneMatrix(self) -> PySide2.QtGui.QMatrix: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def sceneTransform(self) -> PySide2.QtGui.QTransform: ...
    def scroll(self, dx: float, dy: float, rect: PySide2.QtCore.QRectF = ...) -> None: ...
    def setAcceptDrops(self, on: bool) -> None: ...
    def setAcceptHoverEvents(self, enabled: bool) -> None: ...
    def setAcceptTouchEvents(self, enabled: bool) -> None: ...
    def setAcceptedMouseButtons(self, buttons: typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]) -> None: ...
    def setActive(self, active: bool) -> None: ...
    def setBoundingRegionGranularity(self, granularity: float) -> None: ...
    def setCacheMode(self, mode: QGraphicsItem.CacheMode, cacheSize: PySide2.QtCore.QSize = ...) -> None: ...
    def setCursor(self, cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape]) -> None: ...
    def setData(self, key: int, value: typing.Any) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def setFiltersChildEvents(self, enabled: bool) -> None: ...
    def setFlag(self, flag: QGraphicsItem.GraphicsItemFlag, enabled: bool = ...) -> None: ...
    def setFlags(self, flags: typing.Union[QGraphicsItem.GraphicsItemFlags, QGraphicsItem.GraphicsItemFlag]) -> None: ...
    def setFocus(self, focusReason: PySide2.QtCore.Qt.FocusReason = ...) -> None: ...
    def setFocusProxy(self, item: QGraphicsItem) -> None: ...
    def setGraphicsEffect(self, effect: QGraphicsEffect) -> None: ...
    def setGroup(self, group: QGraphicsItemGroup) -> None: ...
    def setHandlesChildEvents(self, enabled: bool) -> None: ...
    def setInputMethodHints(self, hints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint]) -> None: ...
    def setMatrix(self, matrix: PySide2.QtGui.QMatrix, combine: bool = ...) -> None: ...
    def setOpacity(self, opacity: float) -> None: ...
    def setPanelModality(self, panelModality: QGraphicsItem.PanelModality) -> None: ...
    def setParentItem(self, parent: QGraphicsItem) -> None: ...
    @typing.overload
    def setPos(self, x: float, y: float) -> None: ...
    @typing.overload
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setRotation(self, angle: float) -> None: ...
    def setScale(self, scale: float) -> None: ...
    def setSelected(self, selected: bool) -> None: ...
    def setToolTip(self, toolTip: str) -> None: ...
    def setTransform(self, matrix: PySide2.QtGui.QTransform, combine: bool = ...) -> None: ...
    @typing.overload
    def setTransformOriginPoint(self, ax: float, ay: float) -> None: ...
    @typing.overload
    def setTransformOriginPoint(self, origin: PySide2.QtCore.QPointF) -> None: ...
    def setTransformations(self, transformations: typing.Iterable[QGraphicsTransform]) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def setX(self, x: float) -> None: ...
    def setY(self, y: float) -> None: ...
    def setZValue(self, z: float) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def show(self) -> None: ...
    def stackBefore(self, sibling: QGraphicsItem) -> None: ...
    def toGraphicsObject(self) -> QGraphicsObject: ...
    def toolTip(self) -> str: ...
    def topLevelItem(self) -> QGraphicsItem: ...
    def topLevelWidget(self) -> QGraphicsWidget: ...
    def transform(self) -> PySide2.QtGui.QTransform: ...
    def transformOriginPoint(self) -> PySide2.QtCore.QPointF: ...
    def transformations(self) -> typing.List[QGraphicsTransform]: ...
    def type(self) -> int: ...
    def ungrabKeyboard(self) -> None: ...
    def ungrabMouse(self) -> None: ...
    def unsetCursor(self) -> None: ...
    @typing.overload
    def update(self, x: float, y: float, width: float, height: float) -> None: ...
    @typing.overload
    def update(self, rect: PySide2.QtCore.QRectF = ...) -> None: ...
    def updateMicroFocus(self) -> None: ...
    def wheelEvent(self, event: QGraphicsSceneWheelEvent) -> None: ...
    def window(self) -> QGraphicsWidget: ...
    def x(self) -> float: ...
    def y(self) -> float: ...
    def zValue(self) -> float: ...

class QGraphicsItemAnimation(PySide2.QtCore.QObject):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def afterAnimationStep(self, step: float) -> None: ...
    def beforeAnimationStep(self, step: float) -> None: ...
    def clear(self) -> None: ...
    def horizontalScaleAt(self, step: float) -> float: ...
    def horizontalShearAt(self, step: float) -> float: ...
    def item(self) -> QGraphicsItem: ...
    def matrixAt(self, step: float) -> PySide2.QtGui.QMatrix: ...
    def posAt(self, step: float) -> PySide2.QtCore.QPointF: ...
    def posList(self) -> typing.List[typing.Tuple[float, PySide2.QtCore.QPointF]]: ...
    def reset(self) -> None: ...
    def rotationAt(self, step: float) -> float: ...
    def rotationList(self) -> typing.List[typing.Tuple[float, float]]: ...
    def scaleList(self) -> typing.List[typing.Tuple[float, PySide2.QtCore.QPointF]]: ...
    def setItem(self, item: QGraphicsItem) -> None: ...
    def setPosAt(self, step: float, pos: PySide2.QtCore.QPointF) -> None: ...
    def setRotationAt(self, step: float, angle: float) -> None: ...
    def setScaleAt(self, step: float, sx: float, sy: float) -> None: ...
    def setShearAt(self, step: float, sh: float, sv: float) -> None: ...
    def setStep(self, x: float) -> None: ...
    def setTimeLine(self, timeLine: PySide2.QtCore.QTimeLine) -> None: ...
    def setTranslationAt(self, step: float, dx: float, dy: float) -> None: ...
    def shearList(self) -> typing.List[typing.Tuple[float, PySide2.QtCore.QPointF]]: ...
    def timeLine(self) -> PySide2.QtCore.QTimeLine: ...
    def transformAt(self, step: float) -> PySide2.QtGui.QTransform: ...
    def translationList(self) -> typing.List[typing.Tuple[float, PySide2.QtCore.QPointF]]: ...
    def verticalScaleAt(self, step: float) -> float: ...
    def verticalShearAt(self, step: float) -> float: ...
    def xTranslationAt(self, step: float) -> float: ...
    def yTranslationAt(self, step: float) -> float: ...

class QGraphicsItemGroup(QGraphicsItem):
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def addToGroup(self, item: QGraphicsItem) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def removeFromGroup(self, item: QGraphicsItem) -> None: ...
    def type(self) -> int: ...

class QGraphicsLayout(QGraphicsLayoutItem):
    def __init__(self, parent: typing.Union[QGraphicsLayoutItem, None] = ...) -> None: ...
    def activate(self) -> None: ...
    def addChildLayoutItem(self, layoutItem: QGraphicsLayoutItem) -> None: ...
    def count(self) -> int: ...
    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]: ...
    @classmethod
    def instantInvalidatePropagation(cls) -> bool: ...
    def invalidate(self) -> None: ...
    def isActivated(self) -> bool: ...
    def itemAt(self, i: int) -> QGraphicsLayoutItem: ...
    def removeAt(self, index: int) -> None: ...
    def setContentsMargins(self, left: float, top: float, right: float, bottom: float) -> None: ...
    @classmethod
    def setInstantInvalidatePropagation(cls, enable: bool) -> None: ...
    def updateGeometry(self) -> None: ...
    def widgetEvent(self, e: PySide2.QtCore.QEvent) -> None: ...

class QGraphicsLayoutItem(shiboken2.Object):
    def __init__(self, parent: typing.Union[QGraphicsLayoutItem, None] = ..., isLayout: bool = ...) -> None: ...
    def contentsRect(self) -> PySide2.QtCore.QRectF: ...
    def effectiveSizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def geometry(self) -> PySide2.QtCore.QRectF: ...
    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]: ...
    def graphicsItem(self) -> QGraphicsItem: ...
    def isLayout(self) -> bool: ...
    def maximumHeight(self) -> float: ...
    def maximumSize(self) -> PySide2.QtCore.QSizeF: ...
    def maximumWidth(self) -> float: ...
    def minimumHeight(self) -> float: ...
    def minimumSize(self) -> PySide2.QtCore.QSizeF: ...
    def minimumWidth(self) -> float: ...
    def ownedByLayout(self) -> bool: ...
    def parentLayoutItem(self) -> QGraphicsLayoutItem: ...
    def preferredHeight(self) -> float: ...
    def preferredSize(self) -> PySide2.QtCore.QSizeF: ...
    def preferredWidth(self) -> float: ...
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setGraphicsItem(self, item: QGraphicsItem) -> None: ...
    def setMaximumHeight(self, height: float) -> None: ...
    @typing.overload
    def setMaximumSize(self, w: float, h: float) -> None: ...
    @typing.overload
    def setMaximumSize(self, size: PySide2.QtCore.QSizeF) -> None: ...
    def setMaximumWidth(self, width: float) -> None: ...
    def setMinimumHeight(self, height: float) -> None: ...
    @typing.overload
    def setMinimumSize(self, w: float, h: float) -> None: ...
    @typing.overload
    def setMinimumSize(self, size: PySide2.QtCore.QSizeF) -> None: ...
    def setMinimumWidth(self, width: float) -> None: ...
    def setOwnedByLayout(self, ownedByLayout: bool) -> None: ...
    def setParentLayoutItem(self, parent: QGraphicsLayoutItem) -> None: ...
    def setPreferredHeight(self, height: float) -> None: ...
    @typing.overload
    def setPreferredSize(self, w: float, h: float) -> None: ...
    @typing.overload
    def setPreferredSize(self, size: PySide2.QtCore.QSizeF) -> None: ...
    def setPreferredWidth(self, width: float) -> None: ...
    @typing.overload
    def setSizePolicy(self, hPolicy: QSizePolicy.Policy, vPolicy: QSizePolicy.Policy, controlType: QSizePolicy.ControlType = ...) -> None: ...
    @typing.overload
    def setSizePolicy(self, policy: QSizePolicy) -> None: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def sizePolicy(self) -> QSizePolicy: ...
    def updateGeometry(self) -> None: ...

class QGraphicsLineItem(QGraphicsItem):
    @typing.overload
    def __init__(self, x1: float, y1: float, x2: float, y2: float, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, line: PySide2.QtCore.QLineF, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def line(self) -> PySide2.QtCore.QLineF: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def pen(self) -> PySide2.QtGui.QPen: ...
    @typing.overload
    def setLine(self, x1: float, y1: float, x2: float, y2: float) -> None: ...
    @typing.overload
    def setLine(self, line: PySide2.QtCore.QLineF) -> None: ...
    def setPen(self, pen: PySide2.QtGui.QPen) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def type(self) -> int: ...

class QGraphicsLinearLayout(QGraphicsLayout):
    @typing.overload
    def __init__(self, orientation: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QGraphicsLayoutItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsLayoutItem, None] = ...) -> None: ...
    def addItem(self, item: QGraphicsLayoutItem) -> None: ...
    def addStretch(self, stretch: int = ...) -> None: ...
    def alignment(self, item: QGraphicsLayoutItem) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def count(self) -> int: ...
    def dump(self, indent: int = ...) -> None: ...
    def insertItem(self, index: int, item: QGraphicsLayoutItem) -> None: ...
    def insertStretch(self, index: int, stretch: int = ...) -> None: ...
    def invalidate(self) -> None: ...
    def itemAt(self, index: int) -> QGraphicsLayoutItem: ...
    def itemSpacing(self, index: int) -> float: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def removeAt(self, index: int) -> None: ...
    def removeItem(self, item: QGraphicsLayoutItem) -> None: ...
    def setAlignment(self, item: QGraphicsLayoutItem, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setItemSpacing(self, index: int, spacing: float) -> None: ...
    def setOrientation(self, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setSpacing(self, spacing: float) -> None: ...
    def setStretchFactor(self, item: QGraphicsLayoutItem, stretch: int) -> None: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def spacing(self) -> float: ...
    def stretchFactor(self, item: QGraphicsLayoutItem) -> int: ...

class QGraphicsObject(QGraphicsItem, PySide2.QtCore.QObject):
    childrenChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    enabledChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    heightChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    opacityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    parentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    rotationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    visibleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    widthChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    xChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    yChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    zChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def event(self, ev: PySide2.QtCore.QEvent) -> bool: ...
    def grabGesture(self, type: PySide2.QtCore.Qt.GestureType, flags: typing.Union[PySide2.QtCore.Qt.GestureFlags, PySide2.QtCore.Qt.GestureFlag] = ...) -> None: ...
    def ungrabGesture(self, type: PySide2.QtCore.Qt.GestureType) -> None: ...
    def updateMicroFocus(self) -> None: ...

class QGraphicsOpacityEffect(QGraphicsEffect):
    opacityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    opacityMaskChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opacity: float = ..., opacityChanged: typing.Callable = ..., opacityMask: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., opacityMaskChanged: typing.Callable = ...) -> None: ...
    def draw(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def opacity(self) -> float: ...
    def opacityMask(self) -> PySide2.QtGui.QBrush: ...
    def setOpacity(self, opacity: float) -> None: ...
    def setOpacityMask(self, mask: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...

class QGraphicsPathItem(QAbstractGraphicsShapeItem):
    @typing.overload
    def __init__(self, path: PySide2.QtGui.QPainterPath, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def path(self) -> PySide2.QtGui.QPainterPath: ...
    def setPath(self, path: PySide2.QtGui.QPainterPath) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def type(self) -> int: ...

class QGraphicsPixmapItem(QGraphicsItem):
    class ShapeMode:
        BoundingRectShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
        HeuristicMaskShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
        MaskShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsPixmapItem.ShapeMode: ...
    BoundingRectShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
    HeuristicMaskShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
    MaskShape: typing.ClassVar[QGraphicsPixmapItem.ShapeMode] = ...
    @typing.overload
    def __init__(self, pixmap: PySide2.QtGui.QPixmap, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def offset(self) -> PySide2.QtCore.QPointF: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: QWidget) -> None: ...
    def pixmap(self) -> PySide2.QtGui.QPixmap: ...
    @typing.overload
    def setOffset(self, x: float, y: float) -> None: ...
    @typing.overload
    def setOffset(self, offset: PySide2.QtCore.QPointF) -> None: ...
    def setPixmap(self, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def setShapeMode(self, mode: QGraphicsPixmapItem.ShapeMode) -> None: ...
    def setTransformationMode(self, mode: PySide2.QtCore.Qt.TransformationMode) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def shapeMode(self) -> QGraphicsPixmapItem.ShapeMode: ...
    def transformationMode(self) -> PySide2.QtCore.Qt.TransformationMode: ...
    def type(self) -> int: ...

class QGraphicsPolygonItem(QAbstractGraphicsShapeItem):
    @typing.overload
    def __init__(self, polygon: PySide2.QtGui.QPolygonF, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def fillRule(self) -> PySide2.QtCore.Qt.FillRule: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def polygon(self) -> PySide2.QtGui.QPolygonF: ...
    def setFillRule(self, rule: PySide2.QtCore.Qt.FillRule) -> None: ...
    def setPolygon(self, polygon: PySide2.QtGui.QPolygonF) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def type(self) -> int: ...

class QGraphicsProxyWidget(QGraphicsWidget):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ..., wFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., autoFillBackground: bool = ..., children: typing.Any = ..., childrenChanged: typing.Callable = ..., destroyed: typing.Callable = ..., effect: typing.Any = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., geometry: PySide2.QtCore.QRectF = ..., geometryChanged: typing.Callable = ..., height: float = ..., heightChanged: typing.Callable = ..., layout: typing.Any = ..., layoutChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., maximumSize: PySide2.QtCore.QSizeF = ..., minimumSize: PySide2.QtCore.QSizeF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opacity: float = ..., opacityChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., parentChanged: typing.Callable = ..., pos: PySide2.QtCore.QPointF = ..., preferredSize: PySide2.QtCore.QSizeF = ..., rotation: float = ..., rotationChanged: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., size: PySide2.QtCore.QSizeF = ..., sizePolicy: QSizePolicy = ..., transformOriginPoint: PySide2.QtCore.QPointF = ..., visible: bool = ..., visibleChanged: typing.Callable = ..., width: float = ..., widthChanged: typing.Callable = ..., windowFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., windowTitle: str = ..., x: float = ..., xChanged: typing.Callable = ..., y: float = ..., yChanged: typing.Callable = ..., z: float = ..., zChanged: typing.Callable = ...) -> None: ...
    def contextMenuEvent(self, event: QGraphicsSceneContextMenuEvent) -> None: ...
    def createProxyForChildWidget(self, child: QWidget) -> QGraphicsProxyWidget: ...
    def dragEnterEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragLeaveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragMoveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dropEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def grabMouseEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def hideEvent(self, event: PySide2.QtGui.QHideEvent) -> None: ...
    def hoverEnterEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverLeaveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverMoveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: typing.Any) -> typing.Any: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def mouseDoubleClickEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mousePressEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def newProxyWidget(self, arg__1: QWidget) -> QGraphicsProxyWidget: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: QWidget) -> None: ...
    def resizeEvent(self, event: QGraphicsSceneResizeEvent) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def subWidgetRect(self, widget: QWidget) -> PySide2.QtCore.QRectF: ...
    def type(self) -> int: ...
    def ungrabMouseEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def wheelEvent(self, event: QGraphicsSceneWheelEvent) -> None: ...
    def widget(self) -> QWidget: ...

class QGraphicsRectItem(QAbstractGraphicsShapeItem):
    @typing.overload
    def __init__(self, x: float, y: float, w: float, h: float, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, rect: PySide2.QtCore.QRectF, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def rect(self) -> PySide2.QtCore.QRectF: ...
    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def setRect(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def type(self) -> int: ...

class QGraphicsRotation(QGraphicsTransform):
    angleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    axisChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    originChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., angle: float = ..., angleChanged: typing.Callable = ..., axis: PySide2.QtGui.QVector3D = ..., axisChanged: typing.Callable = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., origin: PySide2.QtGui.QVector3D = ..., originChanged: typing.Callable = ...) -> None: ...
    def angle(self) -> float: ...
    def applyTo(self, matrix: PySide2.QtGui.QMatrix4x4) -> None: ...
    def axis(self) -> PySide2.QtGui.QVector3D: ...
    def origin(self) -> PySide2.QtGui.QVector3D: ...
    def setAngle(self, arg__1: float) -> None: ...
    @typing.overload
    def setAxis(self, axis: PySide2.QtCore.Qt.Axis) -> None: ...
    @typing.overload
    def setAxis(self, axis: PySide2.QtGui.QVector3D) -> None: ...
    def setOrigin(self, point: PySide2.QtGui.QVector3D) -> None: ...

class QGraphicsScale(QGraphicsTransform):
    originChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    xScaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    yScaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    zScaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., origin: PySide2.QtGui.QVector3D = ..., originChanged: typing.Callable = ..., scaleChanged: typing.Callable = ..., xScale: float = ..., xScaleChanged: typing.Callable = ..., yScale: float = ..., yScaleChanged: typing.Callable = ..., zScale: float = ..., zScaleChanged: typing.Callable = ...) -> None: ...
    def applyTo(self, matrix: PySide2.QtGui.QMatrix4x4) -> None: ...
    def origin(self) -> PySide2.QtGui.QVector3D: ...
    def setOrigin(self, point: PySide2.QtGui.QVector3D) -> None: ...
    def setXScale(self, arg__1: float) -> None: ...
    def setYScale(self, arg__1: float) -> None: ...
    def setZScale(self, arg__1: float) -> None: ...
    def xScale(self) -> float: ...
    def yScale(self) -> float: ...
    def zScale(self) -> float: ...

class QGraphicsScene(PySide2.QtCore.QObject):
    class ItemIndexMethod:
        BspTreeIndex: typing.ClassVar[QGraphicsScene.ItemIndexMethod] = ...
        NoIndex: typing.ClassVar[QGraphicsScene.ItemIndexMethod] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsScene.ItemIndexMethod: ...

    class SceneLayer:
        AllLayers: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
        BackgroundLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
        ForegroundLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
        ItemLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsScene.SceneLayers: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...

    class SceneLayers:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsScene.SceneLayers: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsScene.SceneLayers: ...
    AllLayers: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
    BackgroundLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
    BspTreeIndex: typing.ClassVar[QGraphicsScene.ItemIndexMethod] = ...
    ForegroundLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
    ItemLayer: typing.ClassVar[QGraphicsScene.SceneLayer] = ...
    NoIndex: typing.ClassVar[QGraphicsScene.ItemIndexMethod] = ...
    changed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    focusItemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sceneRectChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    selectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, x: float, y: float, width: float, height: float, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., backgroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., bspTreeDepth: int = ..., changed: typing.Callable = ..., destroyed: typing.Callable = ..., focusItemChanged: typing.Callable = ..., focusOnTouch: bool = ..., font: PySide2.QtGui.QFont = ..., foregroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., itemIndexMethod: QGraphicsScene.ItemIndexMethod = ..., minimumRenderSize: float = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., sceneRect: PySide2.QtCore.QRectF = ..., sceneRectChanged: typing.Callable = ..., selectionChanged: typing.Callable = ..., sortCacheEnabled: bool = ..., stickyFocus: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, sceneRect: PySide2.QtCore.QRectF, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., backgroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., bspTreeDepth: int = ..., changed: typing.Callable = ..., destroyed: typing.Callable = ..., focusItemChanged: typing.Callable = ..., focusOnTouch: bool = ..., font: PySide2.QtGui.QFont = ..., foregroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., itemIndexMethod: QGraphicsScene.ItemIndexMethod = ..., minimumRenderSize: float = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., sceneRectChanged: typing.Callable = ..., selectionChanged: typing.Callable = ..., sortCacheEnabled: bool = ..., stickyFocus: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., backgroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., bspTreeDepth: int = ..., changed: typing.Callable = ..., destroyed: typing.Callable = ..., focusItemChanged: typing.Callable = ..., focusOnTouch: bool = ..., font: PySide2.QtGui.QFont = ..., foregroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., itemIndexMethod: QGraphicsScene.ItemIndexMethod = ..., minimumRenderSize: float = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., sceneRect: PySide2.QtCore.QRectF = ..., sceneRectChanged: typing.Callable = ..., selectionChanged: typing.Callable = ..., sortCacheEnabled: bool = ..., stickyFocus: bool = ...) -> None: ...
    def activePanel(self) -> QGraphicsItem: ...
    def activeWindow(self) -> QGraphicsWidget: ...
    @typing.overload
    def addEllipse(self, x: float, y: float, w: float, h: float, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsEllipseItem: ...
    @typing.overload
    def addEllipse(self, rect: PySide2.QtCore.QRectF, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsEllipseItem: ...
    def addItem(self, item: QGraphicsItem) -> None: ...
    @typing.overload
    def addLine(self, x1: float, y1: float, x2: float, y2: float, pen: PySide2.QtGui.QPen = ...) -> QGraphicsLineItem: ...
    @typing.overload
    def addLine(self, line: PySide2.QtCore.QLineF, pen: PySide2.QtGui.QPen = ...) -> QGraphicsLineItem: ...
    def addPath(self, path: PySide2.QtGui.QPainterPath, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsPathItem: ...
    def addPixmap(self, pixmap: PySide2.QtGui.QPixmap) -> QGraphicsPixmapItem: ...
    def addPolygon(self, polygon: PySide2.QtGui.QPolygonF, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsPolygonItem: ...
    @typing.overload
    def addRect(self, x: float, y: float, w: float, h: float, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsRectItem: ...
    @typing.overload
    def addRect(self, rect: PySide2.QtCore.QRectF, pen: PySide2.QtGui.QPen = ..., brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ...) -> QGraphicsRectItem: ...
    def addSimpleText(self, text: str, font: PySide2.QtGui.QFont = ...) -> QGraphicsSimpleTextItem: ...
    def addText(self, text: str, font: PySide2.QtGui.QFont = ...) -> QGraphicsTextItem: ...
    def addWidget(self, widget: QWidget, wFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> QGraphicsProxyWidget: ...
    def advance(self) -> None: ...
    def backgroundBrush(self) -> PySide2.QtGui.QBrush: ...
    def bspTreeDepth(self) -> int: ...
    def clear(self) -> None: ...
    def clearFocus(self) -> None: ...
    def clearSelection(self) -> None: ...
    def collidingItems(self, item: QGraphicsItem, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    def contextMenuEvent(self, event: QGraphicsSceneContextMenuEvent) -> None: ...
    def createItemGroup(self, items: typing.Iterable[QGraphicsItem]) -> QGraphicsItemGroup: ...
    def destroyItemGroup(self, group: QGraphicsItemGroup) -> None: ...
    def dragEnterEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragLeaveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragMoveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def drawBackground(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRectF) -> None: ...
    def drawForeground(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRectF) -> None: ...
    def dropEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, watched: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusItem(self) -> QGraphicsItem: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOnTouch(self) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def foregroundBrush(self) -> PySide2.QtGui.QBrush: ...
    def hasFocus(self) -> bool: ...
    def height(self) -> float: ...
    def helpEvent(self, event: QGraphicsSceneHelpEvent) -> None: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    @typing.overload
    def invalidate(self, x: float, y: float, w: float, h: float, layers: typing.Union[QGraphicsScene.SceneLayers, QGraphicsScene.SceneLayer] = ...) -> None: ...
    @typing.overload
    def invalidate(self, rect: PySide2.QtCore.QRectF = ..., layers: typing.Union[QGraphicsScene.SceneLayers, QGraphicsScene.SceneLayer] = ...) -> None: ...
    def isActive(self) -> bool: ...
    def isSortCacheEnabled(self) -> bool: ...
    @typing.overload
    def itemAt(self, x: float, y: float, deviceTransform: PySide2.QtGui.QTransform) -> QGraphicsItem: ...
    @typing.overload
    def itemAt(self, pos: PySide2.QtCore.QPointF, deviceTransform: PySide2.QtGui.QTransform) -> QGraphicsItem: ...
    def itemIndexMethod(self) -> QGraphicsScene.ItemIndexMethod: ...
    @typing.overload
    def items(self, x: float, y: float, w: float, h: float, mode: PySide2.QtCore.Qt.ItemSelectionMode, order: PySide2.QtCore.Qt.SortOrder, deviceTransform: PySide2.QtGui.QTransform = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, rect: PySide2.QtCore.QRectF, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., order: PySide2.QtCore.Qt.SortOrder = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, pos: PySide2.QtCore.QPointF, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., order: PySide2.QtCore.Qt.SortOrder = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, polygon: PySide2.QtGui.QPolygonF, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., order: PySide2.QtCore.Qt.SortOrder = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, path: PySide2.QtGui.QPainterPath, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., order: PySide2.QtCore.Qt.SortOrder = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, order: PySide2.QtCore.Qt.SortOrder = ...) -> typing.List[QGraphicsItem]: ...
    def itemsBoundingRect(self) -> PySide2.QtCore.QRectF: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def minimumRenderSize(self) -> float: ...
    def mouseDoubleClickEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseGrabberItem(self) -> QGraphicsItem: ...
    def mouseMoveEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mousePressEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def palette(self) -> PySide2.QtGui.QPalette: ...
    def removeItem(self, item: QGraphicsItem) -> None: ...
    def render(self, painter: PySide2.QtGui.QPainter, target: PySide2.QtCore.QRectF = ..., source: PySide2.QtCore.QRectF = ..., aspectRatioMode: PySide2.QtCore.Qt.AspectRatioMode = ...) -> None: ...
    def sceneRect(self) -> PySide2.QtCore.QRectF: ...
    def selectedItems(self) -> typing.List[QGraphicsItem]: ...
    def selectionArea(self) -> PySide2.QtGui.QPainterPath: ...
    def sendEvent(self, item: QGraphicsItem, event: PySide2.QtCore.QEvent) -> bool: ...
    def setActivePanel(self, item: QGraphicsItem) -> None: ...
    def setActiveWindow(self, widget: QGraphicsWidget) -> None: ...
    def setBackgroundBrush(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setBspTreeDepth(self, depth: int) -> None: ...
    def setFocus(self, focusReason: PySide2.QtCore.Qt.FocusReason = ...) -> None: ...
    def setFocusItem(self, item: QGraphicsItem, focusReason: PySide2.QtCore.Qt.FocusReason = ...) -> None: ...
    def setFocusOnTouch(self, enabled: bool) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setForegroundBrush(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setItemIndexMethod(self, method: QGraphicsScene.ItemIndexMethod) -> None: ...
    def setMinimumRenderSize(self, minSize: float) -> None: ...
    def setPalette(self, palette: PySide2.QtGui.QPalette) -> None: ...
    @typing.overload
    def setSceneRect(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def setSceneRect(self, rect: PySide2.QtCore.QRectF) -> None: ...
    @typing.overload
    def setSelectionArea(self, path: PySide2.QtGui.QPainterPath, selectionOperation: PySide2.QtCore.Qt.ItemSelectionOperation, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def setSelectionArea(self, path: PySide2.QtGui.QPainterPath, mode: PySide2.QtCore.Qt.ItemSelectionMode = ..., deviceTransform: PySide2.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def setSelectionArea(self, path: PySide2.QtGui.QPainterPath, deviceTransform: PySide2.QtGui.QTransform) -> None: ...
    def setSortCacheEnabled(self, enabled: bool) -> None: ...
    def setStickyFocus(self, enabled: bool) -> None: ...
    def setStyle(self, style: QStyle) -> None: ...
    def stickyFocus(self) -> bool: ...
    def style(self) -> QStyle: ...
    @typing.overload
    def update(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def update(self, rect: PySide2.QtCore.QRectF = ...) -> None: ...
    def views(self) -> typing.List[QGraphicsView]: ...
    def wheelEvent(self, event: QGraphicsSceneWheelEvent) -> None: ...
    def width(self) -> float: ...

class QGraphicsSceneContextMenuEvent(QGraphicsSceneEvent):
    class Reason:
        Keyboard: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
        Mouse: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
        Other: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsSceneContextMenuEvent.Reason: ...
    Keyboard: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
    Mouse: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
    Other: typing.ClassVar[QGraphicsSceneContextMenuEvent.Reason] = ...
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def modifiers(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def reason(self) -> QGraphicsSceneContextMenuEvent.Reason: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setModifiers(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setReason(self, reason: QGraphicsSceneContextMenuEvent.Reason) -> None: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...

class QGraphicsSceneDragDropEvent(QGraphicsSceneEvent):
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def acceptProposedAction(self) -> None: ...
    def buttons(self) -> typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]: ...
    def dropAction(self) -> PySide2.QtCore.Qt.DropAction: ...
    def mimeData(self) -> PySide2.QtCore.QMimeData: ...
    def modifiers(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def possibleActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...
    def proposedAction(self) -> PySide2.QtCore.Qt.DropAction: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setButtons(self, buttons: typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]) -> None: ...
    def setDropAction(self, action: PySide2.QtCore.Qt.DropAction) -> None: ...
    def setModifiers(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setPossibleActions(self, actions: typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]) -> None: ...
    def setProposedAction(self, action: PySide2.QtCore.Qt.DropAction) -> None: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...
    def source(self) -> QWidget: ...

class QGraphicsSceneEvent(PySide2.QtCore.QEvent):
    def __init__(self, type: PySide2.QtCore.QEvent.Type) -> None: ...
    def widget(self) -> QWidget: ...

class QGraphicsSceneHelpEvent(QGraphicsSceneEvent):
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...

class QGraphicsSceneHoverEvent(QGraphicsSceneEvent):
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def lastPos(self) -> PySide2.QtCore.QPointF: ...
    def lastScenePos(self) -> PySide2.QtCore.QPointF: ...
    def lastScreenPos(self) -> PySide2.QtCore.QPoint: ...
    def modifiers(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setLastPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setLastScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setLastScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...
    def setModifiers(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...

class QGraphicsSceneMouseEvent(QGraphicsSceneEvent):
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def button(self) -> PySide2.QtCore.Qt.MouseButton: ...
    def buttonDownPos(self, button: PySide2.QtCore.Qt.MouseButton) -> PySide2.QtCore.QPointF: ...
    def buttonDownScenePos(self, button: PySide2.QtCore.Qt.MouseButton) -> PySide2.QtCore.QPointF: ...
    def buttonDownScreenPos(self, button: PySide2.QtCore.Qt.MouseButton) -> PySide2.QtCore.QPoint: ...
    def buttons(self) -> typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]: ...
    def flags(self) -> typing.Union[PySide2.QtCore.Qt.MouseEventFlags, PySide2.QtCore.Qt.MouseEventFlag]: ...
    def lastPos(self) -> PySide2.QtCore.QPointF: ...
    def lastScenePos(self) -> PySide2.QtCore.QPointF: ...
    def lastScreenPos(self) -> PySide2.QtCore.QPoint: ...
    def modifiers(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setButton(self, button: PySide2.QtCore.Qt.MouseButton) -> None: ...
    def setButtonDownPos(self, button: PySide2.QtCore.Qt.MouseButton, pos: PySide2.QtCore.QPointF) -> None: ...
    def setButtonDownScenePos(self, button: PySide2.QtCore.Qt.MouseButton, pos: PySide2.QtCore.QPointF) -> None: ...
    def setButtonDownScreenPos(self, button: PySide2.QtCore.Qt.MouseButton, pos: PySide2.QtCore.QPoint) -> None: ...
    def setButtons(self, buttons: typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]) -> None: ...
    def setFlags(self, arg__1: typing.Union[PySide2.QtCore.Qt.MouseEventFlags, PySide2.QtCore.Qt.MouseEventFlag]) -> None: ...
    def setLastPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setLastScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setLastScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...
    def setModifiers(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...
    def setSource(self, source: PySide2.QtCore.Qt.MouseEventSource) -> None: ...
    def source(self) -> PySide2.QtCore.Qt.MouseEventSource: ...

class QGraphicsSceneMoveEvent(QGraphicsSceneEvent):
    def __init__(self) -> None: ...
    def newPos(self) -> PySide2.QtCore.QPointF: ...
    def oldPos(self) -> PySide2.QtCore.QPointF: ...
    def setNewPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setOldPos(self, pos: PySide2.QtCore.QPointF) -> None: ...

class QGraphicsSceneResizeEvent(QGraphicsSceneEvent):
    def __init__(self) -> None: ...
    def newSize(self) -> PySide2.QtCore.QSizeF: ...
    def oldSize(self) -> PySide2.QtCore.QSizeF: ...
    def setNewSize(self, size: PySide2.QtCore.QSizeF) -> None: ...
    def setOldSize(self, size: PySide2.QtCore.QSizeF) -> None: ...

class QGraphicsSceneWheelEvent(QGraphicsSceneEvent):
    def __init__(self, type: typing.Union[PySide2.QtCore.QEvent.Type, None] = ...) -> None: ...
    def buttons(self) -> typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]: ...
    def delta(self) -> int: ...
    def modifiers(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def pos(self) -> PySide2.QtCore.QPointF: ...
    def scenePos(self) -> PySide2.QtCore.QPointF: ...
    def screenPos(self) -> PySide2.QtCore.QPoint: ...
    def setButtons(self, buttons: typing.Union[PySide2.QtCore.Qt.MouseButtons, PySide2.QtCore.Qt.MouseButton]) -> None: ...
    def setDelta(self, delta: int) -> None: ...
    def setModifiers(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...
    def setOrientation(self, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setPos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScenePos(self, pos: PySide2.QtCore.QPointF) -> None: ...
    def setScreenPos(self, pos: PySide2.QtCore.QPoint) -> None: ...

class QGraphicsSimpleTextItem(QAbstractGraphicsShapeItem):
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ...) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: QWidget) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setText(self, text: str) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def text(self) -> str: ...
    def type(self) -> int: ...

class QGraphicsTextItem(QGraphicsObject):
    linkActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    linkHovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QGraphicsItem, None] = ..., children: typing.Any = ..., childrenChanged: typing.Callable = ..., destroyed: typing.Callable = ..., effect: typing.Any = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., height: float = ..., heightChanged: typing.Callable = ..., linkActivated: typing.Callable = ..., linkHovered: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opacity: float = ..., opacityChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., pos: PySide2.QtCore.QPointF = ..., rotation: float = ..., rotationChanged: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., transformOriginPoint: PySide2.QtCore.QPointF = ..., visible: bool = ..., visibleChanged: typing.Callable = ..., width: float = ..., widthChanged: typing.Callable = ..., x: float = ..., xChanged: typing.Callable = ..., y: float = ..., yChanged: typing.Callable = ..., z: float = ..., zChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ..., children: typing.Any = ..., childrenChanged: typing.Callable = ..., destroyed: typing.Callable = ..., effect: typing.Any = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., height: float = ..., heightChanged: typing.Callable = ..., linkActivated: typing.Callable = ..., linkHovered: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opacity: float = ..., opacityChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., pos: PySide2.QtCore.QPointF = ..., rotation: float = ..., rotationChanged: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., transformOriginPoint: PySide2.QtCore.QPointF = ..., visible: bool = ..., visibleChanged: typing.Callable = ..., width: float = ..., widthChanged: typing.Callable = ..., x: float = ..., xChanged: typing.Callable = ..., y: float = ..., yChanged: typing.Callable = ..., z: float = ..., zChanged: typing.Callable = ...) -> None: ...
    def adjustSize(self) -> None: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def contains(self, point: PySide2.QtCore.QPointF) -> bool: ...
    def contextMenuEvent(self, event: QGraphicsSceneContextMenuEvent) -> None: ...
    def defaultTextColor(self) -> PySide2.QtGui.QColor: ...
    def document(self) -> PySide2.QtGui.QTextDocument: ...
    def dragEnterEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragLeaveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dragMoveEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def dropEvent(self, event: QGraphicsSceneDragDropEvent) -> None: ...
    def extension(self, variant: typing.Any) -> typing.Any: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def hoverEnterEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverLeaveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverMoveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def isObscuredBy(self, item: QGraphicsItem) -> bool: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def mouseDoubleClickEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mousePressEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: QGraphicsSceneMouseEvent) -> None: ...
    def opaqueArea(self) -> PySide2.QtGui.QPainterPath: ...
    def openExternalLinks(self) -> bool: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: QWidget) -> None: ...
    def sceneEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def setDefaultTextColor(self, c: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setDocument(self, document: PySide2.QtGui.QTextDocument) -> None: ...
    def setExtension(self, extension: QGraphicsItem.Extension, variant: typing.Any) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setHtml(self, html: str) -> None: ...
    def setOpenExternalLinks(self, open: bool) -> None: ...
    def setPlainText(self, text: str) -> None: ...
    def setTabChangesFocus(self, b: bool) -> None: ...
    def setTextCursor(self, cursor: PySide2.QtGui.QTextCursor) -> None: ...
    def setTextInteractionFlags(self, flags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]) -> None: ...
    def setTextWidth(self, width: float) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def supportsExtension(self, extension: QGraphicsItem.Extension) -> bool: ...
    def tabChangesFocus(self) -> bool: ...
    def textCursor(self) -> PySide2.QtGui.QTextCursor: ...
    def textInteractionFlags(self) -> typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]: ...
    def textWidth(self) -> float: ...
    def toHtml(self) -> str: ...
    def toPlainText(self) -> str: ...
    def type(self) -> int: ...

class QGraphicsTransform(PySide2.QtCore.QObject):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def applyTo(self, matrix: PySide2.QtGui.QMatrix4x4) -> None: ...
    def update(self) -> None: ...

class QGraphicsView(QAbstractScrollArea):
    class CacheMode:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsView.CacheMode: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...

    class CacheModeFlag:
        CacheBackground: typing.ClassVar[QGraphicsView.CacheModeFlag] = ...
        CacheNone: typing.ClassVar[QGraphicsView.CacheModeFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsView.CacheMode: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.CacheMode: ...

    class DragMode:
        NoDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
        RubberBandDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
        ScrollHandDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.DragMode: ...

    class OptimizationFlag:
        DontAdjustForAntialiasing: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
        DontClipPainter: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
        DontSavePainterState: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
        IndirectPainting: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsView.OptimizationFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...

    class OptimizationFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QGraphicsView.OptimizationFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.OptimizationFlags: ...

    class ViewportAnchor:
        AnchorUnderMouse: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
        AnchorViewCenter: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
        NoAnchor: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportAnchor: ...

    class ViewportUpdateMode:
        BoundingRectViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
        FullViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
        MinimalViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
        NoViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
        SmartViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __and__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QGraphicsView.ViewportUpdateMode: ...
    AnchorUnderMouse: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
    AnchorViewCenter: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
    BoundingRectViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
    CacheBackground: typing.ClassVar[QGraphicsView.CacheModeFlag] = ...
    CacheNone: typing.ClassVar[QGraphicsView.CacheModeFlag] = ...
    DontAdjustForAntialiasing: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
    DontClipPainter: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
    DontSavePainterState: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
    FullViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
    IndirectPainting: typing.ClassVar[QGraphicsView.OptimizationFlag] = ...
    MinimalViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
    NoAnchor: typing.ClassVar[QGraphicsView.ViewportAnchor] = ...
    NoDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
    NoViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
    RubberBandDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
    ScrollHandDrag: typing.ClassVar[QGraphicsView.DragMode] = ...
    SmartViewportUpdate: typing.ClassVar[QGraphicsView.ViewportUpdateMode] = ...
    rubberBandChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, scene: QGraphicsScene, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., backgroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., baseSize: PySide2.QtCore.QSize = ..., cacheMode: typing.Union[QGraphicsView.CacheMode, QGraphicsView.CacheModeFlag] = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., dragMode: QGraphicsView.DragMode = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., foregroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QGraphicsView.Shadow = ..., frameShape: QGraphicsView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., interactive: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., optimizationFlags: typing.Union[QGraphicsView.OptimizationFlags, QGraphicsView.OptimizationFlag] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., renderHints: typing.Union[PySide2.QtGui.QPainter.RenderHints, PySide2.QtGui.QPainter.RenderHint] = ..., resizeAnchor: QGraphicsView.ViewportAnchor = ..., rubberBandChanged: typing.Callable = ..., rubberBandSelectionMode: PySide2.QtCore.Qt.ItemSelectionMode = ..., sceneRect: PySide2.QtCore.QRectF = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QGraphicsView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., transformationAnchor: QGraphicsView.ViewportAnchor = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., viewportUpdateMode: QGraphicsView.ViewportUpdateMode = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., backgroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., baseSize: PySide2.QtCore.QSize = ..., cacheMode: typing.Union[QGraphicsView.CacheMode, QGraphicsView.CacheModeFlag] = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., dragMode: QGraphicsView.DragMode = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., foregroundBrush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QGraphicsView.Shadow = ..., frameShape: QGraphicsView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., interactive: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., optimizationFlags: typing.Union[QGraphicsView.OptimizationFlags, QGraphicsView.OptimizationFlag] = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., renderHints: typing.Union[PySide2.QtGui.QPainter.RenderHints, PySide2.QtGui.QPainter.RenderHint] = ..., resizeAnchor: QGraphicsView.ViewportAnchor = ..., rubberBandChanged: typing.Callable = ..., rubberBandSelectionMode: PySide2.QtCore.Qt.ItemSelectionMode = ..., sceneRect: PySide2.QtCore.QRectF = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QGraphicsView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., transformationAnchor: QGraphicsView.ViewportAnchor = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., viewportUpdateMode: QGraphicsView.ViewportUpdateMode = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def backgroundBrush(self) -> PySide2.QtGui.QBrush: ...
    def cacheMode(self) -> typing.Union[QGraphicsView.CacheMode, QGraphicsView.CacheModeFlag]: ...
    @typing.overload
    def centerOn(self, x: float, y: float) -> None: ...
    @typing.overload
    def centerOn(self, pos: PySide2.QtCore.QPointF) -> None: ...
    @typing.overload
    def centerOn(self, item: QGraphicsItem) -> None: ...
    def contextMenuEvent(self, event: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def dragEnterEvent(self, event: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, event: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMode(self) -> QGraphicsView.DragMode: ...
    def dragMoveEvent(self, event: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def drawBackground(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRectF) -> None: ...
    def drawForeground(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRectF) -> None: ...
    def drawItems(self, painter: PySide2.QtGui.QPainter, numItems: int, items: typing.Iterable[QGraphicsItem], options: typing.Iterable[QStyleOptionGraphicsItem]) -> None: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    @typing.overload
    def ensureVisible(self, x: float, y: float, w: float, h: float, xmargin: int = ..., ymargin: int = ...) -> None: ...
    @typing.overload
    def ensureVisible(self, rect: PySide2.QtCore.QRectF, xmargin: int = ..., ymargin: int = ...) -> None: ...
    @typing.overload
    def ensureVisible(self, item: QGraphicsItem, xmargin: int = ..., ymargin: int = ...) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    @typing.overload
    def fitInView(self, x: float, y: float, w: float, h: float, aspectRadioMode: PySide2.QtCore.Qt.AspectRatioMode = ...) -> None: ...
    @typing.overload
    def fitInView(self, rect: PySide2.QtCore.QRectF, aspectRadioMode: PySide2.QtCore.Qt.AspectRatioMode = ...) -> None: ...
    @typing.overload
    def fitInView(self, item: QGraphicsItem, aspectRadioMode: PySide2.QtCore.Qt.AspectRatioMode = ...) -> None: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def foregroundBrush(self) -> PySide2.QtGui.QBrush: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def invalidateScene(self, rect: PySide2.QtCore.QRectF = ..., layers: typing.Union[QGraphicsScene.SceneLayers, QGraphicsScene.SceneLayer] = ...) -> None: ...
    def isInteractive(self) -> bool: ...
    def isTransformed(self) -> bool: ...
    @typing.overload
    def itemAt(self, x: int, y: int) -> QGraphicsItem: ...
    @typing.overload
    def itemAt(self, pos: PySide2.QtCore.QPoint) -> QGraphicsItem: ...
    @typing.overload
    def items(self, x: int, y: int, w: int, h: int, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, x: int, y: int) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, rect: PySide2.QtCore.QRect, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, polygon: PySide2.QtGui.QPolygon, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, path: PySide2.QtGui.QPainterPath, mode: PySide2.QtCore.Qt.ItemSelectionMode = ...) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self, pos: PySide2.QtCore.QPoint) -> typing.List[QGraphicsItem]: ...
    @typing.overload
    def items(self) -> typing.List[QGraphicsItem]: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    @typing.overload
    def mapFromScene(self, x: float, y: float, w: float, h: float) -> PySide2.QtGui.QPolygon: ...
    @typing.overload
    def mapFromScene(self, x: float, y: float) -> PySide2.QtCore.QPoint: ...
    @typing.overload
    def mapFromScene(self, rect: PySide2.QtCore.QRectF) -> PySide2.QtGui.QPolygon: ...
    @typing.overload
    def mapFromScene(self, polygon: PySide2.QtGui.QPolygonF) -> PySide2.QtGui.QPolygon: ...
    @typing.overload
    def mapFromScene(self, point: PySide2.QtCore.QPointF) -> PySide2.QtCore.QPoint: ...
    @typing.overload
    def mapFromScene(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    @typing.overload
    def mapToScene(self, x: int, y: int, w: int, h: int) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, x: int, y: int) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToScene(self, rect: PySide2.QtCore.QRect) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, polygon: PySide2.QtGui.QPolygon) -> PySide2.QtGui.QPolygonF: ...
    @typing.overload
    def mapToScene(self, point: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPointF: ...
    @typing.overload
    def mapToScene(self, path: PySide2.QtGui.QPainterPath) -> PySide2.QtGui.QPainterPath: ...
    def matrix(self) -> PySide2.QtGui.QMatrix: ...
    def mouseDoubleClickEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def optimizationFlags(self) -> typing.Union[QGraphicsView.OptimizationFlags, QGraphicsView.OptimizationFlag]: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    @typing.overload
    def render(self, target: PySide2.QtGui.QPaintDevice, targetOffset: PySide2.QtCore.QPoint = ..., sourceRegion: PySide2.QtGui.QRegion = ..., renderFlags: typing.Union[QWidget.RenderFlags, QWidget.RenderFlag] = ...) -> None: ...
    @typing.overload
    def render(self, painter: PySide2.QtGui.QPainter, target: PySide2.QtCore.QRectF = ..., source: PySide2.QtCore.QRect = ..., aspectRatioMode: PySide2.QtCore.Qt.AspectRatioMode = ...) -> None: ...
    def renderHints(self) -> typing.Union[PySide2.QtGui.QPainter.RenderHints, PySide2.QtGui.QPainter.RenderHint]: ...
    def resetCachedContent(self) -> None: ...
    def resetMatrix(self) -> None: ...
    def resetTransform(self) -> None: ...
    def resizeAnchor(self) -> QGraphicsView.ViewportAnchor: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def rotate(self, angle: float) -> None: ...
    def rubberBandRect(self) -> PySide2.QtCore.QRect: ...
    def rubberBandSelectionMode(self) -> PySide2.QtCore.Qt.ItemSelectionMode: ...
    def scale(self, sx: float, sy: float) -> None: ...
    def scene(self) -> QGraphicsScene: ...
    def sceneRect(self) -> PySide2.QtCore.QRectF: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def setAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setBackgroundBrush(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setCacheMode(self, mode: typing.Union[QGraphicsView.CacheMode, QGraphicsView.CacheModeFlag]) -> None: ...
    def setDragMode(self, mode: QGraphicsView.DragMode) -> None: ...
    def setForegroundBrush(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setInteractive(self, allowed: bool) -> None: ...
    def setMatrix(self, matrix: PySide2.QtGui.QMatrix, combine: bool = ...) -> None: ...
    def setOptimizationFlag(self, flag: QGraphicsView.OptimizationFlag, enabled: bool = ...) -> None: ...
    def setOptimizationFlags(self, flags: typing.Union[QGraphicsView.OptimizationFlags, QGraphicsView.OptimizationFlag]) -> None: ...
    def setRenderHint(self, hint: PySide2.QtGui.QPainter.RenderHint, enabled: bool = ...) -> None: ...
    def setRenderHints(self, hints: typing.Union[PySide2.QtGui.QPainter.RenderHints, PySide2.QtGui.QPainter.RenderHint]) -> None: ...
    def setResizeAnchor(self, anchor: QGraphicsView.ViewportAnchor) -> None: ...
    def setRubberBandSelectionMode(self, mode: PySide2.QtCore.Qt.ItemSelectionMode) -> None: ...
    def setScene(self, scene: QGraphicsScene) -> None: ...
    @typing.overload
    def setSceneRect(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def setSceneRect(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setTransform(self, matrix: PySide2.QtGui.QTransform, combine: bool = ...) -> None: ...
    def setTransformationAnchor(self, anchor: QGraphicsView.ViewportAnchor) -> None: ...
    def setViewportUpdateMode(self, mode: QGraphicsView.ViewportUpdateMode) -> None: ...
    def setupViewport(self, widget: QWidget) -> None: ...
    def shear(self, sh: float, sv: float) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def transform(self) -> PySide2.QtGui.QTransform: ...
    def transformationAnchor(self) -> QGraphicsView.ViewportAnchor: ...
    def translate(self, dx: float, dy: float) -> None: ...
    def updateScene(self, rects: typing.Iterable[PySide2.QtCore.QRectF]) -> None: ...
    def updateSceneRect(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def viewportEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def viewportTransform(self) -> PySide2.QtGui.QTransform: ...
    def viewportUpdateMode(self) -> QGraphicsView.ViewportUpdateMode: ...
    def wheelEvent(self, event: PySide2.QtGui.QWheelEvent) -> None: ...

class QGraphicsWidget(QGraphicsObject, QGraphicsLayoutItem):
    geometryChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    layoutChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QGraphicsItem, None] = ..., wFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., autoFillBackground: bool = ..., children: typing.Any = ..., childrenChanged: typing.Callable = ..., destroyed: typing.Callable = ..., effect: typing.Any = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., geometry: PySide2.QtCore.QRectF = ..., geometryChanged: typing.Callable = ..., height: float = ..., heightChanged: typing.Callable = ..., layout: QGraphicsLayout = ..., layoutChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., maximumSize: PySide2.QtCore.QSizeF = ..., minimumSize: PySide2.QtCore.QSizeF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opacity: float = ..., opacityChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., parentChanged: typing.Callable = ..., pos: PySide2.QtCore.QPointF = ..., preferredSize: PySide2.QtCore.QSizeF = ..., rotation: float = ..., rotationChanged: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., size: PySide2.QtCore.QSizeF = ..., sizePolicy: QSizePolicy = ..., transformOriginPoint: PySide2.QtCore.QPointF = ..., visible: bool = ..., visibleChanged: typing.Callable = ..., width: float = ..., widthChanged: typing.Callable = ..., windowFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., windowTitle: str = ..., x: float = ..., xChanged: typing.Callable = ..., y: float = ..., yChanged: typing.Callable = ..., z: float = ..., zChanged: typing.Callable = ...) -> None: ...
    def actions(self) -> typing.List[QAction]: ...
    def addAction(self, action: QAction) -> None: ...
    def addActions(self, actions: typing.Iterable[QAction]) -> None: ...
    def adjustSize(self) -> None: ...
    def autoFillBackground(self) -> bool: ...
    def boundingRect(self) -> PySide2.QtCore.QRectF: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def close(self) -> bool: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusPolicy(self) -> PySide2.QtCore.Qt.FocusPolicy: ...
    def focusWidget(self) -> QGraphicsWidget: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]: ...
    def getWindowFrameMargins(self) -> typing.Tuple[float, float, float, float]: ...
    def grabKeyboardEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def grabMouseEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def grabShortcut(self, sequence: typing.Union[PySide2.QtGui.QKeySequence, str], context: PySide2.QtCore.Qt.ShortcutContext = ...) -> int: ...
    def hideEvent(self, event: PySide2.QtGui.QHideEvent) -> None: ...
    def hoverLeaveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def hoverMoveEvent(self, event: QGraphicsSceneHoverEvent) -> None: ...
    def initStyleOption(self, option: QStyleOption) -> None: ...
    def insertAction(self, before: QAction, action: QAction) -> None: ...
    def insertActions(self, before: QAction, actions: typing.Iterable[QAction]) -> None: ...
    def isActiveWindow(self) -> bool: ...
    def itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: typing.Any) -> typing.Any: ...
    def layout(self) -> QGraphicsLayout: ...
    def layoutDirection(self) -> PySide2.QtCore.Qt.LayoutDirection: ...
    def moveEvent(self, event: QGraphicsSceneMoveEvent) -> None: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def paintWindowFrame(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionGraphicsItem, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def palette(self) -> PySide2.QtGui.QPalette: ...
    def polishEvent(self) -> None: ...
    def propertyChange(self, propertyName: str, value: typing.Any) -> typing.Any: ...
    def rect(self) -> PySide2.QtCore.QRectF: ...
    def releaseShortcut(self, id: int) -> None: ...
    def removeAction(self, action: QAction) -> None: ...
    @typing.overload
    def resize(self, w: float, h: float) -> None: ...
    @typing.overload
    def resize(self, size: PySide2.QtCore.QSizeF) -> None: ...
    def resizeEvent(self, event: QGraphicsSceneResizeEvent) -> None: ...
    def sceneEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def setAttribute(self, attribute: PySide2.QtCore.Qt.WidgetAttribute, on: bool = ...) -> None: ...
    def setAutoFillBackground(self, enabled: bool) -> None: ...
    @typing.overload
    def setContentsMargins(self, left: float, top: float, right: float, bottom: float) -> None: ...
    @typing.overload
    def setContentsMargins(self, margins: PySide2.QtCore.QMarginsF) -> None: ...
    def setFocusPolicy(self, policy: PySide2.QtCore.Qt.FocusPolicy) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    @typing.overload
    def setGeometry(self, x: float, y: float, w: float, h: float) -> None: ...
    @typing.overload
    def setGeometry(self, rect: PySide2.QtCore.QRectF) -> None: ...
    def setLayout(self, layout: QGraphicsLayout) -> None: ...
    def setLayoutDirection(self, direction: PySide2.QtCore.Qt.LayoutDirection) -> None: ...
    def setPalette(self, palette: PySide2.QtGui.QPalette) -> None: ...
    def setShortcutAutoRepeat(self, id: int, enabled: bool = ...) -> None: ...
    def setShortcutEnabled(self, id: int, enabled: bool = ...) -> None: ...
    def setStyle(self, style: QStyle) -> None: ...
    @classmethod
    def setTabOrder(cls, first: QGraphicsWidget, second: QGraphicsWidget) -> None: ...
    def setWindowFlags(self, wFlags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType]) -> None: ...
    @typing.overload
    def setWindowFrameMargins(self, left: float, top: float, right: float, bottom: float) -> None: ...
    @typing.overload
    def setWindowFrameMargins(self, margins: PySide2.QtCore.QMarginsF) -> None: ...
    def setWindowTitle(self, title: str) -> None: ...
    def shape(self) -> PySide2.QtGui.QPainterPath: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def size(self) -> PySide2.QtCore.QSizeF: ...
    def sizeHint(self, which: PySide2.QtCore.Qt.SizeHint, constraint: PySide2.QtCore.QSizeF = ...) -> PySide2.QtCore.QSizeF: ...
    def style(self) -> QStyle: ...
    def testAttribute(self, attribute: PySide2.QtCore.Qt.WidgetAttribute) -> bool: ...
    def type(self) -> int: ...
    def ungrabKeyboardEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def ungrabMouseEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def unsetLayoutDirection(self) -> None: ...
    def unsetWindowFrameMargins(self) -> None: ...
    def updateGeometry(self) -> None: ...
    def windowFlags(self) -> typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType]: ...
    def windowFrameEvent(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def windowFrameGeometry(self) -> PySide2.QtCore.QRectF: ...
    def windowFrameRect(self) -> PySide2.QtCore.QRectF: ...
    def windowFrameSectionAt(self, pos: PySide2.QtCore.QPointF) -> PySide2.QtCore.Qt.WindowFrameSection: ...
    def windowTitle(self) -> str: ...
    def windowType(self) -> PySide2.QtCore.Qt.WindowType: ...

class QGridLayout(QLayout):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QGridLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QGridLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...
    @typing.overload
    def addItem(self, item: QLayoutItem, row: int, column: int, rowSpan: int = ..., columnSpan: int = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addItem(self, arg__1: QLayoutItem) -> None: ...
    @typing.overload
    def addLayout(self, arg__1: QLayout, row: int, column: int, rowSpan: int, columnSpan: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addLayout(self, arg__1: QLayout, row: int, column: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addWidget(self, arg__1: QWidget, row: int, column: int, rowSpan: int, columnSpan: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addWidget(self, arg__1: QWidget, row: int, column: int, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    @typing.overload
    def addWidget(self, w: QWidget) -> None: ...
    def cellRect(self, row: int, column: int) -> PySide2.QtCore.QRect: ...
    def columnCount(self) -> int: ...
    def columnMinimumWidth(self, column: int) -> int: ...
    def columnStretch(self, column: int) -> int: ...
    def count(self) -> int: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def getItemPosition(self, idx: int) -> typing.Tuple[int, int, int, int]: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def horizontalSpacing(self) -> int: ...
    def invalidate(self) -> None: ...
    def itemAt(self, index: int) -> QLayoutItem: ...
    def itemAtPosition(self, row: int, column: int) -> QLayoutItem: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumHeightForWidth(self, arg__1: int) -> int: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def originCorner(self) -> PySide2.QtCore.Qt.Corner: ...
    def rowCount(self) -> int: ...
    def rowMinimumHeight(self, row: int) -> int: ...
    def rowStretch(self, row: int) -> int: ...
    def setColumnMinimumWidth(self, column: int, minSize: int) -> None: ...
    def setColumnStretch(self, column: int, stretch: int) -> None: ...
    def setDefaultPositioning(self, n: int, orient: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def setHorizontalSpacing(self, spacing: int) -> None: ...
    def setOriginCorner(self, arg__1: PySide2.QtCore.Qt.Corner) -> None: ...
    def setRowMinimumHeight(self, row: int, minSize: int) -> None: ...
    def setRowStretch(self, row: int, stretch: int) -> None: ...
    def setSpacing(self, spacing: int) -> None: ...
    def setVerticalSpacing(self, spacing: int) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def spacing(self) -> int: ...
    def takeAt(self, index: int) -> QLayoutItem: ...
    def verticalSpacing(self) -> int: ...

class QGroupBox(QWidget):
    clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    toggled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, title: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., title: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def childEvent(self, event: PySide2.QtCore.QChildEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def initStyleOption(self, option: QStyleOptionGroupBox) -> None: ...
    def isCheckable(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isFlat(self) -> bool: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def setAlignment(self, alignment: int) -> None: ...
    def setCheckable(self, checkable: bool) -> None: ...
    def setChecked(self, checked: bool) -> None: ...
    def setFlat(self, flat: bool) -> None: ...
    def setTitle(self, title: str) -> None: ...
    def title(self) -> str: ...

class QHBoxLayout(QBoxLayout):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QHBoxLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QHBoxLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...

class QHeaderView(QAbstractItemView):
    class ResizeMode:
        Custom: typing.ClassVar[QHeaderView.ResizeMode] = ...
        Fixed: typing.ClassVar[QHeaderView.ResizeMode] = ...
        Interactive: typing.ClassVar[QHeaderView.ResizeMode] = ...
        ResizeToContents: typing.ClassVar[QHeaderView.ResizeMode] = ...
        Stretch: typing.ClassVar[QHeaderView.ResizeMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __and__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QHeaderView.ResizeMode: ...
    Custom: typing.ClassVar[QHeaderView.ResizeMode] = ...
    Fixed: typing.ClassVar[QHeaderView.ResizeMode] = ...
    Interactive: typing.ClassVar[QHeaderView.ResizeMode] = ...
    ResizeToContents: typing.ClassVar[QHeaderView.ResizeMode] = ...
    Stretch: typing.ClassVar[QHeaderView.ResizeMode] = ...
    geometriesChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionCountChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionHandleDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionMoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sectionResized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sortIndicatorChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, orientation: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QAbstractScrollArea.Shadow = ..., frameShape: QAbstractScrollArea.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QAbstractScrollArea.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def cascadingSectionResizes(self) -> bool: ...
    def count(self) -> int: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, old: PySide2.QtCore.QModelIndex) -> None: ...
    def dataChanged(self, topLeft: PySide2.QtCore.QModelIndex, bottomRight: PySide2.QtCore.QModelIndex, roles: typing.List[int] = ...) -> None: ...
    def defaultAlignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def defaultSectionSize(self) -> int: ...
    def doItemsLayout(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def headerDataChanged(self, orientation: PySide2.QtCore.Qt.Orientation, logicalFirst: int, logicalLast: int) -> None: ...
    def hiddenSectionCount(self) -> int: ...
    def hideSection(self, logicalIndex: int) -> None: ...
    def highlightSections(self) -> bool: ...
    def horizontalOffset(self) -> int: ...
    def indexAt(self, p: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def initStyleOption(self, option: QStyleOptionFrame) -> None: ...
    @typing.overload
    def initStyleOption(self, option: QStyleOptionHeader) -> None: ...
    def initialize(self) -> None: ...
    @typing.overload
    def initializeSections(self, start: int, end: int) -> None: ...
    @typing.overload
    def initializeSections(self) -> None: ...
    def isFirstSectionMovable(self) -> bool: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isSectionHidden(self, logicalIndex: int) -> bool: ...
    def isSortIndicatorShown(self) -> bool: ...
    def length(self) -> int: ...
    def logicalIndex(self, visualIndex: int) -> int: ...
    @typing.overload
    def logicalIndexAt(self, x: int, y: int) -> int: ...
    @typing.overload
    def logicalIndexAt(self, position: int) -> int: ...
    @typing.overload
    def logicalIndexAt(self, pos: PySide2.QtCore.QPoint) -> int: ...
    def maximumSectionSize(self) -> int: ...
    def minimumSectionSize(self) -> int: ...
    def mouseDoubleClickEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, arg__1: QAbstractItemView.CursorAction, arg__2: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def moveSection(self, from_: int, to: int) -> None: ...
    def offset(self) -> int: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def paintSection(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, logicalIndex: int) -> None: ...
    def reset(self) -> None: ...
    def resetDefaultSectionSize(self) -> None: ...
    def resizeContentsPrecision(self) -> int: ...
    def resizeSection(self, logicalIndex: int, size: int) -> None: ...
    @typing.overload
    def resizeSections(self, mode: QHeaderView.ResizeMode) -> None: ...
    @typing.overload
    def resizeSections(self) -> None: ...
    def restoreState(self, state: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> bool: ...
    def rowsInserted(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def saveState(self) -> PySide2.QtCore.QByteArray: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint) -> None: ...
    def sectionPosition(self, logicalIndex: int) -> int: ...
    def sectionResizeMode(self, logicalIndex: int) -> QHeaderView.ResizeMode: ...
    def sectionSize(self, logicalIndex: int) -> int: ...
    def sectionSizeFromContents(self, logicalIndex: int) -> PySide2.QtCore.QSize: ...
    def sectionSizeHint(self, logicalIndex: int) -> int: ...
    def sectionViewportPosition(self, logicalIndex: int) -> int: ...
    def sectionsAboutToBeRemoved(self, parent: PySide2.QtCore.QModelIndex, logicalFirst: int, logicalLast: int) -> None: ...
    def sectionsClickable(self) -> bool: ...
    def sectionsHidden(self) -> bool: ...
    def sectionsInserted(self, parent: PySide2.QtCore.QModelIndex, logicalFirst: int, logicalLast: int) -> None: ...
    def sectionsMovable(self) -> bool: ...
    def sectionsMoved(self) -> bool: ...
    def setCascadingSectionResizes(self, enable: bool) -> None: ...
    def setDefaultAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setDefaultSectionSize(self, size: int) -> None: ...
    def setFirstSectionMovable(self, movable: bool) -> None: ...
    def setHighlightSections(self, highlight: bool) -> None: ...
    def setMaximumSectionSize(self, size: int) -> None: ...
    def setMinimumSectionSize(self, size: int) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setOffset(self, offset: int) -> None: ...
    def setOffsetToLastSection(self) -> None: ...
    def setOffsetToSectionPosition(self, visualIndex: int) -> None: ...
    def setResizeContentsPrecision(self, precision: int) -> None: ...
    def setSectionHidden(self, logicalIndex: int, hide: bool) -> None: ...
    @typing.overload
    def setSectionResizeMode(self, logicalIndex: int, mode: QHeaderView.ResizeMode) -> None: ...
    @typing.overload
    def setSectionResizeMode(self, mode: QHeaderView.ResizeMode) -> None: ...
    def setSectionsClickable(self, clickable: bool) -> None: ...
    def setSectionsMovable(self, movable: bool) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, flags: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSortIndicator(self, logicalIndex: int, order: PySide2.QtCore.Qt.SortOrder) -> None: ...
    def setSortIndicatorShown(self, show: bool) -> None: ...
    def setStretchLastSection(self, stretch: bool) -> None: ...
    def setVisible(self, v: bool) -> None: ...
    def showSection(self, logicalIndex: int) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sortIndicatorOrder(self) -> PySide2.QtCore.Qt.SortOrder: ...
    def sortIndicatorSection(self) -> int: ...
    def stretchLastSection(self) -> bool: ...
    def stretchSectionCount(self) -> int: ...
    def swapSections(self, first: int, second: int) -> None: ...
    def updateGeometries(self) -> None: ...
    def updateSection(self, logicalIndex: int) -> None: ...
    def verticalOffset(self) -> int: ...
    def viewportEvent(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def visualIndex(self, logicalIndex: int) -> int: ...
    def visualIndexAt(self, position: int) -> int: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...

class QInputDialog(QDialog):
    class InputDialogOption:
        NoButtons: typing.ClassVar[QInputDialog.InputDialogOption] = ...
        UseListViewForComboBoxItems: typing.ClassVar[QInputDialog.InputDialogOption] = ...
        UsePlainTextEditForTextInput: typing.ClassVar[QInputDialog.InputDialogOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __and__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __rand__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __rmul__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __ror__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __rsub__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __rxor__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __sub__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...
        def __xor__(self, other: typing.SupportsInt) -> QInputDialog.InputDialogOption: ...

    class InputMode:
        DoubleInput: typing.ClassVar[QInputDialog.InputMode] = ...
        IntInput: typing.ClassVar[QInputDialog.InputMode] = ...
        TextInput: typing.ClassVar[QInputDialog.InputMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __and__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QInputDialog.InputMode: ...
    DoubleInput: typing.ClassVar[QInputDialog.InputMode] = ...
    IntInput: typing.ClassVar[QInputDialog.InputMode] = ...
    NoButtons: typing.ClassVar[QInputDialog.InputDialogOption] = ...
    TextInput: typing.ClassVar[QInputDialog.InputMode] = ...
    UseListViewForComboBoxItems: typing.ClassVar[QInputDialog.InputDialogOption] = ...
    UsePlainTextEditForTextInput: typing.ClassVar[QInputDialog.InputDialogOption] = ...
    doubleValueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    doubleValueSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    intValueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    intValueSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textValueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    textValueSelected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., doubleValueChanged: typing.Callable = ..., doubleValueSelected: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., intValueChanged: typing.Callable = ..., intValueSelected: typing.Callable = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., textValueChanged: typing.Callable = ..., textValueSelected: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def cancelButtonText(self) -> str: ...
    def comboBoxItems(self) -> typing.List[str]: ...
    def done(self, result: int) -> None: ...
    def doubleDecimals(self) -> int: ...
    def doubleMaximum(self) -> float: ...
    def doubleMinimum(self) -> float: ...
    def doubleStep(self) -> float: ...
    def doubleValue(self) -> float: ...
    @typing.overload
    @classmethod
    def getDouble(cls, parent: typing.Union[QWidget, None], title: str, label: str, value: float, minValue: float, maxValue: float, decimals: int, flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType], step: float) -> typing.Tuple[float, bool]: ...
    @typing.overload
    @classmethod
    def getDouble(cls, parent: typing.Union[QWidget, None], title: str, label: str, value: float, minValue: float = ..., maxValue: float = ..., decimals: int = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> typing.Tuple[float, bool]: ...
    @classmethod
    def getInt(cls, parent: typing.Union[QWidget, None], title: str, label: str, value: int, minValue: int = ..., maxValue: int = ..., step: int = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> typing.Tuple[int, bool]: ...
    @classmethod
    def getItem(cls, parent: typing.Union[QWidget, None], title: str, label: str, items: typing.Iterable[str], current: int, editable: bool = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ...) -> typing.Tuple[str, bool]: ...
    @classmethod
    def getMultiLineText(cls, parent: typing.Union[QWidget, None], title: str, label: str, text: str, flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ...) -> typing.Tuple[str, bool]: ...
    @classmethod
    def getText(cls, parent: typing.Union[QWidget, None], title: str, label: str, echo: QLineEdit.EchoMode = ..., text: str = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ...) -> typing.Tuple[str, bool]: ...
    def inputMode(self) -> QInputDialog.InputMode: ...
    def intMaximum(self) -> int: ...
    def intMinimum(self) -> int: ...
    def intStep(self) -> int: ...
    def intValue(self) -> int: ...
    def isComboBoxEditable(self) -> bool: ...
    def labelText(self) -> str: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def okButtonText(self) -> str: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    def setCancelButtonText(self, text: str) -> None: ...
    def setComboBoxEditable(self, editable: bool) -> None: ...
    def setComboBoxItems(self, items: typing.Iterable[str]) -> None: ...
    def setDoubleDecimals(self, decimals: int) -> None: ...
    def setDoubleMaximum(self, max: float) -> None: ...
    def setDoubleMinimum(self, min: float) -> None: ...
    def setDoubleRange(self, min: float, max: float) -> None: ...
    def setDoubleStep(self, step: float) -> None: ...
    def setDoubleValue(self, value: float) -> None: ...
    def setInputMode(self, mode: QInputDialog.InputMode) -> None: ...
    def setIntMaximum(self, max: int) -> None: ...
    def setIntMinimum(self, min: int) -> None: ...
    def setIntRange(self, min: int, max: int) -> None: ...
    def setIntStep(self, step: int) -> None: ...
    def setIntValue(self, value: int) -> None: ...
    def setLabelText(self, text: str) -> None: ...
    def setOkButtonText(self, text: str) -> None: ...
    def setOption(self, option: QInputDialog.InputDialogOption, on: bool = ...) -> None: ...
    def setTextEchoMode(self, mode: QLineEdit.EchoMode) -> None: ...
    def setTextValue(self, text: str) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def testOption(self, option: QInputDialog.InputDialogOption) -> bool: ...
    def textEchoMode(self) -> QLineEdit.EchoMode: ...
    def textValue(self) -> str: ...

class QItemDelegate(QAbstractItemDelegate):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., clipping: bool = ..., closeEditor: typing.Callable = ..., commitData: typing.Callable = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeHintChanged: typing.Callable = ...) -> None: ...
    def createEditor(self, parent: typing.Union[QWidget, None], option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> QWidget: ...
    def decoration(self, option: QStyleOptionViewItem, variant: typing.Any) -> PySide2.QtGui.QPixmap: ...
    def doCheck(self, option: QStyleOptionViewItem, bounding: PySide2.QtCore.QRect, variant: typing.Any) -> PySide2.QtCore.QRect: ...
    def drawBackground(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def drawCheck(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, rect: PySide2.QtCore.QRect, state: PySide2.QtCore.Qt.CheckState) -> None: ...
    def drawDecoration(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, rect: PySide2.QtCore.QRect, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def drawDisplay(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, rect: PySide2.QtCore.QRect, text: str) -> None: ...
    def drawFocus(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, rect: PySide2.QtCore.QRect) -> None: ...
    def editorEvent(self, event: PySide2.QtCore.QEvent, model: PySide2.QtCore.QAbstractItemModel, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def hasClipping(self) -> bool: ...
    def itemEditorFactory(self) -> QItemEditorFactory: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def rect(self, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex, role: PySide2.QtCore.Qt.ItemDataRole) -> PySide2.QtCore.QRect: ...
    @classmethod
    def selectedPixmap(cls, pixmap: PySide2.QtGui.QPixmap, palette: PySide2.QtGui.QPalette, enabled: bool) -> PySide2.QtGui.QPixmap: ...
    def setClipping(self, clip: bool) -> None: ...
    def setEditorData(self, editor: QWidget, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setItemEditorFactory(self, factory: QItemEditorFactory) -> None: ...
    def setModelData(self, editor: QWidget, model: PySide2.QtCore.QAbstractItemModel, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setOptions(self, index: PySide2.QtCore.QModelIndex, option: QStyleOptionViewItem) -> QStyleOptionViewItem: ...
    def sizeHint(self, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QSize: ...
    def textRectangle(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, font: PySide2.QtGui.QFont, text: str) -> PySide2.QtCore.QRect: ...
    def updateEditorGeometry(self, editor: QWidget, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...

class QItemEditorCreatorBase(shiboken2.Object):
    def __init__(self) -> None: ...
    def createWidget(self, parent: typing.Union[QWidget, None]) -> QWidget: ...
    def valuePropertyName(self) -> PySide2.QtCore.QByteArray: ...

class QItemEditorFactory(shiboken2.Object):
    def __init__(self) -> None: ...
    def createEditor(self, userType: int, parent: typing.Union[QWidget, None]) -> QWidget: ...
    @classmethod
    def defaultFactory(cls) -> QItemEditorFactory: ...
    def registerEditor(self, userType: int, creator: QItemEditorCreatorBase) -> None: ...
    @classmethod
    def setDefaultFactory(cls, factory: QItemEditorFactory) -> None: ...
    def valuePropertyName(self, userType: int) -> PySide2.QtCore.QByteArray: ...

class QKeyEventTransition(PySide2.QtCore.QEventTransition):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, object: PySide2.QtCore.QObject, type: PySide2.QtCore.QEvent.Type, key: int, sourceState: typing.Union[PySide2.QtCore.QState, None] = ..., destroyed: typing.Callable = ..., eventSource: PySide2.QtCore.QObject = ..., eventType: typing.Any = ..., modifierMask: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., targetState: typing.Any = ..., targetStateChanged: typing.Callable = ..., targetStates: typing.Any = ..., targetStatesChanged: typing.Callable = ..., transitionType: QKeyEventTransition.TransitionType = ..., triggered: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, sourceState: typing.Union[PySide2.QtCore.QState, None] = ..., destroyed: typing.Callable = ..., eventSource: PySide2.QtCore.QObject = ..., eventType: typing.Any = ..., key: int = ..., modifierMask: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., targetState: typing.Any = ..., targetStateChanged: typing.Callable = ..., targetStates: typing.Any = ..., targetStatesChanged: typing.Callable = ..., transitionType: QKeyEventTransition.TransitionType = ..., triggered: typing.Callable = ...) -> None: ...
    def eventTest(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def key(self) -> int: ...
    def modifierMask(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def onTransition(self, event: PySide2.QtCore.QEvent) -> None: ...
    def setKey(self, key: int) -> None: ...
    def setModifierMask(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...

class QKeySequenceEdit(QWidget):
    editingFinished: typing.ClassVar[PySide2.QtCore.Signal] = ...
    keySequenceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, keySequence: typing.Union[PySide2.QtGui.QKeySequence, str], parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keySequenceChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keySequence: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., keySequenceChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def clear(self) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def keySequence(self) -> PySide2.QtGui.QKeySequence: ...
    def setKeySequence(self, keySequence: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...

class QLCDNumber(QFrame):
    class Mode:
        Bin: typing.ClassVar[QLCDNumber.Mode] = ...
        Dec: typing.ClassVar[QLCDNumber.Mode] = ...
        Hex: typing.ClassVar[QLCDNumber.Mode] = ...
        Oct: typing.ClassVar[QLCDNumber.Mode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __and__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __rand__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __ror__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __sub__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...
        def __xor__(self, other: typing.SupportsInt) -> QLCDNumber.Mode: ...

    class SegmentStyle:
        Filled: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
        Flat: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
        Outline: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __and__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __rand__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __rmul__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __ror__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __rsub__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __rxor__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __sub__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
        def __xor__(self, other: typing.SupportsInt) -> QLCDNumber.SegmentStyle: ...
    Bin: typing.ClassVar[QLCDNumber.Mode] = ...
    Dec: typing.ClassVar[QLCDNumber.Mode] = ...
    Filled: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
    Flat: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
    Hex: typing.ClassVar[QLCDNumber.Mode] = ...
    Oct: typing.ClassVar[QLCDNumber.Mode] = ...
    Outline: typing.ClassVar[QLCDNumber.SegmentStyle] = ...
    overflow: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, numDigits: int, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., digitCount: int = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QLCDNumber.Shadow = ..., frameShape: QLCDNumber.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., intValue: int = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mode: QLCDNumber.Mode = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overflow: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., segmentStyle: QLCDNumber.SegmentStyle = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., smallDecimalPoint: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: float = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., digitCount: int = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QLCDNumber.Shadow = ..., frameShape: QLCDNumber.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., intValue: int = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mode: QLCDNumber.Mode = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overflow: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., segmentStyle: QLCDNumber.SegmentStyle = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., smallDecimalPoint: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: float = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def checkOverflow(self, num: float) -> bool: ...
    @typing.overload
    def checkOverflow(self, num: int) -> bool: ...
    def digitCount(self) -> int: ...
    @typing.overload
    def display(self, str: str) -> None: ...
    @typing.overload
    def display(self, num: float) -> None: ...
    @typing.overload
    def display(self, num: int) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def intValue(self) -> int: ...
    def mode(self) -> QLCDNumber.Mode: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def segmentStyle(self) -> QLCDNumber.SegmentStyle: ...
    def setBinMode(self) -> None: ...
    def setDecMode(self) -> None: ...
    def setDigitCount(self, nDigits: int) -> None: ...
    def setHexMode(self) -> None: ...
    def setMode(self, arg__1: QLCDNumber.Mode) -> None: ...
    def setOctMode(self) -> None: ...
    def setSegmentStyle(self, arg__1: QLCDNumber.SegmentStyle) -> None: ...
    def setSmallDecimalPoint(self, arg__1: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def smallDecimalPoint(self) -> bool: ...
    def value(self) -> float: ...

class QLabel(QFrame):
    linkActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    linkHovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QLabel.Shadow = ..., frameShape: QLabel.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., hasSelectedText: bool = ..., height: int = ..., indent: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., linkActivated: typing.Callable = ..., linkHovered: typing.Callable = ..., locale: PySide2.QtCore.QLocale = ..., margin: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., openExternalLinks: bool = ..., palette: PySide2.QtGui.QPalette = ..., pixmap: PySide2.QtGui.QPixmap = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., scaledContents: bool = ..., selectedText: str = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., textFormat: PySide2.QtCore.Qt.TextFormat = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QLabel.Shadow = ..., frameShape: QLabel.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., hasSelectedText: bool = ..., height: int = ..., indent: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., linkActivated: typing.Callable = ..., linkHovered: typing.Callable = ..., locale: PySide2.QtCore.QLocale = ..., margin: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., openExternalLinks: bool = ..., palette: PySide2.QtGui.QPalette = ..., pixmap: PySide2.QtGui.QPixmap = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., scaledContents: bool = ..., selectedText: str = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., textFormat: PySide2.QtCore.Qt.TextFormat = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def buddy(self) -> QWidget: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def contextMenuEvent(self, ev: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, ev: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, ev: PySide2.QtGui.QFocusEvent) -> None: ...
    def hasScaledContents(self) -> bool: ...
    def hasSelectedText(self) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def indent(self) -> int: ...
    def keyPressEvent(self, ev: PySide2.QtGui.QKeyEvent) -> None: ...
    def margin(self) -> int: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def movie(self) -> PySide2.QtGui.QMovie: ...
    def openExternalLinks(self) -> bool: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def picture(self) -> PySide2.QtGui.QPicture: ...
    def pixmap(self) -> PySide2.QtGui.QPixmap: ...
    def selectedText(self) -> str: ...
    def selectionStart(self) -> int: ...
    def setAlignment(self, arg__1: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setBuddy(self, arg__1: QWidget) -> None: ...
    def setIndent(self, arg__1: int) -> None: ...
    def setMargin(self, arg__1: int) -> None: ...
    def setMovie(self, movie: PySide2.QtGui.QMovie) -> None: ...
    @typing.overload
    def setNum(self, arg__1: float) -> None: ...
    @typing.overload
    def setNum(self, arg__1: int) -> None: ...
    def setOpenExternalLinks(self, open: bool) -> None: ...
    def setPicture(self, arg__1: PySide2.QtGui.QPicture) -> None: ...
    def setPixmap(self, arg__1: typing.Union[PySide2.QtGui.QPixmap, None]) -> None: ...
    def setScaledContents(self, arg__1: bool) -> None: ...
    def setSelection(self, arg__1: int, arg__2: int) -> None: ...
    def setText(self, arg__1: str) -> None: ...
    def setTextFormat(self, arg__1: PySide2.QtCore.Qt.TextFormat) -> None: ...
    def setTextInteractionFlags(self, flags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]) -> None: ...
    def setWordWrap(self, on: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def text(self) -> str: ...
    def textFormat(self) -> PySide2.QtCore.Qt.TextFormat: ...
    def textInteractionFlags(self) -> typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]: ...
    def wordWrap(self) -> bool: ...

class QLayout(PySide2.QtCore.QObject, QLayoutItem):
    class SizeConstraint:
        SetDefaultConstraint: typing.ClassVar[QLayout.SizeConstraint] = ...
        SetFixedSize: typing.ClassVar[QLayout.SizeConstraint] = ...
        SetMaximumSize: typing.ClassVar[QLayout.SizeConstraint] = ...
        SetMinAndMaxSize: typing.ClassVar[QLayout.SizeConstraint] = ...
        SetMinimumSize: typing.ClassVar[QLayout.SizeConstraint] = ...
        SetNoConstraint: typing.ClassVar[QLayout.SizeConstraint] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __and__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __rand__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __rmul__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __ror__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __rsub__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __rxor__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __sub__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
        def __xor__(self, other: typing.SupportsInt) -> QLayout.SizeConstraint: ...
    SetDefaultConstraint: typing.ClassVar[QLayout.SizeConstraint] = ...
    SetFixedSize: typing.ClassVar[QLayout.SizeConstraint] = ...
    SetMaximumSize: typing.ClassVar[QLayout.SizeConstraint] = ...
    SetMinAndMaxSize: typing.ClassVar[QLayout.SizeConstraint] = ...
    SetMinimumSize: typing.ClassVar[QLayout.SizeConstraint] = ...
    SetNoConstraint: typing.ClassVar[QLayout.SizeConstraint] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def activate(self) -> bool: ...
    def addChildLayout(self, l: QLayout) -> None: ...
    def addChildWidget(self, w: QWidget) -> None: ...
    def addItem(self, arg__1: QLayoutItem) -> None: ...
    def addWidget(self, w: QWidget) -> None: ...
    def adoptLayout(self, layout: QLayout) -> bool: ...
    def alignmentRect(self, arg__1: PySide2.QtCore.QRect) -> PySide2.QtCore.QRect: ...
    def childEvent(self, e: PySide2.QtCore.QChildEvent) -> None: ...
    @classmethod
    def closestAcceptableSize(cls, w: QWidget, s: PySide2.QtCore.QSize) -> PySide2.QtCore.QSize: ...
    def contentsMargins(self) -> PySide2.QtCore.QMargins: ...
    def contentsRect(self) -> PySide2.QtCore.QRect: ...
    def controlTypes(self) -> typing.Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType]: ...
    def count(self) -> int: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def getContentsMargins(self) -> typing.Tuple[int, int, int, int]: ...
    @typing.overload
    def indexOf(self, arg__1: QLayoutItem) -> int: ...
    @typing.overload
    def indexOf(self, arg__1: QWidget) -> int: ...
    def invalidate(self) -> None: ...
    def isEmpty(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def itemAt(self, index: int) -> typing.Optional[QLayoutItem]: ...
    def layout(self) -> QLayout: ...
    def margin(self) -> int: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def menuBar(self) -> QWidget: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def parentWidget(self) -> QWidget: ...
    def removeItem(self, arg__1: QLayoutItem) -> None: ...
    def removeWidget(self, w: QWidget) -> None: ...
    def replaceWidget(self, from_: QWidget, to: QWidget, options: typing.Union[PySide2.QtCore.Qt.FindChildOptions, PySide2.QtCore.Qt.FindChildOption] = ...) -> QLayoutItem: ...
    @typing.overload
    def setAlignment(self, w: QWidget, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> bool: ...
    @typing.overload
    def setAlignment(self, l: QLayout, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> bool: ...
    @typing.overload
    def setAlignment(self, arg__1: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    @typing.overload
    def setContentsMargins(self, left: int, top: int, right: int, bottom: int) -> None: ...
    @typing.overload
    def setContentsMargins(self, margins: PySide2.QtCore.QMargins) -> None: ...
    def setEnabled(self, arg__1: bool) -> None: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def setMargin(self, arg__1: int) -> None: ...
    def setMenuBar(self, w: QWidget) -> None: ...
    def setSizeConstraint(self, arg__1: QLayout.SizeConstraint) -> None: ...
    def setSpacing(self, arg__1: int) -> None: ...
    def sizeConstraint(self) -> QLayout.SizeConstraint: ...
    def spacing(self) -> int: ...
    def takeAt(self, index: int) -> typing.Optional[QLayoutItem]: ...
    def totalHeightForWidth(self, w: int) -> int: ...
    def totalMaximumSize(self) -> PySide2.QtCore.QSize: ...
    def totalMinimumSize(self) -> PySide2.QtCore.QSize: ...
    def totalSizeHint(self) -> PySide2.QtCore.QSize: ...
    def update(self) -> None: ...
    def widgetEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...

class QLayoutItem(shiboken2.Object):
    align: _typeshed.Incomplete
    def __init__(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def controlTypes(self) -> typing.Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType]: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def invalidate(self) -> None: ...
    def isEmpty(self) -> bool: ...
    def layout(self) -> QLayout: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumHeightForWidth(self, arg__1: int) -> int: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def setAlignment(self, a: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def spacerItem(self) -> QSpacerItem: ...
    def widget(self) -> QWidget: ...

class QLineEdit(QWidget):
    class ActionPosition:
        LeadingPosition: typing.ClassVar[QLineEdit.ActionPosition] = ...
        TrailingPosition: typing.ClassVar[QLineEdit.ActionPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QLineEdit.ActionPosition: ...

    class EchoMode:
        NoEcho: typing.ClassVar[QLineEdit.EchoMode] = ...
        Normal: typing.ClassVar[QLineEdit.EchoMode] = ...
        Password: typing.ClassVar[QLineEdit.EchoMode] = ...
        PasswordEchoOnEdit: typing.ClassVar[QLineEdit.EchoMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __and__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QLineEdit.EchoMode: ...
    LeadingPosition: typing.ClassVar[QLineEdit.ActionPosition] = ...
    NoEcho: typing.ClassVar[QLineEdit.EchoMode] = ...
    Normal: typing.ClassVar[QLineEdit.EchoMode] = ...
    Password: typing.ClassVar[QLineEdit.EchoMode] = ...
    PasswordEchoOnEdit: typing.ClassVar[QLineEdit.EchoMode] = ...
    TrailingPosition: typing.ClassVar[QLineEdit.ActionPosition] = ...
    cursorPositionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    editingFinished: typing.ClassVar[PySide2.QtCore.Signal] = ...
    inputRejected: typing.ClassVar[PySide2.QtCore.Signal] = ...
    returnPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    selectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    textEdited: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, arg__1: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clearButtonEnabled: bool = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorMoveStyle: PySide2.QtCore.Qt.CursorMoveStyle = ..., cursorPosition: int = ..., cursorPositionChanged: typing.Callable = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., displayText: str = ..., dragEnabled: bool = ..., echoMode: QLineEdit.EchoMode = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., hasSelectedText: bool = ..., height: int = ..., inputMask: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., inputRejected: typing.Callable = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maxLength: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modified: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: bool = ..., returnPressed: typing.Callable = ..., selectedText: str = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., textChanged: typing.Callable = ..., textEdited: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: bool = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clearButtonEnabled: bool = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorMoveStyle: PySide2.QtCore.Qt.CursorMoveStyle = ..., cursorPosition: int = ..., cursorPositionChanged: typing.Callable = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., displayText: str = ..., dragEnabled: bool = ..., echoMode: QLineEdit.EchoMode = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., hasSelectedText: bool = ..., height: int = ..., inputMask: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., inputRejected: typing.Callable = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maxLength: int = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modified: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: bool = ..., returnPressed: typing.Callable = ..., selectedText: str = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., textChanged: typing.Callable = ..., textEdited: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: bool = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, position: QLineEdit.ActionPosition) -> QAction: ...
    @typing.overload
    def addAction(self, action: QAction, position: QLineEdit.ActionPosition) -> None: ...
    @typing.overload
    def addAction(self, arg__1: QAction) -> None: ...
    @typing.overload
    def addAction(self, action: QAction) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def backspace(self) -> None: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def completer(self) -> QCompleter: ...
    def contextMenuEvent(self, arg__1: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def copy(self) -> None: ...
    def createStandardContextMenu(self) -> QMenu: ...
    def cursorBackward(self, mark: bool, steps: int = ...) -> None: ...
    def cursorForward(self, mark: bool, steps: int = ...) -> None: ...
    def cursorMoveStyle(self) -> PySide2.QtCore.Qt.CursorMoveStyle: ...
    def cursorPosition(self) -> int: ...
    def cursorPositionAt(self, pos: PySide2.QtCore.QPoint) -> int: ...
    def cursorRect(self) -> PySide2.QtCore.QRect: ...
    def cursorWordBackward(self, mark: bool) -> None: ...
    def cursorWordForward(self, mark: bool) -> None: ...
    def cut(self) -> None: ...
    def del_(self) -> None: ...
    def deselect(self) -> None: ...
    def displayText(self) -> str: ...
    def dragEnabled(self) -> bool: ...
    def dragEnterEvent(self, arg__1: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, e: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, e: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, arg__1: PySide2.QtGui.QDropEvent) -> None: ...
    def echoMode(self) -> QLineEdit.EchoMode: ...
    def end(self, mark: bool) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def getTextMargins(self) -> typing.Tuple[int, int, int, int]: ...
    def hasAcceptableInput(self) -> bool: ...
    def hasFrame(self) -> bool: ...
    def hasSelectedText(self) -> bool: ...
    def home(self, mark: bool) -> None: ...
    def initStyleOption(self, option: QStyleOptionFrame) -> None: ...
    def inputMask(self) -> str: ...
    def inputMethodEvent(self, arg__1: PySide2.QtGui.QInputMethodEvent) -> None: ...
    @typing.overload
    def inputMethodQuery(self, property: PySide2.QtCore.Qt.InputMethodQuery, argument: typing.Any) -> typing.Any: ...
    @typing.overload
    def inputMethodQuery(self, arg__1: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def insert(self, arg__1: str) -> None: ...
    def isClearButtonEnabled(self) -> bool: ...
    def isModified(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def isRedoAvailable(self) -> bool: ...
    def isUndoAvailable(self) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def maxLength(self) -> int: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseDoubleClickEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def paste(self) -> None: ...
    def placeholderText(self) -> str: ...
    def redo(self) -> None: ...
    def selectAll(self) -> None: ...
    def selectedText(self) -> str: ...
    def selectionEnd(self) -> int: ...
    def selectionLength(self) -> int: ...
    def selectionStart(self) -> int: ...
    def setAlignment(self, flag: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setClearButtonEnabled(self, enable: bool) -> None: ...
    def setCompleter(self, completer: QCompleter) -> None: ...
    def setCursorMoveStyle(self, style: PySide2.QtCore.Qt.CursorMoveStyle) -> None: ...
    def setCursorPosition(self, arg__1: int) -> None: ...
    def setDragEnabled(self, b: bool) -> None: ...
    def setEchoMode(self, arg__1: QLineEdit.EchoMode) -> None: ...
    def setFrame(self, arg__1: bool) -> None: ...
    def setInputMask(self, inputMask: str) -> None: ...
    def setMaxLength(self, arg__1: int) -> None: ...
    def setModified(self, arg__1: bool) -> None: ...
    def setPlaceholderText(self, arg__1: str) -> None: ...
    def setReadOnly(self, arg__1: bool) -> None: ...
    def setSelection(self, arg__1: int, arg__2: int) -> None: ...
    def setText(self, arg__1: str) -> None: ...
    @typing.overload
    def setTextMargins(self, left: int, top: int, right: int, bottom: int) -> None: ...
    @typing.overload
    def setTextMargins(self, margins: PySide2.QtCore.QMargins) -> None: ...
    def setValidator(self, arg__1: PySide2.QtGui.QValidator) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def text(self) -> str: ...
    def textMargins(self) -> PySide2.QtCore.QMargins: ...
    def undo(self) -> None: ...
    def validator(self) -> PySide2.QtGui.QValidator: ...

class QListView(QAbstractItemView):
    class Flow:
        LeftToRight: typing.ClassVar[QListView.Flow] = ...
        TopToBottom: typing.ClassVar[QListView.Flow] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __and__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __rand__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __ror__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __sub__(self, other: typing.SupportsInt) -> QListView.Flow: ...
        def __xor__(self, other: typing.SupportsInt) -> QListView.Flow: ...

    class LayoutMode:
        Batched: typing.ClassVar[QListView.LayoutMode] = ...
        SinglePass: typing.ClassVar[QListView.LayoutMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __and__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QListView.LayoutMode: ...

    class Movement:
        Free: typing.ClassVar[QListView.Movement] = ...
        Snap: typing.ClassVar[QListView.Movement] = ...
        Static: typing.ClassVar[QListView.Movement] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __and__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __rand__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __ror__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __sub__(self, other: typing.SupportsInt) -> QListView.Movement: ...
        def __xor__(self, other: typing.SupportsInt) -> QListView.Movement: ...

    class ResizeMode:
        Adjust: typing.ClassVar[QListView.ResizeMode] = ...
        Fixed: typing.ClassVar[QListView.ResizeMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __and__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QListView.ResizeMode: ...

    class ViewMode:
        IconMode: typing.ClassVar[QListView.ViewMode] = ...
        ListMode: typing.ClassVar[QListView.ViewMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __and__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QListView.ViewMode: ...
    Adjust: typing.ClassVar[QListView.ResizeMode] = ...
    Batched: typing.ClassVar[QListView.LayoutMode] = ...
    Fixed: typing.ClassVar[QListView.ResizeMode] = ...
    Free: typing.ClassVar[QListView.Movement] = ...
    IconMode: typing.ClassVar[QListView.ViewMode] = ...
    LeftToRight: typing.ClassVar[QListView.Flow] = ...
    ListMode: typing.ClassVar[QListView.ViewMode] = ...
    SinglePass: typing.ClassVar[QListView.LayoutMode] = ...
    Snap: typing.ClassVar[QListView.Movement] = ...
    Static: typing.ClassVar[QListView.Movement] = ...
    TopToBottom: typing.ClassVar[QListView.Flow] = ...
    indexesMoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., batchSize: int = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QListView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QListView.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., flow: QListView.Flow = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QListView.Shadow = ..., frameShape: QListView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridSize: PySide2.QtCore.QSize = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QListView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indexesMoved: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., isWrapping: bool = ..., itemAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., layoutMode: QListView.LayoutMode = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., movement: QListView.Movement = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeMode: QListView.ResizeMode = ..., selectionBehavior: QListView.SelectionBehavior = ..., selectionMode: QListView.SelectionMode = ..., selectionRectVisible: bool = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QListView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., spacing: int = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformItemSizes: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QListView.ScrollMode = ..., viewMode: QListView.ViewMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def batchSize(self) -> int: ...
    def clearPropertyFlags(self) -> None: ...
    def contentsSize(self) -> PySide2.QtCore.QSize: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, previous: PySide2.QtCore.QModelIndex) -> None: ...
    def dataChanged(self, topLeft: PySide2.QtCore.QModelIndex, bottomRight: PySide2.QtCore.QModelIndex, roles: typing.List[int] = ...) -> None: ...
    def doItemsLayout(self) -> None: ...
    def dragLeaveEvent(self, e: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, e: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, e: PySide2.QtGui.QDropEvent) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def flow(self) -> QListView.Flow: ...
    def gridSize(self) -> PySide2.QtCore.QSize: ...
    def horizontalOffset(self) -> int: ...
    def indexAt(self, p: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isRowHidden(self, row: int) -> bool: ...
    def isSelectionRectVisible(self) -> bool: ...
    def isWrapping(self) -> bool: ...
    def itemAlignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def layoutMode(self) -> QListView.LayoutMode: ...
    def modelColumn(self) -> int: ...
    def mouseMoveEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def movement(self) -> QListView.Movement: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def rectForIndex(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def reset(self) -> None: ...
    def resizeContents(self, width: int, height: int) -> None: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    def resizeMode(self) -> QListView.ResizeMode: ...
    def rowsAboutToBeRemoved(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def rowsInserted(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectedIndexes(self) -> typing.List[PySide2.QtCore.QModelIndex]: ...
    def selectionChanged(self, selected: PySide2.QtCore.QItemSelection, deselected: PySide2.QtCore.QItemSelection) -> None: ...
    def setBatchSize(self, batchSize: int) -> None: ...
    def setFlow(self, flow: QListView.Flow) -> None: ...
    def setGridSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setItemAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setLayoutMode(self, mode: QListView.LayoutMode) -> None: ...
    def setModelColumn(self, column: int) -> None: ...
    def setMovement(self, movement: QListView.Movement) -> None: ...
    def setPositionForIndex(self, position: PySide2.QtCore.QPoint, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setResizeMode(self, mode: QListView.ResizeMode) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setRowHidden(self, row: int, hide: bool) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSelectionRectVisible(self, show: bool) -> None: ...
    def setSpacing(self, space: int) -> None: ...
    def setUniformItemSizes(self, enable: bool) -> None: ...
    def setViewMode(self, mode: QListView.ViewMode) -> None: ...
    def setWordWrap(self, on: bool) -> None: ...
    def setWrapping(self, enable: bool) -> None: ...
    def spacing(self) -> int: ...
    def startDrag(self, supportedActions: typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]) -> None: ...
    def timerEvent(self, e: PySide2.QtCore.QTimerEvent) -> None: ...
    def uniformItemSizes(self) -> bool: ...
    def updateGeometries(self) -> None: ...
    def verticalOffset(self) -> int: ...
    def viewMode(self) -> QListView.ViewMode: ...
    def viewOptions(self) -> QStyleOptionViewItem: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...
    def wheelEvent(self, e: PySide2.QtGui.QWheelEvent) -> None: ...
    def wordWrap(self) -> bool: ...

class QListWidget(QListView):
    currentItemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentRowChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemSelectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., batchSize: int = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentItemChanged: typing.Callable = ..., currentRow: int = ..., currentRowChanged: typing.Callable = ..., currentTextChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QListWidget.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QListWidget.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., flow: QListWidget.Flow = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QListWidget.Shadow = ..., frameShape: QListWidget.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridSize: PySide2.QtCore.QSize = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QListWidget.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indexesMoved: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., isWrapping: bool = ..., itemActivated: typing.Callable = ..., itemAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., itemChanged: typing.Callable = ..., itemClicked: typing.Callable = ..., itemDoubleClicked: typing.Callable = ..., itemEntered: typing.Callable = ..., itemPressed: typing.Callable = ..., itemSelectionChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., layoutMode: QListWidget.LayoutMode = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., movement: QListWidget.Movement = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeMode: QListWidget.ResizeMode = ..., selectionBehavior: QListWidget.SelectionBehavior = ..., selectionMode: QListWidget.SelectionMode = ..., selectionRectVisible: bool = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QListWidget.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., spacing: int = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformItemSizes: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QListWidget.ScrollMode = ..., viewMode: QListWidget.ViewMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addItem(self, label: str) -> None: ...
    @typing.overload
    def addItem(self, item: QListWidgetItem) -> None: ...
    def addItems(self, labels: typing.Iterable[str]) -> None: ...
    def clear(self) -> None: ...
    @typing.overload
    def closePersistentEditor(self, item: QListWidgetItem) -> None: ...
    @typing.overload
    def closePersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def count(self) -> int: ...
    def currentItem(self) -> QListWidgetItem: ...
    def currentRow(self) -> int: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    def dropMimeData(self, index: int, data: PySide2.QtCore.QMimeData, action: PySide2.QtCore.Qt.DropAction) -> bool: ...
    def editItem(self, item: QListWidgetItem) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def findItems(self, text: str, flags: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag]) -> typing.List[QListWidgetItem]: ...
    def indexFromItem(self, item: QListWidgetItem) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def insertItem(self, row: int, label: str) -> None: ...
    @typing.overload
    def insertItem(self, row: int, item: QListWidgetItem) -> None: ...
    def insertItems(self, row: int, labels: typing.Iterable[str]) -> None: ...
    def isItemHidden(self, item: QListWidgetItem) -> bool: ...
    def isItemSelected(self, item: QListWidgetItem) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, item: QListWidgetItem) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isSortingEnabled(self) -> bool: ...
    def item(self, row: int) -> QListWidgetItem: ...
    @typing.overload
    def itemAt(self, x: int, y: int) -> QListWidgetItem: ...
    @typing.overload
    def itemAt(self, p: PySide2.QtCore.QPoint) -> QListWidgetItem: ...
    def itemFromIndex(self, index: PySide2.QtCore.QModelIndex) -> QListWidgetItem: ...
    def itemWidget(self, item: QListWidgetItem) -> QWidget: ...
    def items(self, data: PySide2.QtCore.QMimeData) -> typing.List[QListWidgetItem]: ...
    def mimeData(self, items: typing.Iterable[QListWidgetItem]) -> PySide2.QtCore.QMimeData: ...
    def mimeTypes(self) -> typing.List[str]: ...
    @typing.overload
    def openPersistentEditor(self, item: QListWidgetItem) -> None: ...
    @typing.overload
    def openPersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def removeItemWidget(self, item: QListWidgetItem) -> None: ...
    def row(self, item: QListWidgetItem) -> int: ...
    def scrollToItem(self, item: QListWidgetItem, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectedItems(self) -> typing.List[QListWidgetItem]: ...
    @typing.overload
    def setCurrentItem(self, item: QListWidgetItem, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QListWidgetItem) -> None: ...
    @typing.overload
    def setCurrentRow(self, row: int, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    @typing.overload
    def setCurrentRow(self, row: int) -> None: ...
    def setItemHidden(self, item: QListWidgetItem, hide: bool) -> None: ...
    def setItemSelected(self, item: QListWidgetItem, select: bool) -> None: ...
    def setItemWidget(self, item: QListWidgetItem, widget: QWidget) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def setSortingEnabled(self, enable: bool) -> None: ...
    def sortItems(self, order: PySide2.QtCore.Qt.SortOrder = ...) -> None: ...
    def supportedDropActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...
    def takeItem(self, row: int) -> QListWidgetItem: ...
    def visualItemRect(self, item: QListWidgetItem) -> PySide2.QtCore.QRect: ...

class QListWidgetItem(shiboken2.Object):
    class ItemType:
        Type: typing.ClassVar[QListWidgetItem.ItemType] = ...
        UserType: typing.ClassVar[QListWidgetItem.ItemType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __and__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __rand__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __ror__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __sub__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
        def __xor__(self, other: typing.SupportsInt) -> QListWidgetItem.ItemType: ...
    Type: typing.ClassVar[QListWidgetItem.ItemType] = ...
    UserType: typing.ClassVar[QListWidgetItem.ItemType] = ...
    @typing.overload
    def __init__(self, icon: PySide2.QtGui.QIcon, text: str, listview: typing.Union[QListWidget, None] = ..., type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, text: str, listview: typing.Union[QListWidget, None] = ..., type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, listview: typing.Union[QListWidget, None] = ..., type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QListWidgetItem) -> None: ...
    def background(self) -> PySide2.QtGui.QBrush: ...
    def backgroundColor(self) -> PySide2.QtGui.QColor: ...
    def checkState(self) -> PySide2.QtCore.Qt.CheckState: ...
    def clone(self) -> QListWidgetItem: ...
    def data(self, role: PySide2.QtCore.Qt.ItemDataRole) -> typing.Any: ...
    def flags(self) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def foreground(self) -> PySide2.QtGui.QBrush: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    def isHidden(self) -> bool: ...
    def isSelected(self) -> bool: ...
    def listWidget(self) -> QListWidget: ...
    def read(self, in_: PySide2.QtCore.QDataStream) -> None: ...
    def setBackground(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setBackgroundColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setCheckState(self, state: PySide2.QtCore.Qt.CheckState) -> None: ...
    def setData(self, role: PySide2.QtCore.Qt.ItemDataRole, value: typing.Any) -> None: ...
    def setFlags(self, flags: typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setForeground(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setHidden(self, hide: bool) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setSelected(self, select: bool) -> None: ...
    def setSizeHint(self, size: PySide2.QtCore.QSize) -> None: ...
    def setStatusTip(self, statusTip: str) -> None: ...
    def setText(self, text: str) -> None: ...
    def setTextAlignment(self, alignment: int) -> None: ...
    def setTextColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setToolTip(self, toolTip: str) -> None: ...
    def setWhatsThis(self, whatsThis: str) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def statusTip(self) -> str: ...
    def text(self) -> str: ...
    def textAlignment(self) -> int: ...
    def textColor(self) -> PySide2.QtGui.QColor: ...
    def toolTip(self) -> str: ...
    def type(self) -> int: ...
    def whatsThis(self) -> str: ...
    def write(self, out: PySide2.QtCore.QDataStream) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, out: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, in_: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...

class QMainWindow(QWidget):
    class DockOption:
        AllowNestedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
        AllowTabbedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
        AnimatedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
        ForceTabbedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
        GroupedDragging: typing.ClassVar[QMainWindow.DockOption] = ...
        VerticalTabs: typing.ClassVar[QMainWindow.DockOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMainWindow.DockOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...

    class DockOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMainWindow.DockOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMainWindow.DockOptions: ...
    AllowNestedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
    AllowTabbedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
    AnimatedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
    ForceTabbedDocks: typing.ClassVar[QMainWindow.DockOption] = ...
    GroupedDragging: typing.ClassVar[QMainWindow.DockOption] = ...
    VerticalTabs: typing.ClassVar[QMainWindow.DockOption] = ...
    iconSizeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    tabifiedDockWidgetActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    toolButtonStyleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., animated: bool = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., dockNestingEnabled: bool = ..., dockOptions: typing.Union[QMainWindow.DockOptions, QMainWindow.DockOption] = ..., documentMode: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabShape: typing.Any = ..., tabifiedDockWidgetActivated: typing.Callable = ..., tabletTracking: bool = ..., toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle = ..., toolButtonStyleChanged: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., unifiedTitleAndToolBarOnMac: bool = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addDockWidget(self, area: PySide2.QtCore.Qt.DockWidgetArea, dockwidget: QDockWidget, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    @typing.overload
    def addDockWidget(self, area: PySide2.QtCore.Qt.DockWidgetArea, dockwidget: QDockWidget) -> None: ...
    @typing.overload
    def addToolBar(self, area: PySide2.QtCore.Qt.ToolBarArea, toolbar: QToolBar) -> None: ...
    @typing.overload
    def addToolBar(self, toolbar: QToolBar) -> None: ...
    @typing.overload
    def addToolBar(self, title: str) -> QToolBar: ...
    def addToolBarBreak(self, area: PySide2.QtCore.Qt.ToolBarArea = ...) -> None: ...
    def centralWidget(self) -> QWidget: ...
    def contextMenuEvent(self, event: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def corner(self, corner: PySide2.QtCore.Qt.Corner) -> PySide2.QtCore.Qt.DockWidgetArea: ...
    def createPopupMenu(self) -> QMenu: ...
    def dockOptions(self) -> typing.Union[QMainWindow.DockOptions, QMainWindow.DockOption]: ...
    def dockWidgetArea(self, dockwidget: QDockWidget) -> PySide2.QtCore.Qt.DockWidgetArea: ...
    def documentMode(self) -> bool: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def insertToolBar(self, before: QToolBar, toolbar: QToolBar) -> None: ...
    def insertToolBarBreak(self, before: QToolBar) -> None: ...
    def isAnimated(self) -> bool: ...
    def isDockNestingEnabled(self) -> bool: ...
    def isSeparator(self, pos: PySide2.QtCore.QPoint) -> bool: ...
    def menuBar(self) -> QMenuBar: ...
    def menuWidget(self) -> QWidget: ...
    def removeDockWidget(self, dockwidget: QDockWidget) -> None: ...
    def removeToolBar(self, toolbar: QToolBar) -> None: ...
    def removeToolBarBreak(self, before: QToolBar) -> None: ...
    def resizeDocks(self, docks: typing.Iterable[QDockWidget], sizes: typing.Iterable[int], orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def restoreDockWidget(self, dockwidget: QDockWidget) -> bool: ...
    def restoreState(self, state: typing.Union[PySide2.QtCore.QByteArray, bytes], version: int = ...) -> bool: ...
    def saveState(self, version: int = ...) -> PySide2.QtCore.QByteArray: ...
    def setAnimated(self, enabled: bool) -> None: ...
    def setCentralWidget(self, widget: QWidget) -> None: ...
    def setCorner(self, corner: PySide2.QtCore.Qt.Corner, area: PySide2.QtCore.Qt.DockWidgetArea) -> None: ...
    def setDockNestingEnabled(self, enabled: bool) -> None: ...
    def setDockOptions(self, options: typing.Union[QMainWindow.DockOptions, QMainWindow.DockOption]) -> None: ...
    def setDocumentMode(self, enabled: bool) -> None: ...
    def setIconSize(self, iconSize: PySide2.QtCore.QSize) -> None: ...
    def setMenuBar(self, menubar: QMenuBar) -> None: ...
    def setMenuWidget(self, menubar: QWidget) -> None: ...
    def setStatusBar(self, statusbar: QStatusBar) -> None: ...
    def setTabPosition(self, areas: typing.Union[PySide2.QtCore.Qt.DockWidgetAreas, PySide2.QtCore.Qt.DockWidgetArea], tabPosition: QTabWidget.TabPosition) -> None: ...
    def setTabShape(self, tabShape: QTabWidget.TabShape) -> None: ...
    def setToolButtonStyle(self, toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle) -> None: ...
    def setUnifiedTitleAndToolBarOnMac(self, set: bool) -> None: ...
    def splitDockWidget(self, after: QDockWidget, dockwidget: QDockWidget, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def statusBar(self) -> QStatusBar: ...
    def tabPosition(self, area: PySide2.QtCore.Qt.DockWidgetArea) -> QTabWidget.TabPosition: ...
    def tabShape(self) -> QTabWidget.TabShape: ...
    def tabifiedDockWidgets(self, dockwidget: QDockWidget) -> typing.List[QDockWidget]: ...
    def tabifyDockWidget(self, first: QDockWidget, second: QDockWidget) -> None: ...
    def takeCentralWidget(self) -> QWidget: ...
    def toolBarArea(self, toolbar: QToolBar) -> PySide2.QtCore.Qt.ToolBarArea: ...
    def toolBarBreak(self, toolbar: QToolBar) -> bool: ...
    def toolButtonStyle(self) -> PySide2.QtCore.Qt.ToolButtonStyle: ...
    def unifiedTitleAndToolBarOnMac(self) -> bool: ...

class QMdiArea(QAbstractScrollArea):
    class AreaOption:
        DontMaximizeSubWindowOnActivation: typing.ClassVar[QMdiArea.AreaOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMdiArea.AreaOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...

    class AreaOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMdiArea.AreaOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiArea.AreaOptions: ...

    class ViewMode:
        SubWindowView: typing.ClassVar[QMdiArea.ViewMode] = ...
        TabbedView: typing.ClassVar[QMdiArea.ViewMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiArea.ViewMode: ...

    class WindowOrder:
        ActivationHistoryOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
        CreationOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
        StackingOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __rmul__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __rsub__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __sub__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiArea.WindowOrder: ...
    ActivationHistoryOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
    CreationOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
    DontMaximizeSubWindowOnActivation: typing.ClassVar[QMdiArea.AreaOption] = ...
    StackingOrder: typing.ClassVar[QMdiArea.WindowOrder] = ...
    SubWindowView: typing.ClassVar[QMdiArea.ViewMode] = ...
    TabbedView: typing.ClassVar[QMdiArea.ViewMode] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    subWindowActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activationOrder: QMdiArea.WindowOrder = ..., autoFillBackground: bool = ..., background: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient] = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., documentMode: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QMdiArea.Shadow = ..., frameShape: QMdiArea.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QMdiArea.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., subWindowActivated: typing.Callable = ..., tabPosition: typing.Any = ..., tabShape: typing.Any = ..., tabletTracking: bool = ..., tabsClosable: bool = ..., tabsMovable: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., viewMode: QMdiArea.ViewMode = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def activateNextSubWindow(self) -> None: ...
    def activatePreviousSubWindow(self) -> None: ...
    def activationOrder(self) -> QMdiArea.WindowOrder: ...
    def activeSubWindow(self) -> QMdiSubWindow: ...
    def addSubWindow(self, widget: QWidget, flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> QMdiSubWindow: ...
    def background(self) -> PySide2.QtGui.QBrush: ...
    def cascadeSubWindows(self) -> None: ...
    def childEvent(self, childEvent: PySide2.QtCore.QChildEvent) -> None: ...
    def closeActiveSubWindow(self) -> None: ...
    def closeAllSubWindows(self) -> None: ...
    def currentSubWindow(self) -> QMdiSubWindow: ...
    def documentMode(self) -> bool: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def paintEvent(self, paintEvent: PySide2.QtGui.QPaintEvent) -> None: ...
    def removeSubWindow(self, widget: QWidget) -> None: ...
    def resizeEvent(self, resizeEvent: PySide2.QtGui.QResizeEvent) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def setActivationOrder(self, order: QMdiArea.WindowOrder) -> None: ...
    def setActiveSubWindow(self, window: QMdiSubWindow) -> None: ...
    def setBackground(self, background: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setDocumentMode(self, enabled: bool) -> None: ...
    def setOption(self, option: QMdiArea.AreaOption, on: bool = ...) -> None: ...
    def setTabPosition(self, position: QTabWidget.TabPosition) -> None: ...
    def setTabShape(self, shape: QTabWidget.TabShape) -> None: ...
    def setTabsClosable(self, closable: bool) -> None: ...
    def setTabsMovable(self, movable: bool) -> None: ...
    def setViewMode(self, mode: QMdiArea.ViewMode) -> None: ...
    def setupViewport(self, viewport: QWidget) -> None: ...
    def showEvent(self, showEvent: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def subWindowList(self, order: QMdiArea.WindowOrder = ...) -> typing.List[QMdiSubWindow]: ...
    def tabPosition(self) -> QTabWidget.TabPosition: ...
    def tabShape(self) -> QTabWidget.TabShape: ...
    def tabsClosable(self) -> bool: ...
    def tabsMovable(self) -> bool: ...
    def testOption(self, opton: QMdiArea.AreaOption) -> bool: ...
    def tileSubWindows(self) -> None: ...
    def timerEvent(self, timerEvent: PySide2.QtCore.QTimerEvent) -> None: ...
    def viewMode(self) -> QMdiArea.ViewMode: ...
    def viewportEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...

class QMdiSubWindow(QWidget):
    class SubWindowOption:
        AllowOutsideAreaHorizontally: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
        AllowOutsideAreaVertically: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
        RubberBandMove: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
        RubberBandResize: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMdiSubWindow.SubWindowOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...

    class SubWindowOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMdiSubWindow.SubWindowOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QMdiSubWindow.SubWindowOptions: ...
    AllowOutsideAreaHorizontally: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
    AllowOutsideAreaVertically: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
    RubberBandMove: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
    RubberBandResize: typing.ClassVar[QMdiSubWindow.SubWindowOption] = ...
    aboutToActivate: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    windowStateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., aboutToActivate: typing.Callable = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardPageStep: int = ..., keyboardSingleStep: int = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowStateChanged: typing.Callable = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, changeEvent: PySide2.QtCore.QEvent) -> None: ...
    def childEvent(self, childEvent: PySide2.QtCore.QChildEvent) -> None: ...
    def closeEvent(self, closeEvent: PySide2.QtGui.QCloseEvent) -> None: ...
    def contextMenuEvent(self, contextMenuEvent: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, focusInEvent: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, focusOutEvent: PySide2.QtGui.QFocusEvent) -> None: ...
    def hideEvent(self, hideEvent: PySide2.QtGui.QHideEvent) -> None: ...
    def isShaded(self) -> bool: ...
    def keyPressEvent(self, keyEvent: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyboardPageStep(self) -> int: ...
    def keyboardSingleStep(self) -> int: ...
    def leaveEvent(self, leaveEvent: PySide2.QtCore.QEvent) -> None: ...
    def maximizedButtonsWidget(self) -> QWidget: ...
    def maximizedSystemMenuIconWidget(self) -> QWidget: ...
    def mdiArea(self) -> QMdiArea: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseDoubleClickEvent(self, mouseEvent: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, mouseEvent: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, mouseEvent: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, mouseEvent: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveEvent(self, moveEvent: PySide2.QtGui.QMoveEvent) -> None: ...
    def paintEvent(self, paintEvent: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, resizeEvent: PySide2.QtGui.QResizeEvent) -> None: ...
    def setKeyboardPageStep(self, step: int) -> None: ...
    def setKeyboardSingleStep(self, step: int) -> None: ...
    def setOption(self, option: QMdiSubWindow.SubWindowOption, on: bool = ...) -> None: ...
    def setSystemMenu(self, systemMenu: QMenu) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def showEvent(self, showEvent: PySide2.QtGui.QShowEvent) -> None: ...
    def showShaded(self) -> None: ...
    def showSystemMenu(self) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def systemMenu(self) -> QMenu: ...
    def testOption(self, arg__1: QMdiSubWindow.SubWindowOption) -> bool: ...
    def timerEvent(self, timerEvent: PySide2.QtCore.QTimerEvent) -> None: ...
    def widget(self) -> QWidget: ...

class QMenu(QWidget):
    aboutToHide: typing.ClassVar[PySide2.QtCore.Signal] = ...
    aboutToShow: typing.ClassVar[PySide2.QtCore.Signal] = ...
    hovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    triggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, title: str, parent: typing.Union[QWidget, None] = ..., aboutToHide: typing.Callable = ..., aboutToShow: typing.Callable = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., hovered: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., separatorsCollapsible: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., tearOffEnabled: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., toolTipsVisible: bool = ..., triggered: typing.Callable = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., aboutToHide: typing.Callable = ..., aboutToShow: typing.Callable = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., hovered: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., separatorsCollapsible: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., tearOffEnabled: bool = ..., title: str = ..., toolTip: str = ..., toolTipDuration: int = ..., toolTipsVisible: bool = ..., triggered: typing.Callable = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def actionAt(self, arg__1: PySide2.QtCore.QPoint) -> QAction: ...
    def actionEvent(self, arg__1: PySide2.QtGui.QActionEvent) -> None: ...
    def actionGeometry(self, arg__1: QAction) -> PySide2.QtCore.QRect: ...
    def activeAction(self) -> QAction: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, text: str, receiver: PySide2.QtCore.QObject, member: bytes, shortcut: typing.Union[PySide2.QtGui.QKeySequence, str, None] = ...) -> QAction: ...
    @typing.overload
    def addAction(self, text: str, receiver: PySide2.QtCore.QObject, member: bytes, shortcut: typing.Union[PySide2.QtGui.QKeySequence, str, None] = ...) -> QAction: ...
    @typing.overload
    def addAction(self, arg__1: PySide2.QtGui.QIcon, arg__2: str, arg__3: typing.Callable[[], typing.Any], arg__4: typing.Union[PySide2.QtGui.QKeySequence, str, None] = ...) -> None: ...
    @typing.overload
    def addAction(self, arg__1: str, arg__2: typing.Callable[[], typing.Any], arg__3: typing.Union[PySide2.QtGui.QKeySequence, str, None] = ...) -> None: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, arg__1: QAction) -> None: ...
    @typing.overload
    def addMenu(self, icon: PySide2.QtGui.QIcon, title: str) -> QMenu: ...
    @typing.overload
    def addMenu(self, title: str) -> QMenu: ...
    @typing.overload
    def addMenu(self, menu: QMenu) -> QAction: ...
    @typing.overload
    def addSection(self, icon: PySide2.QtGui.QIcon, text: str) -> QAction: ...
    @typing.overload
    def addSection(self, text: str) -> QAction: ...
    def addSeparator(self) -> QAction: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def columnCount(self) -> int: ...
    def defaultAction(self) -> QAction: ...
    def enterEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    @typing.overload
    def exec_(self, pos: PySide2.QtCore.QPoint, at: typing.Union[QAction, None] = ...) -> QAction: ...
    @typing.overload
    def exec_(self) -> QAction: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def hideEvent(self, arg__1: PySide2.QtGui.QHideEvent) -> None: ...
    def hideTearOffMenu(self) -> None: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    def initStyleOption(self, option: QStyleOptionMenuItem, action: QAction) -> None: ...
    def insertMenu(self, before: QAction, menu: QMenu) -> QAction: ...
    @typing.overload
    def insertSection(self, before: QAction, icon: PySide2.QtGui.QIcon, text: str) -> QAction: ...
    @typing.overload
    def insertSection(self, before: QAction, text: str) -> QAction: ...
    def insertSeparator(self, before: QAction) -> QAction: ...
    def isEmpty(self) -> bool: ...
    def isTearOffEnabled(self) -> bool: ...
    def isTearOffMenuVisible(self) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def leaveEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def menuAction(self) -> QAction: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def popup(self, pos: PySide2.QtCore.QPoint, at: typing.Union[QAction, None] = ...) -> None: ...
    def separatorsCollapsible(self) -> bool: ...
    def setActiveAction(self, act: QAction) -> None: ...
    def setAsDockMenu(self) -> None: ...
    def setDefaultAction(self, arg__1: QAction) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setSeparatorsCollapsible(self, collapse: bool) -> None: ...
    def setTearOffEnabled(self, arg__1: bool) -> None: ...
    def setTitle(self, title: str) -> None: ...
    def setToolTipsVisible(self, visible: bool) -> None: ...
    @typing.overload
    def showTearOffMenu(self, pos: PySide2.QtCore.QPoint) -> None: ...
    @typing.overload
    def showTearOffMenu(self) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...
    def title(self) -> str: ...
    def toolTipsVisible(self) -> bool: ...
    def wheelEvent(self, arg__1: PySide2.QtGui.QWheelEvent) -> None: ...

class QMenuBar(QWidget):
    hovered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    triggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultUp: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., hovered: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., nativeMenuBar: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., triggered: typing.Callable = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def actionAt(self, arg__1: PySide2.QtCore.QPoint) -> QAction: ...
    def actionEvent(self, arg__1: PySide2.QtGui.QActionEvent) -> None: ...
    def actionGeometry(self, arg__1: QAction) -> PySide2.QtCore.QRect: ...
    def activeAction(self) -> QAction: ...
    @typing.overload
    def addAction(self, text: str, receiver: PySide2.QtCore.QObject, member: bytes) -> QAction: ...
    @typing.overload
    def addAction(self, arg__1: str, arg__2: typing.Callable[[], typing.Any]) -> None: ...
    @typing.overload
    def addAction(self, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, arg__1: QAction) -> None: ...
    @typing.overload
    def addMenu(self, icon: PySide2.QtGui.QIcon, title: str) -> QMenu: ...
    @typing.overload
    def addMenu(self, title: str) -> QMenu: ...
    @typing.overload
    def addMenu(self, menu: QMenu) -> QAction: ...
    def addSeparator(self) -> QAction: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def cornerWidget(self, corner: PySide2.QtCore.Qt.Corner = ...) -> QWidget: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def initStyleOption(self, option: QStyleOptionMenuItem, action: QAction) -> None: ...
    def insertMenu(self, before: QAction, menu: QMenu) -> QAction: ...
    def insertSeparator(self, before: QAction) -> QAction: ...
    def isDefaultUp(self) -> bool: ...
    def isNativeMenuBar(self) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def leaveEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def setActiveAction(self, action: QAction) -> None: ...
    def setCornerWidget(self, w: QWidget, corner: PySide2.QtCore.Qt.Corner = ...) -> None: ...
    def setDefaultUp(self, arg__1: bool) -> None: ...
    def setNativeMenuBar(self, nativeMenuBar: bool) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...

class QMessageBox(QDialog):
    class ButtonRole:
        AcceptRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        ActionRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        ApplyRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        DestructiveRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        HelpRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        InvalidRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        NRoles: typing.ClassVar[QMessageBox.ButtonRole] = ...
        NoRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        RejectRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        ResetRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        YesRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __and__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __rand__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __rmul__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __ror__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __rsub__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __sub__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...
        def __xor__(self, other: typing.SupportsInt) -> QMessageBox.ButtonRole: ...

    class Icon:
        Critical: typing.ClassVar[QMessageBox.Icon] = ...
        Information: typing.ClassVar[QMessageBox.Icon] = ...
        NoIcon: typing.ClassVar[QMessageBox.Icon] = ...
        Question: typing.ClassVar[QMessageBox.Icon] = ...
        Warning: typing.ClassVar[QMessageBox.Icon] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __and__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __rand__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __rmul__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __ror__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __rsub__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __sub__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...
        def __xor__(self, other: typing.SupportsInt) -> QMessageBox.Icon: ...

    class StandardButton:
        Abort: typing.ClassVar[QMessageBox.StandardButton] = ...
        Apply: typing.ClassVar[QMessageBox.StandardButton] = ...
        ButtonMask: typing.ClassVar[QMessageBox.StandardButton] = ...
        Cancel: typing.ClassVar[QMessageBox.StandardButton] = ...
        Close: typing.ClassVar[QMessageBox.StandardButton] = ...
        Default: typing.ClassVar[QMessageBox.StandardButton] = ...
        Discard: typing.ClassVar[QMessageBox.StandardButton] = ...
        Escape: typing.ClassVar[QMessageBox.StandardButton] = ...
        FirstButton: typing.ClassVar[QMessageBox.StandardButton] = ...
        FlagMask: typing.ClassVar[QMessageBox.StandardButton] = ...
        Help: typing.ClassVar[QMessageBox.StandardButton] = ...
        Ignore: typing.ClassVar[QMessageBox.StandardButton] = ...
        LastButton: typing.ClassVar[QMessageBox.StandardButton] = ...
        No: typing.ClassVar[QMessageBox.StandardButton] = ...
        NoAll: typing.ClassVar[QMessageBox.StandardButton] = ...
        NoButton: typing.ClassVar[QMessageBox.StandardButton] = ...
        NoToAll: typing.ClassVar[QMessageBox.StandardButton] = ...
        Ok: typing.ClassVar[QMessageBox.StandardButton] = ...
        Open: typing.ClassVar[QMessageBox.StandardButton] = ...
        Reset: typing.ClassVar[QMessageBox.StandardButton] = ...
        RestoreDefaults: typing.ClassVar[QMessageBox.StandardButton] = ...
        Retry: typing.ClassVar[QMessageBox.StandardButton] = ...
        Save: typing.ClassVar[QMessageBox.StandardButton] = ...
        SaveAll: typing.ClassVar[QMessageBox.StandardButton] = ...
        Yes: typing.ClassVar[QMessageBox.StandardButton] = ...
        YesAll: typing.ClassVar[QMessageBox.StandardButton] = ...
        YesToAll: typing.ClassVar[QMessageBox.StandardButton] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMessageBox.StandardButtons: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __rand__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __ror__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __xor__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...

    class StandardButtons:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QMessageBox.StandardButtons: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __rand__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __ror__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __rxor__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
        def __xor__(self, other: typing.SupportsInt) -> QMessageBox.StandardButtons: ...
    Abort: typing.ClassVar[QMessageBox.StandardButton] = ...
    AcceptRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    ActionRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    Apply: typing.ClassVar[QMessageBox.StandardButton] = ...
    ApplyRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    ButtonMask: typing.ClassVar[QMessageBox.StandardButton] = ...
    Cancel: typing.ClassVar[QMessageBox.StandardButton] = ...
    Close: typing.ClassVar[QMessageBox.StandardButton] = ...
    Critical: typing.ClassVar[QMessageBox.Icon] = ...
    Default: typing.ClassVar[QMessageBox.StandardButton] = ...
    DestructiveRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    Discard: typing.ClassVar[QMessageBox.StandardButton] = ...
    Escape: typing.ClassVar[QMessageBox.StandardButton] = ...
    FirstButton: typing.ClassVar[QMessageBox.StandardButton] = ...
    FlagMask: typing.ClassVar[QMessageBox.StandardButton] = ...
    Help: typing.ClassVar[QMessageBox.StandardButton] = ...
    HelpRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    Ignore: typing.ClassVar[QMessageBox.StandardButton] = ...
    Information: typing.ClassVar[QMessageBox.Icon] = ...
    InvalidRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    LastButton: typing.ClassVar[QMessageBox.StandardButton] = ...
    NRoles: typing.ClassVar[QMessageBox.ButtonRole] = ...
    No: typing.ClassVar[QMessageBox.StandardButton] = ...
    NoAll: typing.ClassVar[QMessageBox.StandardButton] = ...
    NoButton: typing.ClassVar[QMessageBox.StandardButton] = ...
    NoIcon: typing.ClassVar[QMessageBox.Icon] = ...
    NoRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    NoToAll: typing.ClassVar[QMessageBox.StandardButton] = ...
    Ok: typing.ClassVar[QMessageBox.StandardButton] = ...
    Open: typing.ClassVar[QMessageBox.StandardButton] = ...
    Question: typing.ClassVar[QMessageBox.Icon] = ...
    RejectRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    Reset: typing.ClassVar[QMessageBox.StandardButton] = ...
    ResetRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    RestoreDefaults: typing.ClassVar[QMessageBox.StandardButton] = ...
    Retry: typing.ClassVar[QMessageBox.StandardButton] = ...
    Save: typing.ClassVar[QMessageBox.StandardButton] = ...
    SaveAll: typing.ClassVar[QMessageBox.StandardButton] = ...
    Warning: typing.ClassVar[QMessageBox.Icon] = ...
    Yes: typing.ClassVar[QMessageBox.StandardButton] = ...
    YesAll: typing.ClassVar[QMessageBox.StandardButton] = ...
    YesRole: typing.ClassVar[QMessageBox.ButtonRole] = ...
    YesToAll: typing.ClassVar[QMessageBox.StandardButton] = ...
    buttonClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, icon: QMessageBox.Icon, title: str, text: str, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonClicked: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., detailedText: str = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconPixmap: PySide2.QtGui.QPixmap = ..., informativeText: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., textFormat: PySide2.QtCore.Qt.TextFormat = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonClicked: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., detailedText: str = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: QMessageBox.Icon = ..., iconPixmap: PySide2.QtGui.QPixmap = ..., informativeText: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., standardButtons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., textFormat: PySide2.QtCore.Qt.TextFormat = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @classmethod
    def about(cls, parent: typing.Union[QWidget, None], title: str, text: str) -> None: ...
    @classmethod
    def aboutQt(cls, parent: typing.Union[QWidget, None], title: str = ...) -> None: ...
    @typing.overload
    def addButton(self, text: str, role: QMessageBox.ButtonRole) -> QPushButton: ...
    @typing.overload
    def addButton(self, button: QAbstractButton, role: QMessageBox.ButtonRole) -> None: ...
    @typing.overload
    def addButton(self, button: QMessageBox.StandardButton) -> QPushButton: ...
    def button(self, which: QMessageBox.StandardButton) -> QAbstractButton: ...
    def buttonRole(self, button: QAbstractButton) -> QMessageBox.ButtonRole: ...
    def buttonText(self, button: int) -> str: ...
    def buttons(self) -> typing.List[QAbstractButton]: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def checkBox(self) -> QCheckBox: ...
    def clickedButton(self) -> QAbstractButton: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    @typing.overload
    @classmethod
    def critical(cls, parent: typing.Union[QWidget, None], title: str, text: str, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., defaultButton: QMessageBox.StandardButton = ...) -> QMessageBox.StandardButton: ...
    @typing.overload
    @classmethod
    def critical(cls, parent: typing.Union[QWidget, None], title: str, text: str, button0: QMessageBox.StandardButton, button1: QMessageBox.StandardButton) -> int: ...
    def defaultButton(self) -> QPushButton: ...
    def detailedText(self) -> str: ...
    def escapeButton(self) -> QAbstractButton: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def icon(self) -> QMessageBox.Icon: ...
    def iconPixmap(self) -> PySide2.QtGui.QPixmap: ...
    @typing.overload
    @classmethod
    def information(cls, parent: typing.Union[QWidget, None], title: str, text: str, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., defaultButton: QMessageBox.StandardButton = ...) -> QMessageBox.StandardButton: ...
    @typing.overload
    @classmethod
    def information(cls, parent: typing.Union[QWidget, None], title: str, text: str, button0: QMessageBox.StandardButton, button1: QMessageBox.StandardButton = ...) -> QMessageBox.StandardButton: ...
    def informativeText(self) -> str: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    @typing.overload
    @classmethod
    def question(cls, parent: typing.Union[QWidget, None], title: str, text: str, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., defaultButton: QMessageBox.StandardButton = ...) -> QMessageBox.StandardButton: ...
    @typing.overload
    @classmethod
    def question(cls, parent: typing.Union[QWidget, None], title: str, text: str, button0: QMessageBox.StandardButton, button1: QMessageBox.StandardButton) -> int: ...
    def removeButton(self, button: QAbstractButton) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def setButtonText(self, button: int, text: str) -> None: ...
    def setCheckBox(self, cb: QCheckBox) -> None: ...
    @typing.overload
    def setDefaultButton(self, button: QMessageBox.StandardButton) -> None: ...
    @typing.overload
    def setDefaultButton(self, button: QPushButton) -> None: ...
    def setDetailedText(self, text: str) -> None: ...
    @typing.overload
    def setEscapeButton(self, button: QAbstractButton) -> None: ...
    @typing.overload
    def setEscapeButton(self, button: QMessageBox.StandardButton) -> None: ...
    def setIcon(self, arg__1: QMessageBox.Icon) -> None: ...
    def setIconPixmap(self, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def setInformativeText(self, text: str) -> None: ...
    def setStandardButtons(self, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton]) -> None: ...
    def setText(self, text: str) -> None: ...
    def setTextFormat(self, format: PySide2.QtCore.Qt.TextFormat) -> None: ...
    def setTextInteractionFlags(self, flags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]) -> None: ...
    def setWindowModality(self, windowModality: PySide2.QtCore.Qt.WindowModality) -> None: ...
    def setWindowTitle(self, title: str) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def standardButton(self, button: QAbstractButton) -> QMessageBox.StandardButton: ...
    def standardButtons(self) -> typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton]: ...
    @classmethod
    def standardIcon(cls, icon: QMessageBox.Icon) -> PySide2.QtGui.QPixmap: ...
    def text(self) -> str: ...
    def textFormat(self) -> PySide2.QtCore.Qt.TextFormat: ...
    def textInteractionFlags(self) -> typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]: ...
    @typing.overload
    @classmethod
    def warning(cls, parent: typing.Union[QWidget, None], title: str, text: str, buttons: typing.Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = ..., defaultButton: QMessageBox.StandardButton = ...) -> QMessageBox.StandardButton: ...
    @typing.overload
    @classmethod
    def warning(cls, parent: typing.Union[QWidget, None], title: str, text: str, button0: QMessageBox.StandardButton, button1: QMessageBox.StandardButton) -> int: ...

class QMouseEventTransition(PySide2.QtCore.QEventTransition):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, object: PySide2.QtCore.QObject, type: PySide2.QtCore.QEvent.Type, button: PySide2.QtCore.Qt.MouseButton, sourceState: typing.Union[PySide2.QtCore.QState, None] = ..., destroyed: typing.Callable = ..., eventSource: PySide2.QtCore.QObject = ..., eventType: typing.Any = ..., modifierMask: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., targetState: typing.Any = ..., targetStateChanged: typing.Callable = ..., targetStates: typing.Any = ..., targetStatesChanged: typing.Callable = ..., transitionType: QMouseEventTransition.TransitionType = ..., triggered: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, sourceState: typing.Union[PySide2.QtCore.QState, None] = ..., button: PySide2.QtCore.Qt.MouseButton = ..., destroyed: typing.Callable = ..., eventSource: PySide2.QtCore.QObject = ..., eventType: typing.Any = ..., modifierMask: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., targetState: typing.Any = ..., targetStateChanged: typing.Callable = ..., targetStates: typing.Any = ..., targetStatesChanged: typing.Callable = ..., transitionType: QMouseEventTransition.TransitionType = ..., triggered: typing.Callable = ...) -> None: ...
    def button(self) -> PySide2.QtCore.Qt.MouseButton: ...
    def eventTest(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def hitTestPath(self) -> PySide2.QtGui.QPainterPath: ...
    def modifierMask(self) -> typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]: ...
    def onTransition(self, event: PySide2.QtCore.QEvent) -> None: ...
    def setButton(self, button: PySide2.QtCore.Qt.MouseButton) -> None: ...
    def setHitTestPath(self, path: PySide2.QtGui.QPainterPath) -> None: ...
    def setModifierMask(self, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> None: ...

class QOpenGLWidget(QWidget):
    class UpdateBehavior:
        NoPartialUpdate: typing.ClassVar[QOpenGLWidget.UpdateBehavior] = ...
        PartialUpdate: typing.ClassVar[QOpenGLWidget.UpdateBehavior] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __and__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __rand__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __rmul__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __ror__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __rsub__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __rxor__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __sub__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
        def __xor__(self, other: typing.SupportsInt) -> QOpenGLWidget.UpdateBehavior: ...
    NoPartialUpdate: typing.ClassVar[QOpenGLWidget.UpdateBehavior] = ...
    PartialUpdate: typing.ClassVar[QOpenGLWidget.UpdateBehavior] = ...
    aboutToCompose: typing.ClassVar[PySide2.QtCore.Signal] = ...
    aboutToResize: typing.ClassVar[PySide2.QtCore.Signal] = ...
    frameSwapped: typing.ClassVar[PySide2.QtCore.Signal] = ...
    resized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., aboutToCompose: typing.Callable = ..., aboutToResize: typing.Callable = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., frameSwapped: typing.Callable = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., resized: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def context(self) -> PySide2.QtGui.QOpenGLContext: ...
    def defaultFramebufferObject(self) -> int: ...
    def doneCurrent(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def format(self) -> PySide2.QtGui.QSurfaceFormat: ...
    def grabFramebuffer(self) -> PySide2.QtGui.QImage: ...
    def initializeGL(self) -> None: ...
    def isValid(self) -> bool: ...
    def makeCurrent(self) -> None: ...
    def metric(self, metric: PySide2.QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEngine(self) -> PySide2.QtGui.QPaintEngine: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def paintGL(self) -> None: ...
    def redirected(self, p: PySide2.QtCore.QPoint) -> PySide2.QtGui.QPaintDevice: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    def resizeGL(self, w: int, h: int) -> None: ...
    def setFormat(self, format: PySide2.QtGui.QSurfaceFormat) -> None: ...
    def setTextureFormat(self, texFormat: int) -> None: ...
    def setUpdateBehavior(self, updateBehavior: QOpenGLWidget.UpdateBehavior) -> None: ...
    def textureFormat(self) -> int: ...
    def updateBehavior(self) -> QOpenGLWidget.UpdateBehavior: ...

class QPanGesture(QGesture):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., acceleration: float = ..., delta: PySide2.QtCore.QPointF = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., horizontalVelocity: float = ..., hotSpot: PySide2.QtCore.QPointF = ..., lastOffset: PySide2.QtCore.QPointF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., offset: PySide2.QtCore.QPointF = ..., state: PySide2.QtCore.Qt.GestureState = ..., verticalVelocity: float = ...) -> None: ...
    def acceleration(self) -> float: ...
    def delta(self) -> PySide2.QtCore.QPointF: ...
    def lastOffset(self) -> PySide2.QtCore.QPointF: ...
    def offset(self) -> PySide2.QtCore.QPointF: ...
    def setAcceleration(self, value: float) -> None: ...
    def setLastOffset(self, value: PySide2.QtCore.QPointF) -> None: ...
    def setOffset(self, value: PySide2.QtCore.QPointF) -> None: ...

class QPinchGesture(QGesture):
    class ChangeFlag:
        CenterPointChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
        RotationAngleChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
        ScaleFactorChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QPinchGesture.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...

    class ChangeFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QPinchGesture.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QPinchGesture.ChangeFlags: ...
    CenterPointChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
    RotationAngleChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
    ScaleFactorChanged: typing.ClassVar[QPinchGesture.ChangeFlag] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., centerPoint: PySide2.QtCore.QPointF = ..., changeFlags: typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag] = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., hotSpot: PySide2.QtCore.QPointF = ..., lastCenterPoint: PySide2.QtCore.QPointF = ..., lastRotationAngle: float = ..., lastScaleFactor: float = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., rotationAngle: float = ..., scaleFactor: float = ..., startCenterPoint: PySide2.QtCore.QPointF = ..., state: PySide2.QtCore.Qt.GestureState = ..., totalChangeFlags: typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag] = ..., totalRotationAngle: float = ..., totalScaleFactor: float = ...) -> None: ...
    def centerPoint(self) -> PySide2.QtCore.QPointF: ...
    def changeFlags(self) -> typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag]: ...
    def lastCenterPoint(self) -> PySide2.QtCore.QPointF: ...
    def lastRotationAngle(self) -> float: ...
    def lastScaleFactor(self) -> float: ...
    def rotationAngle(self) -> float: ...
    def scaleFactor(self) -> float: ...
    def setCenterPoint(self, value: PySide2.QtCore.QPointF) -> None: ...
    def setChangeFlags(self, value: typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag]) -> None: ...
    def setLastCenterPoint(self, value: PySide2.QtCore.QPointF) -> None: ...
    def setLastRotationAngle(self, value: float) -> None: ...
    def setLastScaleFactor(self, value: float) -> None: ...
    def setRotationAngle(self, value: float) -> None: ...
    def setScaleFactor(self, value: float) -> None: ...
    def setStartCenterPoint(self, value: PySide2.QtCore.QPointF) -> None: ...
    def setTotalChangeFlags(self, value: typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag]) -> None: ...
    def setTotalRotationAngle(self, value: float) -> None: ...
    def setTotalScaleFactor(self, value: float) -> None: ...
    def startCenterPoint(self) -> PySide2.QtCore.QPointF: ...
    def totalChangeFlags(self) -> typing.Union[QPinchGesture.ChangeFlags, QPinchGesture.ChangeFlag]: ...
    def totalRotationAngle(self) -> float: ...
    def totalScaleFactor(self) -> float: ...

class QPlainTextDocumentLayout(PySide2.QtGui.QAbstractTextDocumentLayout):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, document: PySide2.QtGui.QTextDocument, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def blockBoundingRect(self, block: PySide2.QtGui.QTextBlock) -> PySide2.QtCore.QRectF: ...
    def cursorWidth(self) -> int: ...
    def documentChanged(self, from_: int, arg__2: int, charsAdded: int) -> None: ...
    def documentSize(self) -> PySide2.QtCore.QSizeF: ...
    def draw(self, arg__1: PySide2.QtGui.QPainter, arg__2: PySide2.QtGui.QAbstractTextDocumentLayout.PaintContext) -> None: ...
    def ensureBlockLayout(self, block: PySide2.QtGui.QTextBlock) -> None: ...
    def frameBoundingRect(self, arg__1: PySide2.QtGui.QTextFrame) -> PySide2.QtCore.QRectF: ...
    def hitTest(self, arg__1: PySide2.QtCore.QPointF, arg__2: PySide2.QtCore.Qt.HitTestAccuracy) -> int: ...
    def pageCount(self) -> int: ...
    def requestUpdate(self) -> None: ...
    def setCursorWidth(self, width: int) -> None: ...

class QPlainTextEdit(QAbstractScrollArea):
    class LineWrapMode:
        NoWrap: typing.ClassVar[QPlainTextEdit.LineWrapMode] = ...
        WidgetWidth: typing.ClassVar[QPlainTextEdit.LineWrapMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __and__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QPlainTextEdit.LineWrapMode: ...
    NoWrap: typing.ClassVar[QPlainTextEdit.LineWrapMode] = ...
    WidgetWidth: typing.ClassVar[QPlainTextEdit.LineWrapMode] = ...
    blockCountChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    copyAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cursorPositionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    modificationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    redoAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    selectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    undoAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    updateRequest: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., backgroundVisible: bool = ..., baseSize: PySide2.QtCore.QSize = ..., blockCount: int = ..., blockCountChanged: typing.Callable = ..., centerOnScroll: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., copyAvailable: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorPositionChanged: typing.Callable = ..., cursorWidth: int = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., documentTitle: str = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QPlainTextEdit.Shadow = ..., frameShape: QPlainTextEdit.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., lineWrapMode: QPlainTextEdit.LineWrapMode = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumBlockCount: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modificationChanged: typing.Callable = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overwriteMode: bool = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., plainText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: typing.Callable = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QPlainTextEdit.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabChangesFocus: bool = ..., tabStopDistance: float = ..., tabStopWidth: int = ..., tabletTracking: bool = ..., textChanged: typing.Callable = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: typing.Callable = ..., undoRedoEnabled: bool = ..., updateRequest: typing.Callable = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., backgroundVisible: bool = ..., baseSize: PySide2.QtCore.QSize = ..., blockCount: int = ..., blockCountChanged: typing.Callable = ..., centerOnScroll: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., copyAvailable: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorPositionChanged: typing.Callable = ..., cursorWidth: int = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., documentTitle: str = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QPlainTextEdit.Shadow = ..., frameShape: QPlainTextEdit.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., lineWrapMode: QPlainTextEdit.LineWrapMode = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumBlockCount: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modificationChanged: typing.Callable = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overwriteMode: bool = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., plainText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: typing.Callable = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QPlainTextEdit.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabChangesFocus: bool = ..., tabStopDistance: float = ..., tabStopWidth: int = ..., tabletTracking: bool = ..., textChanged: typing.Callable = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: typing.Callable = ..., undoRedoEnabled: bool = ..., updateRequest: typing.Callable = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def anchorAt(self, pos: PySide2.QtCore.QPoint) -> str: ...
    def appendHtml(self, html: str) -> None: ...
    def appendPlainText(self, text: str) -> None: ...
    def backgroundVisible(self) -> bool: ...
    def blockBoundingGeometry(self, block: PySide2.QtGui.QTextBlock) -> PySide2.QtCore.QRectF: ...
    def blockBoundingRect(self, block: PySide2.QtGui.QTextBlock) -> PySide2.QtCore.QRectF: ...
    def blockCount(self) -> int: ...
    def canInsertFromMimeData(self, source: PySide2.QtCore.QMimeData) -> bool: ...
    def canPaste(self) -> bool: ...
    def centerCursor(self) -> None: ...
    def centerOnScroll(self) -> bool: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def contentOffset(self) -> PySide2.QtCore.QPointF: ...
    def contextMenuEvent(self, e: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def copy(self) -> None: ...
    def createMimeDataFromSelection(self) -> PySide2.QtCore.QMimeData: ...
    @typing.overload
    def createStandardContextMenu(self, position: PySide2.QtCore.QPoint) -> QMenu: ...
    @typing.overload
    def createStandardContextMenu(self) -> QMenu: ...
    def currentCharFormat(self) -> PySide2.QtGui.QTextCharFormat: ...
    def cursorForPosition(self, pos: PySide2.QtCore.QPoint) -> PySide2.QtGui.QTextCursor: ...
    @typing.overload
    def cursorRect(self, cursor: PySide2.QtGui.QTextCursor) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def cursorRect(self) -> PySide2.QtCore.QRect: ...
    def cursorWidth(self) -> int: ...
    def cut(self) -> None: ...
    def doSetTextCursor(self, cursor: PySide2.QtGui.QTextCursor) -> None: ...
    def document(self) -> PySide2.QtGui.QTextDocument: ...
    def documentTitle(self) -> str: ...
    def dragEnterEvent(self, e: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, e: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, e: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, e: PySide2.QtGui.QDropEvent) -> None: ...
    def ensureCursorVisible(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def extraSelections(self) -> typing.List[QTextEdit.ExtraSelection]: ...
    @typing.overload
    def find(self, exp: PySide2.QtCore.QRegExp, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    @typing.overload
    def find(self, exp: PySide2.QtCore.QRegularExpression, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    @typing.overload
    def find(self, exp: str, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    def firstVisibleBlock(self) -> PySide2.QtGui.QTextBlock: ...
    def focusInEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def getPaintContext(self) -> PySide2.QtGui.QAbstractTextDocumentLayout.PaintContext: ...
    def inputMethodEvent(self, arg__1: PySide2.QtGui.QInputMethodEvent) -> None: ...
    @typing.overload
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery, argument: typing.Any) -> typing.Any: ...
    @typing.overload
    def inputMethodQuery(self, property: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def insertFromMimeData(self, source: PySide2.QtCore.QMimeData) -> None: ...
    def insertPlainText(self, text: str) -> None: ...
    def isReadOnly(self) -> bool: ...
    def isUndoRedoEnabled(self) -> bool: ...
    def keyPressEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def lineWrapMode(self) -> QPlainTextEdit.LineWrapMode: ...
    def loadResource(self, type: int, name: PySide2.QtCore.QUrl) -> typing.Any: ...
    def maximumBlockCount(self) -> int: ...
    def mergeCurrentCharFormat(self, modifier: PySide2.QtGui.QTextCharFormat) -> None: ...
    def mouseDoubleClickEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, operation: PySide2.QtGui.QTextCursor.MoveOperation, mode: PySide2.QtGui.QTextCursor.MoveMode = ...) -> None: ...
    def overwriteMode(self) -> bool: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def paste(self) -> None: ...
    def placeholderText(self) -> str: ...
    def print_(self, printer: PySide2.QtGui.QPagedPaintDevice) -> None: ...
    def redo(self) -> None: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def selectAll(self) -> None: ...
    def setBackgroundVisible(self, visible: bool) -> None: ...
    def setCenterOnScroll(self, enabled: bool) -> None: ...
    def setCurrentCharFormat(self, format: PySide2.QtGui.QTextCharFormat) -> None: ...
    def setCursorWidth(self, width: int) -> None: ...
    def setDocument(self, document: PySide2.QtGui.QTextDocument) -> None: ...
    def setDocumentTitle(self, title: str) -> None: ...
    def setExtraSelections(self, selections: typing.Iterable[QTextEdit.ExtraSelection]) -> None: ...
    def setLineWrapMode(self, mode: QPlainTextEdit.LineWrapMode) -> None: ...
    def setMaximumBlockCount(self, maximum: int) -> None: ...
    def setOverwriteMode(self, overwrite: bool) -> None: ...
    def setPlaceholderText(self, placeholderText: str) -> None: ...
    def setPlainText(self, text: str) -> None: ...
    def setReadOnly(self, ro: bool) -> None: ...
    def setTabChangesFocus(self, b: bool) -> None: ...
    def setTabStopDistance(self, distance: float) -> None: ...
    def setTabStopWidth(self, width: int) -> None: ...
    def setTextCursor(self, cursor: PySide2.QtGui.QTextCursor) -> None: ...
    def setTextInteractionFlags(self, flags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]) -> None: ...
    def setUndoRedoEnabled(self, enable: bool) -> None: ...
    def setWordWrapMode(self, policy: PySide2.QtGui.QTextOption.WrapMode) -> None: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def tabChangesFocus(self) -> bool: ...
    def tabStopDistance(self) -> float: ...
    def tabStopWidth(self) -> int: ...
    def textCursor(self) -> PySide2.QtGui.QTextCursor: ...
    def textInteractionFlags(self) -> typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]: ...
    def timerEvent(self, e: PySide2.QtCore.QTimerEvent) -> None: ...
    def toPlainText(self) -> str: ...
    def undo(self) -> None: ...
    def wheelEvent(self, e: PySide2.QtGui.QWheelEvent) -> None: ...
    def wordWrapMode(self) -> PySide2.QtGui.QTextOption.WrapMode: ...
    def zoomIn(self, range: int = ...) -> None: ...
    def zoomInF(self, range: float) -> None: ...
    def zoomOut(self, range: int = ...) -> None: ...

class QProgressBar(QWidget):
    class Direction:
        BottomToTop: typing.ClassVar[QProgressBar.Direction] = ...
        TopToBottom: typing.ClassVar[QProgressBar.Direction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __and__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __rand__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __ror__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __sub__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
        def __xor__(self, other: typing.SupportsInt) -> QProgressBar.Direction: ...
    BottomToTop: typing.ClassVar[QProgressBar.Direction] = ...
    TopToBottom: typing.ClassVar[QProgressBar.Direction] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., format: str = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., textDirection: QProgressBar.Direction = ..., textVisible: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def format(self) -> str: ...
    def initStyleOption(self, option: QStyleOptionProgressBar) -> None: ...
    def invertedAppearance(self) -> bool: ...
    def isTextVisible(self) -> bool: ...
    def maximum(self) -> int: ...
    def minimum(self) -> int: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def reset(self) -> None: ...
    def resetFormat(self) -> None: ...
    def setAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setFormat(self, format: str) -> None: ...
    def setInvertedAppearance(self, invert: bool) -> None: ...
    def setMaximum(self, maximum: int) -> None: ...
    def setMinimum(self, minimum: int) -> None: ...
    def setOrientation(self, arg__1: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setRange(self, minimum: int, maximum: int) -> None: ...
    def setTextDirection(self, textDirection: QProgressBar.Direction) -> None: ...
    def setTextVisible(self, visible: bool) -> None: ...
    def setValue(self, value: int) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def text(self) -> str: ...
    def textDirection(self) -> QProgressBar.Direction: ...
    def value(self) -> int: ...

class QProgressDialog(QDialog):
    canceled: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, labelText: str, cancelButtonText: str, minimum: int, maximum: int, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoClose: bool = ..., autoFillBackground: bool = ..., autoReset: bool = ..., baseSize: PySide2.QtCore.QSize = ..., canceled: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDuration: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: int = ..., visible: bool = ..., wasCanceled: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoClose: bool = ..., autoFillBackground: bool = ..., autoReset: bool = ..., baseSize: PySide2.QtCore.QSize = ..., canceled: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., labelText: str = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumDuration: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: int = ..., visible: bool = ..., wasCanceled: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def autoClose(self) -> bool: ...
    def autoReset(self) -> bool: ...
    def cancel(self) -> None: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    def forceShow(self) -> None: ...
    def labelText(self) -> str: ...
    def maximum(self) -> int: ...
    def minimum(self) -> int: ...
    def minimumDuration(self) -> int: ...
    @typing.overload
    def open(self, receiver: PySide2.QtCore.QObject, member: bytes) -> None: ...
    @typing.overload
    def open(self) -> None: ...
    def reset(self) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def setAutoClose(self, close: bool) -> None: ...
    def setAutoReset(self, reset: bool) -> None: ...
    def setBar(self, bar: QProgressBar) -> None: ...
    def setCancelButton(self, button: typing.Union[QPushButton, None]) -> None: ...
    def setCancelButtonText(self, text: str) -> None: ...
    def setLabel(self, label: QLabel) -> None: ...
    def setLabelText(self, text: str) -> None: ...
    def setMaximum(self, maximum: int) -> None: ...
    def setMinimum(self, minimum: int) -> None: ...
    def setMinimumDuration(self, ms: int) -> None: ...
    def setRange(self, minimum: int, maximum: int) -> None: ...
    def setValue(self, progress: int) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def value(self) -> int: ...
    def wasCanceled(self) -> bool: ...

class QProxyStyle(QCommonStyle):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, style: typing.Union[QStyle, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def baseStyle(self) -> QStyle: ...
    def drawComplexControl(self, control: QStyle.ComplexControl, option: QStyleOptionComplex, painter: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def drawControl(self, element: QStyle.ControlElement, option: QStyleOption, painter: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def drawItemPixmap(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, alignment: int, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def drawItemText(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, flags: typing.SupportsInt, pal: PySide2.QtGui.QPalette, enabled: bool, text: str, textRole: PySide2.QtGui.QPalette.ColorRole = ...) -> None: ...
    def drawPrimitive(self, element: QStyle.PrimitiveElement, option: QStyleOption, painter: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def generatedIconPixmap(self, iconMode: PySide2.QtGui.QIcon.Mode, pixmap: PySide2.QtGui.QPixmap, opt: QStyleOption) -> PySide2.QtGui.QPixmap: ...
    def hitTestComplexControl(self, control: QStyle.ComplexControl, option: QStyleOptionComplex, pos: PySide2.QtCore.QPoint, widget: typing.Union[QWidget, None] = ...) -> QStyle.SubControl: ...
    def itemPixmapRect(self, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, pixmap: PySide2.QtGui.QPixmap) -> PySide2.QtCore.QRect: ...
    def itemTextRect(self, fm: PySide2.QtGui.QFontMetrics, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, enabled: bool, text: str) -> PySide2.QtCore.QRect: ...
    def layoutSpacing(self, control1: QSizePolicy.ControlType, control2: QSizePolicy.ControlType, orientation: PySide2.QtCore.Qt.Orientation, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    def pixelMetric(self, metric: QStyle.PixelMetric, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    @typing.overload
    def polish(self, widget: QWidget) -> None: ...
    @typing.overload
    def polish(self, pal: PySide2.QtGui.QPalette) -> None: ...
    @typing.overload
    def polish(self, app: QApplication) -> None: ...
    def setBaseStyle(self, style: QStyle) -> None: ...
    def sizeFromContents(self, type: QStyle.ContentsType, option: QStyleOption, size: PySide2.QtCore.QSize, widget: QWidget) -> PySide2.QtCore.QSize: ...
    def standardIcon(self, standardIcon: QStyle.StandardPixmap, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QIcon: ...
    def standardPalette(self) -> PySide2.QtGui.QPalette: ...
    def standardPixmap(self, standardPixmap: QStyle.StandardPixmap, opt: QStyleOption, widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QPixmap: ...
    def styleHint(self, hint: QStyle.StyleHint, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ..., returnData: typing.Union[QStyleHintReturn, None] = ...) -> int: ...
    def subControlRect(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, sc: QStyle.SubControl, widget: QWidget) -> PySide2.QtCore.QRect: ...
    def subElementRect(self, element: QStyle.SubElement, option: QStyleOption, widget: QWidget) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def unpolish(self, widget: QWidget) -> None: ...
    @typing.overload
    def unpolish(self, application: QApplication) -> None: ...
    @typing.overload
    def unpolish(self, app: QApplication) -> None: ...

class QPushButton(QAbstractButton):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, icon: PySide2.QtGui.QIcon, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoDefault: bool = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., default: bool = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., flat: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def autoDefault(self) -> bool: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def focusInEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusOutEvent(self, arg__1: PySide2.QtGui.QFocusEvent) -> None: ...
    def hitButton(self, pos: PySide2.QtCore.QPoint) -> bool: ...
    def initStyleOption(self, option: QStyleOptionButton) -> None: ...
    def isDefault(self) -> bool: ...
    def isFlat(self) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def menu(self) -> QMenu: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setAutoDefault(self, arg__1: bool) -> None: ...
    def setDefault(self, arg__1: bool) -> None: ...
    def setFlat(self, arg__1: bool) -> None: ...
    def setMenu(self, menu: QMenu) -> None: ...
    def showMenu(self) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QRadioButton(QAbstractButton):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def hitButton(self, arg__1: PySide2.QtCore.QPoint) -> bool: ...
    def initStyleOption(self, button: QStyleOptionButton) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QRubberBand(QWidget):
    class Shape:
        Line: typing.ClassVar[QRubberBand.Shape] = ...
        Rectangle: typing.ClassVar[QRubberBand.Shape] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __and__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __rand__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __rmul__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __ror__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __rsub__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __rxor__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __sub__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
        def __xor__(self, other: typing.SupportsInt) -> QRubberBand.Shape: ...
    Line: typing.ClassVar[QRubberBand.Shape] = ...
    Rectangle: typing.ClassVar[QRubberBand.Shape] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, arg__1: QRubberBand.Shape, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def initStyleOption(self, option: QStyleOptionRubberBand) -> None: ...
    @typing.overload
    def move(self, x: int, y: int) -> None: ...
    @typing.overload
    def move(self, p: PySide2.QtCore.QPoint) -> None: ...
    def moveEvent(self, arg__1: PySide2.QtGui.QMoveEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    @typing.overload
    def resize(self, w: int, h: int) -> None: ...
    @typing.overload
    def resize(self, s: PySide2.QtCore.QSize) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    @typing.overload
    def setGeometry(self, x: int, y: int, w: int, h: int) -> None: ...
    @typing.overload
    def setGeometry(self, r: PySide2.QtCore.QRect) -> None: ...
    def shape(self) -> QRubberBand.Shape: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...

class QScrollArea(QAbstractScrollArea):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QScrollArea.Shadow = ..., frameShape: QScrollArea.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QScrollArea.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., widgetResizable: bool = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def ensureVisible(self, x: int, y: int, xmargin: int = ..., ymargin: int = ...) -> None: ...
    def ensureWidgetVisible(self, childWidget: QWidget, xmargin: int = ..., ymargin: int = ...) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def setAlignment(self, arg__1: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setWidget(self, widget: QWidget) -> None: ...
    def setWidgetResizable(self, resizable: bool) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def takeWidget(self) -> QWidget: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def widget(self) -> QWidget: ...
    def widgetResizable(self) -> bool: ...

class QScrollBar(QAbstractSlider):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def contextMenuEvent(self, arg__1: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def hideEvent(self, arg__1: PySide2.QtGui.QHideEvent) -> None: ...
    def initStyleOption(self, option: QStyleOptionSlider) -> None: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sliderChange(self, change: QAbstractSlider.SliderChange) -> None: ...
    def wheelEvent(self, arg__1: PySide2.QtGui.QWheelEvent) -> None: ...

class QScroller(PySide2.QtCore.QObject):
    class Input:
        InputMove: typing.ClassVar[QScroller.Input] = ...
        InputPress: typing.ClassVar[QScroller.Input] = ...
        InputRelease: typing.ClassVar[QScroller.Input] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __and__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __rand__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __ror__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __sub__(self, other: typing.SupportsInt) -> QScroller.Input: ...
        def __xor__(self, other: typing.SupportsInt) -> QScroller.Input: ...

    class ScrollerGestureType:
        LeftMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
        MiddleMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
        RightMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
        TouchGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __and__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __rand__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __ror__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __sub__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...
        def __xor__(self, other: typing.SupportsInt) -> QScroller.ScrollerGestureType: ...

    class State:
        Dragging: typing.ClassVar[QScroller.State] = ...
        Inactive: typing.ClassVar[QScroller.State] = ...
        Pressed: typing.ClassVar[QScroller.State] = ...
        Scrolling: typing.ClassVar[QScroller.State] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __and__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __rand__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __ror__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __sub__(self, other: typing.SupportsInt) -> QScroller.State: ...
        def __xor__(self, other: typing.SupportsInt) -> QScroller.State: ...
    Dragging: typing.ClassVar[QScroller.State] = ...
    Inactive: typing.ClassVar[QScroller.State] = ...
    InputMove: typing.ClassVar[QScroller.Input] = ...
    InputPress: typing.ClassVar[QScroller.Input] = ...
    InputRelease: typing.ClassVar[QScroller.Input] = ...
    LeftMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
    MiddleMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
    Pressed: typing.ClassVar[QScroller.State] = ...
    RightMouseButtonGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
    Scrolling: typing.ClassVar[QScroller.State] = ...
    TouchGesture: typing.ClassVar[QScroller.ScrollerGestureType] = ...
    scrollerPropertiesChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    stateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def activeScrollers(cls) -> typing.List[QScroller]: ...
    @typing.overload
    def ensureVisible(self, rect: PySide2.QtCore.QRectF, xmargin: float, ymargin: float, scrollTime: int) -> None: ...
    @typing.overload
    def ensureVisible(self, rect: PySide2.QtCore.QRectF, xmargin: float, ymargin: float) -> None: ...
    def finalPosition(self) -> PySide2.QtCore.QPointF: ...
    @classmethod
    def grabGesture(cls, target: PySide2.QtCore.QObject, gestureType: QScroller.ScrollerGestureType = ...) -> PySide2.QtCore.Qt.GestureType: ...
    @classmethod
    def grabbedGesture(cls, target: PySide2.QtCore.QObject) -> PySide2.QtCore.Qt.GestureType: ...
    def handleInput(self, input: QScroller.Input, position: PySide2.QtCore.QPointF, timestamp: int = ...) -> bool: ...
    @classmethod
    def hasScroller(cls, target: PySide2.QtCore.QObject) -> bool: ...
    def pixelPerMeter(self) -> PySide2.QtCore.QPointF: ...
    def resendPrepareEvent(self) -> None: ...
    @typing.overload
    def scrollTo(self, pos: PySide2.QtCore.QPointF, scrollTime: int) -> None: ...
    @typing.overload
    def scrollTo(self, pos: PySide2.QtCore.QPointF) -> None: ...
    @classmethod
    def scroller(cls, target: PySide2.QtCore.QObject) -> QScroller: ...
    def scrollerProperties(self) -> QScrollerProperties: ...
    def setScrollerProperties(self, prop: QScrollerProperties) -> None: ...
    @typing.overload
    def setSnapPositionsX(self, first: float, interval: float) -> None: ...
    @typing.overload
    def setSnapPositionsX(self, positions: typing.Iterable[float]) -> None: ...
    @typing.overload
    def setSnapPositionsY(self, first: float, interval: float) -> None: ...
    @typing.overload
    def setSnapPositionsY(self, positions: typing.Iterable[float]) -> None: ...
    def state(self) -> QScroller.State: ...
    def stop(self) -> None: ...
    def target(self) -> PySide2.QtCore.QObject: ...
    @classmethod
    def ungrabGesture(cls, target: PySide2.QtCore.QObject) -> None: ...
    def velocity(self) -> PySide2.QtCore.QPointF: ...

class QScrollerProperties(shiboken2.Object):
    class FrameRates:
        Fps20: typing.ClassVar[QScrollerProperties.FrameRates] = ...
        Fps30: typing.ClassVar[QScrollerProperties.FrameRates] = ...
        Fps60: typing.ClassVar[QScrollerProperties.FrameRates] = ...
        Standard: typing.ClassVar[QScrollerProperties.FrameRates] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __and__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __rand__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __ror__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __sub__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...
        def __xor__(self, other: typing.SupportsInt) -> QScrollerProperties.FrameRates: ...

    class OvershootPolicy:
        OvershootAlwaysOff: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
        OvershootAlwaysOn: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
        OvershootWhenScrollable: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QScrollerProperties.OvershootPolicy: ...

    class ScrollMetric:
        AcceleratingFlickMaximumTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        AcceleratingFlickSpeedupFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        AxisLockThreshold: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        DecelerationFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        DragStartDistance: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        DragVelocitySmoothingFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        FrameRate: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        HorizontalOvershootPolicy: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        MaximumClickThroughVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        MaximumVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        MinimumVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        MousePressEventDelay: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        OvershootDragDistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        OvershootDragResistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        OvershootScrollDistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        OvershootScrollTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        ScrollMetricCount: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        ScrollingCurve: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        SnapPositionRatio: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        SnapTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        VerticalOvershootPolicy: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __and__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __rand__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __ror__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __sub__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
        def __xor__(self, other: typing.SupportsInt) -> QScrollerProperties.ScrollMetric: ...
    AcceleratingFlickMaximumTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    AcceleratingFlickSpeedupFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    AxisLockThreshold: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    DecelerationFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    DragStartDistance: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    DragVelocitySmoothingFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    Fps20: typing.ClassVar[QScrollerProperties.FrameRates] = ...
    Fps30: typing.ClassVar[QScrollerProperties.FrameRates] = ...
    Fps60: typing.ClassVar[QScrollerProperties.FrameRates] = ...
    FrameRate: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    HorizontalOvershootPolicy: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    MaximumClickThroughVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    MaximumVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    MinimumVelocity: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    MousePressEventDelay: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    OvershootAlwaysOff: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
    OvershootAlwaysOn: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
    OvershootDragDistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    OvershootDragResistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    OvershootScrollDistanceFactor: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    OvershootScrollTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    OvershootWhenScrollable: typing.ClassVar[QScrollerProperties.OvershootPolicy] = ...
    ScrollMetricCount: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    ScrollingCurve: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    SnapPositionRatio: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    SnapTime: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    Standard: typing.ClassVar[QScrollerProperties.FrameRates] = ...
    VerticalOvershootPolicy: typing.ClassVar[QScrollerProperties.ScrollMetric] = ...
    @typing.overload
    def __init__(self, sp: QScrollerProperties) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def scrollMetric(self, metric: QScrollerProperties.ScrollMetric) -> typing.Any: ...
    @classmethod
    def setDefaultScrollerProperties(cls, sp: QScrollerProperties) -> None: ...
    def setScrollMetric(self, metric: QScrollerProperties.ScrollMetric, value: typing.Any) -> None: ...
    @classmethod
    def unsetDefaultScrollerProperties(cls) -> None: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class QShortcut(PySide2.QtCore.QObject):
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    activatedAmbiguously: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, key: typing.Union[PySide2.QtGui.QKeySequence, str], parent: typing.Union[QWidget, None], member: typing.Union[bytes, None] = ..., ambiguousMember: typing.Union[bytes, None] = ..., shortcutContext: PySide2.QtCore.Qt.ShortcutContext = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: typing.Union[PySide2.QtGui.QKeySequence, str], arg__2: QWidget, arg__3: typing.Callable, arg__4: PySide2.QtCore.Qt.ShortcutContext = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def autoRepeat(self) -> bool: ...
    def context(self) -> PySide2.QtCore.Qt.ShortcutContext: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def id(self) -> int: ...
    def isEnabled(self) -> bool: ...
    def key(self) -> PySide2.QtGui.QKeySequence: ...
    def parentWidget(self) -> QWidget: ...
    def setAutoRepeat(self, on: bool) -> None: ...
    def setContext(self, context: PySide2.QtCore.Qt.ShortcutContext) -> None: ...
    def setEnabled(self, enable: bool) -> None: ...
    def setKey(self, key: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    def setWhatsThis(self, text: str) -> None: ...
    def whatsThis(self) -> str: ...

class QSizeGrip(QWidget):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None], acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def hideEvent(self, hideEvent: PySide2.QtGui.QHideEvent) -> None: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, mouseEvent: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveEvent(self, moveEvent: PySide2.QtGui.QMoveEvent) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def setVisible(self, arg__1: bool) -> None: ...
    def showEvent(self, showEvent: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...

class QSizePolicy(shiboken2.Object):
    class ControlType:
        ButtonBox: typing.ClassVar[QSizePolicy.ControlType] = ...
        CheckBox: typing.ClassVar[QSizePolicy.ControlType] = ...
        ComboBox: typing.ClassVar[QSizePolicy.ControlType] = ...
        DefaultType: typing.ClassVar[QSizePolicy.ControlType] = ...
        Frame: typing.ClassVar[QSizePolicy.ControlType] = ...
        GroupBox: typing.ClassVar[QSizePolicy.ControlType] = ...
        Label: typing.ClassVar[QSizePolicy.ControlType] = ...
        Line: typing.ClassVar[QSizePolicy.ControlType] = ...
        LineEdit: typing.ClassVar[QSizePolicy.ControlType] = ...
        PushButton: typing.ClassVar[QSizePolicy.ControlType] = ...
        RadioButton: typing.ClassVar[QSizePolicy.ControlType] = ...
        Slider: typing.ClassVar[QSizePolicy.ControlType] = ...
        SpinBox: typing.ClassVar[QSizePolicy.ControlType] = ...
        TabWidget: typing.ClassVar[QSizePolicy.ControlType] = ...
        ToolButton: typing.ClassVar[QSizePolicy.ControlType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QSizePolicy.ControlTypes: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __rand__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __ror__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __xor__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...

    class ControlTypes:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QSizePolicy.ControlTypes: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __rand__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __ror__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...
        def __xor__(self, other: typing.SupportsInt) -> QSizePolicy.ControlTypes: ...

    class Policy:
        Expanding: typing.ClassVar[QSizePolicy.Policy] = ...
        Fixed: typing.ClassVar[QSizePolicy.Policy] = ...
        Ignored: typing.ClassVar[QSizePolicy.Policy] = ...
        Maximum: typing.ClassVar[QSizePolicy.Policy] = ...
        Minimum: typing.ClassVar[QSizePolicy.Policy] = ...
        MinimumExpanding: typing.ClassVar[QSizePolicy.Policy] = ...
        Preferred: typing.ClassVar[QSizePolicy.Policy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __and__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __rand__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __ror__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __sub__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...
        def __xor__(self, other: typing.SupportsInt) -> QSizePolicy.Policy: ...

    class PolicyFlag:
        ExpandFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
        GrowFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
        IgnoreFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
        ShrinkFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __and__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __rand__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __ror__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __sub__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
        def __xor__(self, other: typing.SupportsInt) -> QSizePolicy.PolicyFlag: ...
    ButtonBox: typing.ClassVar[QSizePolicy.ControlType] = ...
    CheckBox: typing.ClassVar[QSizePolicy.ControlType] = ...
    ComboBox: typing.ClassVar[QSizePolicy.ControlType] = ...
    DefaultType: typing.ClassVar[QSizePolicy.ControlType] = ...
    ExpandFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
    Expanding: typing.ClassVar[QSizePolicy.Policy] = ...
    Fixed: typing.ClassVar[QSizePolicy.Policy] = ...
    Frame: typing.ClassVar[QSizePolicy.ControlType] = ...
    GroupBox: typing.ClassVar[QSizePolicy.ControlType] = ...
    GrowFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
    IgnoreFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
    Ignored: typing.ClassVar[QSizePolicy.Policy] = ...
    Label: typing.ClassVar[QSizePolicy.ControlType] = ...
    Line: typing.ClassVar[QSizePolicy.ControlType] = ...
    LineEdit: typing.ClassVar[QSizePolicy.ControlType] = ...
    Maximum: typing.ClassVar[QSizePolicy.Policy] = ...
    Minimum: typing.ClassVar[QSizePolicy.Policy] = ...
    MinimumExpanding: typing.ClassVar[QSizePolicy.Policy] = ...
    Preferred: typing.ClassVar[QSizePolicy.Policy] = ...
    PushButton: typing.ClassVar[QSizePolicy.ControlType] = ...
    RadioButton: typing.ClassVar[QSizePolicy.ControlType] = ...
    ShrinkFlag: typing.ClassVar[QSizePolicy.PolicyFlag] = ...
    Slider: typing.ClassVar[QSizePolicy.ControlType] = ...
    SpinBox: typing.ClassVar[QSizePolicy.ControlType] = ...
    TabWidget: typing.ClassVar[QSizePolicy.ControlType] = ...
    ToolButton: typing.ClassVar[QSizePolicy.ControlType] = ...
    @typing.overload
    def __init__(self, horizontal: QSizePolicy.Policy, vertical: QSizePolicy.Policy, type: QSizePolicy.ControlType = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def controlType(self) -> QSizePolicy.ControlType: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def hasHeightForWidth(self) -> bool: ...
    def hasWidthForHeight(self) -> bool: ...
    def horizontalPolicy(self) -> QSizePolicy.Policy: ...
    def horizontalStretch(self) -> int: ...
    def retainSizeWhenHidden(self) -> bool: ...
    def setControlType(self, type: QSizePolicy.ControlType) -> None: ...
    def setHeightForWidth(self, b: bool) -> None: ...
    def setHorizontalPolicy(self, d: QSizePolicy.Policy) -> None: ...
    def setHorizontalStretch(self, stretchFactor: int) -> None: ...
    def setRetainSizeWhenHidden(self, retainSize: bool) -> None: ...
    def setVerticalPolicy(self, d: QSizePolicy.Policy) -> None: ...
    def setVerticalStretch(self, stretchFactor: int) -> None: ...
    def setWidthForHeight(self, b: bool) -> None: ...
    def transpose(self) -> None: ...
    def transposed(self) -> QSizePolicy: ...
    def verticalPolicy(self) -> QSizePolicy.Policy: ...
    def verticalStretch(self) -> int: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...

class QSlider(QAbstractSlider):
    class TickPosition:
        NoTicks: typing.ClassVar[QSlider.TickPosition] = ...
        TicksAbove: typing.ClassVar[QSlider.TickPosition] = ...
        TicksBelow: typing.ClassVar[QSlider.TickPosition] = ...
        TicksBothSides: typing.ClassVar[QSlider.TickPosition] = ...
        TicksLeft: typing.ClassVar[QSlider.TickPosition] = ...
        TicksRight: typing.ClassVar[QSlider.TickPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QSlider.TickPosition: ...
    NoTicks: typing.ClassVar[QSlider.TickPosition] = ...
    TicksAbove: typing.ClassVar[QSlider.TickPosition] = ...
    TicksBelow: typing.ClassVar[QSlider.TickPosition] = ...
    TicksBothSides: typing.ClassVar[QSlider.TickPosition] = ...
    TicksLeft: typing.ClassVar[QSlider.TickPosition] = ...
    TicksRight: typing.ClassVar[QSlider.TickPosition] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, orientation: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., tickInterval: int = ..., tickPosition: QSlider.TickPosition = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., invertedAppearance: bool = ..., invertedControls: bool = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., pageStep: int = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rangeChanged: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sliderDown: bool = ..., sliderMoved: typing.Callable = ..., sliderPosition: int = ..., sliderPressed: typing.Callable = ..., sliderReleased: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., tickInterval: int = ..., tickPosition: QSlider.TickPosition = ..., toolTip: str = ..., toolTipDuration: int = ..., tracking: bool = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def initStyleOption(self, option: QStyleOptionSlider) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def paintEvent(self, ev: PySide2.QtGui.QPaintEvent) -> None: ...
    def setTickInterval(self, ti: int) -> None: ...
    def setTickPosition(self, position: QSlider.TickPosition) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def tickInterval(self) -> int: ...
    def tickPosition(self) -> QSlider.TickPosition: ...

class QSpacerItem(QLayoutItem):
    @typing.overload
    def __init__(self, w: int, h: int, hData: QSizePolicy.Policy = ..., vData: QSizePolicy.Policy = ...) -> None: ...
    @typing.overload
    def __init__(self, w: int, h: int, hPolicy: QSizePolicy.Policy = ..., vPolicy: QSizePolicy.Policy = ...) -> None: ...
    @typing.overload
    def changeSize(self, w: int, h: int, hData: QSizePolicy.Policy = ..., vData: QSizePolicy.Policy = ...) -> None: ...
    @typing.overload
    def changeSize(self, w: int, h: int, hPolicy: QSizePolicy.Policy = ..., vPolicy: QSizePolicy.Policy = ...) -> None: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def isEmpty(self) -> bool: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sizePolicy(self) -> QSizePolicy: ...
    def spacerItem(self) -> QSpacerItem: ...

class QSpinBox(QAbstractSpinBox):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QSpinBox.ButtonSymbols = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., cleanText: str = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QSpinBox.CorrectionMode = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., displayIntegerBase: int = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximum: int = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimum: int = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., prefix: str = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., showGroupSeparator: bool = ..., singleStep: int = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., stepType: QSpinBox.StepType = ..., styleSheet: str = ..., suffix: str = ..., tabletTracking: bool = ..., text: str = ..., textChanged: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., value: int = ..., valueChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def cleanText(self) -> str: ...
    def displayIntegerBase(self) -> int: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def fixup(self, str: str) -> None: ...
    def maximum(self) -> int: ...
    def minimum(self) -> int: ...
    def prefix(self) -> str: ...
    def setDisplayIntegerBase(self, base: int) -> None: ...
    def setMaximum(self, max: int) -> None: ...
    def setMinimum(self, min: int) -> None: ...
    def setPrefix(self, prefix: str) -> None: ...
    def setRange(self, min: int, max: int) -> None: ...
    def setSingleStep(self, val: int) -> None: ...
    def setStepType(self, stepType: QAbstractSpinBox.StepType) -> None: ...
    def setSuffix(self, suffix: str) -> None: ...
    def setValue(self, val: int) -> None: ...
    def singleStep(self) -> int: ...
    def stepType(self) -> QAbstractSpinBox.StepType: ...
    def suffix(self) -> str: ...
    def textFromValue(self, val: int) -> str: ...
    def validate(self, input: str, pos: int) -> PySide2.QtGui.QValidator.State: ...
    def value(self) -> int: ...
    def valueFromText(self, text: str) -> int: ...

class QSplashScreen(QWidget):
    messageChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, screen: PySide2.QtGui.QScreen, pixmap: PySide2.QtGui.QPixmap = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., messageChanged: typing.Callable = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], pixmap: PySide2.QtGui.QPixmap = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., messageChanged: typing.Callable = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, pixmap: PySide2.QtGui.QPixmap = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., messageChanged: typing.Callable = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def clearMessage(self) -> None: ...
    def drawContents(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def finish(self, w: QWidget) -> None: ...
    def message(self) -> str: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def pixmap(self) -> PySide2.QtGui.QPixmap: ...
    def setPixmap(self, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def showMessage(self, message: str, alignment: int = ..., color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int] = ...) -> None: ...

class QSplitter(QFrame):
    splitterMoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtCore.Qt.Orientation, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenCollapsible: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QSplitter.Shadow = ..., frameShape: QSplitter.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., handleWidth: int = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opaqueResize: bool = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., splitterMoved: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenCollapsible: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QSplitter.Shadow = ..., frameShape: QSplitter.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., handleWidth: int = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., opaqueResize: bool = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., splitterMoved: typing.Callable = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def addWidget(self, widget: QWidget) -> None: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def childEvent(self, arg__1: PySide2.QtCore.QChildEvent) -> None: ...
    def childrenCollapsible(self) -> bool: ...
    def closestLegalPosition(self, arg__1: int, arg__2: int) -> int: ...
    def count(self) -> int: ...
    def createHandle(self) -> QSplitterHandle: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def getRange(self, index: int) -> typing.Tuple[int, int]: ...
    def handle(self, index: int) -> QSplitterHandle: ...
    def handleWidth(self) -> int: ...
    def indexOf(self, w: QWidget) -> int: ...
    def insertWidget(self, index: int, widget: QWidget) -> None: ...
    def isCollapsible(self, index: int) -> bool: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def moveSplitter(self, pos: int, index: int) -> None: ...
    def opaqueResize(self) -> bool: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def refresh(self) -> None: ...
    def replaceWidget(self, index: int, widget: QWidget) -> QWidget: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def restoreState(self, state: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> bool: ...
    def saveState(self) -> PySide2.QtCore.QByteArray: ...
    def setChildrenCollapsible(self, arg__1: bool) -> None: ...
    def setCollapsible(self, index: int, arg__2: bool) -> None: ...
    def setHandleWidth(self, arg__1: int) -> None: ...
    def setOpaqueResize(self, opaque: bool = ...) -> None: ...
    def setOrientation(self, arg__1: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setRubberBand(self, position: int) -> None: ...
    def setSizes(self, list: typing.Iterable[int]) -> None: ...
    def setStretchFactor(self, index: int, stretch: int) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sizes(self) -> typing.List[int]: ...
    def widget(self, index: int) -> QWidget: ...
    def __lshift__(self, arg__1: PySide2.QtCore.QTextStream) -> PySide2.QtCore.QTextStream: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, arg__1: PySide2.QtCore.QTextStream) -> PySide2.QtCore.QTextStream: ...

class QSplitterHandle(QWidget):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, o: PySide2.QtCore.Qt.Orientation, parent: QSplitter, acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def closestLegalPosition(self, p: int) -> int: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveSplitter(self, p: int) -> None: ...
    def opaqueResize(self) -> bool: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def setOrientation(self, o: PySide2.QtCore.Qt.Orientation) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def splitter(self) -> QSplitter: ...

class QStackedLayout(QLayout):
    class StackingMode:
        StackAll: typing.ClassVar[QStackedLayout.StackingMode] = ...
        StackOne: typing.ClassVar[QStackedLayout.StackingMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __and__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QStackedLayout.StackingMode: ...
    StackAll: typing.ClassVar[QStackedLayout.StackingMode] = ...
    StackOne: typing.ClassVar[QStackedLayout.StackingMode] = ...
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    widgetRemoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, parentLayout: QLayout, currentChanged: typing.Callable = ..., currentIndex: int = ..., destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QStackedLayout.SizeConstraint = ..., spacing: int = ..., stackingMode: QStackedLayout.StackingMode = ..., widgetRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], currentChanged: typing.Callable = ..., currentIndex: int = ..., destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QStackedLayout.SizeConstraint = ..., spacing: int = ..., stackingMode: QStackedLayout.StackingMode = ..., widgetRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, currentChanged: typing.Callable = ..., currentIndex: int = ..., destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QStackedLayout.SizeConstraint = ..., spacing: int = ..., stackingMode: QStackedLayout.StackingMode = ..., widgetRemoved: typing.Callable = ...) -> None: ...
    def addItem(self, item: QLayoutItem) -> None: ...
    def addWidget(self, w: QWidget) -> int: ...
    def count(self) -> int: ...
    def currentIndex(self) -> int: ...
    def currentWidget(self) -> QWidget: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, width: int) -> int: ...
    def insertWidget(self, index: int, w: QWidget) -> int: ...
    def itemAt(self, arg__1: int) -> QLayoutItem: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentWidget(self, w: QWidget) -> None: ...
    def setGeometry(self, rect: PySide2.QtCore.QRect) -> None: ...
    def setStackingMode(self, stackingMode: QStackedLayout.StackingMode) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def stackingMode(self) -> QStackedLayout.StackingMode: ...
    def takeAt(self, arg__1: int) -> QLayoutItem: ...
    @typing.overload
    def widget(self, arg__1: int) -> QWidget: ...
    @typing.overload
    def widget(self) -> QWidget: ...

class QStackedWidget(QFrame):
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    widgetRemoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentChanged: typing.Callable = ..., currentIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QStackedWidget.Shadow = ..., frameShape: QStackedWidget.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., widgetRemoved: typing.Callable = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def addWidget(self, w: QWidget) -> int: ...
    def count(self) -> int: ...
    def currentIndex(self) -> int: ...
    def currentWidget(self) -> QWidget: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def indexOf(self, arg__1: QWidget) -> int: ...
    def insertWidget(self, index: int, w: QWidget) -> int: ...
    def removeWidget(self, w: QWidget) -> None: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentWidget(self, w: QWidget) -> None: ...
    def widget(self, arg__1: int) -> QWidget: ...

class QStatusBar(QWidget):
    messageChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., messageChanged: typing.Callable = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def addPermanentWidget(self, widget: QWidget, stretch: int = ...) -> None: ...
    def addWidget(self, widget: QWidget, stretch: int = ...) -> None: ...
    def clearMessage(self) -> None: ...
    def currentMessage(self) -> str: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def hideOrShow(self) -> None: ...
    def insertPermanentWidget(self, index: int, widget: QWidget, stretch: int = ...) -> int: ...
    def insertWidget(self, index: int, widget: QWidget, stretch: int = ...) -> int: ...
    def isSizeGripEnabled(self) -> bool: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def reformat(self) -> None: ...
    def removeWidget(self, widget: QWidget) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def setSizeGripEnabled(self, arg__1: bool) -> None: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def showMessage(self, text: str, timeout: int = ...) -> None: ...

class QStyle(PySide2.QtCore.QObject):
    class ComplexControl:
        CC_ComboBox: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_CustomBase: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_Dial: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_GroupBox: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_MdiControls: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_ScrollBar: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_Slider: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_SpinBox: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_TitleBar: typing.ClassVar[QStyle.ComplexControl] = ...
        CC_ToolButton: typing.ClassVar[QStyle.ComplexControl] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.ComplexControl: ...

    class ContentsType:
        CT_CheckBox: typing.ClassVar[QStyle.ContentsType] = ...
        CT_ComboBox: typing.ClassVar[QStyle.ContentsType] = ...
        CT_CustomBase: typing.ClassVar[QStyle.ContentsType] = ...
        CT_DialogButtons: typing.ClassVar[QStyle.ContentsType] = ...
        CT_GroupBox: typing.ClassVar[QStyle.ContentsType] = ...
        CT_HeaderSection: typing.ClassVar[QStyle.ContentsType] = ...
        CT_ItemViewItem: typing.ClassVar[QStyle.ContentsType] = ...
        CT_LineEdit: typing.ClassVar[QStyle.ContentsType] = ...
        CT_MdiControls: typing.ClassVar[QStyle.ContentsType] = ...
        CT_Menu: typing.ClassVar[QStyle.ContentsType] = ...
        CT_MenuBar: typing.ClassVar[QStyle.ContentsType] = ...
        CT_MenuBarItem: typing.ClassVar[QStyle.ContentsType] = ...
        CT_MenuItem: typing.ClassVar[QStyle.ContentsType] = ...
        CT_ProgressBar: typing.ClassVar[QStyle.ContentsType] = ...
        CT_PushButton: typing.ClassVar[QStyle.ContentsType] = ...
        CT_RadioButton: typing.ClassVar[QStyle.ContentsType] = ...
        CT_ScrollBar: typing.ClassVar[QStyle.ContentsType] = ...
        CT_SizeGrip: typing.ClassVar[QStyle.ContentsType] = ...
        CT_Slider: typing.ClassVar[QStyle.ContentsType] = ...
        CT_SpinBox: typing.ClassVar[QStyle.ContentsType] = ...
        CT_Splitter: typing.ClassVar[QStyle.ContentsType] = ...
        CT_TabBarTab: typing.ClassVar[QStyle.ContentsType] = ...
        CT_TabWidget: typing.ClassVar[QStyle.ContentsType] = ...
        CT_ToolButton: typing.ClassVar[QStyle.ContentsType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.ContentsType: ...

    class ControlElement:
        CE_CheckBox: typing.ClassVar[QStyle.ControlElement] = ...
        CE_CheckBoxLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ColumnViewGrip: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ComboBoxLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_CustomBase: typing.ClassVar[QStyle.ControlElement] = ...
        CE_DockWidgetTitle: typing.ClassVar[QStyle.ControlElement] = ...
        CE_FocusFrame: typing.ClassVar[QStyle.ControlElement] = ...
        CE_Header: typing.ClassVar[QStyle.ControlElement] = ...
        CE_HeaderEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
        CE_HeaderLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_HeaderSection: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ItemViewItem: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuBarEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuBarItem: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuHMargin: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuItem: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuScroller: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuTearoff: typing.ClassVar[QStyle.ControlElement] = ...
        CE_MenuVMargin: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ProgressBar: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ProgressBarContents: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ProgressBarGroove: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ProgressBarLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_PushButton: typing.ClassVar[QStyle.ControlElement] = ...
        CE_PushButtonBevel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_PushButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_RadioButton: typing.ClassVar[QStyle.ControlElement] = ...
        CE_RadioButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_RubberBand: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarAddLine: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarAddPage: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarFirst: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarLast: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarSlider: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarSubLine: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ScrollBarSubPage: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ShapedFrame: typing.ClassVar[QStyle.ControlElement] = ...
        CE_SizeGrip: typing.ClassVar[QStyle.ControlElement] = ...
        CE_Splitter: typing.ClassVar[QStyle.ControlElement] = ...
        CE_TabBarTab: typing.ClassVar[QStyle.ControlElement] = ...
        CE_TabBarTabLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_TabBarTabShape: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ToolBar: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ToolBoxTab: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ToolBoxTabLabel: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ToolBoxTabShape: typing.ClassVar[QStyle.ControlElement] = ...
        CE_ToolButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.ControlElement: ...

    class PixelMetric:
        PM_ButtonDefaultIndicator: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ButtonIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ButtonMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ButtonShiftHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ButtonShiftVertical: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_CheckBoxLabelSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ComboBoxFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_CustomBase: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DefaultChildMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DefaultFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DefaultLayoutSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DefaultTopLevelMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DialogButtonsButtonHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DialogButtonsButtonWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DialogButtonsSeparator: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DockWidgetFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DockWidgetHandleExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DockWidgetSeparatorExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DockWidgetTitleBarButtonMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_DockWidgetTitleMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ExclusiveIndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ExclusiveIndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_FocusFrameHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_FocusFrameVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_HeaderDefaultSectionSizeHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_HeaderDefaultSectionSizeVertical: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_HeaderGripMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_HeaderMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_HeaderMarkSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_IconViewIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_IndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_IndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LargeIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutBottomMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutHorizontalSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutLeftMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutRightMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutTopMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_LayoutVerticalSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ListViewIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MDIFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MDIMinimizedWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MaximumDragDistance: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MdiSubWindowFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MdiSubWindowMinimizedWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuBarHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuBarItemSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuBarPanelWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuBarVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuButtonIndicator: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuDesktopFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuPanelWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuScrollerHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuTearoffHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MenuVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_MessageBoxIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ProgressBarChunkWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_RadioButtonLabelSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ScrollBarExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ScrollBarSliderMin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ScrollView_ScrollBarOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ScrollView_ScrollBarSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SizeGripSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SliderControlThickness: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SliderLength: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SliderSpaceAvailable: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SliderThickness: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SliderTickmarkOffset: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SmallIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SpinBoxFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SpinBoxSliderHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SplitterWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_SubMenuOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarBaseHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarBaseOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarScrollButtonWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarTabHSpace: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarTabOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarTabShiftHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarTabShiftVertical: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBarTabVSpace: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabBar_ScrollButtonOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabCloseIndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TabCloseIndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TextCursorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TitleBarButtonIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TitleBarButtonSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TitleBarHeight: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarExtensionExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarHandleExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarItemMargin: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarItemSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolBarSeparatorExtent: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_ToolTipLabelFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
        PM_TreeViewIndentation: typing.ClassVar[QStyle.PixelMetric] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.PixelMetric: ...

    class PrimitiveElement:
        PE_CustomBase: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_Frame: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameButtonBevel: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameButtonTool: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameDefaultButton: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameDockWidget: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameFocusRect: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameGroupBox: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameLineEdit: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameMenu: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameStatusBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameStatusBarItem: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameTabBarBase: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameTabWidget: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_FrameWindow: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorArrowDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorArrowLeft: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorArrowRight: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorArrowUp: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorBranch: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorButtonDropDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorCheckBox: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorColumnViewArrow: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorDockWidgetResizeHandle: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorHeaderArrow: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorItemViewItemCheck: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorItemViewItemDrop: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorMenuCheckMark: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorProgressChunk: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorRadioButton: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorSpinDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorSpinMinus: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorSpinPlus: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorSpinUp: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorTabClose: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorTabTear: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorTabTearLeft: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorTabTearRight: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorToolBarHandle: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorToolBarSeparator: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_IndicatorViewItemCheck: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelButtonBevel: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelButtonCommand: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelButtonTool: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelItemViewItem: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelItemViewRow: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelLineEdit: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelMenu: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelMenuBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelScrollAreaCorner: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelStatusBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelTipLabel: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_PanelToolBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
        PE_Widget: typing.ClassVar[QStyle.PrimitiveElement] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.PrimitiveElement: ...

    class RequestSoftwareInputPanel:
        RSIP_OnMouseClick: typing.ClassVar[QStyle.RequestSoftwareInputPanel] = ...
        RSIP_OnMouseClickAndAlreadyFocused: typing.ClassVar[QStyle.RequestSoftwareInputPanel] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.RequestSoftwareInputPanel: ...

    class StandardPixmap:
        SP_ArrowBack: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ArrowDown: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ArrowForward: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ArrowLeft: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ArrowRight: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ArrowUp: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_BrowserReload: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_BrowserStop: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_CommandLink: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ComputerIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_CustomBase: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DesktopIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogAbortButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogApplyButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogCancelButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogDiscardButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogHelpButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogIgnoreButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogNoButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogNoToAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogOkButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogOpenButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogResetButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogRetryButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogSaveAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogSaveButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogYesButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DialogYesToAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirClosedIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirHomeIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirLinkIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirLinkOpenIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DirOpenIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DockWidgetCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DriveCDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DriveDVDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DriveFDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DriveHDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_DriveNetIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogBack: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogContentsView: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogDetailedView: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogEnd: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogInfoView: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogListView: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogNewFolder: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogStart: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileDialogToParent: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_FileLinkIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_LineEditClearButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaPause: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaPlay: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaSeekBackward: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaSeekForward: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaSkipBackward: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaSkipForward: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaStop: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaVolume: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MediaVolumeMuted: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MessageBoxCritical: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MessageBoxInformation: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MessageBoxQuestion: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_MessageBoxWarning: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_RestoreDefaultsButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarContextHelpButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarMaxButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarMenuButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarMinButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarNormalButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarShadeButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TitleBarUnshadeButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ToolBarHorizontalExtensionButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_ToolBarVerticalExtensionButton: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_TrashIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
        SP_VistaShield: typing.ClassVar[QStyle.StandardPixmap] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.StandardPixmap: ...

    class State:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyle.State: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.State: ...

    class StateFlag:
        State_Active: typing.ClassVar[QStyle.StateFlag] = ...
        State_AutoRaise: typing.ClassVar[QStyle.StateFlag] = ...
        State_Bottom: typing.ClassVar[QStyle.StateFlag] = ...
        State_Children: typing.ClassVar[QStyle.StateFlag] = ...
        State_DownArrow: typing.ClassVar[QStyle.StateFlag] = ...
        State_Editing: typing.ClassVar[QStyle.StateFlag] = ...
        State_Enabled: typing.ClassVar[QStyle.StateFlag] = ...
        State_FocusAtBorder: typing.ClassVar[QStyle.StateFlag] = ...
        State_HasFocus: typing.ClassVar[QStyle.StateFlag] = ...
        State_Horizontal: typing.ClassVar[QStyle.StateFlag] = ...
        State_Item: typing.ClassVar[QStyle.StateFlag] = ...
        State_KeyboardFocusChange: typing.ClassVar[QStyle.StateFlag] = ...
        State_Mini: typing.ClassVar[QStyle.StateFlag] = ...
        State_MouseOver: typing.ClassVar[QStyle.StateFlag] = ...
        State_NoChange: typing.ClassVar[QStyle.StateFlag] = ...
        State_None: typing.ClassVar[QStyle.StateFlag] = ...
        State_Off: typing.ClassVar[QStyle.StateFlag] = ...
        State_On: typing.ClassVar[QStyle.StateFlag] = ...
        State_Open: typing.ClassVar[QStyle.StateFlag] = ...
        State_Raised: typing.ClassVar[QStyle.StateFlag] = ...
        State_ReadOnly: typing.ClassVar[QStyle.StateFlag] = ...
        State_Selected: typing.ClassVar[QStyle.StateFlag] = ...
        State_Sibling: typing.ClassVar[QStyle.StateFlag] = ...
        State_Small: typing.ClassVar[QStyle.StateFlag] = ...
        State_Sunken: typing.ClassVar[QStyle.StateFlag] = ...
        State_Top: typing.ClassVar[QStyle.StateFlag] = ...
        State_UpArrow: typing.ClassVar[QStyle.StateFlag] = ...
        State_Window: typing.ClassVar[QStyle.StateFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyle.State: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.State: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.State: ...

    class StyleHint:
        SH_BlinkCursorWhenTextSelected: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Button_FocusPolicy: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_AllowWheelScrolling: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_LayoutDirection: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_ListMouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_Popup: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_PopupFrameStyle: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ComboBox_UseNativePopup: typing.ClassVar[QStyle.StyleHint] = ...
        SH_CustomBase: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Dial_BackgroundRole: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DialogButtonBox_ButtonsHaveIcons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DialogButtonLayout: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DialogButtons_DefaultButton: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DitherDisabledText: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DockWidget_ButtonsHaveFrame: typing.ClassVar[QStyle.StyleHint] = ...
        SH_DrawMenuBarSeparator: typing.ClassVar[QStyle.StyleHint] = ...
        SH_EtchDisabledText: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FocusFrame_AboveWidget: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FocusFrame_Mask: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FontDialog_SelectAssociatedText: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FormLayoutFieldGrowthPolicy: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FormLayoutFormAlignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FormLayoutLabelAlignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_FormLayoutWrapPolicy: typing.ClassVar[QStyle.StyleHint] = ...
        SH_GroupBox_TextLabelColor: typing.ClassVar[QStyle.StyleHint] = ...
        SH_GroupBox_TextLabelVerticalAlignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Header_ArrowAlignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_ActivateItemOnSingleClick: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_ArrowKeysNavigateIntoChildren: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_ChangeHighlightOnFocus: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_DrawDelegateFrame: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_EllipsisLocation: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_MovementWithoutUpdatingSelection: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_PaintAlternatingRowColorsForEmptyArea: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_ScrollMode: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ItemView_ShowDecorationSelected: typing.ClassVar[QStyle.StyleHint] = ...
        SH_LineEdit_PasswordCharacter: typing.ClassVar[QStyle.StyleHint] = ...
        SH_LineEdit_PasswordMaskDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ListViewExpand_SelectMouseType: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MainWindow_SpaceBelowMenuBar: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MenuBar_AltKeyNavigation: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MenuBar_MouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_AllowActiveAndDisabled: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_FadeOutOnHide: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_FillScreenWithScroll: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_FlashTriggeredItem: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_KeyboardSearch: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_Mask: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_MouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_Scrollable: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SelectionWrap: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SloppySubMenus: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SpaceActivatesItem: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuDontStartSloppyOnLeave: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuPopupDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuResetWhenReenteringParent: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuSloppyCloseTimeout: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuSloppySelectOtherActions: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuUniDirection: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SubMenuUniDirectionFailCount: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Menu_SupportsSections: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MessageBox_CenterButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MessageBox_TextInteractionFlags: typing.ClassVar[QStyle.StyleHint] = ...
        SH_MessageBox_UseBorderForButtonSpacing: typing.ClassVar[QStyle.StyleHint] = ...
        SH_PrintDialog_RightAlignButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ProgressDialog_CenterCancelButton: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ProgressDialog_TextLabelAlignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_RequestSoftwareInputPanel: typing.ClassVar[QStyle.StyleHint] = ...
        SH_RichText_FullWidthSelection: typing.ClassVar[QStyle.StyleHint] = ...
        SH_RubberBand_Mask: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_ContextMenu: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_LeftClickAbsolutePosition: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_MiddleClickAbsolutePosition: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_RollBetweenButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_ScrollWhenPointerLeavesControl: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_StopMouseOverSlider: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollBar_Transient: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ScrollView_FrameOnlyAroundContents: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Slider_AbsoluteSetButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Slider_PageSetButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Slider_SloppyKeyEvents: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Slider_SnapToValue: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Slider_StopMouseOverSlider: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpellCheckUnderlineStyle: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_AnimateButton: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_ButtonsInsideFrame: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_ClickAutoRepeatRate: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_ClickAutoRepeatThreshold: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_KeyPressAutoRepeatRate: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinBox_StepModifier: typing.ClassVar[QStyle.StyleHint] = ...
        SH_SpinControls_DisableOnBounds: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Splitter_OpaqueResize: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_Alignment: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_ChangeCurrentDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_CloseButtonPosition: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_ElideMode: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_PreferNoArrows: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabBar_SelectMouseType: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TabWidget_DefaultTabPosition: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Table_GridLineColor: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TextControl_FocusIndicatorTextCharFormat: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TitleBar_AutoRaise: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TitleBar_ModifyNotification: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TitleBar_NoBorder: typing.ClassVar[QStyle.StyleHint] = ...
        SH_TitleBar_ShowToolTipsOnButtons: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolBar_Movable: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolBox_SelectedPageTitleBold: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolButtonStyle: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolButton_PopupDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolTipLabel_Opacity: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolTip_FallAsleepDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolTip_Mask: typing.ClassVar[QStyle.StyleHint] = ...
        SH_ToolTip_WakeUpDelay: typing.ClassVar[QStyle.StyleHint] = ...
        SH_UnderlineShortcut: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Widget_Animate: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Widget_Animation_Duration: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Widget_ShareActivation: typing.ClassVar[QStyle.StyleHint] = ...
        SH_WindowFrame_Mask: typing.ClassVar[QStyle.StyleHint] = ...
        SH_WizardStyle: typing.ClassVar[QStyle.StyleHint] = ...
        SH_Workspace_FillSpaceOnMaximize: typing.ClassVar[QStyle.StyleHint] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.StyleHint: ...

    class SubControl:
        SC_All: typing.ClassVar[QStyle.SubControl] = ...
        SC_ComboBoxArrow: typing.ClassVar[QStyle.SubControl] = ...
        SC_ComboBoxEditField: typing.ClassVar[QStyle.SubControl] = ...
        SC_ComboBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
        SC_ComboBoxListBoxPopup: typing.ClassVar[QStyle.SubControl] = ...
        SC_CustomBase: typing.ClassVar[QStyle.SubControl] = ...
        SC_DialGroove: typing.ClassVar[QStyle.SubControl] = ...
        SC_DialHandle: typing.ClassVar[QStyle.SubControl] = ...
        SC_DialTickmarks: typing.ClassVar[QStyle.SubControl] = ...
        SC_GroupBoxCheckBox: typing.ClassVar[QStyle.SubControl] = ...
        SC_GroupBoxContents: typing.ClassVar[QStyle.SubControl] = ...
        SC_GroupBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
        SC_GroupBoxLabel: typing.ClassVar[QStyle.SubControl] = ...
        SC_MdiCloseButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_MdiMinButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_MdiNormalButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_None: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarAddLine: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarAddPage: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarFirst: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarGroove: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarLast: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarSlider: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarSubLine: typing.ClassVar[QStyle.SubControl] = ...
        SC_ScrollBarSubPage: typing.ClassVar[QStyle.SubControl] = ...
        SC_SliderGroove: typing.ClassVar[QStyle.SubControl] = ...
        SC_SliderHandle: typing.ClassVar[QStyle.SubControl] = ...
        SC_SliderTickmarks: typing.ClassVar[QStyle.SubControl] = ...
        SC_SpinBoxDown: typing.ClassVar[QStyle.SubControl] = ...
        SC_SpinBoxEditField: typing.ClassVar[QStyle.SubControl] = ...
        SC_SpinBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
        SC_SpinBoxUp: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarCloseButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarContextHelpButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarLabel: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarMaxButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarMinButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarNormalButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarShadeButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarSysMenu: typing.ClassVar[QStyle.SubControl] = ...
        SC_TitleBarUnshadeButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_ToolButton: typing.ClassVar[QStyle.SubControl] = ...
        SC_ToolButtonMenu: typing.ClassVar[QStyle.SubControl] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyle.SubControls: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...

    class SubControls:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyle.SubControls: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.SubControls: ...

    class SubElement:
        SE_CheckBoxClickRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_CheckBoxContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_CheckBoxFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_CheckBoxIndicator: typing.ClassVar[QStyle.SubElement] = ...
        SE_CheckBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_ComboBoxFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_ComboBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_CustomBase: typing.ClassVar[QStyle.SubElement] = ...
        SE_DateTimeEditLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_DialogButtonBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_DockWidgetCloseButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_DockWidgetFloatButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_DockWidgetIcon: typing.ClassVar[QStyle.SubElement] = ...
        SE_DockWidgetTitleBarText: typing.ClassVar[QStyle.SubElement] = ...
        SE_FrameContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_FrameLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_GroupBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_HeaderArrow: typing.ClassVar[QStyle.SubElement] = ...
        SE_HeaderLabel: typing.ClassVar[QStyle.SubElement] = ...
        SE_ItemViewItemCheckIndicator: typing.ClassVar[QStyle.SubElement] = ...
        SE_ItemViewItemDecoration: typing.ClassVar[QStyle.SubElement] = ...
        SE_ItemViewItemFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_ItemViewItemText: typing.ClassVar[QStyle.SubElement] = ...
        SE_LabelLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_LineEditContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_ProgressBarContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_ProgressBarGroove: typing.ClassVar[QStyle.SubElement] = ...
        SE_ProgressBarLabel: typing.ClassVar[QStyle.SubElement] = ...
        SE_ProgressBarLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_PushButtonBevel: typing.ClassVar[QStyle.SubElement] = ...
        SE_PushButtonContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_PushButtonFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_PushButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_RadioButtonClickRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_RadioButtonContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_RadioButtonFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_RadioButtonIndicator: typing.ClassVar[QStyle.SubElement] = ...
        SE_RadioButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_ShapedFrameContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_SliderFocusRect: typing.ClassVar[QStyle.SubElement] = ...
        SE_SliderLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_SpinBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarScrollLeftButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarScrollRightButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTabLeftButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTabRightButton: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTabText: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTearIndicator: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTearIndicatorLeft: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabBarTearIndicatorRight: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetLeftCorner: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetRightCorner: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetTabBar: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetTabContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_TabWidgetTabPane: typing.ClassVar[QStyle.SubElement] = ...
        SE_ToolBarHandle: typing.ClassVar[QStyle.SubElement] = ...
        SE_ToolBoxTabContents: typing.ClassVar[QStyle.SubElement] = ...
        SE_ToolButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_TreeViewDisclosureItem: typing.ClassVar[QStyle.SubElement] = ...
        SE_ViewItemCheckIndicator: typing.ClassVar[QStyle.SubElement] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __and__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyle.SubElement: ...
    CC_ComboBox: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_CustomBase: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_Dial: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_GroupBox: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_MdiControls: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_ScrollBar: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_Slider: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_SpinBox: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_TitleBar: typing.ClassVar[QStyle.ComplexControl] = ...
    CC_ToolButton: typing.ClassVar[QStyle.ComplexControl] = ...
    CE_CheckBox: typing.ClassVar[QStyle.ControlElement] = ...
    CE_CheckBoxLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ColumnViewGrip: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ComboBoxLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_CustomBase: typing.ClassVar[QStyle.ControlElement] = ...
    CE_DockWidgetTitle: typing.ClassVar[QStyle.ControlElement] = ...
    CE_FocusFrame: typing.ClassVar[QStyle.ControlElement] = ...
    CE_Header: typing.ClassVar[QStyle.ControlElement] = ...
    CE_HeaderEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
    CE_HeaderLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_HeaderSection: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ItemViewItem: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuBarEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuBarItem: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuEmptyArea: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuHMargin: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuItem: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuScroller: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuTearoff: typing.ClassVar[QStyle.ControlElement] = ...
    CE_MenuVMargin: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ProgressBar: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ProgressBarContents: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ProgressBarGroove: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ProgressBarLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_PushButton: typing.ClassVar[QStyle.ControlElement] = ...
    CE_PushButtonBevel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_PushButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_RadioButton: typing.ClassVar[QStyle.ControlElement] = ...
    CE_RadioButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_RubberBand: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarAddLine: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarAddPage: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarFirst: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarLast: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarSlider: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarSubLine: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ScrollBarSubPage: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ShapedFrame: typing.ClassVar[QStyle.ControlElement] = ...
    CE_SizeGrip: typing.ClassVar[QStyle.ControlElement] = ...
    CE_Splitter: typing.ClassVar[QStyle.ControlElement] = ...
    CE_TabBarTab: typing.ClassVar[QStyle.ControlElement] = ...
    CE_TabBarTabLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_TabBarTabShape: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ToolBar: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ToolBoxTab: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ToolBoxTabLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ToolBoxTabShape: typing.ClassVar[QStyle.ControlElement] = ...
    CE_ToolButtonLabel: typing.ClassVar[QStyle.ControlElement] = ...
    CT_CheckBox: typing.ClassVar[QStyle.ContentsType] = ...
    CT_ComboBox: typing.ClassVar[QStyle.ContentsType] = ...
    CT_CustomBase: typing.ClassVar[QStyle.ContentsType] = ...
    CT_DialogButtons: typing.ClassVar[QStyle.ContentsType] = ...
    CT_GroupBox: typing.ClassVar[QStyle.ContentsType] = ...
    CT_HeaderSection: typing.ClassVar[QStyle.ContentsType] = ...
    CT_ItemViewItem: typing.ClassVar[QStyle.ContentsType] = ...
    CT_LineEdit: typing.ClassVar[QStyle.ContentsType] = ...
    CT_MdiControls: typing.ClassVar[QStyle.ContentsType] = ...
    CT_Menu: typing.ClassVar[QStyle.ContentsType] = ...
    CT_MenuBar: typing.ClassVar[QStyle.ContentsType] = ...
    CT_MenuBarItem: typing.ClassVar[QStyle.ContentsType] = ...
    CT_MenuItem: typing.ClassVar[QStyle.ContentsType] = ...
    CT_ProgressBar: typing.ClassVar[QStyle.ContentsType] = ...
    CT_PushButton: typing.ClassVar[QStyle.ContentsType] = ...
    CT_RadioButton: typing.ClassVar[QStyle.ContentsType] = ...
    CT_ScrollBar: typing.ClassVar[QStyle.ContentsType] = ...
    CT_SizeGrip: typing.ClassVar[QStyle.ContentsType] = ...
    CT_Slider: typing.ClassVar[QStyle.ContentsType] = ...
    CT_SpinBox: typing.ClassVar[QStyle.ContentsType] = ...
    CT_Splitter: typing.ClassVar[QStyle.ContentsType] = ...
    CT_TabBarTab: typing.ClassVar[QStyle.ContentsType] = ...
    CT_TabWidget: typing.ClassVar[QStyle.ContentsType] = ...
    CT_ToolButton: typing.ClassVar[QStyle.ContentsType] = ...
    PE_CustomBase: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_Frame: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameButtonBevel: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameButtonTool: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameDefaultButton: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameDockWidget: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameFocusRect: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameGroupBox: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameLineEdit: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameMenu: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameStatusBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameStatusBarItem: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameTabBarBase: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameTabWidget: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_FrameWindow: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorArrowDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorArrowLeft: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorArrowRight: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorArrowUp: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorBranch: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorButtonDropDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorCheckBox: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorColumnViewArrow: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorDockWidgetResizeHandle: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorHeaderArrow: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorItemViewItemCheck: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorItemViewItemDrop: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorMenuCheckMark: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorProgressChunk: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorRadioButton: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorSpinDown: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorSpinMinus: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorSpinPlus: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorSpinUp: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorTabClose: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorTabTear: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorTabTearLeft: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorTabTearRight: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorToolBarHandle: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorToolBarSeparator: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_IndicatorViewItemCheck: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelButtonBevel: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelButtonCommand: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelButtonTool: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelItemViewItem: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelItemViewRow: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelLineEdit: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelMenu: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelMenuBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelScrollAreaCorner: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelStatusBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelTipLabel: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_PanelToolBar: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PE_Widget: typing.ClassVar[QStyle.PrimitiveElement] = ...
    PM_ButtonDefaultIndicator: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ButtonIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ButtonMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ButtonShiftHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ButtonShiftVertical: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_CheckBoxLabelSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ComboBoxFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_CustomBase: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DefaultChildMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DefaultFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DefaultLayoutSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DefaultTopLevelMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DialogButtonsButtonHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DialogButtonsButtonWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DialogButtonsSeparator: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DockWidgetFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DockWidgetHandleExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DockWidgetSeparatorExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DockWidgetTitleBarButtonMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_DockWidgetTitleMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ExclusiveIndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ExclusiveIndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_FocusFrameHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_FocusFrameVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_HeaderDefaultSectionSizeHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_HeaderDefaultSectionSizeVertical: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_HeaderGripMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_HeaderMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_HeaderMarkSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_IconViewIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_IndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_IndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LargeIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutBottomMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutHorizontalSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutLeftMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutRightMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutTopMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_LayoutVerticalSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ListViewIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MDIFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MDIMinimizedWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MaximumDragDistance: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MdiSubWindowFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MdiSubWindowMinimizedWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuBarHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuBarItemSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuBarPanelWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuBarVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuButtonIndicator: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuDesktopFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuHMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuPanelWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuScrollerHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuTearoffHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MenuVMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_MessageBoxIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ProgressBarChunkWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_RadioButtonLabelSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ScrollBarExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ScrollBarSliderMin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ScrollView_ScrollBarOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ScrollView_ScrollBarSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SizeGripSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SliderControlThickness: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SliderLength: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SliderSpaceAvailable: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SliderThickness: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SliderTickmarkOffset: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SmallIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SpinBoxFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SpinBoxSliderHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SplitterWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_SubMenuOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarBaseHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarBaseOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarScrollButtonWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarTabHSpace: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarTabOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarTabShiftHorizontal: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarTabShiftVertical: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBarTabVSpace: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabBar_ScrollButtonOverlap: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabCloseIndicatorHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TabCloseIndicatorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TextCursorWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TitleBarButtonIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TitleBarButtonSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TitleBarHeight: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarExtensionExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarHandleExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarIconSize: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarItemMargin: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarItemSpacing: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolBarSeparatorExtent: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_ToolTipLabelFrameWidth: typing.ClassVar[QStyle.PixelMetric] = ...
    PM_TreeViewIndentation: typing.ClassVar[QStyle.PixelMetric] = ...
    RSIP_OnMouseClick: typing.ClassVar[QStyle.RequestSoftwareInputPanel] = ...
    RSIP_OnMouseClickAndAlreadyFocused: typing.ClassVar[QStyle.RequestSoftwareInputPanel] = ...
    SC_All: typing.ClassVar[QStyle.SubControl] = ...
    SC_ComboBoxArrow: typing.ClassVar[QStyle.SubControl] = ...
    SC_ComboBoxEditField: typing.ClassVar[QStyle.SubControl] = ...
    SC_ComboBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
    SC_ComboBoxListBoxPopup: typing.ClassVar[QStyle.SubControl] = ...
    SC_CustomBase: typing.ClassVar[QStyle.SubControl] = ...
    SC_DialGroove: typing.ClassVar[QStyle.SubControl] = ...
    SC_DialHandle: typing.ClassVar[QStyle.SubControl] = ...
    SC_DialTickmarks: typing.ClassVar[QStyle.SubControl] = ...
    SC_GroupBoxCheckBox: typing.ClassVar[QStyle.SubControl] = ...
    SC_GroupBoxContents: typing.ClassVar[QStyle.SubControl] = ...
    SC_GroupBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
    SC_GroupBoxLabel: typing.ClassVar[QStyle.SubControl] = ...
    SC_MdiCloseButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_MdiMinButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_MdiNormalButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_None: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarAddLine: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarAddPage: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarFirst: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarGroove: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarLast: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarSlider: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarSubLine: typing.ClassVar[QStyle.SubControl] = ...
    SC_ScrollBarSubPage: typing.ClassVar[QStyle.SubControl] = ...
    SC_SliderGroove: typing.ClassVar[QStyle.SubControl] = ...
    SC_SliderHandle: typing.ClassVar[QStyle.SubControl] = ...
    SC_SliderTickmarks: typing.ClassVar[QStyle.SubControl] = ...
    SC_SpinBoxDown: typing.ClassVar[QStyle.SubControl] = ...
    SC_SpinBoxEditField: typing.ClassVar[QStyle.SubControl] = ...
    SC_SpinBoxFrame: typing.ClassVar[QStyle.SubControl] = ...
    SC_SpinBoxUp: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarCloseButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarContextHelpButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarLabel: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarMaxButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarMinButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarNormalButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarShadeButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarSysMenu: typing.ClassVar[QStyle.SubControl] = ...
    SC_TitleBarUnshadeButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_ToolButton: typing.ClassVar[QStyle.SubControl] = ...
    SC_ToolButtonMenu: typing.ClassVar[QStyle.SubControl] = ...
    SE_CheckBoxClickRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_CheckBoxContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_CheckBoxFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_CheckBoxIndicator: typing.ClassVar[QStyle.SubElement] = ...
    SE_CheckBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_ComboBoxFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_ComboBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_CustomBase: typing.ClassVar[QStyle.SubElement] = ...
    SE_DateTimeEditLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_DialogButtonBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_DockWidgetCloseButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_DockWidgetFloatButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_DockWidgetIcon: typing.ClassVar[QStyle.SubElement] = ...
    SE_DockWidgetTitleBarText: typing.ClassVar[QStyle.SubElement] = ...
    SE_FrameContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_FrameLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_GroupBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_HeaderArrow: typing.ClassVar[QStyle.SubElement] = ...
    SE_HeaderLabel: typing.ClassVar[QStyle.SubElement] = ...
    SE_ItemViewItemCheckIndicator: typing.ClassVar[QStyle.SubElement] = ...
    SE_ItemViewItemDecoration: typing.ClassVar[QStyle.SubElement] = ...
    SE_ItemViewItemFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_ItemViewItemText: typing.ClassVar[QStyle.SubElement] = ...
    SE_LabelLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_LineEditContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_ProgressBarContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_ProgressBarGroove: typing.ClassVar[QStyle.SubElement] = ...
    SE_ProgressBarLabel: typing.ClassVar[QStyle.SubElement] = ...
    SE_ProgressBarLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_PushButtonBevel: typing.ClassVar[QStyle.SubElement] = ...
    SE_PushButtonContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_PushButtonFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_PushButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_RadioButtonClickRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_RadioButtonContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_RadioButtonFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_RadioButtonIndicator: typing.ClassVar[QStyle.SubElement] = ...
    SE_RadioButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_ShapedFrameContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_SliderFocusRect: typing.ClassVar[QStyle.SubElement] = ...
    SE_SliderLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_SpinBoxLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarScrollLeftButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarScrollRightButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTabLeftButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTabRightButton: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTabText: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTearIndicator: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTearIndicatorLeft: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabBarTearIndicatorRight: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetLeftCorner: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetRightCorner: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetTabBar: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetTabContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_TabWidgetTabPane: typing.ClassVar[QStyle.SubElement] = ...
    SE_ToolBarHandle: typing.ClassVar[QStyle.SubElement] = ...
    SE_ToolBoxTabContents: typing.ClassVar[QStyle.SubElement] = ...
    SE_ToolButtonLayoutItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_TreeViewDisclosureItem: typing.ClassVar[QStyle.SubElement] = ...
    SE_ViewItemCheckIndicator: typing.ClassVar[QStyle.SubElement] = ...
    SH_BlinkCursorWhenTextSelected: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Button_FocusPolicy: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_AllowWheelScrolling: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_LayoutDirection: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_ListMouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_Popup: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_PopupFrameStyle: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ComboBox_UseNativePopup: typing.ClassVar[QStyle.StyleHint] = ...
    SH_CustomBase: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Dial_BackgroundRole: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DialogButtonBox_ButtonsHaveIcons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DialogButtonLayout: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DialogButtons_DefaultButton: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DitherDisabledText: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DockWidget_ButtonsHaveFrame: typing.ClassVar[QStyle.StyleHint] = ...
    SH_DrawMenuBarSeparator: typing.ClassVar[QStyle.StyleHint] = ...
    SH_EtchDisabledText: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FocusFrame_AboveWidget: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FocusFrame_Mask: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FontDialog_SelectAssociatedText: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FormLayoutFieldGrowthPolicy: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FormLayoutFormAlignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FormLayoutLabelAlignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_FormLayoutWrapPolicy: typing.ClassVar[QStyle.StyleHint] = ...
    SH_GroupBox_TextLabelColor: typing.ClassVar[QStyle.StyleHint] = ...
    SH_GroupBox_TextLabelVerticalAlignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Header_ArrowAlignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_ActivateItemOnSingleClick: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_ArrowKeysNavigateIntoChildren: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_ChangeHighlightOnFocus: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_DrawDelegateFrame: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_EllipsisLocation: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_MovementWithoutUpdatingSelection: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_PaintAlternatingRowColorsForEmptyArea: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_ScrollMode: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ItemView_ShowDecorationSelected: typing.ClassVar[QStyle.StyleHint] = ...
    SH_LineEdit_PasswordCharacter: typing.ClassVar[QStyle.StyleHint] = ...
    SH_LineEdit_PasswordMaskDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ListViewExpand_SelectMouseType: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MainWindow_SpaceBelowMenuBar: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MenuBar_AltKeyNavigation: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MenuBar_MouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_AllowActiveAndDisabled: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_FadeOutOnHide: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_FillScreenWithScroll: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_FlashTriggeredItem: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_KeyboardSearch: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_Mask: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_MouseTracking: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_Scrollable: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SelectionWrap: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SloppySubMenus: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SpaceActivatesItem: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuDontStartSloppyOnLeave: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuPopupDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuResetWhenReenteringParent: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuSloppyCloseTimeout: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuSloppySelectOtherActions: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuUniDirection: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SubMenuUniDirectionFailCount: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Menu_SupportsSections: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MessageBox_CenterButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MessageBox_TextInteractionFlags: typing.ClassVar[QStyle.StyleHint] = ...
    SH_MessageBox_UseBorderForButtonSpacing: typing.ClassVar[QStyle.StyleHint] = ...
    SH_PrintDialog_RightAlignButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ProgressDialog_CenterCancelButton: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ProgressDialog_TextLabelAlignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_RequestSoftwareInputPanel: typing.ClassVar[QStyle.StyleHint] = ...
    SH_RichText_FullWidthSelection: typing.ClassVar[QStyle.StyleHint] = ...
    SH_RubberBand_Mask: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_ContextMenu: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_LeftClickAbsolutePosition: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_MiddleClickAbsolutePosition: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_RollBetweenButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_ScrollWhenPointerLeavesControl: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_StopMouseOverSlider: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollBar_Transient: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ScrollView_FrameOnlyAroundContents: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Slider_AbsoluteSetButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Slider_PageSetButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Slider_SloppyKeyEvents: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Slider_SnapToValue: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Slider_StopMouseOverSlider: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpellCheckUnderlineStyle: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_AnimateButton: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_ButtonsInsideFrame: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_ClickAutoRepeatRate: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_ClickAutoRepeatThreshold: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_KeyPressAutoRepeatRate: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinBox_StepModifier: typing.ClassVar[QStyle.StyleHint] = ...
    SH_SpinControls_DisableOnBounds: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Splitter_OpaqueResize: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_Alignment: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_ChangeCurrentDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_CloseButtonPosition: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_ElideMode: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_PreferNoArrows: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabBar_SelectMouseType: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TabWidget_DefaultTabPosition: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Table_GridLineColor: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TextControl_FocusIndicatorTextCharFormat: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TitleBar_AutoRaise: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TitleBar_ModifyNotification: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TitleBar_NoBorder: typing.ClassVar[QStyle.StyleHint] = ...
    SH_TitleBar_ShowToolTipsOnButtons: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolBar_Movable: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolBox_SelectedPageTitleBold: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolButtonStyle: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolButton_PopupDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolTipLabel_Opacity: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolTip_FallAsleepDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolTip_Mask: typing.ClassVar[QStyle.StyleHint] = ...
    SH_ToolTip_WakeUpDelay: typing.ClassVar[QStyle.StyleHint] = ...
    SH_UnderlineShortcut: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Widget_Animate: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Widget_Animation_Duration: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Widget_ShareActivation: typing.ClassVar[QStyle.StyleHint] = ...
    SH_WindowFrame_Mask: typing.ClassVar[QStyle.StyleHint] = ...
    SH_WizardStyle: typing.ClassVar[QStyle.StyleHint] = ...
    SH_Workspace_FillSpaceOnMaximize: typing.ClassVar[QStyle.StyleHint] = ...
    SP_ArrowBack: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ArrowDown: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ArrowForward: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ArrowLeft: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ArrowRight: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ArrowUp: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_BrowserReload: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_BrowserStop: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_CommandLink: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ComputerIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_CustomBase: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DesktopIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogAbortButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogApplyButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogCancelButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogDiscardButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogHelpButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogIgnoreButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogNoButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogNoToAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogOkButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogOpenButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogResetButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogRetryButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogSaveAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogSaveButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogYesButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DialogYesToAllButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirClosedIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirHomeIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirLinkIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirLinkOpenIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DirOpenIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DockWidgetCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DriveCDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DriveDVDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DriveFDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DriveHDIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_DriveNetIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogBack: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogContentsView: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogDetailedView: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogEnd: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogInfoView: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogListView: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogNewFolder: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogStart: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileDialogToParent: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_FileLinkIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_LineEditClearButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaPause: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaPlay: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaSeekBackward: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaSeekForward: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaSkipBackward: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaSkipForward: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaStop: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaVolume: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MediaVolumeMuted: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MessageBoxCritical: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MessageBoxInformation: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MessageBoxQuestion: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_MessageBoxWarning: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_RestoreDefaultsButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarCloseButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarContextHelpButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarMaxButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarMenuButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarMinButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarNormalButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarShadeButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TitleBarUnshadeButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ToolBarHorizontalExtensionButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_ToolBarVerticalExtensionButton: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_TrashIcon: typing.ClassVar[QStyle.StandardPixmap] = ...
    SP_VistaShield: typing.ClassVar[QStyle.StandardPixmap] = ...
    State_Active: typing.ClassVar[QStyle.StateFlag] = ...
    State_AutoRaise: typing.ClassVar[QStyle.StateFlag] = ...
    State_Bottom: typing.ClassVar[QStyle.StateFlag] = ...
    State_Children: typing.ClassVar[QStyle.StateFlag] = ...
    State_DownArrow: typing.ClassVar[QStyle.StateFlag] = ...
    State_Editing: typing.ClassVar[QStyle.StateFlag] = ...
    State_Enabled: typing.ClassVar[QStyle.StateFlag] = ...
    State_FocusAtBorder: typing.ClassVar[QStyle.StateFlag] = ...
    State_HasFocus: typing.ClassVar[QStyle.StateFlag] = ...
    State_Horizontal: typing.ClassVar[QStyle.StateFlag] = ...
    State_Item: typing.ClassVar[QStyle.StateFlag] = ...
    State_KeyboardFocusChange: typing.ClassVar[QStyle.StateFlag] = ...
    State_Mini: typing.ClassVar[QStyle.StateFlag] = ...
    State_MouseOver: typing.ClassVar[QStyle.StateFlag] = ...
    State_NoChange: typing.ClassVar[QStyle.StateFlag] = ...
    State_None: typing.ClassVar[QStyle.StateFlag] = ...
    State_Off: typing.ClassVar[QStyle.StateFlag] = ...
    State_On: typing.ClassVar[QStyle.StateFlag] = ...
    State_Open: typing.ClassVar[QStyle.StateFlag] = ...
    State_Raised: typing.ClassVar[QStyle.StateFlag] = ...
    State_ReadOnly: typing.ClassVar[QStyle.StateFlag] = ...
    State_Selected: typing.ClassVar[QStyle.StateFlag] = ...
    State_Sibling: typing.ClassVar[QStyle.StateFlag] = ...
    State_Small: typing.ClassVar[QStyle.StateFlag] = ...
    State_Sunken: typing.ClassVar[QStyle.StateFlag] = ...
    State_Top: typing.ClassVar[QStyle.StateFlag] = ...
    State_UpArrow: typing.ClassVar[QStyle.StateFlag] = ...
    State_Window: typing.ClassVar[QStyle.StateFlag] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    @classmethod
    def alignedRect(cls, direction: PySide2.QtCore.Qt.LayoutDirection, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag], size: PySide2.QtCore.QSize, rectangle: PySide2.QtCore.QRect) -> PySide2.QtCore.QRect: ...
    def combinedLayoutSpacing(self, controls1: typing.Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType], controls2: typing.Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType], orientation: PySide2.QtCore.Qt.Orientation, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    def drawComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, p: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def drawControl(self, element: QStyle.ControlElement, opt: QStyleOption, p: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def drawItemPixmap(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, alignment: int, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def drawItemText(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, flags: typing.SupportsInt, pal: PySide2.QtGui.QPalette, enabled: bool, text: str, textRole: PySide2.QtGui.QPalette.ColorRole = ...) -> None: ...
    def drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption, p: PySide2.QtGui.QPainter, widget: typing.Union[QWidget, None] = ...) -> None: ...
    def generatedIconPixmap(self, iconMode: PySide2.QtGui.QIcon.Mode, pixmap: PySide2.QtGui.QPixmap, opt: QStyleOption) -> PySide2.QtGui.QPixmap: ...
    def hitTestComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, pt: PySide2.QtCore.QPoint, widget: typing.Union[QWidget, None] = ...) -> QStyle.SubControl: ...
    def itemPixmapRect(self, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, pixmap: PySide2.QtGui.QPixmap) -> PySide2.QtCore.QRect: ...
    def itemTextRect(self, fm: PySide2.QtGui.QFontMetrics, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, enabled: bool, text: str) -> PySide2.QtCore.QRect: ...
    def layoutSpacing(self, control1: QSizePolicy.ControlType, control2: QSizePolicy.ControlType, orientation: PySide2.QtCore.Qt.Orientation, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    def pixelMetric(self, metric: QStyle.PixelMetric, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> int: ...
    @typing.overload
    def polish(self, widget: QWidget) -> None: ...
    @typing.overload
    def polish(self, palette: PySide2.QtGui.QPalette) -> None: ...
    @typing.overload
    def polish(self, application: QApplication) -> None: ...
    def proxy(self) -> QStyle: ...
    def sizeFromContents(self, ct: QStyle.ContentsType, opt: QStyleOption, contentsSize: PySide2.QtCore.QSize, w: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QSize: ...
    @classmethod
    def sliderPositionFromValue(cls, min: int, max: int, val: int, space: int, upsideDown: bool = ...) -> int: ...
    @classmethod
    def sliderValueFromPosition(cls, min: int, max: int, pos: int, space: int, upsideDown: bool = ...) -> int: ...
    def standardIcon(self, standardIcon: QStyle.StandardPixmap, option: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QIcon: ...
    def standardPalette(self) -> PySide2.QtGui.QPalette: ...
    def standardPixmap(self, standardPixmap: QStyle.StandardPixmap, opt: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ...) -> PySide2.QtGui.QPixmap: ...
    def styleHint(self, stylehint: QStyle.StyleHint, opt: typing.Union[QStyleOption, None] = ..., widget: typing.Union[QWidget, None] = ..., returnData: typing.Union[QStyleHintReturn, None] = ...) -> int: ...
    def subControlRect(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex, sc: QStyle.SubControl, widget: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QRect: ...
    def subElementRect(self, subElement: QStyle.SubElement, option: QStyleOption, widget: typing.Union[QWidget, None] = ...) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def unpolish(self, widget: QWidget) -> None: ...
    @typing.overload
    def unpolish(self, application: QApplication) -> None: ...
    @classmethod
    def visualAlignment(cls, direction: PySide2.QtCore.Qt.LayoutDirection, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    @classmethod
    def visualPos(cls, direction: PySide2.QtCore.Qt.LayoutDirection, boundingRect: PySide2.QtCore.QRect, logicalPos: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    @classmethod
    def visualRect(cls, direction: PySide2.QtCore.Qt.LayoutDirection, boundingRect: PySide2.QtCore.QRect, logicalRect: PySide2.QtCore.QRect) -> PySide2.QtCore.QRect: ...

class QStyleFactory(shiboken2.Object):
    def __init__(self) -> None: ...
    @classmethod
    def create(cls, arg__1: str) -> QStyle: ...
    @classmethod
    def keys(cls) -> typing.List[str]: ...

class QStyleHintReturn(shiboken2.Object):
    class HintReturnType:
        SH_Default: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
        SH_Mask: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
        SH_Variant: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturn.HintReturnType: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleHintReturn.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleHintReturn.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturn.StyleOptionVersion: ...
    SH_Default: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
    SH_Mask: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
    SH_Variant: typing.ClassVar[QStyleHintReturn.HintReturnType] = ...
    Type: typing.ClassVar[QStyleHintReturn.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleHintReturn.StyleOptionVersion] = ...
    type: _typeshed.Incomplete
    version: _typeshed.Incomplete
    def __init__(self, version: int = ..., type: int = ...) -> None: ...

class QStyleHintReturnMask(QStyleHintReturn):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleHintReturnMask.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleHintReturnMask.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturnMask.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleHintReturnMask.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleHintReturnMask.StyleOptionVersion] = ...
    region: _typeshed.Incomplete
    def __init__(self) -> None: ...

class QStyleHintReturnVariant(QStyleHintReturn):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleHintReturnVariant.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleHintReturnVariant.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleHintReturnVariant.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleHintReturnVariant.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleHintReturnVariant.StyleOptionVersion] = ...
    variant: _typeshed.Incomplete
    def __init__(self) -> None: ...

class QStyleOption(shiboken2.Object):
    class OptionType:
        SO_Button: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ComboBox: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Complex: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ComplexCustomBase: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_CustomBase: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Default: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_DockWidget: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_FocusRect: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Frame: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_GraphicsItem: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_GroupBox: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Header: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_MenuItem: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ProgressBar: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_RubberBand: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_SizeGrip: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Slider: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_SpinBox: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_Tab: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_TabBarBase: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_TabWidgetFrame: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_TitleBar: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ToolBar: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ToolBox: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ToolButton: typing.ClassVar[QStyleOption.OptionType] = ...
        SO_ViewItem: typing.ClassVar[QStyleOption.OptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOption.OptionType: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOption.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOption.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOption.StyleOptionVersion: ...
    SO_Button: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ComboBox: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Complex: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ComplexCustomBase: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_CustomBase: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Default: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_DockWidget: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_FocusRect: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Frame: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_GraphicsItem: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_GroupBox: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Header: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_MenuItem: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ProgressBar: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_RubberBand: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_SizeGrip: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Slider: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_SpinBox: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_Tab: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_TabBarBase: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_TabWidgetFrame: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_TitleBar: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ToolBar: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ToolBox: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ToolButton: typing.ClassVar[QStyleOption.OptionType] = ...
    SO_ViewItem: typing.ClassVar[QStyleOption.OptionType] = ...
    Type: typing.ClassVar[QStyleOption.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOption.StyleOptionVersion] = ...
    direction: _typeshed.Incomplete
    fontMetrics: _typeshed.Incomplete
    palette: _typeshed.Incomplete
    rect: _typeshed.Incomplete
    state: _typeshed.Incomplete
    styleObject: _typeshed.Incomplete
    type: _typeshed.Incomplete
    version: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int = ..., type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOption) -> None: ...
    def init(self, w: QWidget) -> None: ...
    def initFrom(self, w: QWidget) -> None: ...

class QStyleOptionButton(QStyleOption):
    class ButtonFeature:
        AutoDefaultButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        CommandLinkButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        DefaultButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        Flat: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        HasMenu: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        None_: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionButton.ButtonFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...

    class ButtonFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionButton.ButtonFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionButton.ButtonFeatures: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionButton.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionButton.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionButton.StyleOptionVersion: ...
    AutoDefaultButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    CommandLinkButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    DefaultButton: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    Flat: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    HasMenu: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    None_: typing.ClassVar[QStyleOptionButton.ButtonFeature] = ...
    Type: typing.ClassVar[QStyleOptionButton.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionButton.StyleOptionVersion] = ...
    features: _typeshed.Incomplete
    icon: _typeshed.Incomplete
    iconSize: _typeshed.Incomplete
    text: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionButton) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionComboBox(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionComboBox.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionComboBox.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionComboBox.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionComboBox.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionComboBox.StyleOptionVersion] = ...
    currentIcon: _typeshed.Incomplete
    currentText: _typeshed.Incomplete
    editable: _typeshed.Incomplete
    frame: _typeshed.Incomplete
    iconSize: _typeshed.Incomplete
    popupRect: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionComboBox) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionComplex(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionComplex.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionComplex.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionComplex.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionComplex.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionComplex.StyleOptionVersion] = ...
    activeSubControls: _typeshed.Incomplete
    subControls: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int = ..., type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionComplex) -> None: ...

class QStyleOptionDockWidget(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionDockWidget.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionDockWidget.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionDockWidget.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionDockWidget.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionDockWidget.StyleOptionVersion] = ...
    closable: _typeshed.Incomplete
    floatable: _typeshed.Incomplete
    movable: _typeshed.Incomplete
    title: _typeshed.Incomplete
    verticalTitleBar: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionDockWidget) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionFocusRect(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionFocusRect.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionFocusRect.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFocusRect.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionFocusRect.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionFocusRect.StyleOptionVersion] = ...
    backgroundColor: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionFocusRect) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionFrame(QStyleOption):
    class FrameFeature:
        Flat: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
        None_: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
        Rounded: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionFrame.FrameFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...

    class FrameFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionFrame.FrameFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.FrameFeatures: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionFrame.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionFrame.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionFrame.StyleOptionVersion: ...
    Flat: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
    None_: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
    Rounded: typing.ClassVar[QStyleOptionFrame.FrameFeature] = ...
    Type: typing.ClassVar[QStyleOptionFrame.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionFrame.StyleOptionVersion] = ...
    features: _typeshed.Incomplete
    frameShape: _typeshed.Incomplete
    lineWidth: _typeshed.Incomplete
    midLineWidth: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionFrame) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionGraphicsItem(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionGraphicsItem.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionGraphicsItem.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionGraphicsItem.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionGraphicsItem.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionGraphicsItem.StyleOptionVersion] = ...
    exposedRect: _typeshed.Incomplete
    levelOfDetail: _typeshed.Incomplete
    matrix: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionGraphicsItem) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @classmethod
    def levelOfDetailFromTransform(cls, worldTransform: PySide2.QtGui.QTransform) -> float: ...

class QStyleOptionGroupBox(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionGroupBox.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionGroupBox.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionGroupBox.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionGroupBox.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionGroupBox.StyleOptionVersion] = ...
    features: _typeshed.Incomplete
    lineWidth: _typeshed.Incomplete
    midLineWidth: _typeshed.Incomplete
    text: _typeshed.Incomplete
    textAlignment: _typeshed.Incomplete
    textColor: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionGroupBox) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionHeader(QStyleOption):
    class SectionPosition:
        Beginning: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
        End: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
        Middle: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
        OnlyOneSection: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SectionPosition: ...

    class SelectedPosition:
        NextAndPreviousAreSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
        NextIsSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
        NotAdjacent: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
        PreviousIsSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SelectedPosition: ...

    class SortIndicator:
        None_: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
        SortDown: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
        SortUp: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.SortIndicator: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionHeader.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionHeader.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionHeader.StyleOptionVersion: ...
    Beginning: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
    End: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
    Middle: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
    NextAndPreviousAreSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
    NextIsSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
    None_: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
    NotAdjacent: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
    OnlyOneSection: typing.ClassVar[QStyleOptionHeader.SectionPosition] = ...
    PreviousIsSelected: typing.ClassVar[QStyleOptionHeader.SelectedPosition] = ...
    SortDown: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
    SortUp: typing.ClassVar[QStyleOptionHeader.SortIndicator] = ...
    Type: typing.ClassVar[QStyleOptionHeader.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionHeader.StyleOptionVersion] = ...
    icon: _typeshed.Incomplete
    iconAlignment: _typeshed.Incomplete
    orientation: _typeshed.Incomplete
    position: _typeshed.Incomplete
    section: _typeshed.Incomplete
    selectedPosition: _typeshed.Incomplete
    sortIndicator: _typeshed.Incomplete
    text: _typeshed.Incomplete
    textAlignment: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionHeader) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionMenuItem(QStyleOption):
    class CheckType:
        Exclusive: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
        NonExclusive: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
        NotCheckable: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.CheckType: ...

    class MenuItemType:
        DefaultItem: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        EmptyArea: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        Margin: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        Normal: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        Scroller: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        Separator: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        SubMenu: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        TearOff: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.MenuItemType: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionMenuItem.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionMenuItem.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionMenuItem.StyleOptionVersion: ...
    DefaultItem: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    EmptyArea: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    Exclusive: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
    Margin: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    NonExclusive: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
    Normal: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    NotCheckable: typing.ClassVar[QStyleOptionMenuItem.CheckType] = ...
    Scroller: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    Separator: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    SubMenu: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    TearOff: typing.ClassVar[QStyleOptionMenuItem.MenuItemType] = ...
    Type: typing.ClassVar[QStyleOptionMenuItem.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionMenuItem.StyleOptionVersion] = ...
    checkType: _typeshed.Incomplete
    checked: _typeshed.Incomplete
    font: _typeshed.Incomplete
    icon: _typeshed.Incomplete
    maxIconWidth: _typeshed.Incomplete
    menuHasCheckableItems: _typeshed.Incomplete
    menuItemType: _typeshed.Incomplete
    menuRect: _typeshed.Incomplete
    tabWidth: _typeshed.Incomplete
    text: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionMenuItem) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionProgressBar(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionProgressBar.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionProgressBar.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionProgressBar.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionProgressBar.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionProgressBar.StyleOptionVersion] = ...
    bottomToTop: _typeshed.Incomplete
    invertedAppearance: _typeshed.Incomplete
    maximum: _typeshed.Incomplete
    minimum: _typeshed.Incomplete
    orientation: _typeshed.Incomplete
    progress: _typeshed.Incomplete
    text: _typeshed.Incomplete
    textAlignment: _typeshed.Incomplete
    textVisible: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionProgressBar) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionRubberBand(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionRubberBand.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionRubberBand.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionRubberBand.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionRubberBand.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionRubberBand.StyleOptionVersion] = ...
    opaque: _typeshed.Incomplete
    shape: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionRubberBand) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionSizeGrip(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionSizeGrip.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionSizeGrip.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSizeGrip.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionSizeGrip.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionSizeGrip.StyleOptionVersion] = ...
    corner: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionSizeGrip) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionSlider(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionSlider.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionSlider.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSlider.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionSlider.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionSlider.StyleOptionVersion] = ...
    dialWrapping: _typeshed.Incomplete
    maximum: _typeshed.Incomplete
    minimum: _typeshed.Incomplete
    notchTarget: _typeshed.Incomplete
    orientation: _typeshed.Incomplete
    pageStep: _typeshed.Incomplete
    singleStep: _typeshed.Incomplete
    sliderPosition: _typeshed.Incomplete
    sliderValue: _typeshed.Incomplete
    tickInterval: _typeshed.Incomplete
    tickPosition: _typeshed.Incomplete
    upsideDown: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionSlider) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionSpinBox(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionSpinBox.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionSpinBox.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionSpinBox.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionSpinBox.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionSpinBox.StyleOptionVersion] = ...
    buttonSymbols: _typeshed.Incomplete
    frame: _typeshed.Incomplete
    stepEnabled: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionSpinBox) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionTab(QStyleOption):
    class CornerWidget:
        LeftCornerWidget: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
        NoCornerWidgets: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
        RightCornerWidget: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionTab.CornerWidgets: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...

    class CornerWidgets:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionTab.CornerWidgets: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.CornerWidgets: ...

    class SelectedPosition:
        NextIsSelected: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
        NotAdjacent: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
        PreviousIsSelected: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.SelectedPosition: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionTab.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionTab.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.StyleOptionVersion: ...

    class TabFeature:
        HasFrame: typing.ClassVar[QStyleOptionTab.TabFeature] = ...
        None_: typing.ClassVar[QStyleOptionTab.TabFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionTab.TabFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...

    class TabFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionTab.TabFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabFeatures: ...

    class TabPosition:
        Beginning: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
        End: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
        Middle: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
        OnlyOneTab: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTab.TabPosition: ...
    Beginning: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
    End: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
    HasFrame: typing.ClassVar[QStyleOptionTab.TabFeature] = ...
    LeftCornerWidget: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
    Middle: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
    NextIsSelected: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
    NoCornerWidgets: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
    None_: typing.ClassVar[QStyleOptionTab.TabFeature] = ...
    NotAdjacent: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
    OnlyOneTab: typing.ClassVar[QStyleOptionTab.TabPosition] = ...
    PreviousIsSelected: typing.ClassVar[QStyleOptionTab.SelectedPosition] = ...
    RightCornerWidget: typing.ClassVar[QStyleOptionTab.CornerWidget] = ...
    Type: typing.ClassVar[QStyleOptionTab.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionTab.StyleOptionVersion] = ...
    cornerWidgets: _typeshed.Incomplete
    documentMode: _typeshed.Incomplete
    features: _typeshed.Incomplete
    icon: _typeshed.Incomplete
    iconSize: _typeshed.Incomplete
    leftButtonSize: _typeshed.Incomplete
    position: _typeshed.Incomplete
    rightButtonSize: _typeshed.Incomplete
    row: _typeshed.Incomplete
    selectedPosition: _typeshed.Incomplete
    shape: _typeshed.Incomplete
    text: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionTab) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionTabBarBase(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionTabBarBase.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionTabBarBase.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTabBarBase.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionTabBarBase.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionTabBarBase.StyleOptionVersion] = ...
    documentMode: _typeshed.Incomplete
    selectedTabRect: _typeshed.Incomplete
    shape: _typeshed.Incomplete
    tabBarRect: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionTabBarBase) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionTabWidgetFrame(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionTabWidgetFrame.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionTabWidgetFrame.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTabWidgetFrame.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionTabWidgetFrame.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionTabWidgetFrame.StyleOptionVersion] = ...
    leftCornerWidgetSize: _typeshed.Incomplete
    lineWidth: _typeshed.Incomplete
    midLineWidth: _typeshed.Incomplete
    rightCornerWidgetSize: _typeshed.Incomplete
    selectedTabRect: _typeshed.Incomplete
    shape: _typeshed.Incomplete
    tabBarRect: _typeshed.Incomplete
    tabBarSize: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionTabWidgetFrame) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionTitleBar(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionTitleBar.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionTitleBar.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionTitleBar.StyleOptionVersion: ...
    Type: typing.ClassVar[QStyleOptionTitleBar.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionTitleBar.StyleOptionVersion] = ...
    icon: _typeshed.Incomplete
    text: _typeshed.Incomplete
    titleBarFlags: _typeshed.Incomplete
    titleBarState: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionTitleBar) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionToolBar(QStyleOption):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionToolBar.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionToolBar.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.StyleOptionVersion: ...

    class ToolBarFeature:
        Movable: typing.ClassVar[QStyleOptionToolBar.ToolBarFeature] = ...
        None_: typing.ClassVar[QStyleOptionToolBar.ToolBarFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...

    class ToolBarFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarFeatures: ...

    class ToolBarPosition:
        Beginning: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
        End: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
        Middle: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
        OnlyOne: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBar.ToolBarPosition: ...
    Beginning: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
    End: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
    Middle: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
    Movable: typing.ClassVar[QStyleOptionToolBar.ToolBarFeature] = ...
    None_: typing.ClassVar[QStyleOptionToolBar.ToolBarFeature] = ...
    OnlyOne: typing.ClassVar[QStyleOptionToolBar.ToolBarPosition] = ...
    Type: typing.ClassVar[QStyleOptionToolBar.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionToolBar.StyleOptionVersion] = ...
    features: _typeshed.Incomplete
    lineWidth: _typeshed.Incomplete
    midLineWidth: _typeshed.Incomplete
    positionOfLine: _typeshed.Incomplete
    positionWithinLine: _typeshed.Incomplete
    toolBarArea: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionToolBar) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionToolBox(QStyleOption):
    class SelectedPosition:
        NextIsSelected: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
        NotAdjacent: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
        PreviousIsSelected: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.SelectedPosition: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionToolBox.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionToolBox.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.StyleOptionVersion: ...

    class TabPosition:
        Beginning: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
        End: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
        Middle: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
        OnlyOneTab: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolBox.TabPosition: ...
    Beginning: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
    End: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
    Middle: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
    NextIsSelected: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
    NotAdjacent: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
    OnlyOneTab: typing.ClassVar[QStyleOptionToolBox.TabPosition] = ...
    PreviousIsSelected: typing.ClassVar[QStyleOptionToolBox.SelectedPosition] = ...
    Type: typing.ClassVar[QStyleOptionToolBox.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionToolBox.StyleOptionVersion] = ...
    icon: _typeshed.Incomplete
    position: _typeshed.Incomplete
    selectedPosition: _typeshed.Incomplete
    text: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionToolBox) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionToolButton(QStyleOptionComplex):
    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionToolButton.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionToolButton.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.StyleOptionVersion: ...

    class ToolButtonFeature:
        Arrow: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        HasMenu: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        Menu: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        MenuButtonPopup: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        None_: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        PopupDelay: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...

    class ToolButtonFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionToolButton.ToolButtonFeatures: ...
    Arrow: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    HasMenu: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    Menu: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    MenuButtonPopup: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    None_: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    PopupDelay: typing.ClassVar[QStyleOptionToolButton.ToolButtonFeature] = ...
    Type: typing.ClassVar[QStyleOptionToolButton.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionToolButton.StyleOptionVersion] = ...
    arrowType: _typeshed.Incomplete
    features: _typeshed.Incomplete
    font: _typeshed.Incomplete
    icon: _typeshed.Incomplete
    iconSize: _typeshed.Incomplete
    pos: _typeshed.Incomplete
    text: _typeshed.Incomplete
    toolButtonStyle: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionToolButton) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

class QStyleOptionViewItem(QStyleOption):
    class Position:
        Bottom: typing.ClassVar[QStyleOptionViewItem.Position] = ...
        Left: typing.ClassVar[QStyleOptionViewItem.Position] = ...
        Right: typing.ClassVar[QStyleOptionViewItem.Position] = ...
        Top: typing.ClassVar[QStyleOptionViewItem.Position] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.Position: ...

    class StyleOptionType:
        Type: typing.ClassVar[QStyleOptionViewItem.StyleOptionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionType: ...

    class StyleOptionVersion:
        Version: typing.ClassVar[QStyleOptionViewItem.StyleOptionVersion] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.StyleOptionVersion: ...

    class ViewItemFeature:
        Alternate: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        HasCheckIndicator: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        HasDecoration: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        HasDisplay: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        None_: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        WrapText: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...

    class ViewItemFeatures:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemFeatures: ...

    class ViewItemPosition:
        Beginning: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
        End: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
        Invalid: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
        Middle: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
        OnlyOne: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QStyleOptionViewItem.ViewItemPosition: ...
    Alternate: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    Beginning: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
    Bottom: typing.ClassVar[QStyleOptionViewItem.Position] = ...
    End: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
    HasCheckIndicator: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    HasDecoration: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    HasDisplay: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    Invalid: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
    Left: typing.ClassVar[QStyleOptionViewItem.Position] = ...
    Middle: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
    None_: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    OnlyOne: typing.ClassVar[QStyleOptionViewItem.ViewItemPosition] = ...
    Right: typing.ClassVar[QStyleOptionViewItem.Position] = ...
    Top: typing.ClassVar[QStyleOptionViewItem.Position] = ...
    Type: typing.ClassVar[QStyleOptionViewItem.StyleOptionType] = ...
    Version: typing.ClassVar[QStyleOptionViewItem.StyleOptionVersion] = ...
    WrapText: typing.ClassVar[QStyleOptionViewItem.ViewItemFeature] = ...
    backgroundBrush: _typeshed.Incomplete
    checkState: _typeshed.Incomplete
    decorationAlignment: _typeshed.Incomplete
    decorationPosition: _typeshed.Incomplete
    decorationSize: _typeshed.Incomplete
    displayAlignment: _typeshed.Incomplete
    features: _typeshed.Incomplete
    font: _typeshed.Incomplete
    icon: _typeshed.Incomplete
    index: _typeshed.Incomplete
    locale: _typeshed.Incomplete
    showDecorationSelected: _typeshed.Incomplete
    text: _typeshed.Incomplete
    textElideMode: _typeshed.Incomplete
    viewItemPosition: _typeshed.Incomplete
    widget: _typeshed.Incomplete
    @typing.overload
    def __init__(self, version: int) -> None: ...
    @typing.overload
    def __init__(self, other: QStyleOptionViewItem) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def __copy__(self) -> None: ...

class QStylePainter(PySide2.QtGui.QPainter):
    @typing.overload
    def __init__(self, pd: PySide2.QtGui.QPaintDevice, w: QWidget) -> None: ...
    @typing.overload
    def __init__(self, w: QWidget) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def begin(self, pd: PySide2.QtGui.QPaintDevice, w: QWidget) -> bool: ...
    @typing.overload
    def begin(self, w: QWidget) -> bool: ...
    @typing.overload
    def begin(self, arg__1: PySide2.QtGui.QPaintDevice) -> bool: ...
    def drawComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex) -> None: ...
    def drawControl(self, ce: QStyle.ControlElement, opt: QStyleOption) -> None: ...
    def drawItemPixmap(self, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def drawItemText(self, r: PySide2.QtCore.QRect, flags: typing.SupportsInt, pal: PySide2.QtGui.QPalette, enabled: bool, text: str, textRole: PySide2.QtGui.QPalette.ColorRole = ...) -> None: ...
    def drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption) -> None: ...
    def style(self) -> QStyle: ...

class QStyledItemDelegate(QAbstractItemDelegate):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., closeEditor: typing.Callable = ..., commitData: typing.Callable = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeHintChanged: typing.Callable = ...) -> None: ...
    def createEditor(self, parent: typing.Union[QWidget, None], option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> QWidget: ...
    def displayText(self, value: typing.Any, locale: PySide2.QtCore.QLocale) -> str: ...
    def editorEvent(self, event: PySide2.QtCore.QEvent, model: PySide2.QtCore.QAbstractItemModel, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def eventFilter(self, object: PySide2.QtCore.QObject, event: PySide2.QtCore.QEvent) -> bool: ...
    def initStyleOption(self, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def itemEditorFactory(self) -> QItemEditorFactory: ...
    def paint(self, painter: PySide2.QtGui.QPainter, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setEditorData(self, editor: QWidget, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setItemEditorFactory(self, factory: QItemEditorFactory) -> None: ...
    def setModelData(self, editor: QWidget, model: PySide2.QtCore.QAbstractItemModel, index: PySide2.QtCore.QModelIndex) -> None: ...
    def sizeHint(self, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QSize: ...
    def updateEditorGeometry(self, editor: QWidget, option: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...

class QSwipeGesture(QGesture):
    class SwipeDirection:
        Down: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
        Left: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
        NoDirection: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
        Right: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
        Up: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __and__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __rand__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __ror__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __sub__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
        def __xor__(self, other: typing.SupportsInt) -> QSwipeGesture.SwipeDirection: ...
    Down: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
    Left: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
    NoDirection: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
    Right: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
    Up: typing.ClassVar[QSwipeGesture.SwipeDirection] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., horizontalDirection: QSwipeGesture.SwipeDirection = ..., hotSpot: PySide2.QtCore.QPointF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., state: PySide2.QtCore.Qt.GestureState = ..., swipeAngle: float = ..., velocity: float = ..., verticalDirection: QSwipeGesture.SwipeDirection = ...) -> None: ...
    def horizontalDirection(self) -> QSwipeGesture.SwipeDirection: ...
    def setSwipeAngle(self, value: float) -> None: ...
    def swipeAngle(self) -> float: ...
    def verticalDirection(self) -> QSwipeGesture.SwipeDirection: ...

class QSystemTrayIcon(PySide2.QtCore.QObject):
    class ActivationReason:
        Context: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
        DoubleClick: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
        MiddleClick: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
        Trigger: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
        Unknown: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __and__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __rand__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __ror__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __sub__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...
        def __xor__(self, other: typing.SupportsInt) -> QSystemTrayIcon.ActivationReason: ...

    class MessageIcon:
        Critical: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
        Information: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
        NoIcon: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
        Warning: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __and__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __rand__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __rmul__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __ror__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __rsub__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __rxor__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __sub__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
        def __xor__(self, other: typing.SupportsInt) -> QSystemTrayIcon.MessageIcon: ...
    Context: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
    Critical: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
    DoubleClick: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
    Information: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
    MiddleClick: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
    NoIcon: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
    Trigger: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
    Unknown: typing.ClassVar[QSystemTrayIcon.ActivationReason] = ...
    Warning: typing.ClassVar[QSystemTrayIcon.MessageIcon] = ...
    activated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    messageClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, icon: PySide2.QtGui.QIcon, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activated: typing.Callable = ..., destroyed: typing.Callable = ..., messageClicked: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., toolTip: str = ..., visible: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activated: typing.Callable = ..., destroyed: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., messageClicked: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., toolTip: str = ..., visible: bool = ...) -> None: ...
    def contextMenu(self) -> QMenu: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def hide(self) -> None: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    @classmethod
    def isSystemTrayAvailable(cls) -> bool: ...
    def isVisible(self) -> bool: ...
    def setContextMenu(self, menu: QMenu) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setToolTip(self, tip: str) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def show(self) -> None: ...
    @typing.overload
    def showMessage(self, title: str, msg: str, icon: PySide2.QtGui.QIcon, msecs: int = ...) -> None: ...
    @typing.overload
    def showMessage(self, title: str, msg: str, icon: QSystemTrayIcon.MessageIcon = ..., msecs: int = ...) -> None: ...
    @classmethod
    def supportsMessages(cls) -> bool: ...
    def toolTip(self) -> str: ...

class QTabBar(QWidget):
    class ButtonPosition:
        LeftSide: typing.ClassVar[QTabBar.ButtonPosition] = ...
        RightSide: typing.ClassVar[QTabBar.ButtonPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QTabBar.ButtonPosition: ...

    class SelectionBehavior:
        SelectLeftTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
        SelectPreviousTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
        SelectRightTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __and__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __rand__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __ror__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __sub__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...
        def __xor__(self, other: typing.SupportsInt) -> QTabBar.SelectionBehavior: ...

    class Shape:
        RoundedEast: typing.ClassVar[QTabBar.Shape] = ...
        RoundedNorth: typing.ClassVar[QTabBar.Shape] = ...
        RoundedSouth: typing.ClassVar[QTabBar.Shape] = ...
        RoundedWest: typing.ClassVar[QTabBar.Shape] = ...
        TriangularEast: typing.ClassVar[QTabBar.Shape] = ...
        TriangularNorth: typing.ClassVar[QTabBar.Shape] = ...
        TriangularSouth: typing.ClassVar[QTabBar.Shape] = ...
        TriangularWest: typing.ClassVar[QTabBar.Shape] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __and__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __rand__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __ror__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __sub__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
        def __xor__(self, other: typing.SupportsInt) -> QTabBar.Shape: ...
    LeftSide: typing.ClassVar[QTabBar.ButtonPosition] = ...
    RightSide: typing.ClassVar[QTabBar.ButtonPosition] = ...
    RoundedEast: typing.ClassVar[QTabBar.Shape] = ...
    RoundedNorth: typing.ClassVar[QTabBar.Shape] = ...
    RoundedSouth: typing.ClassVar[QTabBar.Shape] = ...
    RoundedWest: typing.ClassVar[QTabBar.Shape] = ...
    SelectLeftTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
    SelectPreviousTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
    SelectRightTab: typing.ClassVar[QTabBar.SelectionBehavior] = ...
    TriangularEast: typing.ClassVar[QTabBar.Shape] = ...
    TriangularNorth: typing.ClassVar[QTabBar.Shape] = ...
    TriangularSouth: typing.ClassVar[QTabBar.Shape] = ...
    TriangularWest: typing.ClassVar[QTabBar.Shape] = ...
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    tabBarClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    tabBarDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    tabCloseRequested: typing.ClassVar[PySide2.QtCore.Signal] = ...
    tabMoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., autoHide: bool = ..., baseSize: PySide2.QtCore.QSize = ..., changeCurrentOnDrag: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentChanged: typing.Callable = ..., currentIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., documentMode: bool = ..., drawBase: bool = ..., elideMode: PySide2.QtCore.Qt.TextElideMode = ..., enabled: bool = ..., expanding: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., movable: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., selectionBehaviorOnRemove: typing.Any = ..., shape: QTabBar.Shape = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabBarClicked: typing.Callable = ..., tabBarDoubleClicked: typing.Callable = ..., tabCloseRequested: typing.Callable = ..., tabMoved: typing.Callable = ..., tabletTracking: bool = ..., tabsClosable: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., usesScrollButtons: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def accessibleTabName(self, index: int) -> str: ...
    @typing.overload
    def addTab(self, icon: PySide2.QtGui.QIcon, text: str) -> int: ...
    @typing.overload
    def addTab(self, text: str) -> int: ...
    def autoHide(self) -> bool: ...
    def changeCurrentOnDrag(self) -> bool: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def count(self) -> int: ...
    def currentIndex(self) -> int: ...
    def documentMode(self) -> bool: ...
    def drawBase(self) -> bool: ...
    def elideMode(self) -> PySide2.QtCore.Qt.TextElideMode: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def expanding(self) -> bool: ...
    def hideEvent(self, arg__1: PySide2.QtGui.QHideEvent) -> None: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def initStyleOption(self, option: QStyleOptionTab, tabIndex: int) -> None: ...
    @typing.overload
    def insertTab(self, index: int, icon: PySide2.QtGui.QIcon, text: str) -> int: ...
    @typing.overload
    def insertTab(self, index: int, text: str) -> int: ...
    def isMovable(self) -> bool: ...
    def isTabEnabled(self, index: int) -> bool: ...
    def isTabVisible(self, index: int) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def minimumTabSizeHint(self, index: int) -> PySide2.QtCore.QSize: ...
    def mouseMoveEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveTab(self, from_: int, to: int) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def removeTab(self, index: int) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def selectionBehaviorOnRemove(self) -> QTabBar.SelectionBehavior: ...
    def setAccessibleTabName(self, index: int, name: str) -> None: ...
    def setAutoHide(self, hide: bool) -> None: ...
    def setChangeCurrentOnDrag(self, change: bool) -> None: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setDocumentMode(self, set: bool) -> None: ...
    def setDrawBase(self, drawTheBase: bool) -> None: ...
    def setElideMode(self, mode: PySide2.QtCore.Qt.TextElideMode) -> None: ...
    def setExpanding(self, enabled: bool) -> None: ...
    def setIconSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setMovable(self, movable: bool) -> None: ...
    def setSelectionBehaviorOnRemove(self, behavior: QTabBar.SelectionBehavior) -> None: ...
    def setShape(self, shape: QTabBar.Shape) -> None: ...
    def setTabButton(self, index: int, position: QTabBar.ButtonPosition, widget: QWidget) -> None: ...
    def setTabData(self, index: int, data: typing.Any) -> None: ...
    def setTabEnabled(self, index: int, enabled: bool) -> None: ...
    def setTabIcon(self, index: int, icon: PySide2.QtGui.QIcon) -> None: ...
    def setTabText(self, index: int, text: str) -> None: ...
    def setTabTextColor(self, index: int, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setTabToolTip(self, index: int, tip: str) -> None: ...
    def setTabVisible(self, index: int, visible: bool) -> None: ...
    def setTabWhatsThis(self, index: int, text: str) -> None: ...
    def setTabsClosable(self, closable: bool) -> None: ...
    def setUsesScrollButtons(self, useButtons: bool) -> None: ...
    def shape(self) -> QTabBar.Shape: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def tabAt(self, pos: PySide2.QtCore.QPoint) -> int: ...
    def tabButton(self, index: int, position: QTabBar.ButtonPosition) -> QWidget: ...
    def tabData(self, index: int) -> typing.Any: ...
    def tabIcon(self, index: int) -> PySide2.QtGui.QIcon: ...
    def tabInserted(self, index: int) -> None: ...
    def tabLayoutChange(self) -> None: ...
    def tabRect(self, index: int) -> PySide2.QtCore.QRect: ...
    def tabRemoved(self, index: int) -> None: ...
    def tabSizeHint(self, index: int) -> PySide2.QtCore.QSize: ...
    def tabText(self, index: int) -> str: ...
    def tabTextColor(self, index: int) -> PySide2.QtGui.QColor: ...
    def tabToolTip(self, index: int) -> str: ...
    def tabWhatsThis(self, index: int) -> str: ...
    def tabsClosable(self) -> bool: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    def usesScrollButtons(self) -> bool: ...
    def wheelEvent(self, event: PySide2.QtGui.QWheelEvent) -> None: ...

class QTabWidget(QWidget):
    class TabPosition:
        East: typing.ClassVar[QTabWidget.TabPosition] = ...
        North: typing.ClassVar[QTabWidget.TabPosition] = ...
        South: typing.ClassVar[QTabWidget.TabPosition] = ...
        West: typing.ClassVar[QTabWidget.TabPosition] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __and__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __rand__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __ror__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __sub__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...
        def __xor__(self, other: typing.SupportsInt) -> QTabWidget.TabPosition: ...

    class TabShape:
        Rounded: typing.ClassVar[QTabWidget.TabShape] = ...
        Triangular: typing.ClassVar[QTabWidget.TabShape] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __and__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __rand__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __ror__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __sub__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
        def __xor__(self, other: typing.SupportsInt) -> QTabWidget.TabShape: ...
    East: typing.ClassVar[QTabWidget.TabPosition] = ...
    North: typing.ClassVar[QTabWidget.TabPosition] = ...
    Rounded: typing.ClassVar[QTabWidget.TabShape] = ...
    South: typing.ClassVar[QTabWidget.TabPosition] = ...
    Triangular: typing.ClassVar[QTabWidget.TabShape] = ...
    West: typing.ClassVar[QTabWidget.TabPosition] = ...
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    tabBarClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    tabBarDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    tabCloseRequested: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentChanged: typing.Callable = ..., currentIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., documentMode: bool = ..., elideMode: PySide2.QtCore.Qt.TextElideMode = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., movable: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabBarAutoHide: bool = ..., tabBarClicked: typing.Callable = ..., tabBarDoubleClicked: typing.Callable = ..., tabCloseRequested: typing.Callable = ..., tabPosition: QTabWidget.TabPosition = ..., tabShape: QTabWidget.TabShape = ..., tabletTracking: bool = ..., tabsClosable: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., usesScrollButtons: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addTab(self, widget: QWidget, icon: PySide2.QtGui.QIcon, label: str) -> int: ...
    @typing.overload
    def addTab(self, widget: QWidget, arg__2: str) -> int: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def cornerWidget(self, corner: PySide2.QtCore.Qt.Corner = ...) -> QWidget: ...
    def count(self) -> int: ...
    def currentIndex(self) -> int: ...
    def currentWidget(self) -> QWidget: ...
    def documentMode(self) -> bool: ...
    def elideMode(self) -> PySide2.QtCore.Qt.TextElideMode: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, width: int) -> int: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def indexOf(self, widget: QWidget) -> int: ...
    def initStyleOption(self, option: QStyleOptionTabWidgetFrame) -> None: ...
    @typing.overload
    def insertTab(self, index: int, widget: QWidget, icon: PySide2.QtGui.QIcon, label: str) -> int: ...
    @typing.overload
    def insertTab(self, index: int, widget: QWidget, arg__3: str) -> int: ...
    def isMovable(self) -> bool: ...
    def isTabEnabled(self, index: int) -> bool: ...
    def isTabVisible(self, index: int) -> bool: ...
    def keyPressEvent(self, arg__1: PySide2.QtGui.QKeyEvent) -> None: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def removeTab(self, index: int) -> None: ...
    def resizeEvent(self, arg__1: PySide2.QtGui.QResizeEvent) -> None: ...
    def setCornerWidget(self, w: QWidget, corner: PySide2.QtCore.Qt.Corner = ...) -> None: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentWidget(self, widget: QWidget) -> None: ...
    def setDocumentMode(self, set: bool) -> None: ...
    def setElideMode(self, mode: PySide2.QtCore.Qt.TextElideMode) -> None: ...
    def setIconSize(self, size: PySide2.QtCore.QSize) -> None: ...
    def setMovable(self, movable: bool) -> None: ...
    def setTabBar(self, arg__1: QTabBar) -> None: ...
    def setTabBarAutoHide(self, enabled: bool) -> None: ...
    def setTabEnabled(self, index: int, enabled: bool) -> None: ...
    def setTabIcon(self, index: int, icon: PySide2.QtGui.QIcon) -> None: ...
    def setTabPosition(self, position: QTabWidget.TabPosition) -> None: ...
    def setTabShape(self, s: QTabWidget.TabShape) -> None: ...
    def setTabText(self, index: int, text: str) -> None: ...
    def setTabToolTip(self, index: int, tip: str) -> None: ...
    def setTabVisible(self, index: int, visible: bool) -> None: ...
    def setTabWhatsThis(self, index: int, text: str) -> None: ...
    def setTabsClosable(self, closeable: bool) -> None: ...
    def setUsesScrollButtons(self, useButtons: bool) -> None: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def tabBar(self) -> QTabBar: ...
    def tabBarAutoHide(self) -> bool: ...
    def tabIcon(self, index: int) -> PySide2.QtGui.QIcon: ...
    def tabInserted(self, index: int) -> None: ...
    def tabPosition(self) -> QTabWidget.TabPosition: ...
    def tabRemoved(self, index: int) -> None: ...
    def tabShape(self) -> QTabWidget.TabShape: ...
    def tabText(self, index: int) -> str: ...
    def tabToolTip(self, index: int) -> str: ...
    def tabWhatsThis(self, index: int) -> str: ...
    def tabsClosable(self) -> bool: ...
    def usesScrollButtons(self) -> bool: ...
    def widget(self, index: int) -> QWidget: ...

class QTableView(QAbstractItemView):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cornerButtonEnabled: bool = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QTableView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QTableView.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTableView.Shadow = ..., frameShape: QTableView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridStyle: PySide2.QtCore.Qt.PenStyle = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QTableView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., selectionBehavior: QTableView.SelectionBehavior = ..., selectionMode: QTableView.SelectionMode = ..., showDropIndicator: bool = ..., showGrid: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTableView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QTableView.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def clearSpans(self) -> None: ...
    def columnAt(self, x: int) -> int: ...
    def columnCountChanged(self, oldCount: int, newCount: int) -> None: ...
    def columnMoved(self, column: int, oldIndex: int, newIndex: int) -> None: ...
    def columnResized(self, column: int, oldWidth: int, newWidth: int) -> None: ...
    def columnSpan(self, row: int, column: int) -> int: ...
    def columnViewportPosition(self, column: int) -> int: ...
    def columnWidth(self, column: int) -> int: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, previous: PySide2.QtCore.QModelIndex) -> None: ...
    def doItemsLayout(self) -> None: ...
    def gridStyle(self) -> PySide2.QtCore.Qt.PenStyle: ...
    def hideColumn(self, column: int) -> None: ...
    def hideRow(self, row: int) -> None: ...
    def horizontalHeader(self) -> QHeaderView: ...
    def horizontalOffset(self) -> int: ...
    def horizontalScrollbarAction(self, action: int) -> None: ...
    def indexAt(self, p: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    def isColumnHidden(self, column: int) -> bool: ...
    def isCornerButtonEnabled(self) -> bool: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isRowHidden(self, row: int) -> bool: ...
    def isSortingEnabled(self) -> bool: ...
    def moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def resizeColumnToContents(self, column: int) -> None: ...
    def resizeColumnsToContents(self) -> None: ...
    def resizeRowToContents(self, row: int) -> None: ...
    def resizeRowsToContents(self) -> None: ...
    def rowAt(self, y: int) -> int: ...
    def rowCountChanged(self, oldCount: int, newCount: int) -> None: ...
    def rowHeight(self, row: int) -> int: ...
    def rowMoved(self, row: int, oldIndex: int, newIndex: int) -> None: ...
    def rowResized(self, row: int, oldHeight: int, newHeight: int) -> None: ...
    def rowSpan(self, row: int, column: int) -> int: ...
    def rowViewportPosition(self, row: int) -> int: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectColumn(self, column: int) -> None: ...
    def selectRow(self, row: int) -> None: ...
    def selectedIndexes(self) -> typing.List[PySide2.QtCore.QModelIndex]: ...
    def selectionChanged(self, selected: PySide2.QtCore.QItemSelection, deselected: PySide2.QtCore.QItemSelection) -> None: ...
    def setColumnHidden(self, column: int, hide: bool) -> None: ...
    def setColumnWidth(self, column: int, width: int) -> None: ...
    def setCornerButtonEnabled(self, enable: bool) -> None: ...
    def setGridStyle(self, style: PySide2.QtCore.Qt.PenStyle) -> None: ...
    def setHorizontalHeader(self, header: QHeaderView) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setRowHeight(self, row: int, height: int) -> None: ...
    def setRowHidden(self, row: int, hide: bool) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def setShowGrid(self, show: bool) -> None: ...
    def setSortingEnabled(self, enable: bool) -> None: ...
    def setSpan(self, row: int, column: int, rowSpan: int, columnSpan: int) -> None: ...
    def setVerticalHeader(self, header: QHeaderView) -> None: ...
    def setWordWrap(self, on: bool) -> None: ...
    def showColumn(self, column: int) -> None: ...
    def showGrid(self) -> bool: ...
    def showRow(self, row: int) -> None: ...
    def sizeHintForColumn(self, column: int) -> int: ...
    def sizeHintForRow(self, row: int) -> int: ...
    @typing.overload
    def sortByColumn(self, column: int, order: PySide2.QtCore.Qt.SortOrder) -> None: ...
    @typing.overload
    def sortByColumn(self, column: int) -> None: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    def updateGeometries(self) -> None: ...
    def verticalHeader(self) -> QHeaderView: ...
    def verticalOffset(self) -> int: ...
    def verticalScrollbarAction(self, action: int) -> None: ...
    def viewOptions(self) -> QStyleOptionViewItem: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...
    def wordWrap(self) -> bool: ...

class QTableWidget(QTableView):
    cellActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cellChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cellClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cellDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cellEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cellPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentCellChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentItemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemSelectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, rows: int, columns: int, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., cellActivated: typing.Callable = ..., cellChanged: typing.Callable = ..., cellClicked: typing.Callable = ..., cellDoubleClicked: typing.Callable = ..., cellEntered: typing.Callable = ..., cellPressed: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., columnCount: int = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cornerButtonEnabled: bool = ..., currentCellChanged: typing.Callable = ..., currentItemChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QTableWidget.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QTableWidget.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTableWidget.Shadow = ..., frameShape: QTableWidget.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridStyle: PySide2.QtCore.Qt.PenStyle = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QTableWidget.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., itemActivated: typing.Callable = ..., itemChanged: typing.Callable = ..., itemClicked: typing.Callable = ..., itemDoubleClicked: typing.Callable = ..., itemEntered: typing.Callable = ..., itemPressed: typing.Callable = ..., itemSelectionChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., rowCount: int = ..., selectionBehavior: QTableWidget.SelectionBehavior = ..., selectionMode: QTableWidget.SelectionMode = ..., showDropIndicator: bool = ..., showGrid: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTableWidget.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QTableWidget.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., cellActivated: typing.Callable = ..., cellChanged: typing.Callable = ..., cellClicked: typing.Callable = ..., cellDoubleClicked: typing.Callable = ..., cellEntered: typing.Callable = ..., cellPressed: typing.Callable = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., columnCount: int = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cornerButtonEnabled: bool = ..., currentCellChanged: typing.Callable = ..., currentItemChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QTableWidget.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QTableWidget.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTableWidget.Shadow = ..., frameShape: QTableWidget.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridStyle: PySide2.QtCore.Qt.PenStyle = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QTableWidget.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., itemActivated: typing.Callable = ..., itemChanged: typing.Callable = ..., itemClicked: typing.Callable = ..., itemDoubleClicked: typing.Callable = ..., itemEntered: typing.Callable = ..., itemPressed: typing.Callable = ..., itemSelectionChanged: typing.Callable = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., rowCount: int = ..., selectionBehavior: QTableWidget.SelectionBehavior = ..., selectionMode: QTableWidget.SelectionMode = ..., showDropIndicator: bool = ..., showGrid: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTableWidget.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QTableWidget.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def cellWidget(self, row: int, column: int) -> QWidget: ...
    def clear(self) -> None: ...
    def clearContents(self) -> None: ...
    @typing.overload
    def closePersistentEditor(self, item: QTableWidgetItem) -> None: ...
    @typing.overload
    def closePersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def column(self, item: QTableWidgetItem) -> int: ...
    def columnCount(self) -> int: ...
    def currentColumn(self) -> int: ...
    def currentItem(self) -> QTableWidgetItem: ...
    def currentRow(self) -> int: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    def dropMimeData(self, row: int, column: int, data: PySide2.QtCore.QMimeData, action: PySide2.QtCore.Qt.DropAction) -> bool: ...
    def editItem(self, item: QTableWidgetItem) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def findItems(self, text: str, flags: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag]) -> typing.List[QTableWidgetItem]: ...
    def horizontalHeaderItem(self, column: int) -> QTableWidgetItem: ...
    def indexFromItem(self, item: QTableWidgetItem) -> PySide2.QtCore.QModelIndex: ...
    def insertColumn(self, column: int) -> None: ...
    def insertRow(self, row: int) -> None: ...
    def isItemSelected(self, item: QTableWidgetItem) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, item: QTableWidgetItem) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isSortingEnabled(self) -> bool: ...
    def item(self, row: int, column: int) -> QTableWidgetItem: ...
    @typing.overload
    def itemAt(self, x: int, y: int) -> QTableWidgetItem: ...
    @typing.overload
    def itemAt(self, p: PySide2.QtCore.QPoint) -> QTableWidgetItem: ...
    def itemFromIndex(self, index: PySide2.QtCore.QModelIndex) -> QTableWidgetItem: ...
    def itemPrototype(self) -> QTableWidgetItem: ...
    def items(self, data: PySide2.QtCore.QMimeData) -> typing.List[QTableWidgetItem]: ...
    def mimeData(self, items: typing.Iterable[QTableWidgetItem]) -> PySide2.QtCore.QMimeData: ...
    def mimeTypes(self) -> typing.List[str]: ...
    @typing.overload
    def openPersistentEditor(self, item: QTableWidgetItem) -> None: ...
    @typing.overload
    def openPersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def removeCellWidget(self, row: int, column: int) -> None: ...
    def removeColumn(self, column: int) -> None: ...
    def removeRow(self, row: int) -> None: ...
    def row(self, item: QTableWidgetItem) -> int: ...
    def rowCount(self) -> int: ...
    def scrollToItem(self, item: QTableWidgetItem, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectedItems(self) -> typing.List[QTableWidgetItem]: ...
    def selectedRanges(self) -> typing.List[QTableWidgetSelectionRange]: ...
    def setCellWidget(self, row: int, column: int, widget: QWidget) -> None: ...
    def setColumnCount(self, columns: int) -> None: ...
    @typing.overload
    def setCurrentCell(self, row: int, column: int, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    @typing.overload
    def setCurrentCell(self, row: int, column: int) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QTableWidgetItem, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QTableWidgetItem) -> None: ...
    def setHorizontalHeaderItem(self, column: int, item: QTableWidgetItem) -> None: ...
    def setHorizontalHeaderLabels(self, labels: typing.Iterable[str]) -> None: ...
    def setItem(self, row: int, column: int, item: QTableWidgetItem) -> None: ...
    def setItemPrototype(self, item: QTableWidgetItem) -> None: ...
    def setItemSelected(self, item: QTableWidgetItem, select: bool) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setRangeSelected(self, range: QTableWidgetSelectionRange, select: bool) -> None: ...
    def setRowCount(self, rows: int) -> None: ...
    def setSortingEnabled(self, enable: bool) -> None: ...
    def setVerticalHeaderItem(self, row: int, item: QTableWidgetItem) -> None: ...
    def setVerticalHeaderLabels(self, labels: typing.Iterable[str]) -> None: ...
    def sortItems(self, column: int, order: PySide2.QtCore.Qt.SortOrder = ...) -> None: ...
    def supportedDropActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...
    def takeHorizontalHeaderItem(self, column: int) -> QTableWidgetItem: ...
    def takeItem(self, row: int, column: int) -> QTableWidgetItem: ...
    def takeVerticalHeaderItem(self, row: int) -> QTableWidgetItem: ...
    def verticalHeaderItem(self, row: int) -> QTableWidgetItem: ...
    def visualColumn(self, logicalColumn: int) -> int: ...
    def visualItemRect(self, item: QTableWidgetItem) -> PySide2.QtCore.QRect: ...
    def visualRow(self, logicalRow: int) -> int: ...

class QTableWidgetItem(shiboken2.Object):
    class ItemType:
        Type: typing.ClassVar[QTableWidgetItem.ItemType] = ...
        UserType: typing.ClassVar[QTableWidgetItem.ItemType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __and__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __rand__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __ror__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __sub__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
        def __xor__(self, other: typing.SupportsInt) -> QTableWidgetItem.ItemType: ...
    Type: typing.ClassVar[QTableWidgetItem.ItemType] = ...
    UserType: typing.ClassVar[QTableWidgetItem.ItemType] = ...
    @typing.overload
    def __init__(self, icon: PySide2.QtGui.QIcon, text: str, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, text: str, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QTableWidgetItem) -> None: ...
    def background(self) -> PySide2.QtGui.QBrush: ...
    def backgroundColor(self) -> PySide2.QtGui.QColor: ...
    def checkState(self) -> PySide2.QtCore.Qt.CheckState: ...
    def clone(self) -> QTableWidgetItem: ...
    def column(self) -> int: ...
    def data(self, role: PySide2.QtCore.Qt.ItemDataRole) -> typing.Any: ...
    def flags(self) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def foreground(self) -> PySide2.QtGui.QBrush: ...
    def icon(self) -> PySide2.QtGui.QIcon: ...
    def isSelected(self) -> bool: ...
    def read(self, in_: PySide2.QtCore.QDataStream) -> None: ...
    def row(self) -> int: ...
    def setBackground(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setBackgroundColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setCheckState(self, state: PySide2.QtCore.Qt.CheckState) -> None: ...
    def setData(self, role: PySide2.QtCore.Qt.ItemDataRole, value: typing.Any) -> None: ...
    def setFlags(self, flags: typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]) -> None: ...
    def setFont(self, font: PySide2.QtGui.QFont) -> None: ...
    def setForeground(self, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setSelected(self, select: bool) -> None: ...
    def setSizeHint(self, size: PySide2.QtCore.QSize) -> None: ...
    def setStatusTip(self, statusTip: str) -> None: ...
    def setText(self, text: str) -> None: ...
    def setTextAlignment(self, alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setTextColor(self, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setToolTip(self, toolTip: str) -> None: ...
    def setWhatsThis(self, whatsThis: str) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def statusTip(self) -> str: ...
    def tableWidget(self) -> QTableWidget: ...
    def text(self) -> str: ...
    def textAlignment(self) -> int: ...
    def textColor(self) -> PySide2.QtGui.QColor: ...
    def toolTip(self) -> str: ...
    def type(self) -> int: ...
    def whatsThis(self) -> str: ...
    def write(self, out: PySide2.QtCore.QDataStream) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, out: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, in_: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...

class QTableWidgetSelectionRange(shiboken2.Object):
    @typing.overload
    def __init__(self, top: int, left: int, bottom: int, right: int) -> None: ...
    @typing.overload
    def __init__(self, other: QTableWidgetSelectionRange) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def bottomRow(self) -> int: ...
    def columnCount(self) -> int: ...
    def leftColumn(self) -> int: ...
    def rightColumn(self) -> int: ...
    def rowCount(self) -> int: ...
    def topRow(self) -> int: ...
    def __copy__(self) -> None: ...

class QTapAndHoldGesture(QGesture):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., hotSpot: PySide2.QtCore.QPointF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., position: PySide2.QtCore.QPointF = ..., state: PySide2.QtCore.Qt.GestureState = ...) -> None: ...
    def position(self) -> PySide2.QtCore.QPointF: ...
    def setPosition(self, pos: PySide2.QtCore.QPointF) -> None: ...
    @classmethod
    def setTimeout(cls, msecs: int) -> None: ...
    @classmethod
    def timeout(cls) -> int: ...

class QTapGesture(QGesture):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., gestureCancelPolicy: typing.Any = ..., gestureType: PySide2.QtCore.Qt.GestureType = ..., hasHotSpot: bool = ..., hotSpot: PySide2.QtCore.QPointF = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., position: PySide2.QtCore.QPointF = ..., state: PySide2.QtCore.Qt.GestureState = ...) -> None: ...
    def position(self) -> PySide2.QtCore.QPointF: ...
    def setPosition(self, pos: PySide2.QtCore.QPointF) -> None: ...

class QTextBrowser(QTextEdit):
    anchorClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    backwardAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    forwardAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    highlighted: typing.ClassVar[PySide2.QtCore.Signal] = ...
    historyChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    sourceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., acceptRichText: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., anchorClicked: typing.Callable = ..., autoFillBackground: bool = ..., autoFormatting: QTextBrowser.AutoFormatting = ..., backwardAvailable: typing.Callable = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., copyAvailable: typing.Callable = ..., currentCharFormatChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorPositionChanged: typing.Callable = ..., cursorWidth: int = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., document: typing.Any = ..., documentTitle: str = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., forwardAvailable: typing.Callable = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTextBrowser.Shadow = ..., frameShape: QTextBrowser.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., highlighted: typing.Callable = ..., historyChanged: typing.Callable = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., html: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., lineWrapColumnOrWidth: int = ..., lineWrapMode: QTextBrowser.LineWrapMode = ..., locale: PySide2.QtCore.QLocale = ..., markdown: str = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., openExternalLinks: bool = ..., openLinks: bool = ..., overwriteMode: bool = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., plainText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: typing.Callable = ..., searchPaths: None = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTextBrowser.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., source: PySide2.QtCore.QUrl = ..., sourceChanged: typing.Callable = ..., sourceType: typing.Any = ..., statusTip: str = ..., styleSheet: str = ..., tabChangesFocus: bool = ..., tabStopDistance: float = ..., tabStopWidth: int = ..., tabletTracking: bool = ..., textChanged: typing.Callable = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: typing.Callable = ..., undoRedoEnabled: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def backward(self) -> None: ...
    def backwardHistoryCount(self) -> int: ...
    def clearHistory(self) -> None: ...
    def doSetSource(self, name: PySide2.QtCore.QUrl, type: PySide2.QtGui.QTextDocument.ResourceType = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, ev: PySide2.QtGui.QFocusEvent) -> None: ...
    def forward(self) -> None: ...
    def forwardHistoryCount(self) -> int: ...
    def historyTitle(self, arg__1: int) -> str: ...
    def historyUrl(self, arg__1: int) -> PySide2.QtCore.QUrl: ...
    def home(self) -> None: ...
    def isBackwardAvailable(self) -> bool: ...
    def isForwardAvailable(self) -> bool: ...
    def keyPressEvent(self, ev: PySide2.QtGui.QKeyEvent) -> None: ...
    def loadResource(self, type: int, name: PySide2.QtCore.QUrl) -> typing.Any: ...
    def mouseMoveEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, ev: PySide2.QtGui.QMouseEvent) -> None: ...
    def openExternalLinks(self) -> bool: ...
    def openLinks(self) -> bool: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def reload(self) -> None: ...
    def searchPaths(self) -> typing.List[str]: ...
    def setOpenExternalLinks(self, open: bool) -> None: ...
    def setOpenLinks(self, open: bool) -> None: ...
    def setSearchPaths(self, paths: typing.Iterable[str]) -> None: ...
    @typing.overload
    def setSource(self, name: PySide2.QtCore.QUrl, type: PySide2.QtGui.QTextDocument.ResourceType) -> None: ...
    @typing.overload
    def setSource(self, name: PySide2.QtCore.QUrl) -> None: ...
    def source(self) -> PySide2.QtCore.QUrl: ...
    def sourceType(self) -> PySide2.QtGui.QTextDocument.ResourceType: ...

class QTextEdit(QAbstractScrollArea):
    class AutoFormatting:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QTextEdit.AutoFormatting: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __rand__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __ror__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __xor__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...

    class AutoFormattingFlag:
        AutoAll: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
        AutoBulletList: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
        AutoNone: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QTextEdit.AutoFormatting: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __rand__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __ror__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...
        def __xor__(self, other: typing.SupportsInt) -> QTextEdit.AutoFormatting: ...

    class ExtraSelection(shiboken2.Object):
        cursor: _typeshed.Incomplete
        format: _typeshed.Incomplete
        @typing.overload
        def __init__(self, ExtraSelection: QTextEdit.ExtraSelection) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        def __copy__(self) -> None: ...

    class LineWrapMode:
        FixedColumnWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
        FixedPixelWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
        NoWrap: typing.ClassVar[QTextEdit.LineWrapMode] = ...
        WidgetWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __and__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QTextEdit.LineWrapMode: ...
    AutoAll: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
    AutoBulletList: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
    AutoNone: typing.ClassVar[QTextEdit.AutoFormattingFlag] = ...
    FixedColumnWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
    FixedPixelWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
    NoWrap: typing.ClassVar[QTextEdit.LineWrapMode] = ...
    WidgetWidth: typing.ClassVar[QTextEdit.LineWrapMode] = ...
    copyAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    currentCharFormatChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cursorPositionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    redoAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    selectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    textChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    undoAvailable: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., acceptRichText: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., autoFormatting: typing.Union[QTextEdit.AutoFormatting, QTextEdit.AutoFormattingFlag] = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., copyAvailable: typing.Callable = ..., currentCharFormatChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorPositionChanged: typing.Callable = ..., cursorWidth: int = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., document: PySide2.QtGui.QTextDocument = ..., documentTitle: str = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTextEdit.Shadow = ..., frameShape: QTextEdit.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., html: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., lineWrapColumnOrWidth: int = ..., lineWrapMode: QTextEdit.LineWrapMode = ..., locale: PySide2.QtCore.QLocale = ..., markdown: str = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overwriteMode: bool = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., plainText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: typing.Callable = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTextEdit.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabChangesFocus: bool = ..., tabStopDistance: float = ..., tabStopWidth: int = ..., tabletTracking: bool = ..., textChanged: typing.Callable = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: typing.Callable = ..., undoRedoEnabled: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., acceptRichText: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., autoFormatting: typing.Union[QTextEdit.AutoFormatting, QTextEdit.AutoFormattingFlag] = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., copyAvailable: typing.Callable = ..., currentCharFormatChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., cursorPositionChanged: typing.Callable = ..., cursorWidth: int = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., document: PySide2.QtGui.QTextDocument = ..., documentTitle: str = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTextEdit.Shadow = ..., frameShape: QTextEdit.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., html: str = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., lineWrapColumnOrWidth: int = ..., lineWrapMode: QTextEdit.LineWrapMode = ..., locale: PySide2.QtCore.QLocale = ..., markdown: str = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., overwriteMode: bool = ..., palette: PySide2.QtGui.QPalette = ..., placeholderText: str = ..., plainText: str = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., redoAvailable: typing.Callable = ..., selectionChanged: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTextEdit.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabChangesFocus: bool = ..., tabStopDistance: float = ..., tabStopWidth: int = ..., tabletTracking: bool = ..., textChanged: typing.Callable = ..., textInteractionFlags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag] = ..., toolTip: str = ..., toolTipDuration: int = ..., undoAvailable: typing.Callable = ..., undoRedoEnabled: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def acceptRichText(self) -> bool: ...
    def alignment(self) -> typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]: ...
    def anchorAt(self, pos: PySide2.QtCore.QPoint) -> str: ...
    def append(self, text: str) -> None: ...
    def autoFormatting(self) -> typing.Union[QTextEdit.AutoFormatting, QTextEdit.AutoFormattingFlag]: ...
    def canInsertFromMimeData(self, source: PySide2.QtCore.QMimeData) -> bool: ...
    def canPaste(self) -> bool: ...
    def changeEvent(self, e: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def contextMenuEvent(self, e: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def copy(self) -> None: ...
    def createMimeDataFromSelection(self) -> PySide2.QtCore.QMimeData: ...
    @typing.overload
    def createStandardContextMenu(self, position: PySide2.QtCore.QPoint) -> QMenu: ...
    @typing.overload
    def createStandardContextMenu(self) -> QMenu: ...
    def currentCharFormat(self) -> PySide2.QtGui.QTextCharFormat: ...
    def currentFont(self) -> PySide2.QtGui.QFont: ...
    def cursorForPosition(self, pos: PySide2.QtCore.QPoint) -> PySide2.QtGui.QTextCursor: ...
    @typing.overload
    def cursorRect(self, cursor: PySide2.QtGui.QTextCursor) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def cursorRect(self) -> PySide2.QtCore.QRect: ...
    def cursorWidth(self) -> int: ...
    def cut(self) -> None: ...
    def doSetTextCursor(self, cursor: PySide2.QtGui.QTextCursor) -> None: ...
    def document(self) -> PySide2.QtGui.QTextDocument: ...
    def documentTitle(self) -> str: ...
    def dragEnterEvent(self, e: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, e: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, e: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, e: PySide2.QtGui.QDropEvent) -> None: ...
    def ensureCursorVisible(self) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def extraSelections(self) -> typing.List[QTextEdit.ExtraSelection]: ...
    @typing.overload
    def find(self, exp: PySide2.QtCore.QRegExp, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    @typing.overload
    def find(self, exp: PySide2.QtCore.QRegularExpression, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    @typing.overload
    def find(self, exp: str, options: typing.Union[PySide2.QtGui.QTextDocument.FindFlags, PySide2.QtGui.QTextDocument.FindFlag] = ...) -> bool: ...
    def focusInEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, e: PySide2.QtGui.QFocusEvent) -> None: ...
    def fontFamily(self) -> str: ...
    def fontItalic(self) -> bool: ...
    def fontPointSize(self) -> float: ...
    def fontUnderline(self) -> bool: ...
    def fontWeight(self) -> int: ...
    def inputMethodEvent(self, arg__1: PySide2.QtGui.QInputMethodEvent) -> None: ...
    @typing.overload
    def inputMethodQuery(self, query: PySide2.QtCore.Qt.InputMethodQuery, argument: typing.Any) -> typing.Any: ...
    @typing.overload
    def inputMethodQuery(self, property: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def insertFromMimeData(self, source: PySide2.QtCore.QMimeData) -> None: ...
    def insertHtml(self, text: str) -> None: ...
    def insertPlainText(self, text: str) -> None: ...
    def isReadOnly(self) -> bool: ...
    def isUndoRedoEnabled(self) -> bool: ...
    def keyPressEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, e: PySide2.QtGui.QKeyEvent) -> None: ...
    def lineWrapColumnOrWidth(self) -> int: ...
    def lineWrapMode(self) -> QTextEdit.LineWrapMode: ...
    def loadResource(self, type: int, name: PySide2.QtCore.QUrl) -> typing.Any: ...
    def mergeCurrentCharFormat(self, modifier: PySide2.QtGui.QTextCharFormat) -> None: ...
    def mouseDoubleClickEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, e: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, operation: PySide2.QtGui.QTextCursor.MoveOperation, mode: PySide2.QtGui.QTextCursor.MoveMode = ...) -> None: ...
    def overwriteMode(self) -> bool: ...
    def paintEvent(self, e: PySide2.QtGui.QPaintEvent) -> None: ...
    def paste(self) -> None: ...
    def placeholderText(self) -> str: ...
    def print_(self, printer: PySide2.QtGui.QPagedPaintDevice) -> None: ...
    def redo(self) -> None: ...
    def resizeEvent(self, e: PySide2.QtGui.QResizeEvent) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollToAnchor(self, name: str) -> None: ...
    def selectAll(self) -> None: ...
    def setAcceptRichText(self, accept: bool) -> None: ...
    def setAlignment(self, a: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag]) -> None: ...
    def setAutoFormatting(self, features: typing.Union[QTextEdit.AutoFormatting, QTextEdit.AutoFormattingFlag]) -> None: ...
    def setCurrentCharFormat(self, format: PySide2.QtGui.QTextCharFormat) -> None: ...
    def setCurrentFont(self, f: PySide2.QtGui.QFont) -> None: ...
    def setCursorWidth(self, width: int) -> None: ...
    def setDocument(self, document: PySide2.QtGui.QTextDocument) -> None: ...
    def setDocumentTitle(self, title: str) -> None: ...
    def setExtraSelections(self, selections: typing.Iterable[QTextEdit.ExtraSelection]) -> None: ...
    def setFontFamily(self, fontFamily: str) -> None: ...
    def setFontItalic(self, b: bool) -> None: ...
    def setFontPointSize(self, s: float) -> None: ...
    def setFontUnderline(self, b: bool) -> None: ...
    def setFontWeight(self, w: typing.Union[int, PySide2.QtGui.QFont.Weight]) -> None: ...
    def setHtml(self, text: str) -> None: ...
    def setLineWrapColumnOrWidth(self, w: int) -> None: ...
    def setLineWrapMode(self, mode: QTextEdit.LineWrapMode) -> None: ...
    def setMarkdown(self, markdown: str) -> None: ...
    def setOverwriteMode(self, overwrite: bool) -> None: ...
    def setPlaceholderText(self, placeholderText: str) -> None: ...
    def setPlainText(self, text: str) -> None: ...
    def setReadOnly(self, ro: bool) -> None: ...
    def setTabChangesFocus(self, b: bool) -> None: ...
    def setTabStopDistance(self, distance: float) -> None: ...
    def setTabStopWidth(self, width: int) -> None: ...
    def setText(self, text: str) -> None: ...
    def setTextBackgroundColor(self, c: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setTextColor(self, c: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setTextCursor(self, cursor: PySide2.QtGui.QTextCursor) -> None: ...
    def setTextInteractionFlags(self, flags: typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]) -> None: ...
    def setUndoRedoEnabled(self, enable: bool) -> None: ...
    def setWordWrapMode(self, policy: PySide2.QtGui.QTextOption.WrapMode) -> None: ...
    def showEvent(self, arg__1: PySide2.QtGui.QShowEvent) -> None: ...
    def tabChangesFocus(self) -> bool: ...
    def tabStopDistance(self) -> float: ...
    def tabStopWidth(self) -> int: ...
    def textBackgroundColor(self) -> PySide2.QtGui.QColor: ...
    def textColor(self) -> PySide2.QtGui.QColor: ...
    def textCursor(self) -> PySide2.QtGui.QTextCursor: ...
    def textInteractionFlags(self) -> typing.Union[PySide2.QtCore.Qt.TextInteractionFlags, PySide2.QtCore.Qt.TextInteractionFlag]: ...
    def timerEvent(self, e: PySide2.QtCore.QTimerEvent) -> None: ...
    def toHtml(self) -> str: ...
    def toMarkdown(self, features: typing.Union[PySide2.QtGui.QTextDocument.MarkdownFeatures, PySide2.QtGui.QTextDocument.MarkdownFeature] = ...) -> str: ...
    def toPlainText(self) -> str: ...
    def undo(self) -> None: ...
    def wheelEvent(self, e: PySide2.QtGui.QWheelEvent) -> None: ...
    def wordWrapMode(self) -> PySide2.QtGui.QTextOption.WrapMode: ...
    def zoomIn(self, range: int = ...) -> None: ...
    def zoomInF(self, range: float) -> None: ...
    def zoomOut(self, range: int = ...) -> None: ...

class QTileRules(shiboken2.Object):
    horizontal: _typeshed.Incomplete
    vertical: _typeshed.Incomplete
    @typing.overload
    def __init__(self, horizontalRule: PySide2.QtCore.Qt.TileRule, verticalRule: PySide2.QtCore.Qt.TileRule) -> None: ...
    @typing.overload
    def __init__(self, rule: PySide2.QtCore.Qt.TileRule = ...) -> None: ...
    @typing.overload
    def __init__(self, QTileRules: QTileRules) -> None: ...
    def __copy__(self) -> None: ...

class QTimeEdit(QDateTimeEdit):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    userTimeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, time: PySide2.QtCore.QTime, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QTimeEdit.CorrectionMode = ..., currentSection: QTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: QTimeEdit.Sections = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., userTimeChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., accelerated: bool = ..., acceptDrops: bool = ..., acceptableInput: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., alignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., buttonSymbols: QTimeEdit.ButtonSymbols = ..., calendarPopup: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., correctionMode: QTimeEdit.CorrectionMode = ..., currentSection: QTimeEdit.Section = ..., currentSectionIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., date: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., dateChanged: typing.Callable = ..., dateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., dateTimeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., displayFormat: str = ..., displayedSections: QTimeEdit.Sections = ..., editingFinished: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frame: bool = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., keyboardTracking: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., maximumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumTime: PySide2.QtCore.QTime = ..., maximumWidth: int = ..., minimized: bool = ..., minimumDate: typing.Union[PySide2.QtCore.QDate, datetime.date] = ..., minimumDateTime: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime] = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumTime: PySide2.QtCore.QTime = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., readOnly: bool = ..., rect: PySide2.QtCore.QRect = ..., sectionCount: int = ..., showGroupSeparator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., specialValueText: str = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., time: PySide2.QtCore.QTime = ..., timeChanged: typing.Callable = ..., timeSpec: PySide2.QtCore.Qt.TimeSpec = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., userTimeChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wrapping: bool = ..., x: int = ..., y: int = ...) -> None: ...

class QToolBar(QWidget):
    actionTriggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    allowedAreasChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    iconSizeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    movableChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    orientationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    toolButtonStyleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    topLevelChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    visibilityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    @typing.overload
    def __init__(self, title: str, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., allowedAreas: typing.Union[PySide2.QtCore.Qt.ToolBarAreas, PySide2.QtCore.Qt.ToolBarArea] = ..., allowedAreasChanged: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., floatable: bool = ..., floating: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., movable: bool = ..., movableChanged: typing.Callable = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., orientationChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle = ..., toolButtonStyleChanged: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., topLevelChanged: typing.Callable = ..., updatesEnabled: bool = ..., visibilityChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., actionTriggered: typing.Callable = ..., allowedAreas: typing.Union[PySide2.QtCore.Qt.ToolBarAreas, PySide2.QtCore.Qt.ToolBarArea] = ..., allowedAreasChanged: typing.Callable = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., floatable: bool = ..., floating: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., movable: bool = ..., movableChanged: typing.Callable = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., orientation: PySide2.QtCore.Qt.Orientation = ..., orientationChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle = ..., toolButtonStyleChanged: typing.Callable = ..., toolTip: str = ..., toolTipDuration: int = ..., topLevelChanged: typing.Callable = ..., updatesEnabled: bool = ..., visibilityChanged: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def actionAt(self, x: int, y: int) -> QAction: ...
    @typing.overload
    def actionAt(self, p: PySide2.QtCore.QPoint) -> QAction: ...
    def actionEvent(self, event: PySide2.QtGui.QActionEvent) -> None: ...
    def actionGeometry(self, action: QAction) -> PySide2.QtCore.QRect: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, text: str, receiver: PySide2.QtCore.QObject, member: bytes) -> QAction: ...
    @typing.overload
    def addAction(self, text: str, receiver: PySide2.QtCore.QObject, member: bytes) -> QAction: ...
    @typing.overload
    def addAction(self, icon: PySide2.QtGui.QIcon, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, text: str) -> QAction: ...
    @typing.overload
    def addAction(self, arg__1: QAction) -> None: ...
    def addSeparator(self) -> QAction: ...
    def addWidget(self, widget: QWidget) -> QAction: ...
    def allowedAreas(self) -> typing.Union[PySide2.QtCore.Qt.ToolBarAreas, PySide2.QtCore.Qt.ToolBarArea]: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def clear(self) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def iconSize(self) -> PySide2.QtCore.QSize: ...
    def initStyleOption(self, option: QStyleOptionToolBar) -> None: ...
    def insertSeparator(self, before: QAction) -> QAction: ...
    def insertWidget(self, before: QAction, widget: QWidget) -> QAction: ...
    def isAreaAllowed(self, area: PySide2.QtCore.Qt.ToolBarArea) -> bool: ...
    def isFloatable(self) -> bool: ...
    def isFloating(self) -> bool: ...
    def isMovable(self) -> bool: ...
    def orientation(self) -> PySide2.QtCore.Qt.Orientation: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def setAllowedAreas(self, areas: typing.Union[PySide2.QtCore.Qt.ToolBarAreas, PySide2.QtCore.Qt.ToolBarArea]) -> None: ...
    def setFloatable(self, floatable: bool) -> None: ...
    def setIconSize(self, iconSize: PySide2.QtCore.QSize) -> None: ...
    def setMovable(self, movable: bool) -> None: ...
    def setOrientation(self, orientation: PySide2.QtCore.Qt.Orientation) -> None: ...
    def setToolButtonStyle(self, toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle) -> None: ...
    def toggleViewAction(self) -> QAction: ...
    def toolButtonStyle(self) -> PySide2.QtCore.Qt.ToolButtonStyle: ...
    def widgetForAction(self, action: QAction) -> QWidget: ...

class QToolBox(QFrame):
    currentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., count: int = ..., currentChanged: typing.Callable = ..., currentIndex: int = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QToolBox.Shadow = ..., frameShape: QToolBox.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def addItem(self, widget: QWidget, icon: PySide2.QtGui.QIcon, text: str) -> int: ...
    @typing.overload
    def addItem(self, widget: QWidget, text: str) -> int: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def count(self) -> int: ...
    def currentIndex(self) -> int: ...
    def currentWidget(self) -> QWidget: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def indexOf(self, widget: QWidget) -> int: ...
    @typing.overload
    def insertItem(self, index: int, widget: QWidget, icon: PySide2.QtGui.QIcon, text: str) -> int: ...
    @typing.overload
    def insertItem(self, index: int, widget: QWidget, text: str) -> int: ...
    def isItemEnabled(self, index: int) -> bool: ...
    def itemIcon(self, index: int) -> PySide2.QtGui.QIcon: ...
    def itemInserted(self, index: int) -> None: ...
    def itemRemoved(self, index: int) -> None: ...
    def itemText(self, index: int) -> str: ...
    def itemToolTip(self, index: int) -> str: ...
    def removeItem(self, index: int) -> None: ...
    def setCurrentIndex(self, index: int) -> None: ...
    def setCurrentWidget(self, widget: QWidget) -> None: ...
    def setItemEnabled(self, index: int, enabled: bool) -> None: ...
    def setItemIcon(self, index: int, icon: PySide2.QtGui.QIcon) -> None: ...
    def setItemText(self, index: int, text: str) -> None: ...
    def setItemToolTip(self, index: int, toolTip: str) -> None: ...
    def showEvent(self, e: PySide2.QtGui.QShowEvent) -> None: ...
    def widget(self, index: int) -> QWidget: ...

class QToolButton(QAbstractButton):
    class ToolButtonPopupMode:
        DelayedPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
        InstantPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
        MenuButtonPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __and__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QToolButton.ToolButtonPopupMode: ...
    DelayedPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
    InstantPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
    MenuButtonPopup: typing.ClassVar[QToolButton.ToolButtonPopupMode] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    triggered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., arrowType: PySide2.QtCore.Qt.ArrowType = ..., autoExclusive: bool = ..., autoFillBackground: bool = ..., autoRaise: bool = ..., autoRepeat: bool = ..., autoRepeatDelay: int = ..., autoRepeatInterval: int = ..., baseSize: PySide2.QtCore.QSize = ..., checkable: bool = ..., checked: bool = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., down: bool = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., icon: PySide2.QtGui.QIcon = ..., iconSize: PySide2.QtCore.QSize = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., popupMode: QToolButton.ToolButtonPopupMode = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., released: typing.Callable = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., text: str = ..., toggled: typing.Callable = ..., toolButtonStyle: PySide2.QtCore.Qt.ToolButtonStyle = ..., toolTip: str = ..., toolTipDuration: int = ..., triggered: typing.Callable = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def actionEvent(self, arg__1: PySide2.QtGui.QActionEvent) -> None: ...
    def arrowType(self) -> PySide2.QtCore.Qt.ArrowType: ...
    def autoRaise(self) -> bool: ...
    def changeEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def defaultAction(self) -> QAction: ...
    def enterEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def hitButton(self, pos: PySide2.QtCore.QPoint) -> bool: ...
    def initStyleOption(self, option: QStyleOptionToolButton) -> None: ...
    def leaveEvent(self, arg__1: PySide2.QtCore.QEvent) -> None: ...
    def menu(self) -> QMenu: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def mousePressEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide2.QtGui.QMouseEvent) -> None: ...
    def nextCheckState(self) -> None: ...
    def paintEvent(self, arg__1: PySide2.QtGui.QPaintEvent) -> None: ...
    def popupMode(self) -> QToolButton.ToolButtonPopupMode: ...
    def setArrowType(self, type: PySide2.QtCore.Qt.ArrowType) -> None: ...
    def setAutoRaise(self, enable: bool) -> None: ...
    def setDefaultAction(self, arg__1: QAction) -> None: ...
    def setMenu(self, menu: QMenu) -> None: ...
    def setPopupMode(self, mode: QToolButton.ToolButtonPopupMode) -> None: ...
    def setToolButtonStyle(self, style: PySide2.QtCore.Qt.ToolButtonStyle) -> None: ...
    def showMenu(self) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...
    def toolButtonStyle(self) -> PySide2.QtCore.Qt.ToolButtonStyle: ...

class QToolTip(shiboken2.Object):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def font(cls) -> PySide2.QtGui.QFont: ...
    @classmethod
    def hideText(cls) -> None: ...
    @classmethod
    def isVisible(cls) -> bool: ...
    @classmethod
    def palette(cls) -> PySide2.QtGui.QPalette: ...
    @classmethod
    def setFont(cls, arg__1: PySide2.QtGui.QFont) -> None: ...
    @classmethod
    def setPalette(cls, arg__1: PySide2.QtGui.QPalette) -> None: ...
    @typing.overload
    @classmethod
    def showText(cls, pos: PySide2.QtCore.QPoint, text: str, w: QWidget, rect: PySide2.QtCore.QRect, msecShowTime: int) -> None: ...
    @typing.overload
    @classmethod
    def showText(cls, pos: PySide2.QtCore.QPoint, text: str, w: QWidget, rect: PySide2.QtCore.QRect) -> None: ...
    @typing.overload
    @classmethod
    def showText(cls, pos: PySide2.QtCore.QPoint, text: str, w: typing.Union[QWidget, None] = ...) -> None: ...
    @classmethod
    def text(cls) -> str: ...

class QTreeView(QAbstractItemView):
    collapsed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    expanded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., allColumnsShowFocus: bool = ..., alternatingRowColors: bool = ..., animated: bool = ..., autoExpandDelay: int = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., collapsed: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QTreeView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QTreeView.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., expanded: typing.Callable = ..., expandsOnDoubleClick: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTreeView.Shadow = ..., frameShape: QTreeView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., headerHidden: bool = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QTreeView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indentation: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., itemsExpandable: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., rootIsDecorated: bool = ..., selectionBehavior: QTreeView.SelectionBehavior = ..., selectionMode: QTreeView.SelectionMode = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTreeView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformRowHeights: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QTreeView.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def allColumnsShowFocus(self) -> bool: ...
    def autoExpandDelay(self) -> int: ...
    def collapse(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def collapseAll(self) -> None: ...
    def columnAt(self, x: int) -> int: ...
    def columnCountChanged(self, oldCount: int, newCount: int) -> None: ...
    def columnMoved(self) -> None: ...
    def columnResized(self, column: int, oldSize: int, newSize: int) -> None: ...
    def columnViewportPosition(self, column: int) -> int: ...
    def columnWidth(self, column: int) -> int: ...
    def currentChanged(self, current: PySide2.QtCore.QModelIndex, previous: PySide2.QtCore.QModelIndex) -> None: ...
    def dataChanged(self, topLeft: PySide2.QtCore.QModelIndex, bottomRight: PySide2.QtCore.QModelIndex, roles: typing.List[int] = ...) -> None: ...
    def doItemsLayout(self) -> None: ...
    def dragMoveEvent(self, event: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def drawBranches(self, painter: PySide2.QtGui.QPainter, rect: PySide2.QtCore.QRect, index: PySide2.QtCore.QModelIndex) -> None: ...
    def drawRow(self, painter: PySide2.QtGui.QPainter, options: QStyleOptionViewItem, index: PySide2.QtCore.QModelIndex) -> None: ...
    def drawTree(self, painter: PySide2.QtGui.QPainter, region: PySide2.QtGui.QRegion) -> None: ...
    def expand(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def expandAll(self) -> None: ...
    def expandRecursively(self, index: PySide2.QtCore.QModelIndex, depth: int = ...) -> None: ...
    def expandToDepth(self, depth: int) -> None: ...
    def expandsOnDoubleClick(self) -> bool: ...
    def header(self) -> QHeaderView: ...
    def hideColumn(self, column: int) -> None: ...
    def horizontalOffset(self) -> int: ...
    def horizontalScrollbarAction(self, action: int) -> None: ...
    def indentation(self) -> int: ...
    def indexAbove(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    def indexAt(self, p: PySide2.QtCore.QPoint) -> PySide2.QtCore.QModelIndex: ...
    def indexBelow(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    def indexRowSizeHint(self, index: PySide2.QtCore.QModelIndex) -> int: ...
    def isAnimated(self) -> bool: ...
    def isColumnHidden(self, column: int) -> bool: ...
    def isExpanded(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isFirstColumnSpanned(self, row: int, parent: PySide2.QtCore.QModelIndex) -> bool: ...
    def isHeaderHidden(self) -> bool: ...
    def isIndexHidden(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def isRowHidden(self, row: int, parent: PySide2.QtCore.QModelIndex) -> bool: ...
    def isSortingEnabled(self) -> bool: ...
    def itemsExpandable(self) -> bool: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyboardSearch(self, search: str) -> None: ...
    def mouseDoubleClickEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier]) -> PySide2.QtCore.QModelIndex: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def reexpand(self) -> None: ...
    def reset(self) -> None: ...
    def resetIndentation(self) -> None: ...
    def resizeColumnToContents(self, column: int) -> None: ...
    def rootIsDecorated(self) -> bool: ...
    def rowHeight(self, index: PySide2.QtCore.QModelIndex) -> int: ...
    def rowsAboutToBeRemoved(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def rowsInserted(self, parent: PySide2.QtCore.QModelIndex, start: int, end: int) -> None: ...
    def rowsRemoved(self, parent: PySide2.QtCore.QModelIndex, first: int, last: int) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def scrollTo(self, index: PySide2.QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectAll(self) -> None: ...
    def selectedIndexes(self) -> typing.List[PySide2.QtCore.QModelIndex]: ...
    def selectionChanged(self, selected: PySide2.QtCore.QItemSelection, deselected: PySide2.QtCore.QItemSelection) -> None: ...
    def setAllColumnsShowFocus(self, enable: bool) -> None: ...
    def setAnimated(self, enable: bool) -> None: ...
    def setAutoExpandDelay(self, delay: int) -> None: ...
    def setColumnHidden(self, column: int, hide: bool) -> None: ...
    def setColumnWidth(self, column: int, width: int) -> None: ...
    def setExpanded(self, index: PySide2.QtCore.QModelIndex, expand: bool) -> None: ...
    def setExpandsOnDoubleClick(self, enable: bool) -> None: ...
    def setFirstColumnSpanned(self, row: int, parent: PySide2.QtCore.QModelIndex, span: bool) -> None: ...
    def setHeader(self, header: QHeaderView) -> None: ...
    def setHeaderHidden(self, hide: bool) -> None: ...
    def setIndentation(self, i: int) -> None: ...
    def setItemsExpandable(self, enable: bool) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setRootIndex(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def setRootIsDecorated(self, show: bool) -> None: ...
    def setRowHidden(self, row: int, parent: PySide2.QtCore.QModelIndex, hide: bool) -> None: ...
    def setSelection(self, rect: PySide2.QtCore.QRect, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def setSortingEnabled(self, enable: bool) -> None: ...
    def setTreePosition(self, logicalIndex: int) -> None: ...
    def setUniformRowHeights(self, uniform: bool) -> None: ...
    def setWordWrap(self, on: bool) -> None: ...
    def showColumn(self, column: int) -> None: ...
    def sizeHintForColumn(self, column: int) -> int: ...
    @typing.overload
    def sortByColumn(self, column: int, order: PySide2.QtCore.Qt.SortOrder) -> None: ...
    @typing.overload
    def sortByColumn(self, column: int) -> None: ...
    def timerEvent(self, event: PySide2.QtCore.QTimerEvent) -> None: ...
    def treePosition(self) -> int: ...
    def uniformRowHeights(self) -> bool: ...
    def updateGeometries(self) -> None: ...
    def verticalOffset(self) -> int: ...
    def verticalScrollbarValueChanged(self, value: int) -> None: ...
    def viewportEvent(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def viewportSizeHint(self) -> PySide2.QtCore.QSize: ...
    def visualRect(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QRect: ...
    def visualRegionForSelection(self, selection: PySide2.QtCore.QItemSelection) -> PySide2.QtGui.QRegion: ...
    def wordWrap(self) -> bool: ...

class QTreeWidget(QTreeView):
    currentItemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemActivated: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemCollapsed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemDoubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemEntered: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemExpanded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
    itemSelectionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., allColumnsShowFocus: bool = ..., alternatingRowColors: bool = ..., animated: bool = ..., autoExpandDelay: int = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., clicked: typing.Callable = ..., collapsed: typing.Callable = ..., columnCount: int = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentItemChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QTreeWidget.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QTreeWidget.EditTriggers = ..., enabled: bool = ..., entered: typing.Callable = ..., expanded: typing.Callable = ..., expandsOnDoubleClick: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QTreeWidget.Shadow = ..., frameShape: QTreeWidget.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., headerHidden: bool = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QTreeWidget.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indentation: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., itemActivated: typing.Callable = ..., itemChanged: typing.Callable = ..., itemClicked: typing.Callable = ..., itemCollapsed: typing.Callable = ..., itemDoubleClicked: typing.Callable = ..., itemEntered: typing.Callable = ..., itemExpanded: typing.Callable = ..., itemPressed: typing.Callable = ..., itemSelectionChanged: typing.Callable = ..., itemsExpandable: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., rootIsDecorated: bool = ..., selectionBehavior: QTreeWidget.SelectionBehavior = ..., selectionMode: QTreeWidget.SelectionMode = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QTreeWidget.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., sortingEnabled: bool = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., topLevelItemCount: int = ..., uniformRowHeights: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QTreeWidget.ScrollMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def addTopLevelItem(self, item: QTreeWidgetItem) -> None: ...
    def addTopLevelItems(self, items: typing.Iterable[QTreeWidgetItem]) -> None: ...
    def clear(self) -> None: ...
    @typing.overload
    def closePersistentEditor(self, item: QTreeWidgetItem, column: int = ...) -> None: ...
    @typing.overload
    def closePersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def collapseItem(self, item: QTreeWidgetItem) -> None: ...
    def columnCount(self) -> int: ...
    def currentColumn(self) -> int: ...
    def currentItem(self) -> QTreeWidgetItem: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    def dropMimeData(self, parent: QTreeWidgetItem, index: int, data: PySide2.QtCore.QMimeData, action: PySide2.QtCore.Qt.DropAction) -> bool: ...
    def editItem(self, item: QTreeWidgetItem, column: int = ...) -> None: ...
    def event(self, e: PySide2.QtCore.QEvent) -> bool: ...
    def expandItem(self, item: QTreeWidgetItem) -> None: ...
    def findItems(self, text: str, flags: typing.Union[PySide2.QtCore.Qt.MatchFlags, PySide2.QtCore.Qt.MatchFlag], column: int = ...) -> typing.List[QTreeWidgetItem]: ...
    def headerItem(self) -> QTreeWidgetItem: ...
    def indexFromItem(self, item: QTreeWidgetItem, column: int = ...) -> PySide2.QtCore.QModelIndex: ...
    def indexOfTopLevelItem(self, item: QTreeWidgetItem) -> int: ...
    def insertTopLevelItem(self, index: int, item: QTreeWidgetItem) -> None: ...
    def insertTopLevelItems(self, index: int, items: typing.Iterable[QTreeWidgetItem]) -> None: ...
    def invisibleRootItem(self) -> QTreeWidgetItem: ...
    def isFirstItemColumnSpanned(self, item: QTreeWidgetItem) -> bool: ...
    def isItemExpanded(self, item: QTreeWidgetItem) -> bool: ...
    def isItemHidden(self, item: QTreeWidgetItem) -> bool: ...
    def isItemSelected(self, item: QTreeWidgetItem) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, item: QTreeWidgetItem, column: int = ...) -> bool: ...
    @typing.overload
    def isPersistentEditorOpen(self, index: PySide2.QtCore.QModelIndex) -> bool: ...
    def itemAbove(self, item: QTreeWidgetItem) -> QTreeWidgetItem: ...
    @typing.overload
    def itemAt(self, x: int, y: int) -> QTreeWidgetItem: ...
    @typing.overload
    def itemAt(self, p: PySide2.QtCore.QPoint) -> QTreeWidgetItem: ...
    def itemBelow(self, item: QTreeWidgetItem) -> QTreeWidgetItem: ...
    def itemFromIndex(self, index: PySide2.QtCore.QModelIndex) -> QTreeWidgetItem: ...
    def itemWidget(self, item: QTreeWidgetItem, column: int) -> QWidget: ...
    def items(self, data: PySide2.QtCore.QMimeData) -> typing.List[QTreeWidgetItem]: ...
    def mimeData(self, items: typing.Iterable[QTreeWidgetItem]) -> PySide2.QtCore.QMimeData: ...
    def mimeTypes(self) -> typing.List[str]: ...
    @typing.overload
    def openPersistentEditor(self, item: QTreeWidgetItem, column: int = ...) -> None: ...
    @typing.overload
    def openPersistentEditor(self, index: PySide2.QtCore.QModelIndex) -> None: ...
    def removeItemWidget(self, item: QTreeWidgetItem, column: int) -> None: ...
    def scrollToItem(self, item: QTreeWidgetItem, hint: QAbstractItemView.ScrollHint = ...) -> None: ...
    def selectedItems(self) -> typing.List[QTreeWidgetItem]: ...
    def setColumnCount(self, columns: int) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QTreeWidgetItem, column: int, command: typing.Union[PySide2.QtCore.QItemSelectionModel.SelectionFlags, PySide2.QtCore.QItemSelectionModel.SelectionFlag]) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QTreeWidgetItem, column: int) -> None: ...
    @typing.overload
    def setCurrentItem(self, item: QTreeWidgetItem) -> None: ...
    def setFirstItemColumnSpanned(self, item: QTreeWidgetItem, span: bool) -> None: ...
    def setHeaderItem(self, item: QTreeWidgetItem) -> None: ...
    def setHeaderLabel(self, label: str) -> None: ...
    def setHeaderLabels(self, labels: typing.Iterable[str]) -> None: ...
    def setItemExpanded(self, item: QTreeWidgetItem, expand: bool) -> None: ...
    def setItemHidden(self, item: QTreeWidgetItem, hide: bool) -> None: ...
    def setItemSelected(self, item: QTreeWidgetItem, select: bool) -> None: ...
    def setItemWidget(self, item: QTreeWidgetItem, column: int, widget: QWidget) -> None: ...
    def setModel(self, model: typing.Union[PySide2.QtCore.QAbstractItemModel, None]) -> None: ...
    def setSelectionModel(self, selectionModel: PySide2.QtCore.QItemSelectionModel) -> None: ...
    def sortColumn(self) -> int: ...
    def sortItems(self, column: int, order: PySide2.QtCore.Qt.SortOrder) -> None: ...
    def supportedDropActions(self) -> typing.Union[PySide2.QtCore.Qt.DropActions, PySide2.QtCore.Qt.DropAction]: ...
    def takeTopLevelItem(self, index: int) -> QTreeWidgetItem: ...
    def topLevelItem(self, index: int) -> QTreeWidgetItem: ...
    def topLevelItemCount(self) -> int: ...
    def visualItemRect(self, item: QTreeWidgetItem) -> PySide2.QtCore.QRect: ...

class QTreeWidgetItem(shiboken2.Object):
    class ChildIndicatorPolicy:
        DontShowIndicator: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
        DontShowIndicatorWhenChildless: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
        ShowIndicator: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __and__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __rand__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __ror__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __sub__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
        def __xor__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ChildIndicatorPolicy: ...

    class ItemType:
        Type: typing.ClassVar[QTreeWidgetItem.ItemType] = ...
        UserType: typing.ClassVar[QTreeWidgetItem.ItemType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __and__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __rand__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __ror__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __sub__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
        def __xor__(self, other: typing.SupportsInt) -> QTreeWidgetItem.ItemType: ...
    DontShowIndicator: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
    DontShowIndicatorWhenChildless: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
    ShowIndicator: typing.ClassVar[QTreeWidgetItem.ChildIndicatorPolicy] = ...
    Type: typing.ClassVar[QTreeWidgetItem.ItemType] = ...
    UserType: typing.ClassVar[QTreeWidgetItem.ItemType] = ...
    @typing.overload
    def __init__(self, treeview: QTreeWidget, strings: typing.Iterable[str], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, treeview: QTreeWidget, after: QTreeWidgetItem, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QTreeWidgetItem, strings: typing.Iterable[str], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QTreeWidgetItem, after: QTreeWidgetItem, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, treeview: QTreeWidget, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, strings: typing.Iterable[str], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QTreeWidgetItem, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QTreeWidgetItem) -> None: ...
    def addChild(self, child: QTreeWidgetItem) -> None: ...
    def addChildren(self, children: typing.Iterable[QTreeWidgetItem]) -> None: ...
    def background(self, column: int) -> PySide2.QtGui.QBrush: ...
    def backgroundColor(self, column: int) -> PySide2.QtGui.QColor: ...
    def checkState(self, column: int) -> PySide2.QtCore.Qt.CheckState: ...
    def child(self, index: int) -> QTreeWidgetItem: ...
    def childCount(self) -> int: ...
    def childIndicatorPolicy(self) -> QTreeWidgetItem.ChildIndicatorPolicy: ...
    def clone(self) -> QTreeWidgetItem: ...
    def columnCount(self) -> int: ...
    def data(self, column: int, role: PySide2.QtCore.Qt.ItemDataRole) -> typing.Any: ...
    def emitDataChanged(self) -> None: ...
    def flags(self) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def font(self, column: int) -> PySide2.QtGui.QFont: ...
    def foreground(self, column: int) -> PySide2.QtGui.QBrush: ...
    def icon(self, column: int) -> PySide2.QtGui.QIcon: ...
    def indexOfChild(self, child: QTreeWidgetItem) -> int: ...
    def insertChild(self, index: int, child: QTreeWidgetItem) -> None: ...
    def insertChildren(self, index: int, children: typing.Iterable[QTreeWidgetItem]) -> None: ...
    def isDisabled(self) -> bool: ...
    def isExpanded(self) -> bool: ...
    def isFirstColumnSpanned(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isSelected(self) -> bool: ...
    def parent(self) -> QTreeWidgetItem: ...
    def read(self, in_: PySide2.QtCore.QDataStream) -> None: ...
    def removeChild(self, child: QTreeWidgetItem) -> None: ...
    def setBackground(self, column: int, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setBackgroundColor(self, column: int, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setCheckState(self, column: int, state: PySide2.QtCore.Qt.CheckState) -> None: ...
    def setChildIndicatorPolicy(self, policy: QTreeWidgetItem.ChildIndicatorPolicy) -> None: ...
    def setData(self, column: int, role: PySide2.QtCore.Qt.ItemDataRole, value: typing.Any) -> None: ...
    def setDisabled(self, disabled: bool) -> None: ...
    def setExpanded(self, expand: bool) -> None: ...
    def setFirstColumnSpanned(self, span: bool) -> None: ...
    def setFlags(self, flags: typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]) -> None: ...
    def setFont(self, column: int, font: PySide2.QtGui.QFont) -> None: ...
    def setForeground(self, column: int, brush: typing.Union[PySide2.QtGui.QBrush, PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, PySide2.QtGui.QLinearGradient]) -> None: ...
    def setHidden(self, hide: bool) -> None: ...
    def setIcon(self, column: int, icon: PySide2.QtGui.QIcon) -> None: ...
    def setSelected(self, select: bool) -> None: ...
    def setSizeHint(self, column: int, size: PySide2.QtCore.QSize) -> None: ...
    def setStatusTip(self, column: int, statusTip: str) -> None: ...
    def setText(self, column: int, text: str) -> None: ...
    def setTextAlignment(self, column: int, alignment: int) -> None: ...
    def setTextColor(self, column: int, color: typing.Union[PySide2.QtGui.QColor, PySide2.QtCore.Qt.GlobalColor, int]) -> None: ...
    def setToolTip(self, column: int, toolTip: str) -> None: ...
    def setWhatsThis(self, column: int, whatsThis: str) -> None: ...
    def sizeHint(self, column: int) -> PySide2.QtCore.QSize: ...
    def sortChildren(self, column: int, order: PySide2.QtCore.Qt.SortOrder) -> None: ...
    def statusTip(self, column: int) -> str: ...
    def takeChild(self, index: int) -> QTreeWidgetItem: ...
    def takeChildren(self) -> typing.List[QTreeWidgetItem]: ...
    def text(self, column: int) -> str: ...
    def textAlignment(self, column: int) -> int: ...
    def textColor(self, column: int) -> PySide2.QtGui.QColor: ...
    def toolTip(self, column: int) -> str: ...
    def treeWidget(self) -> QTreeWidget: ...
    def type(self) -> int: ...
    def whatsThis(self, column: int) -> str: ...
    def write(self, out: PySide2.QtCore.QDataStream) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, out: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, in_: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...

class QTreeWidgetItemIterator(shiboken2.Object):
    class IteratorFlag:
        All: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Checked: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Disabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        DragDisabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        DragEnabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        DropDisabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        DropEnabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Editable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Enabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        HasChildren: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Hidden: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        NoChildren: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        NotChecked: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        NotEditable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        NotHidden: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        NotSelectable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Selectable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Selected: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        Unselected: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        UserFlag: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...

    class IteratorFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QTreeWidgetItemIterator.IteratorFlags: ...
    All: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Checked: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Disabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    DragDisabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    DragEnabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    DropDisabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    DropEnabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Editable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Enabled: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    HasChildren: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Hidden: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    NoChildren: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    NotChecked: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    NotEditable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    NotHidden: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    NotSelectable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Selectable: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Selected: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    Unselected: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    UserFlag: typing.ClassVar[QTreeWidgetItemIterator.IteratorFlag] = ...
    @typing.overload
    def __init__(self, widget: QTreeWidget, flags: typing.Union[QTreeWidgetItemIterator.IteratorFlags, QTreeWidgetItemIterator.IteratorFlag] = ...) -> None: ...
    @typing.overload
    def __init__(self, item: QTreeWidgetItem, flags: typing.Union[QTreeWidgetItemIterator.IteratorFlags, QTreeWidgetItemIterator.IteratorFlag] = ...) -> None: ...
    @typing.overload
    def __init__(self, it: QTreeWidgetItemIterator) -> None: ...
    def value(self) -> QTreeWidgetItem: ...
    def __copy__(self) -> None: ...
    def __iadd__(self, n: int) -> QTreeWidgetItemIterator: ...
    def __isub__(self, n: int) -> QTreeWidgetItemIterator: ...
    def __iter__(self) -> typing.Iterator[QTreeWidgetItemIterator]: ...
    def __next__(self) -> QTreeWidgetItemIterator: ...

class QUndoCommand(shiboken2.Object):
    @typing.overload
    def __init__(self, text: str, parent: typing.Union[QUndoCommand, None] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QUndoCommand, None] = ...) -> None: ...
    def actionText(self) -> str: ...
    def child(self, index: int) -> QUndoCommand: ...
    def childCount(self) -> int: ...
    def id(self) -> int: ...
    def isObsolete(self) -> bool: ...
    def mergeWith(self, other: QUndoCommand) -> bool: ...
    def redo(self) -> None: ...
    def setObsolete(self, obsolete: bool) -> None: ...
    def setText(self, text: str) -> None: ...
    def text(self) -> str: ...
    def undo(self) -> None: ...

class QUndoGroup(PySide2.QtCore.QObject):
    activeStackChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    canRedoChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    canUndoChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cleanChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    indexChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    redoTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    undoTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., activeStackChanged: typing.Callable = ..., canRedoChanged: typing.Callable = ..., canUndoChanged: typing.Callable = ..., cleanChanged: typing.Callable = ..., destroyed: typing.Callable = ..., indexChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., redoTextChanged: typing.Callable = ..., undoTextChanged: typing.Callable = ...) -> None: ...
    def activeStack(self) -> QUndoStack: ...
    def addStack(self, stack: QUndoStack) -> None: ...
    def canRedo(self) -> bool: ...
    def canUndo(self) -> bool: ...
    def createRedoAction(self, parent: typing.Union[PySide2.QtCore.QObject, None], prefix: str = ...) -> QAction: ...
    def createUndoAction(self, parent: typing.Union[PySide2.QtCore.QObject, None], prefix: str = ...) -> QAction: ...
    def isClean(self) -> bool: ...
    def redo(self) -> None: ...
    def redoText(self) -> str: ...
    def removeStack(self, stack: QUndoStack) -> None: ...
    def setActiveStack(self, stack: QUndoStack) -> None: ...
    def stacks(self) -> typing.List[QUndoStack]: ...
    def undo(self) -> None: ...
    def undoText(self) -> str: ...

class QUndoStack(PySide2.QtCore.QObject):
    canRedoChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    canUndoChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    cleanChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    indexChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    redoTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    undoTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., active: bool = ..., canRedo: bool = ..., canRedoChanged: typing.Callable = ..., canUndo: bool = ..., canUndoChanged: typing.Callable = ..., clean: bool = ..., cleanChanged: typing.Callable = ..., destroyed: typing.Callable = ..., indexChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., redoText: str = ..., redoTextChanged: typing.Callable = ..., undoLimit: int = ..., undoText: str = ..., undoTextChanged: typing.Callable = ...) -> None: ...
    def beginMacro(self, text: str) -> None: ...
    def canRedo(self) -> bool: ...
    def canUndo(self) -> bool: ...
    def cleanIndex(self) -> int: ...
    def clear(self) -> None: ...
    def command(self, index: int) -> QUndoCommand: ...
    def count(self) -> int: ...
    def createRedoAction(self, parent: typing.Union[PySide2.QtCore.QObject, None], prefix: str = ...) -> QAction: ...
    def createUndoAction(self, parent: typing.Union[PySide2.QtCore.QObject, None], prefix: str = ...) -> QAction: ...
    def endMacro(self) -> None: ...
    def index(self) -> int: ...
    def isActive(self) -> bool: ...
    def isClean(self) -> bool: ...
    def push(self, cmd: QUndoCommand) -> None: ...
    def redo(self) -> None: ...
    def redoText(self) -> str: ...
    def resetClean(self) -> None: ...
    def setActive(self, active: bool = ...) -> None: ...
    def setClean(self) -> None: ...
    def setIndex(self, idx: int) -> None: ...
    def setUndoLimit(self, limit: int) -> None: ...
    def text(self, idx: int) -> str: ...
    def undo(self) -> None: ...
    def undoLimit(self) -> int: ...
    def undoText(self) -> str: ...

class QUndoView(QListView):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, stack: QUndoStack, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., batchSize: int = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., cleanIcon: PySide2.QtGui.QIcon = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QUndoView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QUndoView.EditTriggers = ..., emptyLabel: str = ..., enabled: bool = ..., entered: typing.Callable = ..., flow: QUndoView.Flow = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QUndoView.Shadow = ..., frameShape: QUndoView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridSize: PySide2.QtCore.QSize = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QUndoView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indexesMoved: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., isWrapping: bool = ..., itemAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., layoutMode: QUndoView.LayoutMode = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., movement: QUndoView.Movement = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeMode: QUndoView.ResizeMode = ..., selectionBehavior: QUndoView.SelectionBehavior = ..., selectionMode: QUndoView.SelectionMode = ..., selectionRectVisible: bool = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QUndoView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., spacing: int = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformItemSizes: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QUndoView.ScrollMode = ..., viewMode: QUndoView.ViewMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, group: QUndoGroup, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., batchSize: int = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., cleanIcon: PySide2.QtGui.QIcon = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QUndoView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QUndoView.EditTriggers = ..., emptyLabel: str = ..., enabled: bool = ..., entered: typing.Callable = ..., flow: QUndoView.Flow = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QUndoView.Shadow = ..., frameShape: QUndoView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridSize: PySide2.QtCore.QSize = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QUndoView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indexesMoved: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., isWrapping: bool = ..., itemAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., layoutMode: QUndoView.LayoutMode = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., movement: QUndoView.Movement = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeMode: QUndoView.ResizeMode = ..., selectionBehavior: QUndoView.SelectionBehavior = ..., selectionMode: QUndoView.SelectionMode = ..., selectionRectVisible: bool = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QUndoView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., spacing: int = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformItemSizes: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QUndoView.ScrollMode = ..., viewMode: QUndoView.ViewMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., activated: typing.Callable = ..., alternatingRowColors: bool = ..., autoFillBackground: bool = ..., autoScroll: bool = ..., autoScrollMargin: int = ..., baseSize: PySide2.QtCore.QSize = ..., batchSize: int = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., cleanIcon: PySide2.QtGui.QIcon = ..., clicked: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., defaultDropAction: PySide2.QtCore.Qt.DropAction = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., dragDropMode: QUndoView.DragDropMode = ..., dragDropOverwriteMode: bool = ..., dragEnabled: bool = ..., editTriggers: QUndoView.EditTriggers = ..., emptyLabel: str = ..., enabled: bool = ..., entered: typing.Callable = ..., flow: QUndoView.Flow = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameRect: PySide2.QtCore.QRect = ..., frameShadow: QUndoView.Shadow = ..., frameShape: QUndoView.Shape = ..., frameSize: PySide2.QtCore.QSize = ..., frameWidth: int = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., gridSize: PySide2.QtCore.QSize = ..., height: int = ..., horizontalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., horizontalScrollMode: QUndoView.ScrollMode = ..., iconSize: PySide2.QtCore.QSize = ..., iconSizeChanged: typing.Callable = ..., indexesMoved: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., isWrapping: bool = ..., itemAlignment: typing.Union[PySide2.QtCore.Qt.Alignment, PySide2.QtCore.Qt.AlignmentFlag] = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., layoutMode: QUndoView.LayoutMode = ..., lineWidth: int = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., midLineWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., modelColumn: int = ..., mouseTracking: bool = ..., movement: QUndoView.Movement = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., pressed: typing.Callable = ..., rect: PySide2.QtCore.QRect = ..., resizeMode: QUndoView.ResizeMode = ..., selectionBehavior: QUndoView.SelectionBehavior = ..., selectionMode: QUndoView.SelectionMode = ..., selectionRectVisible: bool = ..., showDropIndicator: bool = ..., size: PySide2.QtCore.QSize = ..., sizeAdjustPolicy: QUndoView.SizeAdjustPolicy = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., spacing: int = ..., statusTip: str = ..., styleSheet: str = ..., tabKeyNavigation: bool = ..., tabletTracking: bool = ..., textElideMode: PySide2.QtCore.Qt.TextElideMode = ..., toolTip: str = ..., toolTipDuration: int = ..., uniformItemSizes: bool = ..., updatesEnabled: bool = ..., verticalScrollBarPolicy: PySide2.QtCore.Qt.ScrollBarPolicy = ..., verticalScrollMode: QUndoView.ScrollMode = ..., viewMode: QUndoView.ViewMode = ..., viewportEntered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wordWrap: bool = ..., x: int = ..., y: int = ...) -> None: ...
    def cleanIcon(self) -> PySide2.QtGui.QIcon: ...
    def emptyLabel(self) -> str: ...
    def group(self) -> QUndoGroup: ...
    def setCleanIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setEmptyLabel(self, label: str) -> None: ...
    def setGroup(self, group: QUndoGroup) -> None: ...
    def setStack(self, stack: QUndoStack) -> None: ...
    def stack(self) -> QUndoStack: ...

class QVBoxLayout(QBoxLayout):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[QWidget, None], destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QVBoxLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., margin: int = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., sizeConstraint: QVBoxLayout.SizeConstraint = ..., spacing: int = ...) -> None: ...

class QWhatsThis(shiboken2.Object):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def createAction(cls, parent: typing.Union[PySide2.QtCore.QObject, None] = ...) -> QAction: ...
    @classmethod
    def enterWhatsThisMode(cls) -> None: ...
    @classmethod
    def hideText(cls) -> None: ...
    @classmethod
    def inWhatsThisMode(cls) -> bool: ...
    @classmethod
    def leaveWhatsThisMode(cls) -> None: ...
    @classmethod
    def showText(cls, pos: PySide2.QtCore.QPoint, text: str, w: typing.Union[QWidget, None] = ...) -> None: ...

class QWidget(PySide2.QtCore.QObject, PySide2.QtGui.QPaintDevice):
    class RenderFlag:
        DrawChildren: typing.ClassVar[QWidget.RenderFlag] = ...
        DrawWindowBackground: typing.ClassVar[QWidget.RenderFlag] = ...
        IgnoreMask: typing.ClassVar[QWidget.RenderFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QWidget.RenderFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...

    class RenderFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QWidget.RenderFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QWidget.RenderFlags: ...
    DrawChildren: typing.ClassVar[QWidget.RenderFlag] = ...
    DrawWindowBackground: typing.ClassVar[QWidget.RenderFlag] = ...
    IgnoreMask: typing.ClassVar[QWidget.RenderFlag] = ...
    customContextMenuRequested: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    windowIconChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    windowIconTextChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    windowTitleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., tabletTracking: bool = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def acceptDrops(self) -> bool: ...
    def accessibleDescription(self) -> str: ...
    def accessibleName(self) -> str: ...
    def actionEvent(self, event: PySide2.QtGui.QActionEvent) -> None: ...
    def actions(self) -> typing.List[QAction]: ...
    def activateWindow(self) -> None: ...
    def addAction(self, action: QAction) -> None: ...
    def addActions(self, actions: typing.Iterable[QAction]) -> None: ...
    def adjustSize(self) -> None: ...
    def autoFillBackground(self) -> bool: ...
    def backgroundRole(self) -> PySide2.QtGui.QPalette.ColorRole: ...
    def backingStore(self) -> PySide2.QtGui.QBackingStore: ...
    def baseSize(self) -> PySide2.QtCore.QSize: ...
    def changeEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    @typing.overload
    def childAt(self, x: int, y: int) -> QWidget: ...
    @typing.overload
    def childAt(self, p: PySide2.QtCore.QPoint) -> QWidget: ...
    def childrenRect(self) -> PySide2.QtCore.QRect: ...
    def childrenRegion(self) -> PySide2.QtGui.QRegion: ...
    def clearFocus(self) -> None: ...
    def clearMask(self) -> None: ...
    def close(self) -> bool: ...
    def closeEvent(self, event: PySide2.QtGui.QCloseEvent) -> None: ...
    def contentsMargins(self) -> PySide2.QtCore.QMargins: ...
    def contentsRect(self) -> PySide2.QtCore.QRect: ...
    def contextMenuEvent(self, event: PySide2.QtGui.QContextMenuEvent) -> None: ...
    def contextMenuPolicy(self) -> PySide2.QtCore.Qt.ContextMenuPolicy: ...
    def create(self, arg__1: int = ..., initializeWindow: bool = ..., destroyOldWindow: bool = ...) -> None: ...
    def createWinId(self) -> None: ...
    @classmethod
    def createWindowContainer(cls, window: PySide2.QtGui.QWindow, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> QWidget: ...
    def cursor(self) -> PySide2.QtGui.QCursor: ...
    def destroy(self, destroyWindow: bool = ..., destroySubWindows: bool = ...) -> None: ...
    def devType(self) -> int: ...
    def dragEnterEvent(self, event: PySide2.QtGui.QDragEnterEvent) -> None: ...
    def dragLeaveEvent(self, event: PySide2.QtGui.QDragLeaveEvent) -> None: ...
    def dragMoveEvent(self, event: PySide2.QtGui.QDragMoveEvent) -> None: ...
    def dropEvent(self, event: PySide2.QtGui.QDropEvent) -> None: ...
    def effectiveWinId(self) -> int: ...
    def ensurePolished(self) -> None: ...
    def enterEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    @classmethod
    def find(cls, arg__1: int) -> QWidget: ...
    def focusInEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusNextChild(self) -> bool: ...
    def focusNextPrevChild(self, next: bool) -> bool: ...
    def focusOutEvent(self, event: PySide2.QtGui.QFocusEvent) -> None: ...
    def focusPolicy(self) -> PySide2.QtCore.Qt.FocusPolicy: ...
    def focusPreviousChild(self) -> bool: ...
    def focusProxy(self) -> QWidget: ...
    def focusWidget(self) -> QWidget: ...
    def font(self) -> PySide2.QtGui.QFont: ...
    def fontInfo(self) -> PySide2.QtGui.QFontInfo: ...
    def fontMetrics(self) -> PySide2.QtGui.QFontMetrics: ...
    def foregroundRole(self) -> PySide2.QtGui.QPalette.ColorRole: ...
    def frameGeometry(self) -> PySide2.QtCore.QRect: ...
    def frameSize(self) -> PySide2.QtCore.QSize: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def getContentsMargins(self) -> typing.Tuple[int, int, int, int]: ...
    def grab(self, rectangle: PySide2.QtCore.QRect = ...) -> PySide2.QtGui.QPixmap: ...
    def grabGesture(self, type: PySide2.QtCore.Qt.GestureType, flags: typing.Union[PySide2.QtCore.Qt.GestureFlags, PySide2.QtCore.Qt.GestureFlag] = ...) -> None: ...
    def grabKeyboard(self) -> None: ...
    @typing.overload
    def grabMouse(self, arg__1: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape]) -> None: ...
    @typing.overload
    def grabMouse(self) -> None: ...
    def grabShortcut(self, key: typing.Union[PySide2.QtGui.QKeySequence, str], context: PySide2.QtCore.Qt.ShortcutContext = ...) -> int: ...
    def graphicsEffect(self) -> QGraphicsEffect: ...
    def graphicsProxyWidget(self) -> QGraphicsProxyWidget: ...
    def hasFocus(self) -> bool: ...
    def hasHeightForWidth(self) -> bool: ...
    def hasMouseTracking(self) -> bool: ...
    def hasTabletTracking(self) -> bool: ...
    def height(self) -> int: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def hide(self) -> None: ...
    def hideEvent(self, event: PySide2.QtGui.QHideEvent) -> None: ...
    def initPainter(self, painter: PySide2.QtGui.QPainter) -> None: ...
    def inputMethodEvent(self, event: PySide2.QtGui.QInputMethodEvent) -> None: ...
    def inputMethodHints(self) -> typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint]: ...
    def inputMethodQuery(self, arg__1: PySide2.QtCore.Qt.InputMethodQuery) -> typing.Any: ...
    def insertAction(self, before: QAction, action: QAction) -> None: ...
    def insertActions(self, before: QAction, actions: typing.Iterable[QAction]) -> None: ...
    def internalWinId(self) -> int: ...
    def isActiveWindow(self) -> bool: ...
    def isAncestorOf(self, child: QWidget) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isEnabledTo(self, arg__1: QWidget) -> bool: ...
    def isEnabledToTLW(self) -> bool: ...
    def isFullScreen(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isLeftToRight(self) -> bool: ...
    def isMaximized(self) -> bool: ...
    def isMinimized(self) -> bool: ...
    def isModal(self) -> bool: ...
    def isRightToLeft(self) -> bool: ...
    def isTopLevel(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def isVisibleTo(self, arg__1: QWidget) -> bool: ...
    def isWindow(self) -> bool: ...
    def isWindowModified(self) -> bool: ...
    def keyPressEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    def keyReleaseEvent(self, event: PySide2.QtGui.QKeyEvent) -> None: ...
    @classmethod
    def keyboardGrabber(cls) -> QWidget: ...
    def layout(self) -> QLayout: ...
    def layoutDirection(self) -> PySide2.QtCore.Qt.LayoutDirection: ...
    def leaveEvent(self, event: PySide2.QtCore.QEvent) -> None: ...
    def locale(self) -> PySide2.QtCore.QLocale: ...
    def lower(self) -> None: ...
    def mapFrom(self, arg__1: QWidget, arg__2: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mapFromGlobal(self, arg__1: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mapFromParent(self, arg__1: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mapTo(self, arg__1: QWidget, arg__2: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mapToGlobal(self, arg__1: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mapToParent(self, arg__1: PySide2.QtCore.QPoint) -> PySide2.QtCore.QPoint: ...
    def mask(self) -> PySide2.QtGui.QRegion: ...
    def maximumHeight(self) -> int: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def maximumWidth(self) -> int: ...
    def metric(self, arg__1: PySide2.QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def minimumHeight(self) -> int: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumSizeHint(self) -> PySide2.QtCore.QSize: ...
    def minimumWidth(self) -> int: ...
    def mouseDoubleClickEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    @classmethod
    def mouseGrabber(cls) -> QWidget: ...
    def mouseMoveEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mousePressEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    def mouseReleaseEvent(self, event: PySide2.QtGui.QMouseEvent) -> None: ...
    @typing.overload
    def move(self, x: int, y: int) -> None: ...
    @typing.overload
    def move(self, arg__1: PySide2.QtCore.QPoint) -> None: ...
    def moveEvent(self, event: PySide2.QtGui.QMoveEvent) -> None: ...
    def nativeEvent(self, eventType: typing.Union[PySide2.QtCore.QByteArray, bytes], message: int) -> typing.Tuple[bool, int]: ...
    def nativeParentWidget(self) -> QWidget: ...
    def nextInFocusChain(self) -> QWidget: ...
    def normalGeometry(self) -> PySide2.QtCore.QRect: ...
    def overrideWindowFlags(self, type: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType]) -> None: ...
    def overrideWindowState(self, state: typing.Union[PySide2.QtCore.Qt.WindowStates, PySide2.QtCore.Qt.WindowState]) -> None: ...
    def paintEngine(self) -> PySide2.QtGui.QPaintEngine: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def palette(self) -> PySide2.QtGui.QPalette: ...
    def parentWidget(self) -> QWidget: ...
    def pos(self) -> PySide2.QtCore.QPoint: ...
    def previousInFocusChain(self) -> QWidget: ...
    def raise_(self) -> None: ...
    def rect(self) -> PySide2.QtCore.QRect: ...
    def redirected(self, offset: PySide2.QtCore.QPoint) -> PySide2.QtGui.QPaintDevice: ...
    def releaseKeyboard(self) -> None: ...
    def releaseMouse(self) -> None: ...
    def releaseShortcut(self, id: int) -> None: ...
    def removeAction(self, action: QAction) -> None: ...
    @typing.overload
    def render(self, target: PySide2.QtGui.QPaintDevice, targetOffset: PySide2.QtCore.QPoint = ..., sourceRegion: PySide2.QtGui.QRegion = ..., renderFlags: typing.Union[QWidget.RenderFlags, QWidget.RenderFlag] = ...) -> None: ...
    @typing.overload
    def render(self, painter: PySide2.QtGui.QPainter, targetOffset: PySide2.QtCore.QPoint, sourceRegion: PySide2.QtGui.QRegion = ..., renderFlags: typing.Union[QWidget.RenderFlags, QWidget.RenderFlag] = ...) -> None: ...
    @typing.overload
    def repaint(self, x: int, y: int, w: int, h: int) -> None: ...
    @typing.overload
    def repaint(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    @typing.overload
    def repaint(self, arg__1: PySide2.QtGui.QRegion) -> None: ...
    @typing.overload
    def repaint(self) -> None: ...
    @typing.overload
    def resize(self, w: int, h: int) -> None: ...
    @typing.overload
    def resize(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def restoreGeometry(self, geometry: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> bool: ...
    def saveGeometry(self) -> PySide2.QtCore.QByteArray: ...
    def screen(self) -> PySide2.QtGui.QScreen: ...
    @typing.overload
    def scroll(self, dx: int, dy: int, arg__3: PySide2.QtCore.QRect) -> None: ...
    @typing.overload
    def scroll(self, dx: int, dy: int) -> None: ...
    def setAcceptDrops(self, on: bool) -> None: ...
    def setAccessibleDescription(self, description: str) -> None: ...
    def setAccessibleName(self, name: str) -> None: ...
    def setAttribute(self, arg__1: PySide2.QtCore.Qt.WidgetAttribute, on: bool = ...) -> None: ...
    def setAutoFillBackground(self, enabled: bool) -> None: ...
    def setBackgroundRole(self, arg__1: PySide2.QtGui.QPalette.ColorRole) -> None: ...
    @typing.overload
    def setBaseSize(self, basew: int, baseh: int) -> None: ...
    @typing.overload
    def setBaseSize(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    @typing.overload
    def setContentsMargins(self, left: int, top: int, right: int, bottom: int) -> None: ...
    @typing.overload
    def setContentsMargins(self, margins: PySide2.QtCore.QMargins) -> None: ...
    def setContextMenuPolicy(self, policy: PySide2.QtCore.Qt.ContextMenuPolicy) -> None: ...
    def setCursor(self, arg__1: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape]) -> None: ...
    def setDisabled(self, arg__1: bool) -> None: ...
    def setEnabled(self, arg__1: bool) -> None: ...
    def setFixedHeight(self, h: int) -> None: ...
    @typing.overload
    def setFixedSize(self, w: int, h: int) -> None: ...
    @typing.overload
    def setFixedSize(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    def setFixedWidth(self, w: int) -> None: ...
    @typing.overload
    def setFocus(self, reason: PySide2.QtCore.Qt.FocusReason) -> None: ...
    @typing.overload
    def setFocus(self) -> None: ...
    def setFocusPolicy(self, policy: PySide2.QtCore.Qt.FocusPolicy) -> None: ...
    def setFocusProxy(self, arg__1: QWidget) -> None: ...
    def setFont(self, arg__1: PySide2.QtGui.QFont) -> None: ...
    def setForegroundRole(self, arg__1: PySide2.QtGui.QPalette.ColorRole) -> None: ...
    @typing.overload
    def setGeometry(self, x: int, y: int, w: int, h: int) -> None: ...
    @typing.overload
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def setGraphicsEffect(self, effect: QGraphicsEffect) -> None: ...
    def setHidden(self, hidden: bool) -> None: ...
    def setInputMethodHints(self, hints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint]) -> None: ...
    def setLayout(self, arg__1: QLayout) -> None: ...
    def setLayoutDirection(self, direction: PySide2.QtCore.Qt.LayoutDirection) -> None: ...
    def setLocale(self, locale: PySide2.QtCore.QLocale) -> None: ...
    @typing.overload
    def setMask(self, arg__1: PySide2.QtGui.QBitmap) -> None: ...
    @typing.overload
    def setMask(self, arg__1: PySide2.QtGui.QRegion) -> None: ...
    def setMaximumHeight(self, maxh: int) -> None: ...
    @typing.overload
    def setMaximumSize(self, maxw: int, maxh: int) -> None: ...
    @typing.overload
    def setMaximumSize(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    def setMaximumWidth(self, maxw: int) -> None: ...
    def setMinimumHeight(self, minh: int) -> None: ...
    @typing.overload
    def setMinimumSize(self, minw: int, minh: int) -> None: ...
    @typing.overload
    def setMinimumSize(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    def setMinimumWidth(self, minw: int) -> None: ...
    def setMouseTracking(self, enable: bool) -> None: ...
    def setPalette(self, arg__1: PySide2.QtGui.QPalette) -> None: ...
    def setParent(self, parent: typing.Union[PySide2.QtCore.QObject, None], f: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ...) -> None: ...
    def setShortcutAutoRepeat(self, id: int, enable: bool = ...) -> None: ...
    def setShortcutEnabled(self, id: int, enable: bool = ...) -> None: ...
    @typing.overload
    def setSizeIncrement(self, w: int, h: int) -> None: ...
    @typing.overload
    def setSizeIncrement(self, arg__1: PySide2.QtCore.QSize) -> None: ...
    @typing.overload
    def setSizePolicy(self, horizontal: QSizePolicy.Policy, vertical: QSizePolicy.Policy) -> None: ...
    @typing.overload
    def setSizePolicy(self, arg__1: QSizePolicy) -> None: ...
    def setStatusTip(self, arg__1: str) -> None: ...
    def setStyle(self, arg__1: QStyle) -> None: ...
    def setStyleSheet(self, styleSheet: str) -> None: ...
    @classmethod
    def setTabOrder(cls, arg__1: QWidget, arg__2: QWidget) -> None: ...
    def setTabletTracking(self, enable: bool) -> None: ...
    def setToolTip(self, arg__1: str) -> None: ...
    def setToolTipDuration(self, msec: int) -> None: ...
    def setUpdatesEnabled(self, enable: bool) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def setWhatsThis(self, arg__1: str) -> None: ...
    def setWindowFilePath(self, filePath: str) -> None: ...
    def setWindowFlag(self, arg__1: PySide2.QtCore.Qt.WindowType, on: bool = ...) -> None: ...
    def setWindowFlags(self, type: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType]) -> None: ...
    def setWindowIcon(self, icon: PySide2.QtGui.QIcon) -> None: ...
    def setWindowIconText(self, arg__1: str) -> None: ...
    def setWindowModality(self, windowModality: PySide2.QtCore.Qt.WindowModality) -> None: ...
    def setWindowModified(self, arg__1: bool) -> None: ...
    def setWindowOpacity(self, level: float) -> None: ...
    def setWindowRole(self, arg__1: str) -> None: ...
    def setWindowState(self, state: typing.Union[PySide2.QtCore.Qt.WindowStates, PySide2.QtCore.Qt.WindowState]) -> None: ...
    def setWindowTitle(self, arg__1: str) -> None: ...
    def sharedPainter(self) -> PySide2.QtGui.QPainter: ...
    def show(self) -> None: ...
    def showEvent(self, event: PySide2.QtGui.QShowEvent) -> None: ...
    def showFullScreen(self) -> None: ...
    def showMaximized(self) -> None: ...
    def showMinimized(self) -> None: ...
    def showNormal(self) -> None: ...
    def size(self) -> PySide2.QtCore.QSize: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def sizeIncrement(self) -> PySide2.QtCore.QSize: ...
    def sizePolicy(self) -> QSizePolicy: ...
    def stackUnder(self, arg__1: QWidget) -> None: ...
    def statusTip(self) -> str: ...
    def style(self) -> QStyle: ...
    def styleSheet(self) -> str: ...
    def tabletEvent(self, event: PySide2.QtGui.QTabletEvent) -> None: ...
    def testAttribute(self, arg__1: PySide2.QtCore.Qt.WidgetAttribute) -> bool: ...
    def toolTip(self) -> str: ...
    def toolTipDuration(self) -> int: ...
    def topLevelWidget(self) -> QWidget: ...
    def underMouse(self) -> bool: ...
    def ungrabGesture(self, type: PySide2.QtCore.Qt.GestureType) -> None: ...
    def unsetCursor(self) -> None: ...
    def unsetLayoutDirection(self) -> None: ...
    def unsetLocale(self) -> None: ...
    @typing.overload
    def update(self, x: int, y: int, w: int, h: int) -> None: ...
    @typing.overload
    def update(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    @typing.overload
    def update(self, arg__1: PySide2.QtGui.QRegion) -> None: ...
    @typing.overload
    def update(self) -> None: ...
    def updateGeometry(self) -> None: ...
    def updateMicroFocus(self) -> None: ...
    def updatesEnabled(self) -> bool: ...
    def visibleRegion(self) -> PySide2.QtGui.QRegion: ...
    def whatsThis(self) -> str: ...
    def wheelEvent(self, event: PySide2.QtGui.QWheelEvent) -> None: ...
    def width(self) -> int: ...
    def winId(self) -> int: ...
    def window(self) -> QWidget: ...
    def windowFilePath(self) -> str: ...
    def windowFlags(self) -> typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType]: ...
    def windowHandle(self) -> PySide2.QtGui.QWindow: ...
    def windowIcon(self) -> PySide2.QtGui.QIcon: ...
    def windowIconText(self) -> str: ...
    def windowModality(self) -> PySide2.QtCore.Qt.WindowModality: ...
    def windowOpacity(self) -> float: ...
    def windowRole(self) -> str: ...
    def windowState(self) -> typing.Union[PySide2.QtCore.Qt.WindowStates, PySide2.QtCore.Qt.WindowState]: ...
    def windowTitle(self) -> str: ...
    def windowType(self) -> PySide2.QtCore.Qt.WindowType: ...
    def x(self) -> int: ...
    def y(self) -> int: ...

class QWidgetAction(QAction):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None], autoRepeat: bool = ..., changed: typing.Callable = ..., checkable: bool = ..., checked: bool = ..., destroyed: typing.Callable = ..., enabled: bool = ..., font: PySide2.QtGui.QFont = ..., hovered: typing.Callable = ..., icon: PySide2.QtGui.QIcon = ..., iconText: str = ..., iconVisibleInMenu: bool = ..., menuRole: QAction.MenuRole = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., priority: QAction.Priority = ..., shortcut: typing.Union[PySide2.QtGui.QKeySequence, str] = ..., shortcutContext: PySide2.QtCore.Qt.ShortcutContext = ..., shortcutVisibleInContextMenu: bool = ..., statusTip: str = ..., text: str = ..., toggled: typing.Callable = ..., toolTip: str = ..., triggered: typing.Callable = ..., visible: bool = ..., whatsThis: str = ...) -> None: ...
    def createWidget(self, parent: typing.Union[QWidget, None]) -> QWidget: ...
    def createdWidgets(self) -> typing.List[QWidget]: ...
    def defaultWidget(self) -> QWidget: ...
    def deleteWidget(self, widget: QWidget) -> None: ...
    def event(self, arg__1: PySide2.QtCore.QEvent) -> bool: ...
    def eventFilter(self, arg__1: PySide2.QtCore.QObject, arg__2: PySide2.QtCore.QEvent) -> bool: ...
    def releaseWidget(self, widget: QWidget) -> None: ...
    def requestWidget(self, parent: typing.Union[QWidget, None]) -> QWidget: ...
    def setDefaultWidget(self, w: QWidget) -> None: ...

class QWidgetItem(QLayoutItem):
    wid: _typeshed.Incomplete
    def __init__(self, w: QWidget) -> None: ...
    def controlTypes(self) -> typing.Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType]: ...
    def expandingDirections(self) -> typing.Union[PySide2.QtCore.Qt.Orientations, PySide2.QtCore.Qt.Orientation]: ...
    def geometry(self) -> PySide2.QtCore.QRect: ...
    def hasHeightForWidth(self) -> bool: ...
    def heightForWidth(self, arg__1: int) -> int: ...
    def isEmpty(self) -> bool: ...
    def maximumSize(self) -> PySide2.QtCore.QSize: ...
    def minimumSize(self) -> PySide2.QtCore.QSize: ...
    def setGeometry(self, arg__1: PySide2.QtCore.QRect) -> None: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def widget(self) -> QWidget: ...

class QWizard(QDialog):
    class WizardButton:
        BackButton: typing.ClassVar[QWizard.WizardButton] = ...
        CancelButton: typing.ClassVar[QWizard.WizardButton] = ...
        CommitButton: typing.ClassVar[QWizard.WizardButton] = ...
        CustomButton1: typing.ClassVar[QWizard.WizardButton] = ...
        CustomButton2: typing.ClassVar[QWizard.WizardButton] = ...
        CustomButton3: typing.ClassVar[QWizard.WizardButton] = ...
        FinishButton: typing.ClassVar[QWizard.WizardButton] = ...
        HelpButton: typing.ClassVar[QWizard.WizardButton] = ...
        NButtons: typing.ClassVar[QWizard.WizardButton] = ...
        NStandardButtons: typing.ClassVar[QWizard.WizardButton] = ...
        NextButton: typing.ClassVar[QWizard.WizardButton] = ...
        NoButton: typing.ClassVar[QWizard.WizardButton] = ...
        Stretch: typing.ClassVar[QWizard.WizardButton] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __and__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __rand__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __rmul__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __ror__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __rsub__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __sub__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...
        def __xor__(self, other: typing.SupportsInt) -> QWizard.WizardButton: ...

    class WizardOption:
        CancelButtonOnLeft: typing.ClassVar[QWizard.WizardOption] = ...
        DisabledBackButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
        ExtendedWatermarkPixmap: typing.ClassVar[QWizard.WizardOption] = ...
        HaveCustomButton1: typing.ClassVar[QWizard.WizardOption] = ...
        HaveCustomButton2: typing.ClassVar[QWizard.WizardOption] = ...
        HaveCustomButton3: typing.ClassVar[QWizard.WizardOption] = ...
        HaveFinishButtonOnEarlyPages: typing.ClassVar[QWizard.WizardOption] = ...
        HaveHelpButton: typing.ClassVar[QWizard.WizardOption] = ...
        HaveNextButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
        HelpButtonOnRight: typing.ClassVar[QWizard.WizardOption] = ...
        IgnoreSubTitles: typing.ClassVar[QWizard.WizardOption] = ...
        IndependentPages: typing.ClassVar[QWizard.WizardOption] = ...
        NoBackButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
        NoBackButtonOnStartPage: typing.ClassVar[QWizard.WizardOption] = ...
        NoCancelButton: typing.ClassVar[QWizard.WizardOption] = ...
        NoCancelButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
        NoDefaultButton: typing.ClassVar[QWizard.WizardOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QWizard.WizardOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...

    class WizardOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QWizard.WizardOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QWizard.WizardOptions: ...

    class WizardPixmap:
        BackgroundPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
        BannerPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
        LogoPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
        NPixmaps: typing.ClassVar[QWizard.WizardPixmap] = ...
        WatermarkPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __and__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __rand__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __rmul__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __ror__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __rsub__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __sub__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...
        def __xor__(self, other: typing.SupportsInt) -> QWizard.WizardPixmap: ...

    class WizardStyle:
        AeroStyle: typing.ClassVar[QWizard.WizardStyle] = ...
        ClassicStyle: typing.ClassVar[QWizard.WizardStyle] = ...
        MacStyle: typing.ClassVar[QWizard.WizardStyle] = ...
        ModernStyle: typing.ClassVar[QWizard.WizardStyle] = ...
        NStyles: typing.ClassVar[QWizard.WizardStyle] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __and__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __rand__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __rmul__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __ror__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __rsub__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __rxor__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __sub__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
        def __xor__(self, other: typing.SupportsInt) -> QWizard.WizardStyle: ...
    AeroStyle: typing.ClassVar[QWizard.WizardStyle] = ...
    BackButton: typing.ClassVar[QWizard.WizardButton] = ...
    BackgroundPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
    BannerPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
    CancelButton: typing.ClassVar[QWizard.WizardButton] = ...
    CancelButtonOnLeft: typing.ClassVar[QWizard.WizardOption] = ...
    ClassicStyle: typing.ClassVar[QWizard.WizardStyle] = ...
    CommitButton: typing.ClassVar[QWizard.WizardButton] = ...
    CustomButton1: typing.ClassVar[QWizard.WizardButton] = ...
    CustomButton2: typing.ClassVar[QWizard.WizardButton] = ...
    CustomButton3: typing.ClassVar[QWizard.WizardButton] = ...
    DisabledBackButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
    ExtendedWatermarkPixmap: typing.ClassVar[QWizard.WizardOption] = ...
    FinishButton: typing.ClassVar[QWizard.WizardButton] = ...
    HaveCustomButton1: typing.ClassVar[QWizard.WizardOption] = ...
    HaveCustomButton2: typing.ClassVar[QWizard.WizardOption] = ...
    HaveCustomButton3: typing.ClassVar[QWizard.WizardOption] = ...
    HaveFinishButtonOnEarlyPages: typing.ClassVar[QWizard.WizardOption] = ...
    HaveHelpButton: typing.ClassVar[QWizard.WizardOption] = ...
    HaveNextButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
    HelpButton: typing.ClassVar[QWizard.WizardButton] = ...
    HelpButtonOnRight: typing.ClassVar[QWizard.WizardOption] = ...
    IgnoreSubTitles: typing.ClassVar[QWizard.WizardOption] = ...
    IndependentPages: typing.ClassVar[QWizard.WizardOption] = ...
    LogoPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
    MacStyle: typing.ClassVar[QWizard.WizardStyle] = ...
    ModernStyle: typing.ClassVar[QWizard.WizardStyle] = ...
    NButtons: typing.ClassVar[QWizard.WizardButton] = ...
    NPixmaps: typing.ClassVar[QWizard.WizardPixmap] = ...
    NStandardButtons: typing.ClassVar[QWizard.WizardButton] = ...
    NStyles: typing.ClassVar[QWizard.WizardStyle] = ...
    NextButton: typing.ClassVar[QWizard.WizardButton] = ...
    NoBackButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
    NoBackButtonOnStartPage: typing.ClassVar[QWizard.WizardOption] = ...
    NoButton: typing.ClassVar[QWizard.WizardButton] = ...
    NoCancelButton: typing.ClassVar[QWizard.WizardOption] = ...
    NoCancelButtonOnLastPage: typing.ClassVar[QWizard.WizardOption] = ...
    NoDefaultButton: typing.ClassVar[QWizard.WizardOption] = ...
    Stretch: typing.ClassVar[QWizard.WizardButton] = ...
    WatermarkPixmap: typing.ClassVar[QWizard.WizardPixmap] = ...
    currentIdChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    customButtonClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
    helpRequested: typing.ClassVar[PySide2.QtCore.Signal] = ...
    pageAdded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    pageRemoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., flags: typing.Union[PySide2.QtCore.Qt.WindowFlags, PySide2.QtCore.Qt.WindowType] = ..., acceptDrops: bool = ..., accepted: typing.Callable = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., currentId: int = ..., currentIdChanged: typing.Callable = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customButtonClicked: typing.Callable = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., finished: typing.Callable = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., helpRequested: typing.Callable = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., options: typing.Union[QWizard.WizardOptions, QWizard.WizardOption] = ..., pageAdded: typing.Callable = ..., pageRemoved: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., rejected: typing.Callable = ..., size: PySide2.QtCore.QSize = ..., sizeGripEnabled: bool = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., startId: int = ..., statusTip: str = ..., styleSheet: str = ..., subTitleFormat: PySide2.QtCore.Qt.TextFormat = ..., tabletTracking: bool = ..., titleFormat: PySide2.QtCore.Qt.TextFormat = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., wizardStyle: QWizard.WizardStyle = ..., x: int = ..., y: int = ...) -> None: ...
    def addPage(self, page: QWizardPage) -> int: ...
    def back(self) -> None: ...
    def button(self, which: QWizard.WizardButton) -> QAbstractButton: ...
    def buttonText(self, which: QWizard.WizardButton) -> str: ...
    def cleanupPage(self, id: int) -> None: ...
    def currentId(self) -> int: ...
    def currentPage(self) -> QWizardPage: ...
    def done(self, result: int) -> None: ...
    def event(self, event: PySide2.QtCore.QEvent) -> bool: ...
    def field(self, name: str) -> typing.Any: ...
    def hasVisitedPage(self, id: int) -> bool: ...
    def initializePage(self, id: int) -> None: ...
    def next(self) -> None: ...
    def nextId(self) -> int: ...
    def options(self) -> typing.Union[QWizard.WizardOptions, QWizard.WizardOption]: ...
    def page(self, id: int) -> QWizardPage: ...
    def pageIds(self) -> typing.List[int]: ...
    def paintEvent(self, event: PySide2.QtGui.QPaintEvent) -> None: ...
    def pixmap(self, which: QWizard.WizardPixmap) -> PySide2.QtGui.QPixmap: ...
    def removePage(self, id: int) -> None: ...
    def resizeEvent(self, event: PySide2.QtGui.QResizeEvent) -> None: ...
    def restart(self) -> None: ...
    def setButton(self, which: QWizard.WizardButton, button: QAbstractButton) -> None: ...
    def setButtonLayout(self, layout: typing.Iterable[QWizard.WizardButton]) -> None: ...
    def setButtonText(self, which: QWizard.WizardButton, text: str) -> None: ...
    def setDefaultProperty(self, className: bytes, property: bytes, changedSignal: bytes) -> None: ...
    def setField(self, name: str, value: typing.Any) -> None: ...
    def setOption(self, option: QWizard.WizardOption, on: bool = ...) -> None: ...
    def setOptions(self, options: typing.Union[QWizard.WizardOptions, QWizard.WizardOption]) -> None: ...
    def setPage(self, id: int, page: QWizardPage) -> None: ...
    def setPixmap(self, which: QWizard.WizardPixmap, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def setSideWidget(self, widget: QWidget) -> None: ...
    def setStartId(self, id: int) -> None: ...
    def setSubTitleFormat(self, format: PySide2.QtCore.Qt.TextFormat) -> None: ...
    def setTitleFormat(self, format: PySide2.QtCore.Qt.TextFormat) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def setWizardStyle(self, style: QWizard.WizardStyle) -> None: ...
    def sideWidget(self) -> QWidget: ...
    def sizeHint(self) -> PySide2.QtCore.QSize: ...
    def startId(self) -> int: ...
    def subTitleFormat(self) -> PySide2.QtCore.Qt.TextFormat: ...
    def testOption(self, option: QWizard.WizardOption) -> bool: ...
    def titleFormat(self) -> PySide2.QtCore.Qt.TextFormat: ...
    def validateCurrentPage(self) -> bool: ...
    def visitedIds(self) -> typing.List[int]: ...
    def visitedPages(self) -> typing.List[int]: ...
    def wizardStyle(self) -> QWizard.WizardStyle: ...

class QWizardPage(QWidget):
    completeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[QWidget, None] = ..., acceptDrops: bool = ..., accessibleDescription: str = ..., accessibleName: str = ..., autoFillBackground: bool = ..., baseSize: PySide2.QtCore.QSize = ..., childrenRect: PySide2.QtCore.QRect = ..., childrenRegion: PySide2.QtGui.QRegion = ..., completeChanged: typing.Callable = ..., contextMenuPolicy: PySide2.QtCore.Qt.ContextMenuPolicy = ..., cursor: typing.Union[PySide2.QtGui.QCursor, PySide2.QtCore.Qt.CursorShape] = ..., customContextMenuRequested: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., focus: bool = ..., focusPolicy: PySide2.QtCore.Qt.FocusPolicy = ..., font: PySide2.QtGui.QFont = ..., frameGeometry: PySide2.QtCore.QRect = ..., frameSize: PySide2.QtCore.QSize = ..., fullScreen: bool = ..., geometry: PySide2.QtCore.QRect = ..., height: int = ..., inputMethodHints: typing.Union[PySide2.QtCore.Qt.InputMethodHints, PySide2.QtCore.Qt.InputMethodHint] = ..., isActiveWindow: bool = ..., layoutDirection: PySide2.QtCore.Qt.LayoutDirection = ..., locale: PySide2.QtCore.QLocale = ..., maximized: bool = ..., maximumHeight: int = ..., maximumSize: PySide2.QtCore.QSize = ..., maximumWidth: int = ..., minimized: bool = ..., minimumHeight: int = ..., minimumSize: PySide2.QtCore.QSize = ..., minimumSizeHint: PySide2.QtCore.QSize = ..., minimumWidth: int = ..., modal: bool = ..., mouseTracking: bool = ..., normalGeometry: PySide2.QtCore.QRect = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., palette: PySide2.QtGui.QPalette = ..., pos: PySide2.QtCore.QPoint = ..., rect: PySide2.QtCore.QRect = ..., size: PySide2.QtCore.QSize = ..., sizeHint: PySide2.QtCore.QSize = ..., sizeIncrement: PySide2.QtCore.QSize = ..., sizePolicy: QSizePolicy = ..., statusTip: str = ..., styleSheet: str = ..., subTitle: str = ..., tabletTracking: bool = ..., title: str = ..., toolTip: str = ..., toolTipDuration: int = ..., updatesEnabled: bool = ..., visible: bool = ..., whatsThis: str = ..., width: int = ..., windowFilePath: str = ..., windowIcon: PySide2.QtGui.QIcon = ..., windowIconChanged: typing.Callable = ..., windowIconText: str = ..., windowIconTextChanged: typing.Callable = ..., windowModality: PySide2.QtCore.Qt.WindowModality = ..., windowModified: bool = ..., windowOpacity: float = ..., windowTitle: str = ..., windowTitleChanged: typing.Callable = ..., x: int = ..., y: int = ...) -> None: ...
    def buttonText(self, which: QWizard.WizardButton) -> str: ...
    def cleanupPage(self) -> None: ...
    def field(self, name: str) -> typing.Any: ...
    def initializePage(self) -> None: ...
    def isCommitPage(self) -> bool: ...
    def isComplete(self) -> bool: ...
    def isFinalPage(self) -> bool: ...
    def nextId(self) -> int: ...
    def pixmap(self, which: QWizard.WizardPixmap) -> PySide2.QtGui.QPixmap: ...
    def registerField(self, name: str, widget: QWidget, property: typing.Union[bytes, None] = ..., changedSignal: typing.Union[bytes, None] = ...) -> None: ...
    def setButtonText(self, which: QWizard.WizardButton, text: str) -> None: ...
    def setCommitPage(self, commitPage: bool) -> None: ...
    def setField(self, name: str, value: typing.Any) -> None: ...
    def setFinalPage(self, finalPage: bool) -> None: ...
    def setPixmap(self, which: QWizard.WizardPixmap, pixmap: PySide2.QtGui.QPixmap) -> None: ...
    def setSubTitle(self, subTitle: str) -> None: ...
    def setTitle(self, title: str) -> None: ...
    def subTitle(self) -> str: ...
    def title(self) -> str: ...
    def validatePage(self) -> bool: ...
    def wizard(self) -> QWizard: ...
